/**
 * @license
 * Copyright 2019 The Emscripten Authors
 * SPDX-License-Identifier: MIT
 */

// wasm2js.js - enough of a polyfill for the WebAssembly object so that we can load
// wasm2js code that way.

// Emit "var WebAssembly" if definitely using wasm2js. Otherwise, in MAYBE_WASM2JS
// mode, we can't use a "var" since it would prevent normal wasm from working.
/** @suppress{duplicate, const} */
var
WebAssembly = {
  // Note that we do not use closure quoting (this['buffer'], etc.) on these
  // functions, as they are just meant for internal use. In other words, this is
  // not a fully general polyfill.
  /** @constructor */
  Memory: function(opts) {
    this.buffer = new ArrayBuffer(opts['initial'] * 65536);
  },

  Module: function(binary) {
    // TODO: use the binary and info somehow - right now the wasm2js output is embedded in
    // the main JS
  },

  /** @constructor */
  Instance: function(module, info) {
    // TODO: use the module somehow - right now the wasm2js output is embedded in
    // the main JS
    // This will be replaced by the actual wasm2js code.
    this.exports = (
// EMSCRIPTEN_START_ASM
function instantiate(sb){function c(d){d.set=function(a,b){this[a]=b};d.get=function(a){return this[a]};return d}var e;var f=new ArrayBuffer(16);var g=new Int32Array(f);var h=new Float32Array(f);var i=new Float64Array(f);function j(k){return g[k]}function l(k,m){g[k]=m}function n(){return i[0]}function o(m){i[0]=m}function p(){throw new Error("abort")}function q(m){h[2]=m}function r(){return h[2]}function qb(rb){var s=rb.a;var t=s.a;var u=t.buffer;t.grow=ob;var v=new Int8Array(u);var w=new Int16Array(u);var x=new Int32Array(u);var y=new Uint8Array(u);var z=new Uint16Array(u);var A=new Uint32Array(u);var B=new Float32Array(u);var C=new Float64Array(u);var D=Math.imul;var E=Math.fround;var F=Math.abs;var G=Math.clz32;var H=Math.min;var I=Math.max;var J=Math.floor;var K=Math.ceil;var L=Math.trunc;var M=Math.sqrt;var N=s.b;var O=s.c;var P=s.d;var Q=s.e;var R=s.f;var S=s.g;var T=s.h;var U=s.i;var V=s.j;var W=s.k;var X=s.l;var Y=s.m;var Z=s.n;var _=s.o;var $=s.p;var aa=s.q;var ba=s.r;var ca=s.s;var da=s.t;var ea=s.u;var fa=s.v;var ga=s.w;var ha=s.x;var ia=s.y;var ja=s.z;var ka=s.A;var la=s.B;var ma=s.C;var na=s.D;var oa=s.E;var pa=s.F;var qa=s.G;var ra=s.H;var sa=s.I;var ta=s.J;var ua=s.K;var va=s.L;var wa=s.M;var xa=s.N;var ya=s.O;var za=s.P;var Aa=s.Q;var Ba=s.R;var Ca=s.S;var Da=s.T;var Ea=s.U;var Fa=s.V;var Ga=s.W;var Ha=s.X;var Ia=s.Y;var Ja=s.Z;var Ka=s._;var La=s.$;var Ma=s.aa;var Na=s.ba;var Oa=s.ca;var Pa=s.da;var Qa=s.ea;var Ra=s.fa;var Sa=s.ga;var Ta=s.ha;var Ua=s.ia;var Va=s.ja;var Wa=s.ka;var Xa=s.la;var Ya=s.ma;var Za=s.na;var _a=s.oa;var $a=s.pa;var ab=s.qa;var bb=s.ra;var cb=s.sa;var db=s.ta;var eb=s.ua;var fb=568304;var gb=0;var hb=0;
// EMSCRIPTEN_START_FUNCS
function QM(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,C=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,P=0,R=0,T=0,U=E(0),V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=E(0),Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=E(0),Ta=0;ea=fb-32|0;fb=ea;ga=ea+28|0;x[ga>>2]=48948;x[ga>>2]=48848;e=BB(ea+20|0);f=BB(ea+12|0);ha=b;ma=c;na=x[e>>2];Ca=y[e+4|0];oa=x[f>>2];Da=y[f+4|0];b=0;K=fb-96|0;fb=K;d=a;pa=a+24604|0;a=pa;a:{if(!x[a+16>>2]){break a}c=x[a+20>>2];if(c>>>0>4|!(1<<c&22)){break a}a=x[a+28>>2];if(a>>>0>4){break a}b=23>>>a&1}if(!b){a=K+80|0;pS(a,9149,13086,220,45);b=fb-48|0;fb=b;c=tc(b+24|0,18402);x[31737]=0;f=b+12|0;O(888,f|0,17478);e=x[31737];x[31737]=0;b:{c:{d:{e:{if((e|0)!=1){x[31737]=0;e=b+36|0;S(2,e|0,c|0,f|0);f=x[31737];x[31737]=0;if((f|0)==1){break e}x[31737]=0;S(889,a|0,1,e|0);a=x[31737];x[31737]=0;if((a|0)!=1){break b}a=N()|0;tb(e);break d}a=N()|0;break c}a=N()|0}tb(b+12|0)}tb(c);Q(a|0);p()}tb(b+36|0);tb(b+12|0);tb(c);fb=b+48|0}qa=d+8204|0;ra=d+397452|0;sa=d+397448|0;$=d+393352|0;H=d+397456|0;Y=d+12|0;Ea=d+1074376|0;while(1){f:{g:{b=x[d+480208>>2];if(!(!ha|b&512)){h:{if(x[d+1074380>>2]){break h}a=b|512;i:{if(b&256){break i}j=fb-48|0;fb=j;C=fb-32|0;fb=C;k=d+1074312|0;f=d+1074992|0;o=d+1298264|0;t=d+1074424|0;s=d+484360|0;m=d+1074448|0;r=d+1074376|0;a=x[d+1074392>>2];R=d+480210|0;j:{k:while(1){l:{a=a+1|0;x[d+1074392>>2]=a;if(Pl(r)>>>0>a>>>0){break l}LT(C+30|0,x[d+480180>>2],z[d+480188>>1],r,(x[d+480208>>2]&524288)>>>19|0);m:{n:{o:{p:{l=x[d+480208>>2];if(l&32){g=x[d+484348>>2];h=x[d+484344>>2];b=z[d+1074446>>1];break p}b=65535;q=Xb(x[d+484360>>2],y[d+484376|0]);n=x[q>>2];u=x[q+4>>2];e=Zc(n,u);a=z[d+1074448>>1];if(e>>>0>a>>>0){b=z[_b(n,a)>>1]}w[d+1074446>>1]=b;q:{r:{c=b&65535;h=x[d+484344>>2];g=x[d+484348>>2];J=ck(h,g);if(c>>>0>=J>>>0){break r}c=Wb(h,c);if(Ib(x[c>>2],x[c+4>>2])){break r}c=0;break q}c=1}while(1){if(!c){b=65534;w[d+1074446>>1]=65534;c=1;continue}c=z[q+28>>1];while(1){s:{t:{u:{i=b&65535;if(i>>>0>=J>>>0){b=a&65535;if(!((i|0)!=65535&e>>>0>b>>>0)){if(c){a=c;i=Zc(n,u);break t}if(!(a&65535)|b>>>0>e>>>0){break u}while(1){a=b;b=a-1|0;if(!b){break u}if(z[_b(n,b)>>1]!=65535){continue}break}i=e;break t}a=a+1|0;w[m>>1]=a;b=a&65535;break s}w[d+1074450>>1]=a;break p}a=0;i=e}w[d+1074448>>1]=a;l=l&-524289;x[d+480208>>2]=l;while(1){b=a&65535;if(i>>>0<=b>>>0){break o}if(z[_b(n,b)>>1]==65534){a=a+1|0;w[m>>1]=a;continue}break}if(!bj(q,a&65535)){break o}}if(b>>>0>=e>>>0){b=65535;w[d+1074446>>1]=65535;continue}b=z[_b(n,b)>>1];w[d+1074446>>1]=b;if(b>>>0>=J>>>0){continue}i=Wb(h,b);if(Ib(x[i>>2],x[i+4>>2])){continue}break}c=0;continue}}b=b&65535;if(!He(h,g,b)){break n}a=x[t>>2];if(a>>>0>=A[Wb(h,b)+12>>2]){x[t>>2]=0;a=0}if(l&32?x[d+480272>>2]!=-1:0){break m}if(!Wu(o,z[m>>1],a,Mq(C+20|0,f),y[C+30|0])){break m}a=x[d+480272>>2];if(a){if((a|0)>0){x[d+480272>>2]=a-1}Qo(o,1);Wu(o,z[m>>1],x[t>>2],Mq(C+20|0,f),y[C+30|0]);break m}if(!(y[R|0]&64)){break o}if(!Vu(o,m,t)){x[d+1074424>>2]=0;x[d+1074428>>2]=0;x[d+1074448>>2]=0;b=Nj(x[d+484360>>2],x[d+484364>>2])-1|0;a=y[d+484376|0];if((b|0)<=(a|0)){ak(s,0);break o}ak(s,a+1&255);Qo(o,1)}a=0;while(1)if((a|0)==256){gS(d);x[d+1074416>>2]=x[d+480196>>2];x[d+1074420>>2]=x[d+480204>>2];x[d+1074456>>2]=x[d+480200>>2];a=z[d+1074448>>1];w[d+1074450>>1]=a;b=x[d+1074424>>2];x[d+1074428>>2]=b;c=Xb(x[d+484360>>2],y[d+484376|0]);e=x[c>>2];if(Zc(e,x[c+4>>2])>>>0>a>>>0){Qa=d,Ra=z[_b(e,a)>>1],w[Qa+1074446>>1]=Ra}Wu(o,a,b,Mq(C+20|0,f),y[C+30|0]);if(!He(x[d+484344>>2],x[d+484348>>2],z[d+1074446>>1])){break n}break m}else{Uo((D(a,872)+d|0)+1074992|0,d,a&65535,67108864);a=a+1|0;continue}}Qo(o,1)}a=0;break j}KT(d,r,(x[d+480208>>2]&32)>>>5|0);a=Wb(x[d+484344>>2],z[d+1074446>>1]);b=jd(x[a>>2],x[x[a+48>>2]+12>>2],x[d+1074424>>2],0);e=f+D(z[d+480188>>1],872)|0;a=f;while(1){if((a|0)==(e|0)){v:{w:{a=x[d+484344>>2];b=z[d+1074446>>1];if(vp(a,x[d+484348>>2],b)){a=Wb(a,b);c=x[a+16>>2];b=x[a+20>>2];if(HT(c,b)){break w}}x[d+1074408>>2]=x[d+480216>>2];b=x[d+480220>>2];break v}x[d+1074408>>2]=c}x[d+1074412>>2]=b;if(!y[C+30|0]){break l}a=x[d+1074416>>2];x[d+1074392>>2]=a;continue k}Kb(C+20|0,k,82);x:{if(!Hb(x[x[C+20>>2]>>2],x[C+24>>2])|y[a+805|0]!=1){break x}c=y[b+3|0];if((c|0)!=2&(c|0)!=3){break x}Qa=a,Ra=wh(d,y[a+800|0],w[a+772>>1],x[a+704>>2]),x[Qa+700>>2]=Ra}Kb(C+20|0,k,91);y:{if(!Hb(x[x[C+20>>2]>>2],x[C+24>>2])){break y}if(Sc(y[b|0])){break y}c=y[a+788|0];if(!Sc(c)|y[a+791|0]!=19){break y}i=y[a+793|0];if((i&240)!=208|A[d+1074416>>2]>(i&15)>>>0){break y}Qa=a,Ra=wh(d,c,w[a+772>>1],0),x[Qa+700>>2]=Ra}Kb(C+20|0,k,118);z:{if(!Hb(x[x[C+20>>2]>>2],x[C+24>>2])){break z}if(Sc(y[b|0])|!(y[a+89|0]&2)){break z}c=x[a+708>>2];if(!c){break z}if(!Sc(y[a+788|0])){break z}if(!Ql(y[a+790|0],y[a+791|0])){break z}x[a+700>>2]=c}c=C+20|0;Kb(c,k,92);A:{if(!Hb(x[x[C+20>>2]>>2],x[C+24>>2])){break A}Kb(C+12|0,k,5);if(Hb(x[x[C+12>>2]>>2],x[C+16>>2])|x[d+1074416>>2]!=1|y[a+791|0]!=17){break A}v[C+20|0]=1;Qa=d,Ra=D(y[df(c,a+793|0)|0],1e4),x[Qa+1074420>>2]=Ra}c=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);v[a+788|0]=c;v[a+789|0]=c>>>8;v[a+790|0]=c>>>16;v[a+791|0]=c>>>24;c=y[b+4|0]|y[b+5|0]<<8;v[a+792|0]=c;v[a+793|0]=c>>>8;c=x[a+676>>2];x[a+20>>2]=x[a+672>>2];x[a+24>>2]=c;x[a+88>>2]=x[a+88>>2]&-393217;Kb(C+20|0,k,21);if(!Hb(x[x[C+20>>2]>>2],x[C+24>>2])){v[a+831|0]=0}x[a+860>>2]=0;v[a+805|0]=0;b=b+6|0;a=a+872|0;continue}}break}c=x[d+1074416>>2];if(!c){x[d+1074416>>2]=1;c=1}a=x[d+480208>>2];e=x[d+1074392>>2];B:{C:{if(e){b=a&-4097;x[d+480208>>2]=b;f=x[d+480180>>2];if(f&1048580|!(a&2097152)&(f|0)==1){break B}if(Pl(r)>>>0<=e>>>0){break B}if(!((e>>>0)%(x[d+1074400>>2]+c>>>0)|0)){break C}break B}b=a&-528385}x[d+480208>>2]=b|4096}r=0;h=fb-16|0;fb=h;w[d+1074444>>1]=65535;a=d+1074436|0;x[a>>2]=-1;x[a+4>>2]=-1;W=d+1075809|0;q=d+1074312|0;I=d+906300|0;R=d+1074376|0;V=d+480209|0;Z=d+480210|0;while(1){if(z[d+480188>>1]<=r>>>0){D:{if(!(y[d+480209|0]&16)){break D}if(!zT(d,R,Xb(x[d+484360>>2],y[d+484376|0]),1)){break D}x[d+480208>>2]=x[d+480208>>2]|524288}fb=h+16|0}else{n=D(r,872)+d|0;g=n+1075785|0;a=y[g|0];o=n+1075784|0;s=y[o|0];T=n+1075781|0;c=y[T|0];b=x[d+1074400>>2];e=x[d+1074392>>2];f=x[d+1074416>>2];P=n+1075782|0;m=y[P|0];k=n+1075783|0;t=y[k|0];i=Ql(m,t);L=n+1075843|0;v[L|0]=x[d+480208>>2]>>>12&1|y[L|0]&254;f=(e>>>0)%(b+f>>>0)|0;u=n+1075780|0;b=y[u|0];E:{F:{G:{if((b|0)==252){l=Jj(m,s);J=Jj(t,a);b=252;e=c-1|0;if((e&255)>>>0>249){break G}if(!x[vd(I,e)>>2]){break G}b=x[vd(I,e)>>2];ib[x[x[b>>2]+44>>2]](b,l,E(E(J>>>0)/E(999)));b=y[u|0]}if((b&255)==251){break F}}if(B[n+1075852>>2]==E(0)|t){break E}}l=x[d+480208>>2]&4096;H:{if(!l){e=y[n+1075862|0];break H}e=y[T|0];v[n+1075862|0]=e}e=e-1|0;if((e&255)>>>0>249){break E}if(!x[vd(I,e)>>2]){break E}I:{if(!l){b=z[n+1075860>>1];break I}b=rB(y[P|0],y[o|0]);w[n+1075860>>1]=b;U=E(E(rB(y[k|0],y[g|0])>>>0)/E(999));B[n+1075856>>2]=U;g=x[vd(I,e)>>2];Qa=n+1075852|0,Sa=E(E(U-E(ib[x[x[g>>2]+48>>2]](g,b)))/E(Pl(R)>>>0)),B[Qa>>2]=Sa}g=x[d+1074392>>2];o=Pl(R);e=x[vd(I,e)>>2];l=b;b=(o|0)==(g+1|0);ib[x[x[e>>2]+(b?44:108)>>2]](e,l,B[(b?n+1075856|0:n+1075852|0)>>2]);b=y[u|0]}o=n+1074992|0;if(pT(b&255)){b=fb-16|0;fb=b;w[b+12>>1]=0;x[b+8>>2]=0;a=bh(b+8|0);c=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);v[o+788|0]=c;v[o+789|0]=c>>>8;v[o+790|0]=c>>>16;v[o+791|0]=c>>>24;a=y[a+4|0]|y[a+5|0]<<8;v[o+792|0]=a;v[o+793|0]=a>>>8;fb=b+16|0;t=0;s=0;m=0;c=0;i=0;a=0}J:{if(!(y[V|0]&16)){SS(d,o);break J}if(!c){break J}x[n+1075752>>2]=0}K:{L:{if((t|0)==33){Kb(h+8|0,q,30);b=a>>>4|0;cB(d,r&65535,b+(a&15)|0,Hb(x[x[h+8>>2]>>2],x[h+12>>2]));break L}b=0;if((t-19&255)>>>0>1){break L}M:{if(!(!(x[d+480180>>2]&16777250)|a)){a=y[n+1075825|0];break M}v[n+1075825|0]=a}e=a&240;if((e|0)==208){e=a&15;if(!e){e=x[d+480180>>2];if(e&16777248){b=1;break L}if((e|0)!=2){break L}break K}if(e>>>0>=x[d+1074400>>2]+x[d+1074416>>2]>>>0){Kb(h+8|0,q,14);b=e;if(!Hb(x[x[h+8>>2]>>2],x[h+12>>2])){break L}if(!c){break K}v[n+1075795|0]=c;break K}b=e;break L}if(!(x[d+480208>>2]&4096)|(e|0)!=224){break L}e=x[d+480180>>2];if(x[d+1074396>>2]?e&16777250:0){break L}g=a&15;if(!(e&2?g:1)){break L}x[d+1074396>>2]=g+1}M=a&15;g=x[d+480180>>2]==16&(t|0)==19&(a&240)==208;J=g?0:b;N:{if(!J|y[u|0]!=255|y[P|0]!=2){break N}Kb(h+8|0,q,74);if(!Hb(x[x[h+8>>2]>>2],x[h+12>>2])){break N}v[P|0]=0}k=M|144;e=x[d+1074392>>2];Kb(h+8|0,q,72);O:{if(Hb(x[x[h+8>>2]>>2],x[h+12>>2])){l=0;if(J>>>0>=A[d+1074416>>2]){break O}}Kb(h+8|0,q,88);e=(e|0)==(J|0);l=e|(f|0)==(J|0);if(!(!J|!Hb(x[x[h+8>>2]>>2],x[h+12>>2]))){break O}l=e}a=g?k:a;b=h+8|0;Kb(b,q,44);e=y[L|0];Qa=L,Ra=(Hb(x[x[h+8>>2]>>2],x[h+12>>2])?e&252|(f|0)==(J|0):e)&253,v[Qa|0]=Ra;Kb(b,q,66);e=(!J|Hb(x[x[h+8>>2]>>2],x[h+12>>2])^1)&i;P:{Q:{R:{if(!(x[d+1074392>>2]|(!(y[Z|0]&32)|!c))){x[n+1075652>>2]=0;if(l){i=y[u|0];break R}if(!Ti(x[o+8>>2],x[o+12>>2])){break P}v[n+1075795|0]=c;if(z[d+480190>>1]<c>>>0){break P}b=D(c,104)+d|0;x[n+1075680>>2]=z[b+484410>>1];w[n+1075764>>1]=v[b+484417|0];break P}if(!l){break P}i=y[u|0];if(!c){break Q}}v[n+1075795|0]=c}S:{T:{b=i&255;if(!Sc(b)){break T}Kb(h+8|0,q,67);if(!Hb(x[x[h+8>>2]>>2],x[h+12>>2])){break T}f=w[n+1075762>>1];U:{if(!c|e){break U}g=ur(d,b,c);if(!g){break U}f=v[ti(d,g)+36|0]}i=(b+f|0)-132>>>0>=4294967176?i:0;break S}if(!(x[d+480180>>2]&25165856)){break S}f=z[d+480192>>1];if(!f){break S}if(b){b=Sc(b)}else{b=1}if(!b){break S}b=c;V:{if(!b){b=y[n+1075796|0];if(!b){break V}}if(x[((b<<2)+d|0)+900380>>2]?b>>>0<=f>>>0:0){break S}i=0}c=0}if(!((t|0)!=25|a)){Kb(h+8|0,q,55);b=Hb(x[x[h+8>>2]>>2],x[h+12>>2]);c=b?0:c;i=b?0:i}b=h+8|0;Kb(b,q,65);k=Hb(x[x[h+8>>2]>>2],x[h+12>>2]);G=1;if(!(x[d+480180>>2]&16777248)){Kb(b,q,107);G=Hb(x[x[h+8>>2]>>2],x[h+12>>2])}f=(c|0)!=0;b=i&255;X=!b;Kb(h+8|0,q,85);W:{if(!Hb(x[x[h+8>>2]>>2],x[h+12>>2])){break W}if(Ti(x[o+8>>2],x[o+12>>2])){break W}g=x[n+1075096>>2];if(g){if(je(x[g>>2],x[g+20>>2])){break W}}G=1}X=f&X;g=f&k;X:{Y:{Z:{_:{$:{aa:{if(!(x[d+480180>>2]&1048580)){break aa}ba:{if((b|0)!=255){break ba}if(!(!((m|0)==1|c)&(t|0)!=13)){Kb(h+8|0,q,55);if(Hb(x[x[h+8>>2]>>2],x[h+12>>2])){break ba}}f=x[n+1075648>>2];if(v[f+60|0]&1?f:0){break ba}x[n+1075680>>2]=0;b=n+1075080|0;x[b>>2]=x[b>>2]|2097152;ca:{if(!(x[d+480208>>2]&4096)){break ca}Kb(h+8|0,q,86);if(!Hb(x[x[h+8>>2]>>2],x[h+12>>2])){break ca}x[b>>2]=x[b>>2]|4096}c=0;i=0;b=0;f=0;k=1;if(g){break Y}break X}Kb(h+8|0,q,59);if(!Hb(x[x[h+8>>2]>>2],x[h+12>>2])|x[d+480208>>2]&4096){break aa}da:{if(!b){i=y[n+1075789|0]-y[n+1075762|0]|0;break da}if(b>>>0>250){G=0;g=1;i=0;break da}ea:{if(c){break ea}Kb(h+8|0,q,98);if(!Hb(x[x[h+8>>2]>>2],x[h+12>>2])){break ea}c=0;break da}G=1;g=1}f=i;e=0;break $}f=0;if(!X){break _}}Kb(h+8|0,q,65);if(!Hb(x[x[h+8>>2]>>2],x[h+12>>2])){break Z}i=f;f=1}b=i;k=1;if(g){break Y}break X}i=f;f=1;k=g}fa:{ga:{if(!z[d+480192>>1]){if(z[d+480190>>1]<c>>>0){break fa}b=(D(c,104)+d|0)+484380|0;break ga}b=x[n+1075096>>2];if(!b){break fa}}ha:{if(w[b+34>>1]<0){break ha}if(x[d+480180>>2]==2){if(!je(x[b>>2],x[b+20>>2])){break ha}}x[n+1075680>>2]=z[b+30>>1];g=n+1075080|0;x[g>>2]=x[g>>2]|2097152}if(!k){break fa}Vq(o,z[b+28>>1],d)}b=i}Kb(h+8|0,q,71);if(!(!Hb(x[x[h+8>>2]>>2],x[h+12>>2])|!c)){v[n+1075831|0]=32}ia:{if(!z[d+480192>>1]){break ia}Kb(h+8|0,q,100);if(!Hb(x[x[h+8>>2]>>2],x[h+12>>2])|!c){break ia}if(Sc(b&255)){break ia}i=x[d+480208>>2];ja:{if(e){if(i&8){break ja}break ia}if(!(i&4)){break ia}}cn(o);x[n+1075688>>2]=65536;i=n+1075080|0;x[i>>2]=x[i>>2]|2097152}if(f){Kb(h+8|0,q,11);ka:{la:{ma:{if(!(Hb(x[x[h+8>>2]>>2],x[h+12>>2])|x[d+480180>>2]==268435456)){i=z[d+480192>>1];break ma}Kb(h+8|0,q,87);f=0;if(Hb(x[x[h+8>>2]>>2],x[h+12>>2])){f=Ti(x[o+8>>2],x[o+12>>2])^1}i=z[d+480192>>1];na:{if(i){if(c>>>0>i>>>0){break la}if(x[n+1075648>>2]!=x[((c<<2)+d|0)+900380>>2]|f){break na}break la}if((f^-1)&x[n+1075096>>2]==((D(c,104)+d|0)+484380|0)){break ka}}b=y[n+1075789|0]}if(!(i&65535)){break ka}}if(!(x[d+480180>>2]&1048588)){break ka}cn(o);v[n+1075810|0]=0;x[n+1075748>>2]=0;x[n+1075688>>2]=65536;f=n+1075080|0;x[f>>2]=x[f>>2]&-2101249|2097152;Kb(h+8|0,q,86);if(!Hb(x[x[h+8>>2]>>2],x[h+12>>2])){break ka}x[f>>2]=x[f>>2]&-2049}c=G?c:0}i=b&255;oa:{if(i>>>0<251){break oa}Kb(h+8|0,q,50);pa:{if(!Hb(x[x[h+8>>2]>>2],x[h+12>>2])|!c){break pa}f=ur(d,y[n+1075791|0],c);if(!f){break pa}f=D(f,104)+d|0;if(w[f+484414>>1]<0){break pa}x[n+1075680>>2]=z[f+484410>>1]}Kb(h+8|0,q,100);if(Qa=Hb(x[x[h+8>>2]>>2],x[h+12>>2]),Ra=0,Ta=x[d+480208>>2]&4,Ta?Qa:Ra){break oa}c=0}g=Sc(i);if(g){v[n+1075794|0]=b;v[n+1075791|0]=b;if(!e){TS(d,r&65535,c,i,0)}sV(o)}qa:{ra:{sa:{ta:{ua:{if(c){f=n+1075096|0;k=x[f>>2];Po(d,o,c,e,1,1);va:{if(x[n+1075080>>2]&67109888){break va}b=x[f>>2];if(!b|!(y[b+35|0]&2)){break va}G=x[d+1298300>>2];if(!Dd(G)){break va}RB(G,r&65535,b+68|0)}wa:{xa:{if(x[d+480180>>2]==1){if(!e){break xa}Kb(h+8|0,q,85);if(!Hb(x[x[h+8>>2]>>2],x[h+12>>2])){break xa}break wa}Kb(h+8|0,q,50);if((g|Hb(x[x[h+8>>2]>>2],x[h+12>>2])^1)!=1){break wa}}v[n+1075795|0]=0}Kb(h+8|0,q,42);if(Hb(x[x[h+8>>2]>>2],x[h+12>>2])){if(!g|(k|0)==x[f>>2]){break ta}break ua}if(x[d+480180>>2]&16777248){b=0;if(g&(k|0)!=x[f>>2]){break sa}}Kb(h+8|0,q,107);ya:{if(!Hb(x[x[h+8>>2]>>2],x[h+12>>2])|(!(g^1|e)|(k|0)==x[f>>2])){break ya}b=n+1075068|0;if(A[b>>2]>=A[o+4>>2]){break ya}x[b>>2]=0;break ta}Kb(h+8|0,q,85);if(!Hb(x[x[h+8>>2]>>2],x[h+12>>2])){break ta}if(!Ti(x[o+8>>2],x[o+12>>2])){break ua}break ta}if(!i){b=e;break qa}f=0;k=n+1075795|0;b=y[k|0];if(!(!b|g^1)){Po(d,o,b,e,!(x[n+1075096>>2]?1:x[n+1075648>>2]),!(x[d+480180>>2]&1048580));v[k|0]=0;f=1}b=e;break ra}x[o>>2]=0;x[o+4>>2]=0}b=e}f=0;if(!i){break qa}}e=n+1075080|0;za:{if(x[e>>2]&67109888){break za}g=x[n+1075096>>2];if(!g|!(y[g+35|0]&2)){break za}k=x[d+1298300>>2];if(!Dd(k)){break za}if(!f){if(US(k,r&65535)){break za}}RB(k,r&65535,g+68|0)}f=r&65535;Qu(d,o,i,b,!(x[d+480180>>2]&1048580),0,f);ET(x[d+480180>>2],z[d+480188>>1],R,f);if(!(!(x[d+480180>>2]&1048580)|(!b|!c))){x[e>>2]=x[e>>2]|2097152;cn(o);v[n+1075810|0]=0;x[n+1075748>>2]=0}if(!(x[e>>2]&512)){break qa}if(!Dd(x[d+1298300>>2])){break qa}if(i>>>0<=253){if((i|0)!=253){break qa}Kb(h+8|0,q,99);if(Hb(x[x[h+8>>2]>>2],x[h+12>>2])){break qa}}Kb(h+8|0,q,110);if(Hb(x[x[h+8>>2]>>2],x[h+12>>2])){SB(x[d+1298300>>2],f,0,1,0)}Dk(x[d+1298300>>2],f)}Aa:{Ba:{switch(m-1|0){case 0:s=s>>>0>=64?64:s;x[n+1075680>>2]=s<<2;c=n+1075080|0;x[c>>2]=x[c>>2]|2097152;break Aa;case 1:break Ba;default:break Aa}}dn(d,o,s,6)}if(z[d+480192>>1]){RS(d,r&65535)}e=b}Kb(h+8|0,q,77);if(Hb(x[x[h+8>>2]>>2],x[h+12>>2])){if(x[((r<<5)+d|0)+480280>>2]&1024){break K}}b=x[d+1074392>>2];Kb(h+8|0,q,75);f=b>>>0>=J>>>0;Ca:{Da:{Ea:{Fa:{if(!J|!Hb(x[x[h+8>>2]>>2],x[h+12>>2])){break Fa}c=x[d+1074392>>2];if(!c){break Ea}f=1;if((c|0)!=(J|0)){break Fa}f=!y[T|0]&(m|0)!=11}b=m;if(!f|b>>>0<3){break Ea}if((b|0)==11){b=h+8|0;vB(b,d,y[u+3|0],y[u+4|0],J);b=y[$e(b)|0];bB(d,r&65535,z[h+8>>1]);if(b){break Da}m=11;break Ea}Kb(h+8|0,q,62);Ga:{Ha:{Ia:{Ja:{Ka:{La:{Ma:{if(!(!Hb(x[x[h+8>>2]>>2],x[h+12>>2])|s)){s=0;m=0;Na:{switch(b-8|0){case 0:break Ma;case 1:break Na;default:break Ea}}if(y[V|0]&16){break Ea}x[n+1075684>>2]=0;break Ea}Kb(h+8|0,q,41);Oa:{if(Hb(x[x[h+8>>2]>>2],x[h+12>>2])){break Oa}if(s){v[n+1075826|0]=s;break Oa}s=y[n+1075826|0]}Pa:{switch(b-3|0){case 0:case 1:Qa:{Ra:{if(s){break Ra}Kb(h+8|0,q,41);if(!Hb(x[x[h+8>>2]>>2],x[h+12>>2])){break Ra}s=y[n+1075826|0];if(s){break Qa}s=0;break Ea}v[n+1075826|0]=s}No(d,o,((b|0)==3?s<<4:s)&255);break Ea;case 2:if((J|0)!=x[d+1074392>>2]){Kb(h+8|0,q,41);m=5;if(Hb(x[x[h+8>>2]>>2],x[h+12>>2])){break Ea}}Kb(h+8|0,q,41);Mo(d,o,s,Hb(x[x[h+8>>2]>>2],x[h+12>>2]));m=5;break Ea;case 3:if((J|0)!=x[d+1074392>>2]){Kb(h+8|0,q,41);m=6;if(Hb(x[x[h+8>>2]>>2],x[h+12>>2])){break Ea}}Kb(h+8|0,q,41);Lo(d,o,s,Hb(x[x[h+8>>2]>>2],x[h+12>>2]));m=6;break Ea;case 11:break Ga;case 12:break Ha;case 10:break Ia;case 9:break Ja;case 7:break Ka;case 6:break La;case 5:break Ma;case 4:break Pa;default:break Ea}}Kb(h+8|0,q,53);if(Hb(x[x[h+8>>2]>>2],x[h+12>>2])){v[n+1075815|0]=s&15;m=7;break Ea}Ol(o,s<<4);m=7;break Ea}Ol(o,s);m=8;break Ea}Kb(h+8|0,q,62);aB(d,o,s,Hb(x[x[h+8>>2]>>2],x[h+12>>2])^1);m=9;break Ea}Kb(h+8|0,q,62);aB(d,o,s<<4&240,Hb(x[x[h+8>>2]>>2],x[h+12>>2])^1);m=10;break Ea}m=12;Kb(h+8|0,q,12);PS(d,r&65535,s<<2&252,Hb(x[x[h+8>>2]>>2],x[h+12>>2]));break Ea}Kb(h+8|0,q,12);OS(d,r&65535,s<<2&252,Hb(x[x[h+8>>2]>>2],x[h+12>>2]));m=13;break Ea}m=15;if(!l){break Ea}b=x[n+1075096>>2];if(!b|s>>>0>9){break Ea}Sa:{if(!s){c=x[n+1075656>>2];break Sa}c=x[yb(b+68|0,s-1|0)>>2];x[n+1075656>>2]=c}Oo(d,o,c);break Ea}m=14;if(s>>>0>1){break Ea}v[L|0]=y[L|0]&247|!s<<3}c=a;Ta:{Ua:{Va:{switch(t-1|0){case 12:if(!(y[d+480209|0]&16)){break Da}b=D(r,872)+d|0;x[b+1075680>>2]=a>>>0>=64?256:a<<2;b=b+1075080|0;x[b>>2]=x[b>>2]|2097152;break Da;case 45:if(!(y[d+480209|0]&16)){break Da}b=D(r,872)+d|0;x[b+1075680>>2]=a;b=b+1075080|0;x[b>>2]=x[b>>2]|2097152;break Da;case 1:if(!a){c=0;if(v[d+480180|0]&1){break Ca}}PS(d,r&65535,a,0);break Da;case 2:if(!a){c=0;if(v[d+480180|0]&1){break Ca}}OS(d,r&65535,a,0);break Da;case 10:if(!a){c=0;if(x[d+480180>>2]==1){break Ca}}No(d,o,a);break Da;case 3:bB(d,r&65535,a);break Da;case 5:if(!(!a&x[d+480180>>2]==1)){No(d,o,a)}bB(d,r&65535,0);break Da;case 4:Ol(o,a);break Da;case 6:if(!(!a&x[d+480180>>2]==1)){No(d,o,a)}Ol(o,0);break Da;case 15:if(!(y[d+480209|0]&16)){break Da}break Ta;case 16:Kb(h+8|0,q,5);if(Hb(x[x[h+8>>2]>>2],x[h+12>>2])){if(!(y[d+480209|0]&16)){break Da}if(a){break Ta}break Da}c=Ko(d,z[d+1074446>>1],x[d+1074424>>2],r&65535,0);Wa:{if(!(x[d+480180>>2]&16777250)){break Wa}if(c){v[(D(r,872)+d|0)+1075827|0]=c;break Wa}c=y[(D(r,872)+d|0)+1075827|0]}x[h+8>>2]=D(c,1e4);wc(h+8|0,D(x[x[d+8>>2]+24>>2],1e4));a=fb-16|0;fb=a;e=x[h+8>>2];x[a+12>>2]=e;b=x[d+8>>2];Xa:{if(e>>>0>=(x[d+480180>>2]&16393?1e4:32e4)>>>0){e=x[d+480208>>2];f=a+4|0;Kb(f,d+1074312|0,92);if((Hb(x[x[a+4>>2]>>2],x[a+8>>2])|0)==((e&4096)>>>12|0)){break Xa}x[a+4>>2]=D(x[b+24>>2],1e4);Qa=d+1074420|0,Ra=x[Gb(a+12|0,f)>>2],x[Qa>>2]=Ra;break Xa}if(y[d+480209|0]&16){break Xa}f=d+1074420|0;e=(e>>>0)/1e4|0;i=D(e&15,1e4);x[f>>2]=x[f>>2]+((e&240)==16?i:0-i|0);e=x[b+20>>2];b=x[b+24>>2];Kb(a+4|0,d+1074312|0,8);Kp(f,D(e,1e4),Hb(x[x[a+4>>2]>>2],x[a+8>>2])?255e4:D(b,1e4))}fb=a+16|0;break Ca;case 9:if(!l|x[d+480180>>2]==4&e){break Da}DT(d,o,r&65535,x[d+1074424>>2],z[d+1074446>>1]);break Da;case 43:if(!l){break Da}c=Sua(x[(D(r,872)+d|0)+1075068>>2],0,a,0);b=hb;l=b>>>8|0;Oo(d,o,Bc((b&255)<<24|c>>>8,l));break Da;case 0:if(x[d+1074392>>2]){break Da}b=D(r,872)+d|0;Ya:{if(y[b+1075789|0]?x[b+1075692>>2]:0){break Ya}b=x[b+1075648>>2];if(b){if(Qj(y[b+31|0])){break Ya}}Kb(h+8|0,q,13);if(Hb(x[x[h+8>>2]>>2],x[h+12>>2])){break Ya}if(x[d+480180>>2]&16777248){break Da}}if(!a){c=0;if(y[d+480180|0]&5){break Ca}v[(D(r,872)+d|0)+1075797|0]=1;break Ca}b=D(r,872)+d|0;v[b+1075798|0]=a;v[b+1075797|0]=1;break Da;case 14:if(x[d+480180>>2]&1048580){if(!(a&240)){a=y[(D(r,872)+d|0)+1075799|0]&240|a}if(!(a&15)){a=y[(D(r,872)+d|0)+1075799|0]&15|a}a=a|256}c=a;Kb(h+8|0,q,23);if(Hb(x[x[h+8>>2]>>2],x[h+12>>2])){b=d;e=r&65535;if(a){v[(D(r,872)+d|0)+1075799|0]=a}else{a=y[(D(r,872)+d|0)+1075799|0]}$A(b,e,a&255,(m|0)==15?s+1|0:0);break Ca}Za:{if(c){v[(D(r,872)+d|0)+1075799|0]=c;break Za}c=y[(D(r,872)+d|0)+1075799|0]}$A(d,r&65535,c,(m|0)==15?s+1|0:0);break Ca;case 17:if(!(y[d+480209|0]&16)){break Da}Kb(h+8|0,q,22);_a:{$a:{if(Hb(x[x[h+8>>2]>>2],x[h+12>>2])){if(!a){a=0;break $a}if(y[d+480208|0]&4){break $a}a=a&240?a-16|0:a;a=a-((a&15)!=0)|0;v[(D(r,872)+d|0)+1075832|0]=a;break $a}Kb(h+8|0,q,71);if(!Hb(x[x[h+8>>2]>>2],x[h+12>>2])){break _a}}b=(D(r,872)+d|0)+1075831|0;v[b|0]=y[b|0]|128}b=D(r,872)+d|0;v[b+1075797|0]=18;if(!a){c=0;break Ca}v[b+1075832|0]=a;break Da;case 22:if(!(y[d+480209|0]&16)){break Da}b=a;a=x[d+480180>>2];c=b<<!(a&59593760);if(c>>>0<=128){x[d+1074456>>2]=c<<1;break Ca}if(a&16777250){break Ca}x[d+1074456>>2]=256;break Ca;case 23:Kb(h+8|0,q,9);if(Hb(x[x[h+8>>2]>>2],x[h+12>>2])){NS(d,a,(D(r,872)+d|0)+1075809|0);break Da}NS(d,a,W);break Da;case 8:if(!(y[d+480209|0]&16)){break Da}dn(d,o,a,8);break Da;case 28:aB(d,o,a,1);break Da;case 7:vT(o,a);break Da;case 25:wT(d,o,a);break Da;case 18:f=fb-16|0;fb=f;g=d+1074376|0;c=r&65535;i=D(c,872);e=(g+i|0)+616|0;b=a&15;ab:{bb:{switch(a>>>4|0){case 0:c=(a&1)<<14;e=z[d+480188>>1];b=0;while(1){if((b|0)==(e|0)){break ab}i=(D(b,872)+d|0)+1075080|0;x[i>>2]=(c|x[i>>2]&-16385)^16384;b=b+1|0;continue};case 1:if(!b){b=0;if(!(x[d+480180>>2]&1048580)){break ab}}nB(d,e,b);Kb(f+8|0,d+1074312|0,117);if(Hb(x[x[f+8>>2]>>2],x[f+12>>2])){break ab}Eo(d,c,a|240,1);break ab;case 2:if(!b){b=0;if(!(x[d+480180>>2]&1048580)){break ab}}mB(d,e,b);Kb(f+8|0,d+1074312|0,117);if(Hb(x[x[f+8>>2]>>2],x[f+12>>2])){break ab}Eo(d,c,0-(a|240)|0,1);break ab;case 3:c=(d+i|0)+1075080|0;x[c>>2]=x[c>>2]&-1048577|((b|0)!=0)<<20;break ab;case 4:v[(d+i|0)+1075814|0]=a&7;break ab;case 5:if(!(y[d+480209|0]&16)){break ab}g=x[d+480180>>2];if(g&69206025){c=D(c,872)+d|0;b=b<<28>>24;w[c+1075764>>1]=b;e=c+1075692|0;if(!x[e>>2]){break ab}if(!Sc(y[c+1075780|0])){break ab}Qa=e,Ra=wh(d,y[c+1075789|0],b,x[c+1075696>>2]),x[Qa>>2]=Ra;break ab}e=D(c,872)+d|0;i=Sc(y[e+1075780|0]);if((g|0)==16){if(!i){break ab}c=x[e+1075096>>2];if(!c){break ab}v[c+37|0]=b;w[e+1075764>>1]=b;c=e+1075692|0;if(!x[c>>2]){break ab}Qa=c,Ra=wh(d,y[e+1075789|0],b,x[e+1075696>>2]),x[Qa>>2]=Ra;break ab}if(!i){break ab}b=D(c,872)+d|0;c=(a<<4^-128)<<24>>24;w[b+1075764>>1]=c;e=b+1075692|0;if(!x[e>>2]){break ab}Qa=e,Ra=wh(d,y[b+1075789|0],c,x[b+1075696>>2]),x[Qa>>2]=Ra;break ab;case 6:if(!(y[d+480209|0]&16)){break ab}uB(d,g,c,b);break ab;case 7:v[(d+i|0)+1075817|0]=a&7;break ab;case 8:if(!(y[d+480209|0]&16)){break ab}dn(d,e,b,4);break ab;case 9:$A(d,c,b,0);break ab;case 10:if(b){Mo(d,e,b,0);break ab}if(!(x[d+480180>>2]&1048580)){break ab}Mo(d,e,0,0);break ab;case 11:if(b){Lo(d,e,b,0);break ab}if(!(x[d+480180>>2]&1048580)){break ab}Lo(d,e,0,0);break ab;case 12:cB(d,c,b,0);break ab;case 15:break bb;default:break ab}}if(x[d+480180>>2]==1){v[(D(c,872)+d|0)+1075838|0]=b;if(!(y[d+480209|0]&16)){break ab}SS(d,e);break ab}v[(D(c,872)+d|0)+1075836|0]=b}fb=f+16|0;break Da;case 19:MS(d,r&65535,a);break Da;case 24:Kb(h+8|0,q,55);if(Hb(x[x[h+8>>2]>>2],x[h+12>>2])){if(x[d+1074392>>2]!=(a|0)){break Da}c=D(r,872)+d|0;b=x[c+1075648>>2];if(v[b+60|0]&1?b:0){break Ua}if(!(!(y[T|0]|y[P|0])|a)){b=c+1075080|0;x[b>>2]=x[b>>2]|4096;break Ua}b=D(r,872)+d|0;x[b+1075680>>2]=0;b=b+1075080|0;x[b>>2]=x[b>>2]|2097152;break Ua}if(y[d+480209|0]&16){break Ua}break Da;case 27:b=(a&240)-16>>>4|0;if(b>>>0>9){break Da}if(!(1<<b&880)){if(b){if((b|0)!=1){break Da}lB(d,o,M);Kb(h+8|0,q,117);if(Hb(x[x[h+8>>2]>>2],x[h+12>>2])){break Da}Eo(d,r&65535,-224-M|0,1);break Da}oB(d,o,M);Kb(h+8|0,q,117);if(Hb(x[x[h+8>>2]>>2],x[h+12>>2])){break Da}Eo(d,r&65535,M|224,1);break Da}Kb(h+8|0,q,58);if(Hb(x[x[h+8>>2]>>2],x[h+12>>2])){break Da}MS(d,r&65535,a);break Da;case 34:case 35:f=(t|0)==36;if(!(f|x[d+480208>>2]&4096)){break Da}e=r&65535;c=R+D(e,872)|0;i=c+616|0;b=AT(d,z[d+1074446>>1],x[d+1074424>>2],e);cb:{if(!f){break cb}f=Pl(R)-x[R+16>>2]|0;if((f|0)<2){break cb}g=b;b=w[c+1390>>1];b=ed(((g-b|0)/(f|0)|0)+b|0)}w[c+1390>>1]=b;c=Iq(d,x[c+704>>2],x[i+656>>2]);if(c){ib[x[x[c>>2]+80>>2]](c,(b<<16>>16)+32768>>>2|0,e)}break Da;case 20:if(!(y[d+480209|0]&16)|a>>>0>64){break Da}b=D(r,872)+d|0;x[b+1075740>>2]=a;b=b+1075080|0;x[b>>2]=x[b>>2]|2097152;break Da;case 21:i=x[d+480180>>2];f=x[d+480208>>2];b=a;db:{if(a){v[o+816|0]=a;break db}b=y[o+816|0]}c=b&15;e=b&255;eb:{fb:{if(!((c|0)!=15|e>>>0<16)){if(!(f&4096)){break eb}b=e>>>4|0;break fb}f=f&4096;g=e&240;if(!(!c|(g|0)!=240)){if(!f){break eb}b=0-c|0;break fb}if(f){break eb}if(c){b=0-c|0;if(!g|!(i&25690144)){break fb}break eb}if((b&255)>>>0<16){break eb}b=e>>>4|0}Qa=o,Ra=Yb(b+x[o+748>>2]|0,0,64),x[Qa+748>>2]=Ra}break Da;case 26:uT(o,a);break Da;case 29:if(!(y[d+480209|0]&16)){break Da}b=D(r,872)+d|0;x[b+1075716>>2]=a;Kb(h+8|0,q,60);if(Qa=0,Ra=Hb(x[x[h+8>>2]>>2],x[h+12>>2]),Ta=y[b+1075722|0]&4,Ta?Qa:Ra){break Da}x[b+1075732>>2]=a;x[b+1075724>>2]=a;break Da;case 11:yT(d,R,r&65535);break Da;case 13:b=xT(d,R,r&65535,a);if((b|0)==-1){break Da}x[d+1074436>>2]=b;if(!(y[d+480208|0]&32)){break Da}w[d+1074444>>1]=z[d+1074448>>1];break Da;case 37:case 38:case 39:case 40:lT(d,o,a,(t|0)==38|(t|0)==40,(t&254)==40);break Da;case 41:CT(o,a);break Da;case 42:if(x[d+1074392>>2]|M>>>0>1|a>>>0>47){break Da}b=(a&240)==16;f=b?z[d+480188>>1]-1|0:r;c=b?0:r;b=((M|0)==1)<<25;while(1){e=c&65535;if(e>>>0>(f&65535)>>>0){break Da}i=(D(e,872)+d|0)+1075080|0;g=x[i>>2];e=((e<<5)+d|0)+480280|0;x[e>>2]=b|x[e>>2]&-33554433;x[i>>2]=b|g&-33554433;c=c+1|0;continue};case 44:break Va;default:break Ca}}BT(o,a);break Da}Jo(d,o);break Da}IT(d,R,a)}c=a}Kb(h+8|0,q,78);if(!(!Hb(x[x[h+8>>2]>>2],x[h+12>>2])|!c)){rT(o,c&255)}a=y[T|0];if(!a){break K}v[n+1075796|0]=a}r=r+1|0;continue}break}a=1}fb=C+32|0;L=a&x[d+1074420>>2]!=0;gb:{if(!L){break gb}a=GT(d,d+1074376|0);x[d+1074380>>2]=a;x[d+1074404>>2]=a;b=Kd(z[d+480188>>1],1,31);hb:{if(Gd(y[d+1074366|0])){a=x[d+24628>>2];if((a|0)>=129){a=((D(a-128|0,b+4|0)|0)/16|0)+128|0}o=((D(x[d+480228>>2],a)<<1&-128)>>>0)/y[(b>>>1|0)+30608|0]|0;break hb}o=x[d+480228>>2]}w[d+480212>>1]=0;n=d+1074312|0;u=d+480210|0;M=d+480209|0;t=0;while(1){if((t|0)==256){a=x[d+24608>>2];b=z[d+480212>>1];if(a>>>0>b>>>0){break gb}o=fb-16|0;fb=o;x[o+12>>2]=d;e=d+1074478|0;c=e+(a<<1)|0;if((c|0)!=(e|0)){f=e+(b<<1)|0;ib:{b=c-e>>1;if((b|0)<2){break ib}a=b-2>>>1|0;while(1){if((a|0)<0){break ib}SR(e,x[o+12>>2],b,e+(a<<1)|0);a=a-1|0;continue}}b=c-e>>1;a=c;while(1){if((a|0)!=(f|0)){if(Ll(x[o+12>>2],z[a>>1],z[e>>1])){RR(a,e);SR(e,x[o+12>>2],b,e)}a=a+2|0;continue}break}a=c-e>>1;while(1){if((a|0)>1){g=z[e>>1];b=e;m=x[o+12>>2];f=0;i=a;l=a-2>>>1|0;while(1){k=f<<1;f=k|1;h=b+k|0;a=h+2|0;k=k+2|0;if((k|0)<(i|0)){r=k;k=h+4|0;h=Ll(m,z[a>>1],z[k>>1]);f=h?r:f;a=h?k:a}w[b>>1]=z[a>>1];b=a;if((f|0)<=(l|0)){continue}break}f=c-2|0;jb:{if((f|0)==(a|0)){w[a>>1]=g;break jb}w[b>>1]=z[f>>1];w[f>>1]=g;k=x[o+12>>2];b=b+2|0;a=b-e>>1;kb:{if((a|0)<2){break kb}f=a-2|0;a=e+(f&-2)|0;b=b-2|0;if(!Ll(k,z[a>>1],z[b>>1])){break kb}f=f>>>1|0;m=z[b>>1];while(1){lb:{g=b;b=a;w[g>>1]=z[a>>1];if(!f){break lb}a=f-1|0;f=a>>>1|0;a=e+(a&-2)|0;if(Ll(k,z[a>>1],m)){continue}}break}w[b>>1]=m}}a=i-1|0;c=c-2|0;continue}break}}fb=o+16|0}else{k=D(t,872)+d|0;h=k+1075080|0;mb:{if(!(x[h>>2]&4096)|(x[k+1075016>>2]|(x[k+1075012>>2]|x[k+1075688>>2]))){break mb}Kb(j+16|0,n,64);if(Hb(x[x[j+16>>2]>>2],x[j+20>>2])){break mb}x[k+1075068>>2]=0;a=k+1075084|0;x[a>>2]=0;x[a+4>>2]=0}c=z[d+480188>>1];a=x[h>>2];nb:{if(x[k+1075068>>2]|c>>>0>t>>>0?a&1024:1){if(c>>>0>t>>>0){YR(d,t&65535)}w[k+1075834>>1]=0;break nb}b=0;I=k+1075712|0;x[I>>2]=0;C=k+1075672|0;x[C>>2]=0;r=k+1075e3|0;e=r;x[e>>2]=0;x[e+4>>2]=0;x[k+1075092>>2]=0;x[j+44>>2]=1065353216;w[j+42>>1]=0;R=k+1075648|0;J=x[R>>2];x[j+36>>2]=0;m=0;q=k+1075692|0;m=x[q>>2]?x[k+1075068>>2]!=0:m;e=k+1074992|0;ob:{pb:{qb:{if(c>>>0<=t>>>0){break qb}if(y[((t<<5)+d|0)+480288|0]){break pb}if(!J){break qb}b=y[J+34|0]!=0}if((b|m)!=1){break ob}}x[j+8>>2]=x[k+1075680>>2];x[j+32>>2]=x[k+1075744>>2];G=j+16|0;Kb(G,n,28);b=j+8|0;a=Hb(x[x[j+16>>2]>>2],x[j+20>>2])?j+32|0:b;c=d+1074312|0;rb:{if(Ob(c,28)){x[a>>2]=x[a>>2]+w[e+776>>1];Fe(a,0,64);break rb}f=Ob(c,1);c=w[e+776>>1];if(f){x[a>>2]=c+x[a>>2];Fe(a,0,256);break rb}x[e+688>>2]=c+x[e+688>>2];Fe(e+688|0,0,256);x[a>>2]=x[e+688>>2];w[e+776>>1]=0}sb:{tb:{a=d+1074312|0;if(!Ob(a,28)){if(!Ob(a,1)){break tb}}x[e+684>>2]=x[e+692>>2]+w[e+778>>1];Fe(e+684|0,0,256);break sb}x[e+692>>2]=x[e+692>>2]+w[e+778>>1];Fe(e+692|0,0,256);w[e+778>>1]=0;x[e+684>>2]=x[e+692>>2]}ub:{if(!(y[e+90|0]&4)|(x[d+480208>>2]&2101248)==2101248){break ub}vb:{if(x[b>>2]<=0){if(!Ob(d+1074312|0,21)){break vb}}c=5;if(!(y[d+480180|0]&5)){c=Ob(d+1074312|0,21)?5:6}a=IA(d,y[e+825|0],y[e+820|0]);wb:{if((y[e+825|0]&3)!=1){break wb}if(!Ob(d+1074312|0,89)){break wb}a=y[e+819|0];i=y[e+820|0];f=i<<2&124;a=(!(y[e+90|0]&2)|y[d+480209|0]&16?a:y[e+823|0]+a|0)&32?f^127:f;a=i&32?0-a|0:a}if(x[d+480180>>2]!=131072){a=x[b>>2]+((D(y[e+827|0],a)|0)/(1<<c)|0)|0}else{c=64-a|0;a=x[b>>2];a=((D(y[e+827|0],D(c,a))|0)/-8192|0)+a|0}x[b>>2]=a}a=x[d+480208>>2];if(!(x[d+480180>>2]&16777248)|a&4?a&4096:0){break ub}a=Ob(d+1074312|0,21);c=y[e+826|0];v[e+820|0]=y[e+820|0]+(a?c<<2:c)}f=t&65535;i=fb-16|0;fb=i;a=d+1074312|0;Kb(i+8|0,a,71);xb:{if(Hb(x[x[i+8>>2]>>2],x[i+12>>2])){g=D(f,872)+d|0;a=g+1075831|0;c=v[a|0];if((c|0)>=0){break xb}if(!(y[d+480209|0]&16|y[g+1075797|0]!=18)){yb:{zb:{if((c&-33)!=-64){c=c&223;if((c|0)!=128){break zb}c=y[g+1075832|0]>>>4|-64;break yb}c=y[(D(f,872)+d|0)+1075832|0]&15|-128;break yb}c=c-1|0}v[a|0]=c;a=(D(f,872)+d|0)+1075080|0;x[a>>2]=x[a>>2]|2097152}if((c&224)!=128){break xb}x[b>>2]=0;break xb}g=D(f,872)+d|0;if(y[g+1075797|0]!=18){break xb}Kb(i+8|0,a,22);Ab:{if(Hb(x[x[i+8>>2]>>2],x[i+12>>2])){a=g+1075831|0;l=y[a|0];c=l<<24>>24;if(!(!x[g+1075068>>2]|(c|0)>=0)){Bb:{Cb:{if((l|0)!=192){if((l|0)!=128){break Cb}c=y[g+1075832|0]>>>4|-64;break Bb}c=y[(D(f,872)+d|0)+1075832|0]&15|-128;break Bb}c=c-1|0}v[a|0]=c}if((c&192)!=128){break Ab}x[b>>2]=0;break Ab}a=y[(D(f,872)+d|0)+1075832|0];c=a>>>4|0;s=c+(a&15)|0;g=x[d+480180>>2];if(!(y[d+480208|0]&4?0:g&16777248)){s=s+2|0;c=c+1|0}a=(D(f,872)+d|0)+1075831|0;l=y[a|0];if(!(g&4)){g=c;c=(l&255)>>>0<s>>>0?l:0;if(g>>>0<=(c&255)>>>0){x[b>>2]=0}v[a|0]=c+1;break Ab}Db:{if(y[d+480209|0]&16){a=l&255;g=a-1|0;l=a>>>0>=g>>>0?g:0;break Db}v[a|0]=l+1}if(((l&255)>>>0)%(s>>>0)>>>0<c>>>0){break Ab}x[b>>2]=0}a=(D(f,872)+d|0)+1075080|0;x[a>>2]=x[a>>2]|2097152}a=D(f,872)+d|0;Eb:{if(y[a+1075797|0]!=18){break Eb}c=x[a+1075648>>2];if(!c){break Eb}l=y[c+34|0];if(x[a+1075080>>2]&67109888|(!l|y[c+15|0]&2)){break Eb}g=a+1075791|0;s=y[g|0];if(!Sc(s)){break Eb}a=x[vd(d+906300|0,l-1|0)>>2];if(!a){break Eb}l=ib[x[x[a>>2]+104>>2]](a,s,f)|0;s=x[b>>2];if(!(!l|s)){ib[x[x[a>>2]+96>>2]](a,c,y[g|0]|256,0,f);break Eb}if(l|!s){break Eb}ib[x[x[a>>2]+96>>2]](a,c,y[g|0],z[(D(f,872)+d|0)+1075680>>1],f)}fb=i+16|0;Fe(b,0,256);x[j+8>>2]=x[j+8>>2]<<6;Fb:{if(J){Kb(G,n,31);if(Hb(x[x[j+16>>2]>>2],x[j+20>>2])){Mu(d,e)}a=j+8|0;Gb:{if(!GA(d,e,0)){break Gb}c=x[e+656>>2];i=d+1074312|0;g=Ob(i,31);b=x[e+724>>2];if(b?0:g){break Gb}l=b-Ob(i,31)|0;b=Uq(c+48|0,l,256,64);s=y[c+65|0];Hb:{if((s|0)==255){break Hb}g=w[e+728>>1];if((g|0)==-1){break Hb}s=yb(x[c+48>>2],s);G=y[s+2|0];c=G<<2;b=(l|0)==z[s>>1]?c:b;if(Ob(i,94)){b=g+(b-c<<1)|0;break Hb}if(!G){b=0;break Hb}b=(D(b,g)|0)/(c|0)|0}Qa=a,Ra=(D(Yb(b,0,512),x[a>>2])|0)/256|0,x[Qa>>2]=Ra}jT(e,a);Ib:{if(!GA(d,e,1)){break Ib}a=x[e+656>>2];b=d+1074312|0;i=Ob(b,31);c=x[e+732>>2];if(c?0:i){break Ib}b=Uq(a+68|0,c-Ob(b,31)|0,64,64)-32|0;a=x[e+684>>2];Qa=e,Ra=Yb(((D(b,(a|0)>127?256-a|0:a)|0)/32|0)+a|0,0,256),x[Qa+684>>2]=Ra}Kb(j+16|0,n,115);if(Hb(x[x[j+16>>2]>>2],x[j+20>>2])){break Fb}b=y[k+1075789|0];if(!b){break Fb}a=x[R>>2];if(!a|!y[a+26|0]){break Fb}mT(k+1075676|0,b,y[a+26|0],y[a+27|0]);break Fb}if(!(y[h+1|0]&16)){break Fb}x[k+1075688>>2]=0;x[j+8>>2]=0}Jb:{if(y[k+1075843|0]&8){b=0;x[j+8>>2]=0;break Jb}b=x[j+8>>2];if(!b){b=0;break Jb}if(y[h+3|0]&4){x[C>>2]=0;break Jb}if(Gd(y[d+1074365|0])){a=D(x[j+32>>2],x[k+1075740>>2]);c=a;i=a>>31;a=b<<8;Qa=C,Ra=Gc(Tua(Sua(c,i,a,a>>31),hb,1048576,0),hb),x[Qa>>2]=Ra;break Jb}a=D(x[j+32>>2],x[k+1075740>>2]);c=a;i=a>>31;a=D(x[d+1074456>>2],b);Qa=C,Ra=Gc(Tua(Sua(c,i,a,a>>31),hb,1048576,0),hb),x[Qa>>2]=Ra}x[I>>2]=b;Kb:{Lb:{b=x[q>>2];if(!(x[d+480180>>2]==2|(b|0)>=x[d+480260>>2])){if(!Gj(d)){break Lb}b=x[q>>2]}if((b|0)<x[d+480264>>2]){break Kb}Kb(j+16|0,n,113);if(!Hb(x[x[j+16>>2]>>2],x[j+20>>2])){break Kb}if(Gj(d)){break Kb}x[q>>2]=x[d+480264>>2];break Kb}x[q>>2]=x[d+480260>>2]}Kb(j+16|0,n,73);a=x[q>>2];x[j+36>>2]=a;Mb:{if((x[h>>2]&1572864)!=1572864){break Mb}b=x[d+480208>>2];if(b&2097152){if(!Ql(y[k+1075782|0],y[k+1075783|0])|b&4096){break Mb}}b=k+1075704|0;Nb:{if((a|0)==x[b>>2]){b=x[k+1075708>>2];break Nb}x[b>>2]=a;c=a;a=k+1075764|0;b=k+1075696|0;b=wh(d,Ju(d,c,w[a>>1],x[b>>2]),w[a>>1],x[b>>2]);x[k+1075708>>2]=b}x[j+36>>2]=b}i=fb-16|0;fb=i;b=D(f,872)+d|0;s=b;G=b+1075648|0;a=x[G>>2];Ob:{if(!a){break Ob}c=y[a+34|0];if(x[b+1075080>>2]&67109888|(!c|y[a+15|0]&2)){break Ob}if(!x[vd(d+906300|0,c-1|0)>>2]){break Ob}g=b+1075780|0;a=y[b+1075793|0];T=b+1075783|0;l=y[T|0];Pb:{Qb:{if((l|0)==1){b=a;Rb:{Sb:{switch(((A[d+1074392>>2]%(x[d+1074400>>2]+x[d+1074416>>2]>>>0)>>>0)%3|0)-1|0){case 0:b=a+(y[(D(f,872)+d|0)+1075798|0]>>>4|0)|0;break Rb;case 1:break Sb;default:break Rb}}b=a+(y[(D(f,872)+d|0)+1075798|0]&15)|0}c=D(f,872)+d|0;if(y[c+1075792|0]==(b&255)){break Pb}if(!(v[c+1075843|0]&1)){break Qb}if(!Sc(y[g|0])){break Qb}if(Ql(y[g+2|0],1)){break Qb}break Pb}if(y[g|0]){b=a;if(!Ql(y[g+2|0],l)){break Pb}}b=a;if(!y[(D(f,872)+d|0)+1075792|0]){break Pb}}bn(d,f,b&255|512,z[(D(f,872)+d|0)+1075680>>1])}P=(D(f,872)+d|0)+1075792|0;c=y[P|0];Tb:{Ub:{if(c){if((l|0)!=1|(b&255)!=(c|0)){break Ub}break Tb}if(!(v[(D(f,872)+d|0)+1075843|0]&1)|(l|0)!=1){break Tb}if(Sc(y[g|0])){break Tb}c=a;if(!Sc(a)){break Tb}}bn(d,f,c&255|256,0)}v[P|0]=y[T|0]==1?b:0}Vb:{if(y[s+1075797|0]!=1){break Vb}if(Rj(x[G>>2])){b=0;Wb:{Xb:{Yb:{switch(A[d+1074392>>2]%3|0){case 1:b=y[(D(f,872)+d|0)+1075798|0]>>>4|0;break Xb;case 0:break Xb;case 2:break Yb;default:break Wb}}b=y[(D(f,872)+d|0)+1075798|0]&15}w[j+42>>1]=b}a=(D(f,872)+d|0)+1075843|0;v[a|0]=y[a|0]|96;break Vb}if(!(!(y[d+480209|0]&16)|x[d+480180>>2]!=1048576)){a=D(f,872)+d|0;b=wh(d,y[a+1075789|0],w[a+1075764>>1],x[a+1075696>>2]);x[j+36>>2]=b;x[a+1075692>>2]=b}c=d+1074312|0;Kb(i+8|0,c,13);if(Hb(x[x[i+8>>2]>>2],x[i+12>>2])){b=y[(D(f,872)+d|0)+1075798|0];if(!b){break Vb}a=65536;Zb:{switch(((A[d+1074392>>2]%(x[d+1074400>>2]+x[d+1074416>>2]>>>0)>>>0)%3|0)-1|0){case 1:b=b<<4;case 0:a=x[((b&240)<<2)+35616>>2];break;default:break Zb}}f=Gj(d);b=x[j+36>>2];c=b>>31;if(f){a=Sua(b,c,a,a>>31);f=hb;a=a+32768|0;f=a>>>0<32768?f+1|0:f;a=Tua(a,f,65536,0);b=hb}else{f=(a|0)/2|0;l=f>>31;g=c<<16|b>>>16;c=b<<16;b=c+f|0;l=g+l|0;a=Tua(b,b>>>0<c>>>0?l+1|0:l,a,a>>31);b=hb}Qa=j,Ra=Gc(a,b),x[Qa+36>>2]=Ra;break Vb}Kb(i+8|0,c,51);if(Hb(x[x[i+8>>2]>>2],x[i+12>>2])){if(y[d+480209|0]&16){break Vb}_b:{$b:{a=x[d+1074416>>2];b=a-(A[d+1074392>>2]%(a>>>0)|0)|0;if((b|0)>16){break $b}if((b|0)==16){break Vb}a=0;ac:{switch((b|0)%3|0){case 0:break Vb;case 2:break $b;case 1:break ac;default:break _b}}a=y[(D(f,872)+d|0)+1075798|0]>>>4|0;break _b}a=y[(D(f,872)+d|0)+1075798|0]&15}c=a;a=D(f,872)+d|0;b=a+1075764|0;a=a+1075696|0;c=c+Ju(d,x[j+36>>2],w[b>>1],x[a>>2])|0;b=wh(d,c,w[b>>1],x[a>>2]);x[j+36>>2]=b;if(c>>>0<109){break Vb}x[i+8>>2]=b;Qa=i,Ra=wh(d,109,0,x[a>>2]),x[Qa+4>>2]=Ra;Qa=j,Ra=x[ad(i+8|0,i+4|0)>>2],x[Qa+36>>2]=Ra;break Vb}g=x[d+1074392>>2];b=x[d+480180>>2];bc:{if((b|0)!=1){a=y[(D(f,872)+d|0)+1075789|0];break bc}a=D(f,872)+d|0;a=Ju(d,x[j+36>>2],w[a+1075764>>1],x[a+1075696>>2]);b=x[d+480180>>2]}cc:{dc:{switch((((b&67633152?g+2|0:g)>>>0)%3|0)-1|0){case 0:a=(y[(D(f,872)+d|0)+1075798|0]>>>4|0)+a|0;break cc;case 1:break dc;default:break cc}}a=(y[(D(f,872)+d|0)+1075798|0]&15)+a|0}if(!(b&67633408|y[(D(f,872)+d|0)+1075789|0]!=(a&255))){Kb(i+8|0,c,82);if(!Hb(x[x[i+8>>2]>>2],x[i+12>>2])){break Vb}}if(y[d+480210|0]&32){b=a&255;if((b|0)==85){x[j+36>>2]=2147483647;break Vb}a=b>>>0>85?a-37|0:a}b=D(f,872)+d|0;g=wh(d,a&255,w[b+1075764>>1],x[b+1075696>>2]);x[j+36>>2]=g;if(x[d+480180>>2]&71860480){x[b+1075692>>2]=g;break Vb}Kb(i+8|0,c,82);if(!Hb(x[x[i+8>>2]>>2],x[i+12>>2])){break Vb}v[(D(f,872)+d|0)+1075792|0]=a}fb=i+16|0;if(!(!(y[u|0]&33)|x[j+36>>2]==2147483647)){ec:{if(x[d+480180>>2]==2){b=452;a=3424;break ec}a=D(z[k+1075764>>1]>>>4&15,24);b=z[a+31350>>1]>>>1|0;b=b>>>0<=452?452:b;a=z[a+31328>>1]<<1}Fe(j+36|0,b,a);Fe(q,b,a)}sT(d,e);a=x[h>>2]}fc:{if(!(a&256)|y[M|0]&64){break fc}Kb(j+16|0,n,37);if(!Hb(x[x[j+16>>2]>>2],x[j+20>>2])){break fc}x[k+1075676>>2]=128}a=FT(d,e);gc:{if((a|0)<0|!(y[h+1|0]&2)){break gc}b=x[d+1298300>>2];if(!Dd(b)){break gc}Tq(b,t&65535,a&255,1)}i=t&65535;YR(d,i);hc:{if(!m){break hc}a=kT(d,e,j+36|0);if((a|0)<0|!(y[h+1|0]&2)){break hc}b=x[d+1298300>>2];if(!Dd(b)){break hc}Tq(b,i,a>>>2&255,1)}ic:{if(y[k+1075782|0]!=8){break ic}jc:{kc:{a=y[k+1075783|0];switch(a-5|0){case 1:break ic;case 0:case 2:break jc;default:break kc}}if((a|0)!=26){break ic}}a=x[d+480180>>2];if((a|0)==4){if(y[M|0]&16){break ic}a=k+1075811|0;v[a|0]=y[a|0]+y[k+1075815|0];break ic}if(!(a&16777248)){break ic}Ol(e,y[k+1075784|0]);XR(d,i,j+36|0,j+44|0)}a=j+36|0;XR(d,i,a,j+44|0);lc:{if(!m){break lc}x[j+32>>2]=0;m=fb-16|0;fb=m;c=x[e+104>>2];mc:{if(!c|!y[c+40|0]){break mc}q=Rj(x[e+656>>2]);l=Gj(d);b=l?36640:35616;f=l?35616:36640;if(!(q|!Ob(d+1074312|0,21)|x[d+480180>>2]==1048576)){s=y[c+41|0];if(!s){break mc}g=y[e+818|0];x[m+12>>2]=x[e+756>>2]+y[c+39|0];Ai(m+12|0,y[c+40|0]<<8);q=x[m+12>>2];v[e+818|0]=g+s;x[e+756>>2]=q;q=(q|0)/256|0;nc:{oc:{switch(y[c+38|0]-1|0){case 3:g=UR(Io(d))+-64|0;break nc;case 2:g=64-(g+1>>>1|0)|0;break nc;case 1:g=(g+1>>>1|0)+-64|0;break nc;case 0:g=(g^-1)>>>1&64;break nc;default:break oc}}g=v[g+31920|0]}Ai(a,8388607);c=x[a>>2]<<8;x[a>>2]=c;G=D(g,q);q=(G|0)/64|0;g=q>>31;g=(g^q)-g|0;q=g&3;s=g>>>2|0;g=a;a=c>>31;T=a;pc:{qc:{if((G|0)<=-64){b=x[(s<<2)+b>>2];a=Gc(Tua(Sua(b,b>>31,c,a),hb,65536,0),hb)-c|0;if(!q){break pc}b=l?35552:35488;break qc}b=x[f+(s<<2)>>2];a=Gc(Tua(Sua(b,b>>31,c,a),hb,65536,0),hb)-c|0;if(!q){break pc}b=l?35488:35552}b=x[(q<<2)+b>>2];a=(Gc(Tua(Sua(c,T,b,b>>31),hb,65536,0),hb)+a|0)-c|0}x[g>>2]=(a+c|0)/256;x[j+32>>2]=a&255;break mc}l=x[d+480180>>2]&16777248;g=y[c+39|0];rc:{if(!(l|g)){x[e+756>>2]=y[c+40|0]<<8;break rc}sc:{if(l){x[e+756>>2]=x[e+756>>2]+(g<<1);l=y[c+40|0];break sc}l=y[c+40|0];if(y[e+89|0]&8){break sc}x[e+756>>2]=x[e+756>>2]+(((l<<8&65280)>>>0)/(g>>>0)|0)}Ai(e+756|0,l<<8)}g=y[e+818|0]+y[c+41|0]|0;v[e+818|0]=g;g=g<<24>>24;tc:{uc:{switch(y[c+38|0]-1|0){case 3:v[e+818|0]=g+1;l=v[(g&63)+31856|0];break tc;case 2:l=(64-(g>>>1|0)&127)+-64|0;break tc;case 1:l=((g>>>1|0)- -64&127)+-64|0;break tc;case 0:l=(g|0)>=0?-64:64;break tc;default:break uc}}l=0-v[(g&255)+31920|0]|0;if(x[d+480180>>2]!=1048576){break tc}l=(64-v[(g+-64&255)+31920|0]|0)/2<<16>>16}g=l;s=D(g,x[e+756>>2]);l=(s|0)/256|0;if(q){B[j+44>>2]=B[j+44>>2]+E(E(E(D(g,y[c+40|0])|0)*E(.05000000074505806))*E(.000244140625));v[e+851|0]=y[e+851|0]|64;break mc}if(x[d+480180>>2]!=4){vc:{if((s|0)<=-256){l=0-l|0;c=l>>>8|0;f=(c<<2)+b|0;break vc}b=f;c=l>>>8|0;f=b+(c<<2)|0}g=x[a>>2];c=x[((c<<2)+b|0)+4>>2];b=x[f>>2];b=((D(c-b|0,l>>>2&63)|0)/64|0)+b|0;b=Gc(Tua(Sua(g,g>>31,b,b>>31),hb,256,0),hb);x[a>>2]=b;x[j+32>>2]=b&255;x[a>>2]=x[a>>2]/256;break mc}x[a>>2]=x[a>>2]+((s|0)/16384|0)}fb=m+16|0;m=x[j+36>>2];if((m|0)<=x[d+480260>>2]){Kb(j+16|0,n,81);if(Hb(x[x[j+16>>2]>>2],x[j+20>>2])){x[k+1075068>>2]=0}m=x[d+480260>>2];x[j+36>>2]=m}wc:{if(!Rj(x[e+656>>2])){break wc}a=k+1075843|0;b=y[a|0];if(!(x[d+1074392>>2]|!(b&32)?b&64:1)){break wc}rV(e,B[j+44>>2],w[j+42>>1],d);b=a;a=y[a|0];v[b|0]=(a&64?-65:-33)&a}a=j+16|0;wB(a,d,e,m,x[j+32>>2]);f=zb(a);a=Sua(x[j+16>>2],x[j+20>>2],x[d+480240>>2],0);l=hb;b=Tua(a,l,65536,0);c=hb;g=b;a=a+65535|0;b=!(a>>>0<65535?l+1|0:l)&a>>>0<131071;a=b?1:g;x[j+16>>2]=a;b=b?0:c;x[j+20>>2]=b;x[r>>2]=a;x[r+4>>2]=b;if((x[h>>2]&67110400)!=512){break lc}if(!Dd(x[d+1298300>>2])){break lc}Kb(j+8|0,n,99);a=x[h>>2];c=a&4096;xc:{yc:{if(Qa=Hb(x[x[j+8>>2]>>2],x[j+12>>2]),Ra=1,Ta=c,Ta?Qa:Ra){b=x[d+480180>>2];break yc}b=x[d+480180>>2];if((b|0)!=2){break xc}}g=(b|0)==2;b=a&2048;zc:{if(b?g:0){break zc}a=x[d+480240>>2];g=Sua(x[f>>2],0,261625,0);f=hb;g=g+66904|0;f=g>>>0<66904?f+1|0:f;a=Sua(a,0,Bc(Uua(g,f,133808,0),hb),0);l=hb;a=a+32768|0;l=a>>>0<32768?l+1|0:l;f=Bc((l&65535)<<16|a>>>16,l>>>16|0);a=1;Ac:{if(b){break Ac}a=0;if(!c){break Ac}a=!x[k+1075688>>2]}b=j+8|0;Kb(b,n,110);if(Qa=Hb(x[x[j+8>>2]>>2],x[j+12>>2]),Ra=0,Ta=a,Ta?Qa:Ra){break zc}c=x[d+1298300>>2];Kb(b,n,95);SB(c,i,f,a,Hb(x[x[j+8>>2]>>2],x[j+12>>2]))}a=x[d+1298300>>2];b=Sua(D(x[k+1075744>>2],D(x[k+1075740>>2],x[I>>2])),0,63,0);g=hb;b=b+33554432|0;g=b>>>0<33554432?g+1|0:g;Tq(a,i,Bc((g&67108863)<<6|b>>>26,g>>>26|0)&255,0);a=k+1075676|0;g=a;b=x[a>>2];c=0;a=x[d+1298300>>2];f=Xl(a,i);Bc:{if((f|0)==255){break Bc}m=x[a>>2];if(Mj(m)){break Bc}c=xb(Hd(a+318|0,f),10);l=x[a+4>>2];f=bv(f)|192;a=y[c|0]&-49;a=(b|0)<171?a|16:a;a=(b|0)>84?a|32:a;yh(m,l,i,f,a&255);c=(a>>>5&1)+(a<<27>>31)|0}x[g>>2]=(c<<7)+128}Cc:{a=x[R>>2];if(!a|(y[a+60|0]&7)!=1){break Cc}b=x[a+48>>2];a=x[a+52>>2];if(mc(b,a)){break Cc}b=x[WR(e,0)>>2];a=xf(a);if(b>>>0<z[a>>1]|y[a+2|0]){break Cc}Lj(x[d+1298300>>2],i,1);Kb(j+8|0,n,109);a=x[h>>2];Qa=h,Ra=(Hb(x[x[j+8>>2]>>2],x[j+12>>2])?a:a&-4609)|4096,x[Qa>>2]=Ra;x[k+1075688>>2]=0;break lc}Kb(j+8|0,n,99);if(!Hb(x[x[j+8>>2]>>2],x[j+12>>2])|!(y[h+1|0]&16)|x[k+1075688>>2]){break lc}Lj(x[d+1298300>>2],i,1);x[h>>2]=x[h>>2]&-513}Dc:{if(!J){break Dc}Kb(j+16|0,n,31);if(Hb(x[x[j+16>>2]>>2],x[j+20>>2])){break Dc}Mu(d,e)}f=x[h>>2];g=x[C>>2];s=k+1075016|0;J=k+1075012|0;l=f&-65537|(g|(x[s>>2]|x[J>>2])?!(f&512)<<16:0);x[h>>2]=l;C=k+1075664|0;a=C;x[a>>2]=0;x[a+4>>2]=0;i=k+1075834|0;a=y[i|0];b=a-4|0;a=a>>>0>=b>>>0?b:0;v[i|0]=a;q=k+1075835|0;b=y[q|0];c=b-4|0;b=b>>>0>=c>>>0?c:0;v[q|0]=b;Ec:{Fc:{Gc:{Hc:{Ic:{Jc:{Kc:{Lc:{Mc:{c=x[k+1075096>>2];Nc:{if(!c){break Nc}m=x[c+20>>2];if(!je(x[c>>2],m)|!x[k+1075068>>2]){break Nc}if(Ti(x[e+8>>2],x[e+12>>2])){break Mc}}x[k+1075008>>2]=0;break Lc}x[k+1075008>>2]=m;if(m){break Kc}}if(!Ij(x[e+656>>2])){break Jc}m=0;if(f&6144){break Jc}}I=x[k+1075676>>2];c=(D(g,256-I|0)|0)/16384|0;c=c>>>0>=127?127:c;if(a<<24>>24<0){v[i|0]=c;_=c}else{_=a}a=c>>>1|0;if((_&255)>>>0<a>>>0){v[i|0]=a}a=(D(g,I)|0)/16384|0;a=a>>>0>=127?127:a;if(b<<24>>24<0){v[q|0]=a;b=a}a=a>>>1|0;if(a>>>0>(b&255)>>>0){break Ic}break Hc}if((a&255)>>>0>=129){v[i|0]=0}m=0;a=0;if((b&255)>>>0<129){break Gc}}v[q|0]=a}if(!m){break Gc}m=128;i=x[d+24624>>2];if(i>>>0>=2){m=Yb(x[k+1075676>>2],0,256)}x[j+16>>2]=m;a=D(g,o)>>>(Gd(y[d+1074366|0])?7:8)|0;Oc:{Pc:{Qc:{switch(y[d+1074364|0]){case 0:if(!(y[d+24616|0]&16)){break Pc}case 1:if((m|0)<=127){b=a>>>1|0;c=(D(a,m)|0)/256|0;break Oc}b=(D(a,256-m|0)|0)/256|0;c=a>>>1|0;break Oc;case 3:break Qc;default:break Pc}}Ai(j+16|0,255);c=x[j+16>>2];if((c|0)<=0){b=65536}else{b=z[(0-c<<1)+38176>>1]}b=D(b,a)>>>16|0;c=D(a,z[(c<<1)+37664>>1])>>>16|0;break Oc}b=(D(a,256-m|0)|0)/256|0;c=(D(a,m)|0)/256|0}a=x[R>>2];Rc:{if(a){m=y[a+14|0];if(zp(m)){break Rc}}m=y[d+480268|0];if(zp(m)){break Rc}a=y[d+24648|0];m=y[u|0]&128?x[d+24668>>2]?-1:a:a}g=k+1075668|0;l=k+1075786|0;v[l|0]=m;a=x[r>>2];q=x[r+4>>2];if(!(f&131072|((a|0)!=0|(q|0)!=1)|(x[k+1075748>>2]|(m&255)==255))){v[l|0]=0}l=b;b=1<<x[d+1074360>>2];x[C>>2]=(l|0)/(b|0);b=(c|0)/(b|0)|0;x[g>>2]=(f&256)>>>8|0?(i|0)==2?0-b|0:b:b;if(f&128){x[r>>2]=0-a;x[r+4>>2]=0-(((a|0)!=0)+q|0)}l=0;i=fb-16|0;fb=i;x[e+28>>2]=0;x[e+32>>2]=0;Ai(e+672|0,524287);Ai(e+676|0,524287);a=x[e+676>>2];b=x[e+672>>2];Sc:{Tc:{c=x[e+88>>2];if(!(c&65536)){break Tc}f=x[e+20>>2];g=x[e+24>>2];if((f|0)==(b|0)&(g|0)==(a|0)){break Tc}c=x[d+24620>>2];g=(b|0)<=(f|0)&(a|0)<=(g|0);Uc:{if(!g){a=dv(c,x[d+24636>>2]);break Uc}a=dv(c,x[d+24640>>2])}if(!(!Ob(d+1074312|0,4)|!(y[d+480180|0]&4))){a=x[d+24620>>2];a=Sua(a,a>>31,5,0);f=hb;a=a+500|0;f=a>>>0<500?f+1|0:f;a=Gc(Tua(a,f,1e3,0),hb)}b=a;c=x[e+656>>2];Vc:{if(g|!c){break Vc}c=z[c+12>>1];if(!c){break Vc}l=1;b=(D(c,x[d+24620>>2])>>>0)/1e5|0}m=b>>>0<=1?1:b;f=x[e+672>>2];r=x[e+20>>2];q=f-r<<12;s=e;c=x[e+676>>2];b=x[e+24>>2];g=c-b<<12;if(!(y[e+90|0]&32|(!(c|f)|(!(b|r)|l)))){x[i+12>>2]=x[d+1074380>>2];Fe(i+12|0,a,2048);m=x[i+12>>2]}g=(g|0)/(m|0)|0;x[s+32>>2]=g;l=(q|0)/(m|0)|0;x[e+28>>2]=l;a=c+((D(g,m)|0)/-4096|0)|0;x[e+24>>2]=a;b=f+((D(l,m)|0)/-4096|0)|0;x[e+20>>2]=b;if(g|l){x[e+100>>2]=m;c=x[e+88>>2];break Sc}x[e+24>>2]=c;x[e+20>>2]=f;a=c;b=f;c=x[e+88>>2]&-65537;break Sc}x[e+24>>2]=a;x[e+20>>2]=b;c=c&-65537}x[e+88>>2]=c&-2097153;x[e+40>>2]=a<<12;x[e+36>>2]=b<<12;fb=i+16|0;l=x[h>>2];if(!(l&512)){break Fc}break Ec}x[J>>2]=0;x[s>>2]=0;x[k+1075068>>2]=0;if(x[k+1075088>>2]){break Fc}if(!x[k+1075084>>2]){break Ec}}a=z[d+480212>>1];w[d+480212>>1]=a+1;w[((a<<1)+d|0)+1074478>>1]=t}x[k+1075660>>2]=l;a=k+1075843|0;v[a|0]=y[a|0]&253}t=t+1|0;continue}break}}fb=j+48|0;if(L){b=x[d+480208>>2];break h}if(Gd(y[d+1298424|0])){a=x[d+480208>>2]|512;break i}k=0;Wc:{a=x[d+24620>>2]/10|0;b=Gc(a,a>>31);if(!b){break Wc}c=b>>>0>=1048576?1048576:b;x[d+1074380>>2]=c;f=z[d+480212>>1];e=d+1074376|0;while(1){if((f|0)==(k|0)){break Wc}a=e+D(z[(e+(k<<1)|0)+102>>1],872)|0;i=a+1288|0;x[i>>2]=0;x[i+4>>2]=0;x[a+716>>2]=c;i=x[a+640>>2]<<12;x[a+656>>2]=i;g=x[a+636>>2]<<12;x[a+652>>2]=g;x[a+704>>2]=x[a+704>>2]|65536;x[a+644>>2]=(0-g|0)/(c|0);x[a+648>>2]=(0-i|0)/(c|0);k=k+1|0;continue}}c=x[d+480208>>2];a=c|256;if(b){break i}a=c|512}b=a;x[d+480208>>2]=b}if(!(b&512)){break g}Qa=d+1074392|0,Ra=Pl(Ea),x[Qa>>2]=Ra}fb=K+96|0;break f}x[K+80>>2]=512;a=x[d+1074380>>2];x[K+88>>2]=ha;x[K+84>>2]=a;o=sE(K+80|0);if(x[d+24632>>2]){b=0;a=fb-48|0;fb=a;c=o<<2;while(1){if((b|0)==4){Xc:{b=0;while(1){if((b|0)==4){break Xc}x[(a+32|0)+(b<<2)>>2]=((b<<11)+d|0)+16396;b=b+1|0;continue}}}else{x[a+32>>2]=0;e=((b<<11)+d|0)+16396|0;aA(e,c+e|0,a+32|0);b=b+1|0;continue}break}b=x[d+24632>>2];x[a+28>>2]=o;x[a+24>>2]=b;x[a+20>>2]=a+32;b=x[x[ga>>2]+8>>2];x[a+16>>2]=o;c=x[a+24>>2];x[a+8>>2]=x[a+20>>2];x[a+12>>2]=c;ib[b|0](ga,a+8|0);fb=a+48|0}if(Gd(Da)){b=0;while(1){if((b|0)==4){a=x[d+24632>>2];x[K+76>>2]=o;x[K+72>>2]=a;x[K+68>>2]=K+80;a=x[x[oa>>2]+8>>2];x[K+40>>2]=o;b=x[K+72>>2];x[K+32>>2]=x[K+68>>2];x[K+36>>2]=b;ib[a|0](oa,K+32|0)}else{x[(K+80|0)+(b<<2)>>2]=((b<<11)+d|0)+16396;b=b+1|0;continue}break}}ba=0;k=fb-48|0;fb=k;if(o){C=d+12|0;J=d+24592|0;R=d+24588|0;Pn(C,o,J,R);if(A[d+24624>>2]>=3){Pn(d+8204|0,o,d+24600|0,d+24596|0)}w[k+42>>1]=0;ta=d+1074312|0;Fa=d+24648|0;ca=d+906300|0;_=d+24596|0;Ga=d+24600|0;Ha=d+8204|0;r=d+397452|0;q=d+397448|0;s=d+393352|0;ua=d+397456|0;la=d+1074376|0;while(1){if(z[d+480212>>1]<=ba>>>0){Qa=d,Ra=z[pe(d+480214|0,k+42|0)>>1],w[Qa+480214>>1]=Ra}else{f=la+(ba<<1)|0;u=z[f+102>>1];a=D(u,872);G=a+la|0;Yc:{Zc:{if(x[G+632>>2]){break Zc}b=a+d|0;if(x[b+1075088>>2]){break Zc}if(!x[b+1075084>>2]){break Yc}}j=a+d|0;a=y[j+1075786|0]+1&255;if(a>>>0<=5){g=x[(a<<2)+26192>>2]}else{g=0}M=j+1075080|0;i=x[M>>2];_c:{if(!(y[d+24612|0]&32)|(i&16777216)>>>24){b=J;e=C;c=i;l=R;if(!(c&8388608)){break _c}}if(!y[ua+12|0]){Pn(s,o,q,r)}v[ua+12|0]=1;u=z[f+102>>1];c=x[M>>2];b=q;e=s;l=r}a=c>>>8&A[d+24624>>2]>2;T=a?_:l;P=a?Ga:b;c=a?Ha:e;aa=vm(d,la,u&65535,2,1)-1|0;va=(aa&255)>>>0>249;$c:{if(va){break $c}if(!x[vd(ca,aa)>>2]){break $c}b=x[vd(ca,aa)>>2];a=x[b+24>>2];if(!a){break $c}T=b+36|0;P=b+40|0;if(!(v[b+28|0]&1)){Pn(a,o,P,T);x[b+28>>2]=x[b+28>>2]|1}c=a}m=G+616|0;if(y[j+1075843|0]&8){ZF(m,c,o);a=j+1075084|0;x[P>>2]=x[P>>2]+x[a>>2];x[T>>2]=x[T>>2]+x[j+1075088>>2];x[a>>2]=0;x[a+4>>2]=0;break Yc}ia=0;a=k+20|0;x[a>>2]=0;x[a+4>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;b=d+1074312|0;Qa=a,Ra=Ob(b,33),v[Qa+16|0]=Ra;Qa=a,Ra=Ob(b,116)^1,v[Qa+17|0]=Ra;if(x[m+16>>2]){YF(a,m);b=x[m+12>>2];f=b>>31;e=f;l=e^x[m+8>>2];b=(b^e)-((e>>>0>l>>>0)+e|0)|0;x[a+12>>2]=b>>>0>8191?2:16384/(b+1>>>0)|0}Ia=i>>>12&8|(i>>>5&2|(g|i&1));Ja=j+1075795|0;Ka=j+1075778|0;La=j+1075688|0;Ma=j+1075024|0;Na=j+1075020|0;Oa=j+1075668|0;Pa=j+1075664|0;V=j+1075088|0;W=j+1075084|0;wa=j+1075016|0;xa=j+1075012|0;ja=j+1075096|0;Z=j+1075076|0;L=j+1075068|0;I=j+1075e3|0;ka=j+1075072|0;X=j+1075092|0;t=a;b=o;while(1){ad:{a=x[X>>2];fa=a?a>>>0<b>>>0?a:b:b;x[k+12>>2]=fa;bd:{cd:{if(!fa){break cd}i=x[I>>2];a=x[I+4>>2];if(!(i|a)){break cd}g=x[L>>2];if(!g){break cd}e=x[t>>2];if(!e){break cd}u=x[M>>2];h=u&2;l=x[ka>>2];x[G+632>>2]=e;e=x[m>>2];dd:{ed:{j=l&u<<30>>31;f=x[m+4>>2];if((j|0)>(f|0)){if((a|0)<0){e=ih(0,j<<1,e,f);x[m>>2]=e;f=hb;x[m+4>>2]=f;if(!(f>>>0<g+j>>>1>>>0&(f|0)>=(j|0))){e=0;x[m>>2]=e;f=j;x[m+4>>2]=f}fd:{if(u&4){u=u&-129;x[M>>2]=u;a=0-(((i|0)!=0)+a|0)|0;i=0-i|0;x[I>>2]=i;x[I+4>>2]=a;break fd}x[m>>2]=e;f=g-1|0;x[m+4>>2]=f}if(!h){break cd}if(f>>>0<g>>>0){break dd}break cd}if((f|0)>0|(f|0)>=0){break dd}f=0;break ed}if(f>>>0<g>>>0){break dd}if(!h){break cd}if(u&4){if(!!i&(a|0)>=0|(a|0)>0){a=0-(((i|0)!=0)+a|0)|0;i=0-i|0;x[I>>2]=i;x[I+4>>2]=a}u=u|128;x[M>>2]=u;if(y[k+37|0]){h=y[k+36|0];n=x[Z>>2]-(h+l|0)|0;e=ih(e,f,0,g);f=hb;if(f>>>0<n>>>0){e=ih(0,g-h|0,e,f);f=hb;break ed}f=l;e=0;break ed}h=0-e|0;n=(g<<1)-((1-((e|0)!=0)|0)+f|0)|0;f=n;e=h;x[m>>2]=e;da=0;f=da|f;x[m+4>>2]=f;if(l>>>0<n>>>0&g>>>0>n>>>0){break dd}x[k+44>>2]=y[k+36|0]+1;f=da|g-x[Gb(L,k+44|0)>>2];break ed}if((a|0)<0){a=0-(((i|0)!=0)+a|0)|0;i=0-i|0;x[I>>2]=i;x[I+4>>2]=a}Pb(m,0,l-g|0);u=x[M>>2]|8192;x[M>>2]=u;e=x[m>>2];f=x[m+4>>2];break dd}x[m>>2]=e;x[m+4>>2]=f}gd:{if((f|0)<(j|0)){if((a|f)<0){break cd}x[k+44>>2]=fa;g=i;l=a;break gd}g=x[L>>2];if(g>>>0<f>>>0|(!!i&(a|0)>=0|(a|0)>0)&(f|0)==(g|0)){break cd}x[k+44>>2]=fa;l=a>>31;h=l;n=h^i;g=n-h|0;l=(a^h)-((h>>>0>n>>>0)+h|0)|0}h=g;n=l;wc(k+12|0,x[k+32>>2]);ya=x[k+12>>2];hg(e,f,vf(i,a,ya-1|0),hb);l=hb;g=x[ka>>2];za=g>>>0>f>>>0|g+16>>>0<=f>>>0;if(za){u=u&-8193;x[M>>2]=u}hd:{id:{da=x[k+24>>2];jd:{if(da){g=x[k+28>>2];if(g>>>0<=f>>>0){kd:{if((a|0)<0){i=0;a=g;break kd}i=e;a=f;e=0;f=x[Z>>2]}Qa=k,Ra=Lp(ih(ih(e,f,i,a),hb,1,0),hb,h,n)+1|0,x[Qa+44>>2]=Ra;x[G+632>>2]=da;break hd}if(!(za|!(u&8192))){Qa=k,Ra=Lp(ih(ih(0,j+16|0,e,f),hb,1,0),hb,h,n)+1|0,x[Qa+44>>2]=Ra;Qa=G,Ra=da+D(x[Z>>2]-j|0,cl(z[x[ja>>2]+34>>1]))|0,x[Qa+632>>2]=Ra;break hd}if(!i&(a|0)<=0|(a|0)<0){break jd}if(fa>>>0<2|g>>>0>l>>>0){break id}Qa=k,Ra=Lp(ih(ih(0,g,e,f),hb,1,0),hb,h,n)+1|0,x[Qa+44>>2]=Ra;break hd}if((a|0)>0|(a|0)>=0){break id}}if((j|0)<=(l|0)){break hd}Qa=k,Ra=Lp(ih(ih(e,f,0,j),hb,1,0),hb,h,n)+1|0,x[Qa+44>>2]=Ra;break hd}g=x[L>>2];if((g|0)>(l|0)){break hd}Qa=k,Ra=Lp(ih(ih(0,g,e,f),hb,1,0),hb,h,n)+1|0,x[Qa+44>>2]=Ra}Kp(k+44|0,1,ya);f=x[k+44>>2];if((f|0)>0){break bd}}x[G+632>>2]=0;x[L>>2]=0;x[m>>2]=0;x[m+4>>2]=0;x[X>>2]=0;ZF(m,c,b);x[P>>2]=x[P>>2]+x[W>>2];x[T>>2]=x[T>>2]+x[V>>2];x[V>>2]=0;x[W>>2]=0;x[M>>2]=x[M>>2]&-129;break ad}ld:{md:{if(A[d+24608>>2]>z[k+42>>1]){a=4;if(x[X>>2]){break md}a=0;if(x[wa>>2]|x[xa>>2]){break md}}Pb(m,vf(x[I>>2],x[I+4>>2],f),hb);ia=0;x[V>>2]=0;x[W>>2]=0;c=(f<<3)+c|0;break ld}e=(f<<3)+c|0;i=e-8|0;x[W>>2]=0-x[i>>2];g=e-4|0;x[V>>2]=0-x[g>>2];ib[x[((a|Ia)<<2)+25808>>2]](m,Fa,c,f);x[W>>2]=x[W>>2]+x[i>>2];x[V>>2]=x[V>>2]+x[g>>2];ia=1;c=e}a=x[X>>2];nd:{if(!a){break nd}if(a>>>0<=f>>>0){x[X>>2]=0;x[xa>>2]=x[Pa>>2];x[wa>>2]=x[Oa>>2];x[Na>>2]=0;x[Ma>>2]=0;if(x[La>>2]|!(y[M+1|0]&16)){break nd}x[L>>2]=0;x[G+632>>2]=0;break nd}x[X>>2]=a-f}e=0;u=0;a=x[m+4>>2];u=a>>>0>=A[Z>>2]?(y[M|0]&2)>>>1|0:u;i=a;a=x[L>>2];e=x[M>>2]&2|(i>>>0<a>>>0|!a)?e:!z[Ka>>1];b=b-f|0;Kb(k+12|0,ta,85);od:{pd:{qd:{if(!Hb(x[x[k+12>>2]>>2],x[k+16>>2])){break qd}a=y[Ja|0];if(!a){break qd}if(a>>>0<=z[d+480190>>1]){break pd}}l=0;break od}i=x[ja>>2];a=D(a,104)+d|0;f=a+484380|0;l=(i|0)!=(f|0);if((f|0)==(i|0)|(e|u)!=1){break od}x[ja>>2]=f;e=x[a+484400>>2];x[G+632>>2]=e;f=z[a+484414>>1];x[M>>2]=f|x[M>>2]&-768;i=f<<30>>31;f=x[a+484388>>2];x[L>>2]=i&f;a=x[a+484384>>2];x[ka>>2]=a;x[Z>>2]=f;x[m+4>>2]=a;YF(t,m);if(!e){break ad}if((b|0)>0){continue}break ad}rd:{if(!u|l){break rd}Kb(k+12|0,ta,83);if(!Hb(x[x[k+12>>2]>>2],x[k+16>>2])|x[ka>>2]){break rd}x[m>>2]=x[m>>2];x[m+4>>2]=0;a=x[x[ja>>2]+8>>2];x[L>>2]=a;x[Z>>2]=a}if((b|0)>0){continue}}break}x[G+632>>2]=x[t>>2];w[k+42>>1]=z[k+42>>1]+ia;if(va|!ia){break Yc}if(!x[vd(ca,aa)>>2]){break Yc}a=x[vd(ca,aa)>>2];ib[x[x[a>>2]+152>>2]](a)}ba=ba+1|0;continue}break}}fb=k+48|0;t=x[d+1298300>>2];if(Dd(t)){b=Y;c=o;a=(D(x[d+480232>>2],x[d+480236>>2])>>>0)/48|0;m=fb-16|0;fb=m;sd:{if(!y[t+534|0]){break sd}e=Sua(a,0,6169,0);a=hb;g=a>>>16|0;r=Bc((a&65535)<<16|e>>>16,g);while(1){if(!c){break sd}i=x[t>>2];j=x[i>>2];a=x[i+4>>2];while(1){if((a|0)>=(j|0)){x[i+8>>2]=x[i+12>>2];j=0;l=0;k=0;a=fb-16|0;fb=a;while(1){if((k|0)==18){e=(j|0)>=32767?32767:j;w[i+12>>1]=(e|0)<=-32768?-32768:e;e=(l|0)>=32767?32767:l;w[i+14>>1]=(e|0)<=-32768?-32768:e;w[i+3832>>1]=z[i+3832>>1]+1;e=(z[i+3834>>1]+1>>>0)%13440|0;w[i+3834>>1]=e;e=e>>>0<6720?e:13440-e|0;w[i+3836>>1]=e>>>8;if(!y[i+3843|0]){w[i+3836>>1]=e>>>10}e=z[i+3838>>1]+1|0;w[i+3838>>1]=e;if((e&65535)>>>0>=1024){w[i+3838>>1]=0;w[i+3840>>1]=z[i+3840>>1]+1&7}fb=a+16|0}else{f=i+D(k,44)|0;td:{if(!y[f+56|0]){w[a+12>>1]=0;w[a+14>>1]=0;break td}g=x[f+32>>2];e=z[g+3840>>1];if(e&3){g=(z[f+36>>1]>>>7&7)>>>(y[g+3844|0]^1)>>>(e&1)<<z[f+38>>1];e=e&4?0-g|0:g}else{e=0}g=x[f+52>>2];ud:{if(g){s=z[g+32>>1];q=z[f+48>>1];e=e<<16>>16;g=Dg(x[f+16>>2],x[f+40>>2],e,0,w[f+46>>1]);h=x[f+40>>2];n=x[f+20>>2];if(!s){if(!q){g=Dg(n,h,e,g,0);g=Dg(x[f+24>>2],x[f+40>>2],e,g,0);e=Dg(x[f+28>>2],x[f+40>>2],e,g,0);break ud}h=Dg(n,h,e,0,0);h=Dg(x[f+24>>2],x[f+40>>2],e,h,0);e=Dg(x[f+28>>2],x[f+40>>2],e,h,0)+g|0;break ud}if(!q){g=Dg(n,h,e,g,0);h=Dg(x[f+24>>2],x[f+40>>2],e,0,0);e=Dg(x[f+28>>2],x[f+40>>2],e,h,0)+g|0;break ud}h=Dg(n,h,e,0,0);e=(Dg(x[f+24>>2],x[f+40>>2],e,h,0)+g|0)+Dg(x[f+28>>2],x[f+40>>2],e,0,0)|0;break ud}q=z[f+48>>1];e=e<<16>>16;g=Dg(x[f+16>>2],x[f+40>>2],e,0,w[f+46>>1]);h=x[f+40>>2];n=x[f+20>>2];if(!q){e=Dg(n,h,e,g,0);break ud}e=Dg(n,h,e,0,0)+g|0}w[a+14>>1]=y[f+57|0]?e:0;w[a+12>>1]=y[f+58|0]?e:0}k=k+1|0;l=w[a+12>>1]+l|0;j=w[a+14>>1]+j|0;continue}break}j=x[i>>2];a=x[i+4>>2]-j|0;x[i+4>>2]=a;continue}break}e=j-a|0;w[m+14>>1]=(D(w[i+12>>1],a)+D(e,w[i+8>>1])|0)/(j|0);w[m+12>>1]=(D(w[i+14>>1],a)+D(e,w[i+10>>1])|0)/(j|0);x[i+4>>2]=a+49716;x[b>>2]=x[b>>2]+D(r,w[m+14>>1]);x[b+4>>2]=x[b+4>>2]+D(r,w[m+12>>1]);b=b+8|0;c=c-1|0;continue}}fb=m+16|0}a=y[H+12|0];if(a|x[H+16>>2]){if(!a){Pn($,o,sa,ra)}a=x[H>>2];b=x[H+80>>2];c=D(a,b)>>>4|0;c=c>>>0>=32767?32767:c;w[H+98>>1]=c;w[H+96>>1]=c;c=x[H+49948>>2];e=D(c,a)>>>4|0;e=e>>>0>=65536?65536:e;f=e+127>>>3|0;w[H+49946>>1]=f;e=e+255>>>4|0;w[H+49944>>1]=e;w[H+49942>>1]=e;w[H+49940>>1]=f;b=(b|0)>(c|0)?b:c;a=36-a>>>1|0;a=16-(a>>>0<=8?8:a)|0;a=16-(D((b|0)>=32768?32768:b,a>>>0<=16?a:0)>>15)|0;j=0;while(1){if((j|0)!=(o|0)){b=j<<3;c=b+Y|0;x[c>>2]=x[c>>2]+D(a,x[b+$>>2]>>4);b=b|4;c=b+Y|0;x[c>>2]=x[c>>2]+D(a,x[b+$>>2]>>4);j=j+1|0;continue}break}j=H+68|0;k=0;c=w[H+84>>1];a=x[H+40>>2];f=x[H+36>>2];while(1){if((k|0)==(o|0)){x[H+40>>2]=a;x[H+36>>2]=f;i=o}else{b=(k<<3)+$|0;e=x[b>>2]>>12;f=(D(c,e-f|0)>>15)+e|0;x[b>>2]=f;e=b;b=x[b+4>>2]>>12;a=(D(c,b-a|0)>>15)+b|0;x[e+4>>2]=a;k=k+1|0;continue}break}if(i){c=$;b=i;k=x[j>>2]-1|0;e=z[j+22>>1];g=z[j+20>>1];a=w[j+26>>1];f=w[j+24>>1];n=w[j+18>>1];t=w[j+16>>1];u=x[j+4>>2];m=j+32928|0;while(1){if(b){l=nd(x[c>>2]);h=nd(x[c+4>>2]);g=nd((g<<16>>16)-l|0);e=nd((e<<16>>16)-h|0);g=ed(nd((D(g,t)|0)/65536<<1)+l|0);e=ed(nd((D(e,n)|0)/65536<<1)+h|0);h=m+(u<<2)|0;r=w[h>>1];l=ed(((D(r,f)|0)/-65536|0)+g|0);u=u+1&127;q=m+(u<<2)|0;h=w[h+2>>1];s=ed(((D(h,a)|0)/-65536|0)+e|0);w[q+2>>1]=s;w[q>>1]=l;k=k+1&8191;q=j+(k<<2)|0;Qa=q,Ra=ed(r+((D(f,l)|0)/65536|0)|0),w[Qa+160>>1]=Ra;Qa=q,Ra=ed(h+((D(a,s)|0)/65536|0)|0),w[Qa+162>>1]=Ra;c=c+8|0;b=b-1|0;continue}break}w[j+22>>1]=e;w[j+20>>1]=g;x[j+4>>2]=u}g=H+49892|0;C=H+33508|0;c=i;b=$;while(1){if(c){f=x[H+76>>2];k=f&4095;e=C+(k<<2)|0;a=b;k=4096-k|0;q=f-x[H+49892>>2]&4095;f=4096-q|0;f=f>>>0>k>>>0?k:f;f=c>>>0<f>>>0?c:f;f=f>>>0>=64?64:f;u=f;t=0;m=fb-32|0;fb=m;k=x[j>>2];while(1){if((t|0)==7){vd:{n=w[j+28>>1]/8<<16>>16;wd:while(1){if(!u){break vd}u=u-1|0;t=0;l=0;h=0;while(1)if((t|0)==4){t=4;k=0;s=ed((h|0)/32768|0);J=ed((l|0)/32768|0);l=0;while(1)if((t|0)==7){l=ed(s+((l|0)/32768|0)|0);w[e>>1]=l;x[a>>2]=D(l,n);k=ed(J+((k|0)/32768|0)|0);w[e+2>>1]=k;x[a+4>>2]=D(k,n);a=a+8|0;e=e+4|0;continue wd}else{h=m+(t<<2)|0;r=x[h>>2]+1&8191;x[h>>2]=r;_=k;k=j+(r<<2)|0;r=w[k+160>>1];h=j+(t<<4)|0;R=w[k+162>>1];k=(_+D(r,w[h+44>>1])|0)+D(R,w[h+46>>1])|0;l=(D(r,w[h+40>>1])+l|0)+D(R,w[h+42>>1])|0;t=t+1|0;continue}}else{k=m+(t<<2)|0;r=x[k>>2]+1&8191;x[k>>2]=r;_=l;l=j+(r<<2)|0;r=w[l+160>>1];k=j+(t<<4)|0;s=w[l+162>>1];l=(_+D(r,w[k+44>>1])|0)+D(s,w[k+46>>1])|0;h=(D(r,w[k+40>>1])+h|0)+D(s,w[k+42>>1])|0;t=t+1|0;continue}}}}else{x[m+(t<<2)>>2]=k+(x[(j+(t<<4)|0)+32>>2]^-1);t=t+1|0;continue}break}fb=m+32|0;k=C+(q<<2)|0;e=b;a=f;J=g+2|0;l=x[g+4>>2];m=g+24640|0;h=g+16448|0;while(1){n=l&2047;if(a){T=g+8256|0;R=w[T+((l+1206&2047)<<2)>>1];r=g- -64|0;s=w[r+((l+1750&2047)<<2)>>1];u=w[(J+((l+754&2047)<<2)|0)+8256>>1];M=w[(J+((l+1602&2047)<<2)|0)- -64>>1];t=w[k>>1];q=w[k+2>>1];I=m+((l+502&2047)<<2)|0;L=w[I>>1];G=nd(w[g+32>>1]-L|0);I=w[I+2>>1];P=nd(w[g+34>>1]-I|0);V=w[g+26>>1];W=m+((l+22&2047)<<2)|0;Z=w[W>>1];X=nd(w[g+36>>1]-Z|0);ba=w[g+28>>1];W=w[W+2>>1];ca=nd(w[g+38>>1]-W|0);aa=w[g+30>>1];L=ed(nd((D(G,w[g+24>>1])|0)/65536<<1)+L|0);w[g+32>>1]=L;Qa=g,Ra=ed(nd((D(P,V)|0)/65536<<1)+I|0),w[Qa+34>>1]=Ra;Qa=g,Ra=ed(nd((D(X,ba)|0)/65536<<1)+Z|0),w[Qa+36>>1]=Ra;I=ed(nd((D(ca,aa)|0)/65536<<1)+W|0);w[g+38>>1]=I;L=nd((D(L,w[g+16>>1])|0)/32768|0);G=nd((D(I,w[g+22>>1])|0)/32768|0);I=nd(((t|0)/4<<16>>16)+L|0);L=nd(G+((q|0)/4<<16>>16)|0);t=w[g+8>>1];G=nd(I+((D(t,s)|0)/-65536|0)|0);_=r;r=n<<2;P=_+r|0;q=w[g+10>>1];V=nd(L+((D(q,M)|0)/-65536|0)|0);w[P+2>>1]=V;w[P>>1]=G;s=nd(s+((D(t,G)|0)/65536|0)|0);G=h+r|0;P=nd(M+((D(q,V)|0)/65536|0)|0);w[G+2>>1]=P;w[G>>1]=s;M=nd(s+I|0);I=nd(L+P|0);s=h+((l+682&2047)<<2)|0;L=w[s+2>>1];G=w[s>>1];s=nd((D(L,w[g+42>>1])+D(G,w[g+40>>1])|0)/32768|0);l=h+((l+426&2047)<<2)|0;P=w[l+2>>1];V=w[l>>1];l=nd((D(P,w[g+46>>1])+D(V,w[g+44>>1])|0)/32768|0);G=nd(nd(G+M|0)-s|0);L=nd(nd(I+L|0)-l|0);M=nd(nd(M+V|0)-s|0);I=nd(nd(I+P|0)-l|0);s=nd(s+((D(t,R)|0)/-65536|0)|0);T=r+T|0;P=nd(l+((D(q,u)|0)/-65536|0)|0);w[T+2>>1]=P;w[T>>1]=s;t=(D(s,t)|0)/65536|0;l=nd(t+R|0);r=m+r|0;q=(D(q,P)|0)/65536|0;s=nd(q+u|0);w[r+2>>1]=s;w[r>>1]=l;Qa=e,Ra=(x[e>>2]+D(nd(l+G|0),w[g+48>>1])|0)+D(nd(s+L|0),w[g+50>>1])|0,x[Qa>>2]=Ra;Qa=e,Ra=(x[e+4>>2]+D(nd(nd(t)+M|0),w[g+52>>1])|0)+D(nd(nd(q)+I|0),w[g+54>>1])|0,x[Qa+4>>2]=Ra;e=e+8|0;l=n+1|0;k=k+4|0;a=a-1|0;continue}break}x[g+4>>2]=n;x[H+76>>2]=f+x[H+76>>2]&4095;x[H+68>>2]=f+x[H+68>>2]&8191;c=c-f|0;b=(f<<3)+b|0;continue}break}x[H+68>>2]=x[H+68>>2]&8191;k=$;e=Y;a=i;f=0;g=0;l=x[H+56>>2];c=x[H- -64>>2];j=x[H+52>>2];b=x[H+60>>2];while(1){if(a){f=x[k>>2];g=x[k+4>>2];c=c-g|0;c=(((c|0)/1024|0)-c|0)+l|0;x[e+4>>2]=c+x[e+4>>2];b=b-f|0;b=(((b|0)/1024|0)-b|0)+j|0;x[e>>2]=b+x[e>>2];l=c+((c|0)/-512|0)|0;j=b+((b|0)/-512|0)|0;e=e+8|0;k=k+8|0;a=a-1|0;b=f;c=g;continue}break}x[H+64>>2]=g;x[H+60>>2]=f;x[H+56>>2]=l;x[H+52>>2]=j;a=x[H+20>>2];xd:{if(y[H+12|0]){break xd}a=x[H+16>>2];if(a>>>0>i>>>0){a=a-i|0;break xd}QP(H,sa,ra);a=0}v[H+12|0]=0;x[H+16>>2]=a}if(x[d+946300>>2]){yd:{t=0;e=0;f=o<<2;n=d+906300|0;u=z[d+480214>>1]!=0;Aa=B[d+1074336>>2];U=B[d+1074332>>2];while(1)if((t|0)==250){g=d+12|0;k=d+12300|0;m=d+14348|0;Ww(g,k,m,o,U);a=d+1074476|0;C=y[a|0];v[a|0]=0;b=m;a=k;while(1){zd:{Ad:{Bd:{if((e|0)!=250){h=vd(n,e);i=x[h>>2];if(!i|!x[i+24>>2]){break zd}if(!zi(i+44|0)){break zd}l=i;Cd:{if(Jp(y[h+24|0])){break Cd}c=ib[x[x[i>>2]+148>>2]](i)|0;l=x[h>>2];if(c){break Cd}t=0;if(y[l+28|0]&2){break Cd}while(1){if((e|0)==(t|0)){break zd}c=vd(n,t);t=t+1|0;if((um(x[c+28>>2])|0)!=(e|0)){continue}break}}c=x[i+44>>2];r=Hc(c,0);q=Hc(c,1);s=(a|0)==(r|0);a=s?k:a;j=a;b=s?m:b;f=x[h+28>>2];c=b;Dd:{if(!f){break Dd}f=um(f);c=b;if(f>>>0<=e>>>0){break Dd}c=b;if(f>>>0>249){break Dd}c=b;if(!x[vd(n,f)>>2]){break Dd}f=x[vd(n,f)>>2];if(!(y[l+28|0]&4)){ib[x[x[f>>2]+152>>2]](f)}c=b;if(!zi(f+44|0)){break Dd}c=x[f+44>>2];j=Hc(c,0);c=Hc(c,1)}if(!Jp(y[h+24|0])){break Ad}t=0;Ed:{if(s){break Ed}while(1){if((o|0)==(t|0)){break Ed}f=t<<2;s=f+r|0;J=a+f|0;B[s>>2]=B[J>>2]+B[s>>2];s=f+q|0;f=b+f|0;B[s>>2]=B[f>>2]+B[s>>2];x[J>>2]=0;x[f>>2]=0;t=t+1|0;continue}}b=c;a=j;if(!(u&1)){break Ad}a=x[h>>2];if(a){ib[x[x[a>>2]+152>>2]](a)}f=um(x[h+28>>2]);b=e;while(1){a=f;f=a&255;if(f>>>0>249|f>>>0<=(b&255)>>>0){break Bd}t=vd(n,f);f=um(x[t+28>>2]);b=a;a=x[t>>2];if(!a){continue}ib[x[x[a>>2]+152>>2]](a);continue}}c=0;while(1){if((c|0)!=(o|0)){U=E(B[a>>2]*Aa);Fd:{if(E(F(U))<E(2147483648)){e=~~U;break Fd}e=-2147483648}x[g>>2]=e;U=E(B[b>>2]*Aa);Gd:{if(E(F(U))<E(2147483648)){e=~~U;break Gd}e=-2147483648}x[g+4>>2]=e;c=c+1|0;g=g+8|0;b=b+4|0;a=a+4|0;continue}break}break yd}b=c;a=j}Hd:{Id:{f=y[h+24|0];if(!VF(f)){if(!UF(f)|!(y[l+28|0]&4)){break Id}}t=0;while(1){if((o|0)==(t|0)){break Hd}f=t<<2;i=f+j|0;B[i>>2]=B[f+r>>2]+B[i>>2];i=c+f|0;B[i>>2]=B[f+q>>2]+B[i>>2];t=t+1|0;continue}}if(C){ib[x[x[i>>2]+132>>2]](i)}ib[x[x[i>>2]+60>>2]](i,j,c,o);x[l+32>>2]=o+x[l+32>>2];if(!UF(y[h+24|0])){break Hd}if((ib[x[x[i>>2]+160>>2]](i)|0)<=0){break Hd}t=0;if(A[l+32>>2]<x[d+24620>>2]<<2>>>0){break Hd}Jd:{while(1){if((o|0)==(t|0)){break Jd}f=t<<2;U=B[f+j>>2];Kd:{if(U>=E(1.1920928955078125e-7)|U<=E(-1.1920928955078125e-7)){break Kd}U=B[c+f>>2];if(U>=E(1.1920928955078125e-7)){break Kd}t=t+1|0;if(!(U<=E(-1.1920928955078125e-7))){continue}}break}x[l+32>>2]=0;break Hd}x[l+28>>2]=x[l+28>>2]|4}x[l+28>>2]=x[l+28>>2]&-3}e=e+1|0;continue}}else{i=vd(n,t);a=x[i>>2];Ld:{if(!a|!x[a+24>>2]){break Ld}if(!zi(a+44|0)){break Ld}if(!(ib[x[x[a>>2]+116>>2]](a)|0)){ib[x[x[a>>2]+112>>2]](a,1);ib[x[x[a>>2]+124>>2]](a)}c=x[a+44>>2];b=Hc(c,0);c=Hc(c,1);Md:{if(v[a+28|0]&1){Ww(x[a+24>>2],b,c,o,U);break Md}g=a+40|0;if(x[g>>2]|x[a+36>>2]){Pn(x[a+24>>2],o,g,a+36|0);Ww(x[a+24>>2],b,c,o,U);break Md}Rb(b,0,f);Rb(c,0,f)}b=a;a=x[a+28>>2];x[b+28>>2]=a&-2;if(Jp(y[i+24|0])){break Ld}u=!(a&4)|u}t=t+1|0;continue}}}if(x[d+24624>>2]==1){c=0;while(1){if((c|0)!=(o|0)){a=(c<<3)+Y|0;x[(c<<2)+Y>>2]=(x[a+4>>2]+x[a>>2]|0)/2;c=c+1|0;continue}break}}if(Gd(y[d+1074365|0])){a=0;i=fb-16|0;fb=i;Nd:{if(!x[d+1074376>>2]){k=d+1074460|0;b=k;x[b>>2]=0;x[b+4>>2]=0;b=x[d+1074456>>2];x[d+1074468>>2]=b;break Nd}b=x[d+1074456>>2];c=x[d+1074468>>2];Od:{if((b|0)==(c|0)){e=x[d+1074460>>2];break Od}x[d+1074468>>2]=b;e=x[d+24620>>2];f=d+1074460|0;Pd:{if((b|0)>(c|0)){e=dv(e,x[d+24636>>2]);break Pd}e=dv(e,x[d+24640>>2])}x[f>>2]=e;x[d+1074464>>2]=e;c=b}k=d+1074460|0;if((e|0)<=0){break Nd}c=(c<<12)-x[d+1074472>>2]|0;a=(c|0)/(e|0)|0;if(y[d+1074368|0]!=2){break Nd}x[i+12>>2]=50;f=x[d+1074464>>2];x[i+8>>2]=1e4/(f+1|0);g=x[Ye(i+12|0,i+8|0)>>2];while(1){j=a>>31;if((g|0)>=((j^a)-j|0)){break Nd}e=e+f|0;x[k>>2]=e;a=(c|0)/(e|0)|0;continue}}Qd:{Rd:{switch(x[d+24624>>2]-1|0){case 0:g=b<<12;e=d+12|0;j=b>>31;c=0;while(1){if((c|0)==(o|0)){break Qd}Sd:{if(x[k>>2]>0){f=x[d+1074472>>2]+a|0;x[d+1074472>>2]=f;m=x[e>>2];Qa=e,Ra=Gc(Tua(Sua(m,m>>31,f,f>>31),hb,1048576,0),hb),x[Qa>>2]=Ra;x[d+1074460>>2]=x[d+1074460>>2]-1;break Sd}f=x[e>>2];Qa=e,Ra=Gc(Tua(Sua(f,f>>31,b,j),hb,256,0),hb),x[Qa>>2]=Ra;x[d+1074472>>2]=g}c=c+1|0;e=e+4|0;continue};case 1:j=b<<12;e=d+12|0;f=b>>31;c=0;while(1){if((c|0)==(o|0)){break Qd}Td:{if(x[k>>2]>0){g=x[d+1074472>>2]+a|0;x[d+1074472>>2]=g;m=x[e>>2];Qa=e,Ra=Gc(Tua(Sua(m,m>>31,g,g>>31),hb,1048576,0),hb),x[Qa>>2]=Ra;g=x[d+1074472>>2];l=g;r=g>>31;g=x[e+4>>2];Qa=e,Ra=Gc(Tua(Sua(l,r,g,g>>31),hb,1048576,0),hb),x[Qa+4>>2]=Ra;x[d+1074460>>2]=x[d+1074460>>2]-1;break Td}g=x[e>>2];Qa=e,Ra=Gc(Tua(Sua(g,g>>31,b,f),hb,256,0),hb),x[Qa>>2]=Ra;g=x[e+4>>2];Qa=e,Ra=Gc(Tua(Sua(g,g>>31,b,f),hb,256,0),hb),x[Qa+4>>2]=Ra;x[d+1074472>>2]=j}c=c+1|0;e=e+8|0;continue};case 3:break Rd;default:break Qd}}m=b<<12;e=d+8204|0;c=d+12|0;f=b;g=b>>31;b=0;while(1){if((b|0)==(o|0)){break Qd}Ud:{if(x[k>>2]>0){j=x[d+1074472>>2]+a|0;x[d+1074472>>2]=j;l=x[c>>2];Qa=c,Ra=Gc(Tua(Sua(l,l>>31,j,j>>31),hb,1048576,0),hb),x[Qa>>2]=Ra;j=x[d+1074472>>2];l=j;r=j>>31;j=x[c+4>>2];Qa=c,Ra=Gc(Tua(Sua(l,r,j,j>>31),hb,1048576,0),hb),x[Qa+4>>2]=Ra;j=x[d+1074472>>2];l=j;r=j>>31;j=x[e>>2];Qa=e,Ra=Gc(Tua(Sua(l,r,j,j>>31),hb,1048576,0),hb),x[Qa>>2]=Ra;j=x[d+1074472>>2];l=j;r=j>>31;j=x[e+4>>2];Qa=e,Ra=Gc(Tua(Sua(l,r,j,j>>31),hb,1048576,0),hb),x[Qa+4>>2]=Ra;x[d+1074460>>2]=x[d+1074460>>2]-1;break Ud}j=x[c>>2];Qa=c,Ra=Gc(Tua(Sua(j,j>>31,f,g),hb,256,0),hb),x[Qa>>2]=Ra;j=x[c+4>>2];Qa=c,Ra=Gc(Tua(Sua(j,j>>31,f,g),hb,256,0),hb),x[Qa+4>>2]=Ra;j=x[e>>2];Qa=e,Ra=Gc(Tua(Sua(j,j>>31,f,g),hb,256,0),hb),x[Qa>>2]=Ra;j=x[e+4>>2];Qa=e,Ra=Gc(Tua(Sua(j,j>>31,f,g),hb,256,0),hb),x[Qa+4>>2]=Ra;x[d+1074472>>2]=m}b=b+1|0;e=e+8|0;c=c+8|0;continue}}fb=i+16|0}if(x[pa>>2]!=128){b=d+12|0;c=d+8204|0;a=x[d+24604>>2];e=x[d+24624>>2];Vd:{if((a|0)==128|e>>>0<2){break Vd}QR(b,o,a);if(e>>>0<4){break Vd}QR(c,o,a)}}b=x[d+24624>>2];if((b|0)==4){b=o;while(1){b=b-1|0;if((b|0)>=0){a=(b<<4)+Y|0;c=b<<3;e=c|4;x[a+12>>2]=x[e+qa>>2];x[a+8>>2]=x[c+qa>>2];x[a+4>>2]=x[e+Y>>2];x[a>>2]=x[c+Y>>2];continue}break}b=x[d+24624>>2]}if(Gd(Ca)){x[K- -64>>2]=o;x[K+60>>2]=b;x[K+56>>2]=Y;a=x[x[na>>2]+8>>2];x[K+24>>2]=o;b=x[K+60>>2];x[K+16>>2]=x[K+56>>2];x[K+20>>2]=b;ib[a|0](na,K+16|0);b=x[d+24624>>2]}x[K+52>>2]=o;x[K+48>>2]=b;x[K+44>>2]=Y;a=x[x[ma>>2]+8>>2];x[K+8>>2]=o;b=x[K+48>>2];x[K>>2]=x[K+44>>2];x[K+4>>2]=b;ib[a|0](ma,K);x[d+1074380>>2]=x[d+1074380>>2]-o;x[d+1074376>>2]=o+x[d+1074376>>2];ha=ha-o|0;Ba=o+Ba|0;continue}break}fb=ea+32|0;return Ba}function fg(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,m=E(0),o=0,q=0,s=0,t=0,u=E(0),G=0,H=0,I=0,J=E(0),K=0,L=0,M=0,O=0,V=0;s=fb-2240|0;fb=s;a:{b:{c:{d:{e:{f:{g:{if(Yw(x[c>>2])){wc(b,268435456);L=x[c+8>>2];I=s+2220|0;e=I;x[e>>2]=0;x[e+4>>2]=0;Nb(e+8|0);h:{i:{j:{k:{l:{e=y[a+3|0];m:{n:{if((e-4&255)>>>0<=4){x[31737]=0;j=R(203,c|0)|0;e=x[31737];x[31737]=0;if((e|0)!=1){break n}break b}if(e>>>0>17){break m}o:{d=1<<e;if(!(d&63503)){if(!(d&198144)){break m}break o}if(y[a|0]){break o}break n}e=0;f=wD(a,x[b>>2]);x[31737]=0;d=s+48|0;S(187,d|0,c|0,f|0);f=x[31737];x[31737]=0;if((f|0)==1){break l}f=x[d+4>>2];x[I>>2]=x[d>>2];x[I+4>>2]=f;Fn(I+8|0,d+8|0);Kc(d);f=_e(I);if(!f){break h}j=x[I>>2]}e=y[a+3|0]}p:{q:{switch(e&255){case 0:case 1:case 2:case 3:case 11:case 12:case 13:case 14:case 15:h=y[a|0];break p;case 9:case 10:case 16:case 17:break q;default:break p}}h=8}d=!h;h=x[b>>2];if(!(d|h>>>0<262145)){d=e&255;x[s+48>>2]=((d|0)==10)<<4;x[s+28>>2]=j;k=j-x[Gb(s+48|0,s+28|0)>>2]|0;if(d>>>0>15){break k}r:{if(!(1<<d&63503)){if((d|0)==10){break r}break k}if(!(y[a|0]&7)){break k}}e=(k|0)<0?-1:k<<1;break j}e=e&255;if(e>>>0>8){break i}if(!(1<<e&432)){if((e|0)!=6){break i}e=0;if(j>>>0<10){break h}x[31737]=0;P(184,c|0,4)|0;e=x[31737];x[31737]=0;if((e|0)==1){break b}x[31737]=0;d=R(152,c|0)|0;e=x[31737];x[31737]=0;if((e|0)!=1){x[s+48>>2]=d;x[s+28>>2]=j;e=x[Gb(s+48|0,s+28|0)>>2];Gh(c,8);e=((e>>>0>50529027?-1:D(e,85))>>>0)/(y[a|0]>>>3>>>0)|0;break j}a=N()|0;break a}d=8/(mr(y[a+1|0])>>>0)|0;e=D(d,j);Sua(d,0,j,0);e=hb?-1:e;break j}a=N()|0;break a}h=0;e=mr(y[a+1|0]);s:{t:{switch(d|0){case 0:case 1:case 2:case 3:case 11:case 12:case 13:case 14:case 15:h=y[a|0];break s;case 9:h=16;break s;case 10:h=4;break s;case 16:case 17:break t;default:break s}}h=8}d=D(e,h)>>>3|0;e=(d+k|0)-1|0;e=((e>>>0<k>>>0?-1:e)>>>0)/(d>>>0)|0}wc(b,e);h=x[b>>2]}if(!h){e=0;break h}w[b+34>>1]=z[b+34>>1]&65470|y[a|0]>15|(y[a+1|0]!=1)<<6;if(!Eh(b)){e=0;x[b>>2]=0;break h}u:{e=s+48|0;if(ne(a,Xc(e,8,1,0,10))){x[31737]=0;d=P(204,c|0,e|0)|0;a=x[31737];x[31737]=0;if((a|0)!=1){e=0;if(!d){break u}a=x[b>>2];h=0;x[31737]=0;x[s+28>>2]=a+1>>>1;e=R(203,c|0)|0;a=x[31737];x[31737]=0;if((a|0)==1){break c}wc(s+28|0,e);a=f+16|0;b=x[b+20>>2];g=x[s+28>>2];e=g;while(1)if(e){d=s+48|0;f=y[d|y[a|0]&15]+h|0;v[b|0]=f;h=y[d|y[a|0]>>>4]+(f&255)|0;v[b+1|0]=h;e=e-1|0;a=a+1|0;b=b+2|0;continue}else{e=g+16|0;break u}}a=N()|0;break a}v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{h=y[a+3|0];switch(h-4|0){case 3:break B;case 4:break E;case 5:break F;case 2:break G;case 0:case 1:break H;default:break D}}x[31737]=0;b=ba(205,s+1132|0,c|0,b|0,(h|0)==5|0)|0;a=x[31737];x[31737]=0;if((a|0)==1){break g}ub(b);e=x[c+8>>2]-L|0;break u}if(y[a+1|0]!=1){break C}x[31737]=0;P(184,c|0,4)|0;a=x[31737];x[31737]=0;if((a|0)==1){break g}x[31737]=0;e=R(152,c|0)|0;a=x[31737];x[31737]=0;I:{J:{K:{if((a|0)!=1){x[31737]=0;x[s+28>>2]=e;f=R(198,c|0)|0;a=x[31737];x[31737]=0;if((a|0)==1){break K}x[31737]=0;d=s+48|0;S(206,d|0,c|0,e|0);a=x[31737];x[31737]=0;if((a|0)==1){break J}wc(s+28|0,x[s+48>>2]);e=x[s+28>>2];Rn(s+1124|0,d);bc(s+1116|0,x[b+20>>2],Vk(x[b>>2],z[b+34>>1]));x[31737]=0;aa(207,x[s+1124>>2],x[s+1128>>2],x[s+1116>>2],x[s+1120>>2],f<<24>>24);a=x[31737];x[31737]=0;if((a|0)==1){break I}e=e+9|0;Kc(d);break u}a=N()|0;break a}a=N()|0;break a}a=N()|0;break a}a=N()|0;Kc(s+48|0);break a}if(y[a+1|0]!=1|y[a|0]!=16){break C}e=al(s+1114|0);a=x[b>>2];d=x[b+20>>2];e=z[e>>1];h=fb-16|0;fb=h;x[h+12>>2]=j>>>1;x[h+8>>2]=a;b=x[Gb(h+12|0,h+8|0)>>2];g=b;while(1){if(g){a=y[f|0]+e|0;e=a+y[f+1|0]|0;w[d>>1]=e<<8|a&255;d=d+2|0;f=f+2|0;g=g-1|0;continue}break}fb=h+16|0;e=b<<1;break u}if(y[a+1|0]!=1|y[a|0]>16){break C}d=x[c+8>>2];f=x[c>>2];e=0;x[31737]=0;d=U(151,f|0,d|0,8)|0;f=x[31737];x[31737]=0;if((f|0)==1){break g}if(!d){break u}x[31737]=0;d=R(152,c|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break g}if(d>>>0<4){break u}x[31737]=0;f=s+28|0;S(186,f|0,c|0,d|0);e=x[31737];x[31737]=0;if((e|0)==1){break d}o=qs(s+48|0,f);ub(f);e=x[o>>2];x[31737]=0;f=R(208,e|0)|0;e=x[31737];x[31737]=0;if((e|0)==1){break f}e=f+4|0;k=y[a|0];h=(k|0)!=16;f=0;while(1){if(A[b>>2]<=f>>>0){break w}L:{if(h){break L}x[31737]=0;i=P(159,o|0,8)|0;a=x[31737];x[31737]=0;if((a|0)!=1){break L}a=T(28896)|0;break x}x[31737]=0;g=P(159,o|0,1)|0;a=x[31737];x[31737]=0;if((a|0)==1){break y}x[31737]=0;d=P(159,o|0,1)|0;a=x[31737];x[31737]=0;if((a|0)==1){break y}M:{N:{O:{if(!d){j=8;while(1){x[31737]=0;d=P(159,o|0,1)|0;a=x[31737];x[31737]=0;if((a|0)==1){break M}if(d){break O}j=j+16|0;continue}}x[31737]=0;a=P(159,o|0,3)|0;d=x[31737];x[31737]=0;if((d|0)!=1){break N}break y}x[31737]=0;d=P(159,o|0,4)|0;a=x[31737];x[31737]=0;if((a|0)==1){break y}a=d+j|0}t=(t&255)+(((g?-1:0)^a)&255)|0;P:{if((k|0)!=16){v[x[b+20>>2]+f|0]=t;break P}w[x[b+20>>2]+(f<<1)>>1]=i&255|t<<8}f=f+1|0;continue}break}a=T(28896)|0;break x}Q:{if((h|0)==16){e=y[a|0];break Q}e=y[a|0];if((h|0)!=17){break z}}if((e&255)!=16){break z}d=y[a+1|0];if((d-1&255)>>>0>1){break z}M=s,O=D(x[b>>2],mr(d)),x[M+48>>2]=O;wc(s+48|0,j);a=x[b+20>>2];e=x[s+48>>2];if((h|0)==16){b=e;while(1){if(!b){break u}M=a,O=z[_b(28928,y[f|0])>>1],w[M>>1]=O;a=a+2|0;f=f+1|0;b=b-1|0;continue}}b=e;while(1){if(!b){break u}M=a,O=z[_b(29440,y[f|0])>>1],w[M>>1]=O;a=a+2|0;f=f+1|0;b=b-1|0;continue}}if((h|0)!=7){break A}}if(y[a+1|0]!=1|y[a|0]>16){break A}e=0;if(j>>>0<5){break u}f=x[b+20>>2];e=z[b+34>>1];a=x[b>>2];x[31737]=0;e=U(209,c|0,f|0,Vk(a,e)|0)|0;a=x[31737];x[31737]=0;if((a|0)!=1){break u}break g}e=y[a|0]}d=(e&255)!=8;if(!(d|y[a+1|0]!=1)){R:{switch(h|0){case 0:a=x[b>>2];e=x[b+20>>2];d=fb-16|0;fb=d;x[d+12>>2]=j;x[d+8>>2]=a;a=x[Gb(d+12|0,d+8|0)>>2];b=a;while(1){if(b){v[e|0]=y[f|0];e=e+1|0;f=f+1|0;b=b-1|0;continue}break};fb=d+16|0;e=a;break u;case 1:a=x[b>>2];e=x[b+20>>2];d=fb-16|0;fb=d;x[d+12>>2]=j;x[d+8>>2]=a;a=x[Gb(d+12|0,d+8|0)>>2];b=a;while(1){if(b){v[e|0]=y[f|0]^128;e=e+1|0;f=f+1|0;b=b-1|0;continue}break};fb=d+16|0;e=a;break u;default:e=0;if((h|0)!=11){break u}break;case 2:break R}}e=sv(s+27|0);a=x[b>>2];g=x[b+20>>2];b=y[e|0];d=fb-16|0;fb=d;x[d+12>>2]=j;x[d+8>>2]=a;a=x[Gb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){b=y[f|0]+b|0;v[g|0]=b;g=g+1|0;f=f+1|0;e=e-1|0;continue}break}fb=d+16|0;e=a;break u}if(!(y[a+1|0]!=3|d)){S:{switch(h|0){case 0:i=fb-16|0;fb=i;x[i+12>>2]=j;e=x[b>>2];x[i+8>>2]=e;a=i+8|0;g=x[Gb(a,i+12|0)>>2];x[i+8>>2]=e;x[i+4>>2]=j-g;e=x[Gb(a,i+4|0)>>2];h=x[b+20>>2];a=g;d=f;while(1){if(a){v[h|0]=y[d|0];h=h+2|0;d=d+1|0;a=a-1|0;continue}break};h=x[b+20>>2]+1|0;d=x[b>>2]+f|0;a=e;while(1){if(a){v[h|0]=y[d|0];h=h+2|0;d=d+1|0;a=a-1|0;continue}break};fb=i+16|0;e=e+g|0;break u;case 1:i=fb-16|0;fb=i;x[i+12>>2]=j;e=x[b>>2];x[i+8>>2]=e;a=i+8|0;g=x[Gb(a,i+12|0)>>2];x[i+8>>2]=e;x[i+4>>2]=j-g;e=x[Gb(a,i+4|0)>>2];h=x[b+20>>2];a=g;d=f;while(1){if(a){v[h|0]=y[d|0]^128;h=h+2|0;d=d+1|0;a=a-1|0;continue}break};h=x[b+20>>2]+1|0;d=x[b>>2]+f|0;a=e;while(1){if(a){v[h|0]=y[d|0]^128;h=h+2|0;d=d+1|0;a=a-1|0;continue}break};fb=i+16|0;e=e+g|0;break u;default:e=0;if((h|0)!=11){break u}break;case 2:break S}}g=y[sv(s+26|0)|0];k=fb-16|0;fb=k;x[k+12>>2]=j;d=x[b>>2];x[k+8>>2]=d;e=k+8|0;h=x[Gb(e,k+12|0)>>2];x[k+8>>2]=d;x[k+4>>2]=j-h;d=x[Gb(e,k+4|0)>>2];j=b;t=x[b+20>>2];e=g;b=h;i=f;while(1){if(b){e=y[i|0]+e|0;v[t|0]=e;t=t+2|0;i=i+1|0;b=b-1|0;continue}break}t=x[j+20>>2]+1|0;i=x[j>>2]+f|0;b=d;while(1){if(b){g=y[i|0]+g|0;v[t|0]=g;t=t+2|0;i=i+1|0;b=b-1|0;continue}break}fb=k+16|0;e=d+h|0;if(y[a+3|0]!=11){break u}a=x[j+20>>2];b=a+(x[j>>2]<<1)|0;while(1){if(a>>>0>=b>>>0){break u}v[a+1|0]=y[a+1|0]+y[a|0];a=a+2|0;continue}}d=e&255;if(!((d|0)!=8|y[a+1|0]!=2)){e=0;T:{switch(h|0){case 0:a=x[b>>2];e=x[b+20>>2];d=fb-16|0;fb=d;x[d+12>>2]=j>>>1;x[d+8>>2]=a;a=x[Gb(d+12|0,d+8|0)>>2];b=a;while(1){if(b){v[e|0]=y[f|0];v[e+1|0]=y[f+1|0];e=e+2|0;f=f+2|0;b=b-1|0;continue}break};fb=d+16|0;e=a<<1;break u;case 1:a=x[b>>2];e=x[b+20>>2];d=fb-16|0;fb=d;x[d+12>>2]=j>>>1;x[d+8>>2]=a;a=x[Gb(d+12|0,d+8|0)>>2];b=a;while(1){if(b){v[e|0]=y[f|0]^128;v[e+1|0]=y[f+1|0]^128;e=e+2|0;f=f+2|0;b=b-1|0;continue}break};fb=d+16|0;e=a<<1;break u;case 2:break T;default:break u}}e=sv(s+25|0);a=x[b>>2];d=x[b+20>>2];b=y[e|0];h=fb-16|0;fb=h;x[h+12>>2]=j>>>1;x[h+8>>2]=a;a=b;e=x[Gb(h+12|0,h+8|0)>>2];g=e;while(1){if(g){b=y[f|0]+b|0;v[d|0]=b;a=y[f+1|0]+a|0;v[d+1|0]=a;d=d+2|0;f=f+2|0;g=g-1|0;continue}break}fb=h+16|0;e=e<<1;break u}if(!(y[a+2|0]|((d|0)!=16|y[a+1|0]!=1))){U:{switch(h|0){case 0:a=x[b>>2];e=x[b+20>>2];d=fb-16|0;fb=d;x[d+12>>2]=j>>>1;x[d+8>>2]=a;a=x[Gb(d+12|0,d+8|0)>>2];b=a;while(1){if(b){w[e>>1]=y[f|0]|y[f+1|0]<<8;e=e+2|0;f=f+2|0;b=b-1|0;continue}break};fb=d+16|0;e=a<<1;break u;case 1:a=x[b>>2];e=x[b+20>>2];d=fb-16|0;fb=d;x[d+12>>2]=j>>>1;x[d+8>>2]=a;a=x[Gb(d+12|0,d+8|0)>>2];b=a;while(1){if(b){w[e>>1]=(y[f|0]|y[f+1|0]<<8)^32768;e=e+2|0;f=f+2|0;b=b-1|0;continue}break};fb=d+16|0;e=a<<1;break u;default:e=0;if((h|0)!=11){break u}break;case 2:break U}}e=al(s+22|0);a=x[b>>2];g=x[b+20>>2];b=z[e>>1];d=fb-16|0;fb=d;x[d+12>>2]=j>>>1;x[d+8>>2]=a;a=x[Gb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){b=(y[f|0]+b|0)+(y[f+1|0]<<8)|0;w[g>>1]=b;g=g+2|0;f=f+2|0;e=e-1|0;continue}break}fb=d+16|0;e=a<<1;break u}d=e&255;if(!((d|0)!=16|y[a+1|0]!=1|y[a+2|0]!=1)){e=0;V:{switch(h|0){case 0:a=x[b>>2];g=x[b+20>>2];d=fb-16|0;fb=d;x[d+12>>2]=j>>>1;x[d+8>>2]=a;b=x[Gb(d+12|0,d+8|0)>>2];e=b;while(1){if(e){a=y[f|0]|y[f+1|0]<<8;w[g>>1]=a<<8|a>>>8;g=g+2|0;f=f+2|0;e=e-1|0;continue}break};fb=d+16|0;e=b<<1;break u;case 1:a=x[b>>2];g=x[b+20>>2];d=fb-16|0;fb=d;x[d+12>>2]=j>>>1;x[d+8>>2]=a;b=x[Gb(d+12|0,d+8|0)>>2];e=b;while(1){if(e){a=y[f|0]|y[f+1|0]<<8;w[g>>1]=(a<<8|a>>>8)^32768;g=g+2|0;f=f+2|0;e=e-1|0;continue}break};fb=d+16|0;e=b<<1;break u;case 2:break V;default:break u}}e=al(s+20|0);a=x[b>>2];g=x[b+20>>2];b=z[e>>1];d=fb-16|0;fb=d;x[d+12>>2]=j>>>1;x[d+8>>2]=a;a=x[Gb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){b=(y[f+1|0]+b|0)+(y[f|0]<<8)|0;w[g>>1]=b;g=g+2|0;f=f+2|0;e=e-1|0;continue}break}fb=d+16|0;e=a<<1;break u}if(!(y[a+2|0]|((d|0)!=16|y[a+1|0]!=3))){W:{switch(h|0){case 0:k=fb-16|0;fb=k;x[k+12>>2]=j;i=x[b>>2]<<1;x[k+8>>2]=i;a=k+8|0;e=x[Gb(a,k+12|0)>>2];x[k+8>>2]=i;x[k+4>>2]=j-e;a=x[Gb(a,k+4|0)>>2];g=x[b+20>>2];e=e>>>1|0;h=e;d=f;while(1){if(h){w[g>>1]=y[d|0]|y[d+1|0]<<8;g=g+4|0;d=d+2|0;h=h-1|0;continue}break};g=f+i|0;d=x[b+20>>2]+2|0;a=a>>>1|0;h=a;while(1){if(h){w[d>>1]=y[g|0]|y[g+1|0]<<8;d=d+4|0;g=g+2|0;h=h-1|0;continue}break};fb=k+16|0;e=a+e<<1;break u;case 1:k=fb-16|0;fb=k;x[k+12>>2]=j;i=x[b>>2]<<1;x[k+8>>2]=i;a=k+8|0;e=x[Gb(a,k+12|0)>>2];x[k+8>>2]=i;x[k+4>>2]=j-e;a=x[Gb(a,k+4|0)>>2];g=x[b+20>>2];e=e>>>1|0;h=e;d=f;while(1){if(h){w[g>>1]=(y[d|0]|y[d+1|0]<<8)^32768;g=g+4|0;d=d+2|0;h=h-1|0;continue}break};g=f+i|0;d=x[b+20>>2]+2|0;a=a>>>1|0;h=a;while(1){if(h){w[d>>1]=(y[g|0]|y[g+1|0]<<8)^32768;d=d+4|0;g=g+2|0;h=h-1|0;continue}break};fb=k+16|0;e=a+e<<1;break u;default:e=0;if((h|0)!=11){break u}break;case 2:break W}}g=z[al(s+18|0)>>1];o=fb-16|0;fb=o;x[o+12>>2]=j;k=x[b>>2]<<1;x[o+8>>2]=k;e=o+8|0;d=x[Gb(e,o+12|0)>>2];x[o+8>>2]=k;x[o+4>>2]=j-d;h=x[Gb(e,o+4|0)>>2];t=x[b+20>>2];e=g;d=d>>>1|0;i=d;j=f;while(1){if(i){e=(y[j|0]+e|0)+(y[j+1|0]<<8)|0;w[t>>1]=e;t=t+4|0;j=j+2|0;i=i-1|0;continue}break}j=f+k|0;t=x[b+20>>2]+2|0;e=h>>>1|0;i=e;while(1){if(i){g=(y[j|0]+g|0)+(y[j+1|0]<<8)|0;w[t>>1]=g;t=t+4|0;j=j+2|0;i=i-1|0;continue}break}fb=o+16|0;e=d+e<<1;if(y[a+3|0]!=11){break u}a=x[b+20>>2];b=a+(x[b>>2]<<2)|0;while(1){if(a>>>0>=b>>>0){break u}w[a+2>>1]=z[a+2>>1]+z[a>>1];a=a+4|0;continue}}d=e&255;if(!((d|0)!=16|y[a+1|0]!=3|y[a+2|0]!=1)){e=0;X:{switch(h|0){case 0:o=fb-16|0;fb=o;x[o+12>>2]=j;k=x[b>>2]<<1;x[o+8>>2]=k;a=o+8|0;e=x[Gb(a,o+12|0)>>2];x[o+8>>2]=k;x[o+4>>2]=j-e;d=x[Gb(a,o+4|0)>>2];i=x[b+20>>2];e=e>>>1|0;g=e;h=f;while(1){if(g){a=y[h|0]|y[h+1|0]<<8;w[i>>1]=a<<8|a>>>8;i=i+4|0;h=h+2|0;g=g-1|0;continue}break};i=f+k|0;h=x[b+20>>2]+2|0;b=d>>>1|0;g=b;while(1){if(g){a=y[i|0]|y[i+1|0]<<8;w[h>>1]=a<<8|a>>>8;h=h+4|0;i=i+2|0;g=g-1|0;continue}break};fb=o+16|0;e=b+e<<1;break u;case 1:o=fb-16|0;fb=o;x[o+12>>2]=j;k=x[b>>2]<<1;x[o+8>>2]=k;a=o+8|0;e=x[Gb(a,o+12|0)>>2];x[o+8>>2]=k;x[o+4>>2]=j-e;d=x[Gb(a,o+4|0)>>2];i=x[b+20>>2];e=e>>>1|0;g=e;h=f;while(1){if(g){a=y[h|0]|y[h+1|0]<<8;w[i>>1]=(a<<8|a>>>8)^32768;i=i+4|0;h=h+2|0;g=g-1|0;continue}break};i=f+k|0;h=x[b+20>>2]+2|0;b=d>>>1|0;g=b;while(1){if(g){a=y[i|0]|y[i+1|0]<<8;w[h>>1]=(a<<8|a>>>8)^32768;h=h+4|0;i=i+2|0;g=g-1|0;continue}break};fb=o+16|0;e=b+e<<1;break u;case 2:break X;default:break u}}e=z[al(s+16|0)>>1];o=fb-16|0;fb=o;x[o+12>>2]=j;k=x[b>>2]<<1;x[o+8>>2]=k;a=o+8|0;d=x[Gb(a,o+12|0)>>2];x[o+8>>2]=k;x[o+4>>2]=j-d;j=x[Gb(a,o+4|0)>>2];i=x[b+20>>2];a=e;h=d>>>1|0;g=h;d=f;while(1){if(g){a=(y[d+1|0]+a|0)+(y[d|0]<<8)|0;w[i>>1]=a;i=i+4|0;d=d+2|0;g=g-1|0;continue}break}d=f+k|0;i=x[b+20>>2]+2|0;a=j>>>1|0;g=a;while(1){if(g){e=(y[d+1|0]+e|0)+(y[d|0]<<8)|0;w[i>>1]=e;i=i+4|0;d=d+2|0;g=g-1|0;continue}break}fb=o+16|0;e=a+h<<1;break u}if(!(y[a+2|0]|((d|0)!=16|y[a+1|0]!=2))){e=0;Y:{switch(h|0){case 0:a=x[b>>2];e=x[b+20>>2];d=fb-16|0;fb=d;x[d+12>>2]=j>>>2;x[d+8>>2]=a;a=x[Gb(d+12|0,d+8|0)>>2];b=a;while(1){if(b){w[e>>1]=y[f|0]|y[f+1|0]<<8;w[e+2>>1]=y[f+2|0]|y[f+3|0]<<8;e=e+4|0;f=f+4|0;b=b-1|0;continue}break};fb=d+16|0;e=a<<2;break u;case 1:a=x[b>>2];e=x[b+20>>2];d=fb-16|0;fb=d;x[d+12>>2]=j>>>2;x[d+8>>2]=a;a=x[Gb(d+12|0,d+8|0)>>2];b=a;while(1){if(b){w[e>>1]=(y[f|0]|y[f+1|0]<<8)^32768;w[e+2>>1]=(y[f+2|0]|y[f+3|0]<<8)^32768;e=e+4|0;f=f+4|0;b=b-1|0;continue}break};fb=d+16|0;e=a<<2;break u;case 2:break Y;default:break u}}e=al(s+14|0);a=x[b>>2];d=x[b+20>>2];b=z[e>>1];h=fb-16|0;fb=h;x[h+12>>2]=j>>>2;x[h+8>>2]=a;a=b;e=x[Gb(h+12|0,h+8|0)>>2];g=e;while(1){if(g){b=(y[f|0]+b|0)+(y[f+1|0]<<8)|0;w[d>>1]=b;a=(y[f+2|0]+a|0)+(y[f+3|0]<<8)|0;w[d+2>>1]=a;d=d+4|0;f=f+4|0;g=g-1|0;continue}break}fb=h+16|0;e=e<<2;break u}d=e&255;if(!((d|0)!=16|y[a+1|0]!=2|y[a+2|0]!=1)){e=0;Z:{switch(h|0){case 0:a=x[b>>2];g=x[b+20>>2];d=fb-16|0;fb=d;x[d+12>>2]=j>>>2;x[d+8>>2]=a;b=x[Gb(d+12|0,d+8|0)>>2];e=b;while(1){if(e){a=y[f|0]|y[f+1|0]<<8;w[g>>1]=a<<8|a>>>8;a=y[f+2|0]|y[f+3|0]<<8;w[g+2>>1]=a<<8|a>>>8;g=g+4|0;f=f+4|0;e=e-1|0;continue}break};fb=d+16|0;e=b<<2;break u;case 1:a=x[b>>2];g=x[b+20>>2];d=fb-16|0;fb=d;x[d+12>>2]=j>>>2;x[d+8>>2]=a;b=x[Gb(d+12|0,d+8|0)>>2];e=b;while(1){if(e){a=y[f|0]|y[f+1|0]<<8;w[g>>1]=(a<<8|a>>>8)^32768;a=y[f+2|0]|y[f+3|0]<<8;w[g+2>>1]=(a<<8|a>>>8)^32768;g=g+4|0;f=f+4|0;e=e-1|0;continue}break};fb=d+16|0;e=b<<2;break u;case 2:break Z;default:break u}}e=al(s+12|0);a=x[b>>2];d=x[b+20>>2];b=z[e>>1];h=fb-16|0;fb=h;x[h+12>>2]=j>>>2;x[h+8>>2]=a;a=b;e=x[Gb(h+12|0,h+8|0)>>2];g=e;while(1){if(g){b=(y[f+1|0]+b|0)+(y[f|0]<<8)|0;w[d>>1]=b;a=(y[f+3|0]+a|0)+(y[f+2|0]<<8)|0;w[d+2>>1]=a;d=d+4|0;f=f+4|0;g=g-1|0;continue}break}fb=h+16|0;e=e<<2;break u}if(!(h|y[a+1|0]!=1|(d|0)!=24)){e=x[b+20>>2];b=x[b>>2];if(!y[a+2|0]){d=fb-16|0;fb=d;x[d+12>>2]=(j>>>0)/3;x[d+8>>2]=b;a=x[Gb(d+12|0,d+8|0)>>2];b=a;while(1){if(b){M=e,O=qd(y[f+1|0]<<16|y[f|0]<<8|y[f+2|0]<<24,16),w[M>>1]=O;e=e+2|0;f=f+3|0;b=b-1|0;continue}break}fb=d+16|0;e=D(a,3);break u}d=fb-16|0;fb=d;x[d+12>>2]=(j>>>0)/3;x[d+8>>2]=b;a=x[Gb(d+12|0,d+8|0)>>2];b=a;while(1){if(b){M=e,O=qd(y[f+1|0]<<16|y[f+2|0]<<8|y[f|0]<<24,16),w[M>>1]=O;e=e+2|0;f=f+3|0;b=b-1|0;continue}break}fb=d+16|0;e=D(a,3);break u}d=e&255;if(!(h|y[a+1|0]!=2|(d|0)!=24)){e=x[b+20>>2];b=x[b>>2];if(!y[a+2|0]){d=fb-16|0;fb=d;x[d+12>>2]=(j>>>0)/6;x[d+8>>2]=b;a=x[Gb(d+12|0,d+8|0)>>2];b=a;while(1){if(b){M=e,O=qd(y[f+1|0]<<16|y[f|0]<<8|y[f+2|0]<<24,16),w[M>>1]=O;M=e,O=qd(y[f+4|0]<<16|y[f+3|0]<<8|y[f+5|0]<<24,16),w[M+2>>1]=O;e=e+4|0;f=f+6|0;b=b-1|0;continue}break}fb=d+16|0;e=D(a,6);break u}d=fb-16|0;fb=d;x[d+12>>2]=(j>>>0)/6;x[d+8>>2]=b;a=x[Gb(d+12|0,d+8|0)>>2];b=a;while(1){if(b){M=e,O=qd(y[f+1|0]<<16|y[f+2|0]<<8|y[f|0]<<24,16),w[M>>1]=O;M=e,O=qd(y[f+4|0]<<16|y[f+5|0]<<8|y[f+3|0]<<24,16),w[M+2>>1]=O;e=e+4|0;f=f+6|0;b=b-1|0;continue}break}fb=d+16|0;e=D(a,6);break u}if(!(h|y[a+1|0]!=1|(d|0)!=32)){e=x[b+20>>2];b=x[b>>2];if(!y[a+2|0]){d=fb-16|0;fb=d;x[d+12>>2]=j>>>2;x[d+8>>2]=b;a=x[Gb(d+12|0,d+8|0)>>2];b=a;while(1){if(b){M=e,O=qd(y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24),16),w[M>>1]=O;e=e+2|0;f=f+4|0;b=b-1|0;continue}break}fb=d+16|0;e=a<<2;break u}d=fb-16|0;fb=d;x[d+12>>2]=j>>>2;x[d+8>>2]=b;a=x[Gb(d+12|0,d+8|0)>>2];g=a;while(1){if(g){b=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);M=e,O=qd(b<<24|(b&65280)<<8|(b>>>8&65280|b>>>24),16),w[M>>1]=O;e=e+2|0;f=f+4|0;g=g-1|0;continue}break}fb=d+16|0;e=a<<2;break u}d=e&255;if(!(h|y[a+1|0]!=2|(d|0)!=32)){e=x[b+20>>2];b=x[b>>2];if(!y[a+2|0]){d=fb-16|0;fb=d;x[d+12>>2]=j>>>3;x[d+8>>2]=b;a=x[Gb(d+12|0,d+8|0)>>2];b=a;while(1){if(b){M=e,O=qd(y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24),16),w[M>>1]=O;M=e,O=qd(y[f+4|0]|y[f+5|0]<<8|(y[f+6|0]<<16|y[f+7|0]<<24),16),w[M+2>>1]=O;e=e+4|0;f=f+8|0;b=b-1|0;continue}break}fb=d+16|0;e=a<<3;break u}d=fb-16|0;fb=d;x[d+12>>2]=j>>>3;x[d+8>>2]=b;a=x[Gb(d+12|0,d+8|0)>>2];g=a;while(1){if(g){b=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);M=e,O=qd(b<<24|(b&65280)<<8|(b>>>8&65280|b>>>24),16),w[M>>1]=O;b=y[f+4|0]|y[f+5|0]<<8|(y[f+6|0]<<16|y[f+7|0]<<24);M=e,O=qd(b<<24|(b&65280)<<8|(b>>>8&65280|b>>>24),16),w[M+2>>1]=O;e=e+4|0;f=f+8|0;g=g-1|0;continue}break}fb=d+16|0;e=a<<3;break u}if(!(h|y[a+1|0]!=1|(d|0)!=64)){e=x[b+20>>2];b=x[b>>2];if(!y[a+2|0]){d=fb-16|0;fb=d;x[d+12>>2]=j>>>3;x[d+8>>2]=b;a=x[Gb(d+12|0,d+8|0)>>2];b=a;while(1){if(b){M=e,O=Rc(y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24),y[f+4|0]|y[f+5|0]<<8|(y[f+6|0]<<16|y[f+7|0]<<24),48),w[M>>1]=O;e=e+2|0;f=f+8|0;b=b-1|0;continue}break}fb=d+16|0;e=a<<3;break u}k=fb-16|0;fb=k;x[k+12>>2]=j>>>3;x[k+8>>2]=b;h=x[Gb(k+12|0,k+8|0)>>2];b=h;while(1){if(b){i=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);g=i<<24|(i&65280)<<8;a=i&-16777216;d=a>>>24|0;o=a<<8;a=i&16711680;j=y[f+4|0]|y[f+5|0]<<8|(y[f+6|0]<<16|y[f+7|0]<<24);M=e,O=Rc(o|a<<24|(((j&255)<<24|i>>>8)&-16777216|((j&16777215)<<8|i>>>24)&16711680|(j>>>8&65280|j>>>24)),g|(d|a>>>8),48),w[M>>1]=O;e=e+2|0;f=f+8|0;b=b-1|0;continue}break}fb=k+16|0;e=h<<3;break u}d=e&255;if(!(h|y[a+1|0]!=2|(d|0)!=64)){e=x[b+20>>2];b=x[b>>2];if(!y[a+2|0]){d=fb-16|0;fb=d;x[d+12>>2]=j>>>4;x[d+8>>2]=b;a=x[Gb(d+12|0,d+8|0)>>2];b=a;while(1){if(b){M=e,O=Rc(y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24),y[f+4|0]|y[f+5|0]<<8|(y[f+6|0]<<16|y[f+7|0]<<24),48),w[M>>1]=O;M=e,O=Rc(y[f+8|0]|y[f+9|0]<<8|(y[f+10|0]<<16|y[f+11|0]<<24),y[f+12|0]|y[f+13|0]<<8|(y[f+14|0]<<16|y[f+15|0]<<24),48),w[M+2>>1]=O;e=e+4|0;f=f+16|0;b=b-1|0;continue}break}fb=d+16|0;e=a<<4;break u}k=fb-16|0;fb=k;x[k+12>>2]=j>>>4;x[k+8>>2]=b;h=x[Gb(k+12|0,k+8|0)>>2];b=h;while(1){if(b){i=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);g=i<<24|(i&65280)<<8;a=i&-16777216;d=a>>>24|0;o=a<<8;a=i&16711680;j=y[f+4|0]|y[f+5|0]<<8|(y[f+6|0]<<16|y[f+7|0]<<24);M=e,O=Rc(o|a<<24|(((j&255)<<24|i>>>8)&-16777216|((j&16777215)<<8|i>>>24)&16711680|(j>>>8&65280|j>>>24)),g|(d|a>>>8),48),w[M>>1]=O;i=y[f+8|0]|y[f+9|0]<<8|(y[f+10|0]<<16|y[f+11|0]<<24);g=i<<24|(i&65280)<<8;a=i&-16777216;d=a>>>24|0;o=a<<8;a=i&16711680;j=y[f+12|0]|y[f+13|0]<<8|(y[f+14|0]<<16|y[f+15|0]<<24);M=e,O=Rc(o|a<<24|(((j&255)<<24|i>>>8)&-16777216|((j&16777215)<<8|i>>>24)&16711680|(j>>>8&65280|j>>>24)),g|(d|a>>>8),48),w[M+2>>1]=O;e=e+4|0;f=f+16|0;b=b-1|0;continue}break}fb=k+16|0;e=h<<4;break u}if(!(y[a+1|0]!=1|(h|0)!=3|(d|0)!=32)){e=x[b+20>>2];b=x[b>>2];if(!y[a+2|0]){d=fb-16|0;fb=d;x[d+12>>2]=j>>>2;x[d+8>>2]=b;a=x[Gb(d+12|0,d+8|0)>>2];b=a;while(1){if(b){m=cg((l(2,y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24)),r()));m=ri(E(Pd(Jg(m)?m>=E(0)?E(1):E(-1):m,E(-1))*E(32768)));_:{if(E(F(m))<E(2147483648)){g=~~m;break _}g=-2147483648}M=e,O=ed(g),w[M>>1]=O;e=e+2|0;f=f+4|0;b=b-1|0;continue}break}fb=d+16|0;e=a<<2;break u}d=fb-16|0;fb=d;x[d+12>>2]=j>>>2;x[d+8>>2]=b;a=x[Gb(d+12|0,d+8|0)>>2];g=a;while(1){if(g){b=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);m=cg((l(2,b<<24|(b&65280)<<8|(b>>>8&65280|b>>>24)),r()));m=ri(E(Pd(Jg(m)?m>=E(0)?E(1):E(-1):m,E(-1))*E(32768)));$:{if(E(F(m))<E(2147483648)){b=~~m;break $}b=-2147483648}M=e,O=ed(b),w[M>>1]=O;e=e+2|0;f=f+4|0;g=g-1|0;continue}break}fb=d+16|0;e=a<<2;break u}d=e&255;if(!(y[a+1|0]!=2|(h|0)!=3|(d|0)!=32)){e=x[b+20>>2];b=x[b>>2];if(!y[a+2|0]){d=fb-16|0;fb=d;x[d+12>>2]=j>>>3;x[d+8>>2]=b;a=x[Gb(d+12|0,d+8|0)>>2];b=a;while(1){if(b){m=cg((l(2,y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24)),r()));m=ri(E(Pd(Jg(m)?m>=E(0)?E(1):E(-1):m,E(-1))*E(32768)));aa:{if(E(F(m))<E(2147483648)){g=~~m;break aa}g=-2147483648}M=e,O=ed(g),w[M>>1]=O;m=cg((l(2,y[f+4|0]|y[f+5|0]<<8|(y[f+6|0]<<16|y[f+7|0]<<24)),r()));m=ri(E(Pd(Jg(m)?m>=E(0)?E(1):E(-1):m,E(-1))*E(32768)));ba:{if(E(F(m))<E(2147483648)){g=~~m;break ba}g=-2147483648}M=e,O=ed(g),w[M+2>>1]=O;e=e+4|0;f=f+8|0;b=b-1|0;continue}break}fb=d+16|0;e=a<<3;break u}d=fb-16|0;fb=d;x[d+12>>2]=j>>>3;x[d+8>>2]=b;a=x[Gb(d+12|0,d+8|0)>>2];g=a;while(1){if(g){b=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);m=cg((l(2,b<<24|(b&65280)<<8|(b>>>8&65280|b>>>24)),r()));m=ri(E(Pd(Jg(m)?m>=E(0)?E(1):E(-1):m,E(-1))*E(32768)));ca:{if(E(F(m))<E(2147483648)){b=~~m;break ca}b=-2147483648}M=e,O=ed(b),w[M>>1]=O;b=y[f+4|0]|y[f+5|0]<<8|(y[f+6|0]<<16|y[f+7|0]<<24);m=cg((l(2,b<<24|(b&65280)<<8|(b>>>8&65280|b>>>24)),r()));m=ri(E(Pd(Jg(m)?m>=E(0)?E(1):E(-1):m,E(-1))*E(32768)));da:{if(E(F(m))<E(2147483648)){b=~~m;break da}b=-2147483648}M=e,O=ed(b),w[M+2>>1]=O;e=e+4|0;f=f+8|0;g=g-1|0;continue}break}fb=d+16|0;e=a<<3;break u}if(!(y[a+1|0]!=1|(h|0)!=3|(d|0)!=64)){e=x[b+20>>2];b=x[b>>2];if(!y[a+2|0]){g=fb-32|0;fb=g;x[g+24>>2]=j>>>3;x[g+16>>2]=b;d=x[Gb(g+24|0,g+16|0)>>2];b=d;while(1){if(b){a=y[f+4|0]|y[f+5|0]<<8|(y[f+6|0]<<16|y[f+7|0]<<24);l(0,y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24));l(1,a|0);q=Ig(+n());M=g,V=zf(q)?q>=0?1:-1:q,C[M+24>>3]=V;x[g+16>>2]=0;x[g+20>>2]=-1074790400;x[g+8>>2]=0;x[g+12>>2]=1072693248;q=Ee(C[Yg(g+24|0,g+16|0,g+8|0)>>3]*32768);ea:{if(F(q)<2147483648){a=~~q;break ea}a=-2147483648}M=e,O=ed(a),w[M>>1]=O;e=e+2|0;f=f+8|0;b=b-1|0;continue}break}fb=g+32|0;e=d<<3;break u}k=fb-32|0;fb=k;x[k+24>>2]=j>>>3;x[k+16>>2]=b;h=x[Gb(k+24|0,k+16|0)>>2];b=h;while(1){if(b){i=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);g=i<<24|(i&65280)<<8;a=i&-16777216;d=a>>>24|0;o=a<<8;a=i&16711680;j=y[f+4|0]|y[f+5|0]<<8|(y[f+6|0]<<16|y[f+7|0]<<24);l(0,o|a<<24|(((j&255)<<24|i>>>8)&-16777216|((j&16777215)<<8|i>>>24)&16711680|(j>>>8&65280|j>>>24)));l(1,g|(d|a>>>8));q=Ig(+n());M=k,V=zf(q)?q>=0?1:-1:q,C[M+24>>3]=V;x[k+16>>2]=0;x[k+20>>2]=-1074790400;x[k+8>>2]=0;x[k+12>>2]=1072693248;q=Ee(C[Yg(k+24|0,k+16|0,k+8|0)>>3]*32768);fa:{if(F(q)<2147483648){a=~~q;break fa}a=-2147483648}M=e,O=ed(a),w[M>>1]=O;e=e+2|0;f=f+8|0;b=b-1|0;continue}break}fb=k+32|0;e=h<<3;break u}d=e&255;if(!(y[a+1|0]!=2|(h|0)!=3|(d|0)!=64)){e=x[b+20>>2];b=x[b>>2];if(!y[a+2|0]){g=fb-32|0;fb=g;x[g+24>>2]=j>>>4;x[g+16>>2]=b;d=x[Gb(g+24|0,g+16|0)>>2];b=d;while(1){if(b){a=y[f+4|0]|y[f+5|0]<<8|(y[f+6|0]<<16|y[f+7|0]<<24);l(0,y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24));l(1,a|0);q=Ig(+n());M=g,V=zf(q)?q>=0?1:-1:q,C[M+24>>3]=V;x[g+16>>2]=0;x[g+20>>2]=-1074790400;x[g+8>>2]=0;x[g+12>>2]=1072693248;q=Ee(C[Yg(g+24|0,g+16|0,g+8|0)>>3]*32768);ga:{if(F(q)<2147483648){a=~~q;break ga}a=-2147483648}M=e,O=ed(a),w[M>>1]=O;a=y[f+12|0]|y[f+13|0]<<8|(y[f+14|0]<<16|y[f+15|0]<<24);l(0,y[f+8|0]|y[f+9|0]<<8|(y[f+10|0]<<16|y[f+11|0]<<24));l(1,a|0);q=Ig(+n());M=g,V=zf(q)?q>=0?1:-1:q,C[M+24>>3]=V;x[g+16>>2]=0;x[g+20>>2]=-1074790400;x[g+8>>2]=0;x[g+12>>2]=1072693248;q=Ee(C[Yg(g+24|0,g+16|0,g+8|0)>>3]*32768);ha:{if(F(q)<2147483648){a=~~q;break ha}a=-2147483648}M=e,O=ed(a),w[M+2>>1]=O;e=e+4|0;f=f+16|0;b=b-1|0;continue}break}fb=g+32|0;e=d<<4;break u}k=fb-32|0;fb=k;x[k+24>>2]=j>>>4;x[k+16>>2]=b;h=x[Gb(k+24|0,k+16|0)>>2];b=h;while(1){if(b){i=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);g=i<<24|(i&65280)<<8;a=i&-16777216;d=a>>>24|0;o=a<<8;a=i&16711680;j=y[f+4|0]|y[f+5|0]<<8|(y[f+6|0]<<16|y[f+7|0]<<24);l(0,o|a<<24|(((j&255)<<24|i>>>8)&-16777216|((j&16777215)<<8|i>>>24)&16711680|(j>>>8&65280|j>>>24)));l(1,g|(d|a>>>8));q=Ig(+n());M=k,V=zf(q)?q>=0?1:-1:q,C[M+24>>3]=V;x[k+16>>2]=0;x[k+20>>2]=-1074790400;x[k+8>>2]=0;x[k+12>>2]=1072693248;q=Ee(C[Yg(k+24|0,k+16|0,k+8|0)>>3]*32768);ia:{if(F(q)<2147483648){a=~~q;break ia}a=-2147483648}M=e,O=ed(a),w[M>>1]=O;i=y[f+8|0]|y[f+9|0]<<8|(y[f+10|0]<<16|y[f+11|0]<<24);g=i<<24|(i&65280)<<8;a=i&-16777216;d=a>>>24|0;o=a<<8;a=i&16711680;j=y[f+12|0]|y[f+13|0]<<8|(y[f+14|0]<<16|y[f+15|0]<<24);l(0,o|a<<24|(((j&255)<<24|i>>>8)&-16777216|((j&16777215)<<8|i>>>24)&16711680|(j>>>8&65280|j>>>24)));l(1,g|(d|a>>>8));q=Ig(+n());M=k,V=zf(q)?q>=0?1:-1:q,C[M+24>>3]=V;x[k+16>>2]=0;x[k+20>>2]=-1074790400;x[k+8>>2]=0;x[k+12>>2]=1072693248;q=Ee(C[Yg(k+24|0,k+16|0,k+8|0)>>3]*32768);ja:{if(F(q)<2147483648){a=~~q;break ja}a=-2147483648}M=e,O=ed(a),w[M+2>>1]=O;e=e+4|0;f=f+16|0;b=b-1|0;continue}break}fb=k+32|0;e=h<<4;break u}ka:{if((d|0)==24){if((h|0)!=15|(y[a+1|0]-1&255)>>>0>1){break ka}x[s+48>>2]=-2147483648;la:{if(!y[a+2|0]){o=s+48|0;t=fb-16|0;fb=t;M=t,O=D(x[b>>2],_d(z[b+34>>1])),x[M+12>>2]=O;wc(t+12|0,(j>>>0)/3|0);e=f;h=x[t+12>>2];d=h;while(1){if(d){i=y[e+1|0]<<16|y[e|0]<<8|y[e+2|0]<<24;ma:{if((i|0)<0){a=-2147483648;if((i|0)==-2147483648){break ma}i=0-i|0}a=g>>>0<i>>>0?i:g}g=a;d=d-1|0;e=e+3|0;continue}else{na:{if(!g){break na}k=g-1|0;j=g>>>1|0;i=x[b+20>>2];e=h;while(1){if(!e){break na}a=y[f+1|0]<<16|y[f|0]<<8|y[f+2|0]<<24;d=a&-2147483648|a>>>1;a=j|a<<31;oa:{if((d|0)>0|(d|0)>=0){a=Uua(a,d,g,0);d=hb;break oa}d=Uua(k-a|0,0-((a>>>0>k>>>0)+d|0)|0,g,0);a=0-d|0;d=0-(hb+((d|0)!=0)|0)|0}M=i,O=qd(Gc(a,d),16),w[M>>1]=O;e=e-1|0;f=f+3|0;i=i+2|0;continue}}}break}if(o){x[o>>2]=g}fb=t+16|0;e=D(h,3);break la}o=s+48|0;t=fb-16|0;fb=t;M=t,O=D(x[b>>2],_d(z[b+34>>1])),x[M+12>>2]=O;wc(t+12|0,(j>>>0)/3|0);e=f;h=x[t+12>>2];d=h;while(1){if(d){i=y[e+1|0]<<16|y[e+2|0]<<8|y[e|0]<<24;pa:{if((i|0)<0){a=-2147483648;if((i|0)==-2147483648){break pa}i=0-i|0}a=g>>>0<i>>>0?i:g}g=a;d=d-1|0;e=e+3|0;continue}else{qa:{if(!g){break qa}k=g-1|0;j=g>>>1|0;i=x[b+20>>2];e=h;while(1){if(!e){break qa}a=y[f+1|0]<<16|y[f+2|0]<<8|y[f|0]<<24;d=a&-2147483648|a>>>1;a=j|a<<31;ra:{if((d|0)>0|(d|0)>=0){a=Uua(a,d,g,0);d=hb;break ra}d=Uua(k-a|0,0-((a>>>0>k>>>0)+d|0)|0,g,0);a=0-d|0;d=0-(hb+((d|0)!=0)|0)|0}M=i,O=qd(Gc(a,d),16),w[M>>1]=O;e=e-1|0;f=f+3|0;i=i+2|0;continue}}}break}if(o){x[o>>2]=g}fb=t+16|0;e=D(h,3)}if(!e){break u}a=x[s+48>>2];if((a|0)==-2147483648){break u}f=Sua(z[b+32>>1],0,a,0);a=hb;f=f+1073741824|0;a=f>>>0<1073741824?a+1|0:a;M=b,O=Kd(Bc((a&2147483647)<<1|f>>>31,a>>>31|0),1,64),w[M+32>>1]=O;w[b+34>>1]=z[b+34>>1]|8192;break u}d=e&255;if((d|0)==32){if(!((h|0)!=15|(y[a+1|0]-1&255)>>>0>1)){x[s+48>>2]=-2147483648;sa:{if(!y[a+2|0]){o=s+48|0;t=fb-16|0;fb=t;M=t,O=D(x[b>>2],_d(z[b+34>>1])),x[M+12>>2]=O;wc(t+12|0,j>>>2|0);d=f;h=x[t+12>>2];g=h;while(1){if(g){e=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);ta:{if((e|0)<0){a=-2147483648;if((e|0)==-2147483648){break ta}e=0-e|0}a=e>>>0>i>>>0?e:i}i=a;g=g-1|0;d=d+4|0;continue}else{ua:{if(!i){break ua}k=i-1|0;j=i>>>1|0;g=x[b+20>>2];e=h;while(1){if(!e){break ua}a=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);d=a&-2147483648|a>>>1;a=j|a<<31;va:{if((d|0)>0|(d|0)>=0){a=Uua(a,d,i,0);d=hb;break va}d=Uua(k-a|0,0-((a>>>0>k>>>0)+d|0)|0,i,0);a=0-d|0;d=0-(hb+((d|0)!=0)|0)|0}M=g,O=qd(Gc(a,d),16),w[M>>1]=O;e=e-1|0;f=f+4|0;g=g+2|0;continue}}}break}if(o){x[o>>2]=i}fb=t+16|0;e=h<<2;break sa}o=s+48|0;t=fb-16|0;fb=t;M=t,O=D(x[b>>2],_d(z[b+34>>1])),x[M+12>>2]=O;wc(t+12|0,j>>>2|0);g=f;h=x[t+12>>2];e=h;while(1){if(e){a=y[g|0]|y[g+1|0]<<8|(y[g+2|0]<<16|y[g+3|0]<<24);d=a<<24|(a&65280)<<8|(a>>>8&65280|a>>>24);wa:{if((d|0)<0){a=-2147483648;if((d|0)==-2147483648){break wa}d=0-d|0}a=d>>>0>i>>>0?d:i}i=a;e=e-1|0;g=g+4|0;continue}else{xa:{if(!i){break xa}k=i-1|0;j=i>>>1|0;g=x[b+20>>2];e=h;while(1){if(!e){break xa}a=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);a=a<<24|(a&65280)<<8|(a>>>8&65280|a>>>24);d=a&-2147483648|a>>>1;a=j|a<<31;ya:{if((d|0)>0|(d|0)>=0){a=Uua(a,d,i,0);d=hb;break ya}d=Uua(k-a|0,0-((a>>>0>k>>>0)+d|0)|0,i,0);a=0-d|0;d=0-(hb+((d|0)!=0)|0)|0}M=g,O=qd(Gc(a,d),16),w[M>>1]=O;e=e-1|0;f=f+4|0;g=g+2|0;continue}}}break}if(o){x[o>>2]=i}fb=t+16|0;e=h<<2}if(!e){break u}a=x[s+48>>2];if((a|0)==-2147483648){break u}f=Sua(z[b+32>>1],0,a,0);a=hb;f=f+1073741824|0;a=f>>>0<1073741824?a+1|0:a;M=b,O=Kd(Bc((a&2147483647)<<1|f>>>31,a>>>31|0),1,64),w[M+32>>1]=O;w[b+34>>1]=z[b+34>>1]|8192;break u}if((h|0)!=14|(y[a+1|0]-1&255)>>>0>1){break ka}x[s+48>>2]=1065353216;za:{if(!y[a+2|0]){d=s+48|0;g=fb-16|0;fb=g;M=g,O=D(x[b>>2],_d(z[b+34>>1])),x[M+12>>2]=O;wc(g+12|0,j>>>2|0);h=f;a=x[g+12>>2];e=a;while(1){if(e){m=cg((l(2,y[h|0]|y[h+1|0]<<8|(y[h+2|0]<<16|y[h+3|0]<<24)),r()));m=E(F(Jg(m)?m>=E(0)?E(1):E(-1):m));u=m>u?m:u;e=e-1|0;h=h+4|0;continue}else{Aa:{if(u==E(0)){break Aa}J=E(E(1)/u);h=x[b+20>>2];e=a;while(1){if(!e){break Aa}m=cg((l(2,y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24)),r()));m=ri(E(Pd(E(J*(Jg(m)?m>=E(0)?E(1):E(-1):m)),E(-1))*E(32768)));Ba:{if(E(F(m))<E(2147483648)){i=~~m;break Ba}i=-2147483648}M=h,O=ed(i),w[M>>1]=O;e=e-1|0;f=f+4|0;h=h+2|0;continue}}if(d){B[d>>2]=u}fb=g+16|0;e=a<<2}break}break za}d=s+48|0;i=fb-16|0;fb=i;M=i,O=D(x[b>>2],_d(z[b+34>>1])),x[M+12>>2]=O;wc(i+12|0,j>>>2|0);g=f;a=x[i+12>>2];e=a;while(1){if(e){h=y[g|0]|y[g+1|0]<<8|(y[g+2|0]<<16|y[g+3|0]<<24);m=cg((l(2,h<<24|(h&65280)<<8|(h>>>8&65280|h>>>24)),r()));m=E(F(Jg(m)?m>=E(0)?E(1):E(-1):m));u=m>u?m:u;e=e-1|0;g=g+4|0;continue}else{Ca:{if(u==E(0)){break Ca}J=E(E(1)/u);g=x[b+20>>2];e=a;while(1){if(!e){break Ca}h=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);m=cg((l(2,h<<24|(h&65280)<<8|(h>>>8&65280|h>>>24)),r()));m=ri(E(Pd(E(J*(Jg(m)?m>=E(0)?E(1):E(-1):m)),E(-1))*E(32768)));Da:{if(E(F(m))<E(2147483648)){h=~~m;break Da}h=-2147483648}M=g,O=ed(h),w[M>>1]=O;e=e-1|0;f=f+4|0;g=g+2|0;continue}}if(d){B[d>>2]=u}fb=i+16|0;e=a<<2}break}}if(!e){break u}m=B[s+48>>2];if(m==E(1)){break u}m=ri(zB(E(m*E(z[b+32>>1])),E(1),E(64)));a=65535;Ea:{if(m>=E(65535)){break Ea}a=0;if(m<=E(0)){break Ea}a=~~m>>>0;if(m<E(4294967296)&m>=E(0)){break Ea}a=0}w[b+32>>1]=a;w[b+34>>1]=z[b+34>>1]|8192;break u}if((h|0)!=14|(y[a+1|0]-1&255)>>>0>1|(d|0)!=64){break ka}x[s+48>>2]=0;x[s+52>>2]=1072693248;Fa:{if(!y[a+2|0]){h=s+48|0;i=fb-32|0;fb=i;M=i,O=D(x[b>>2],_d(z[b+34>>1])),x[M+4>>2]=O;wc(i+4|0,j>>>3|0);d=f;a=x[i+4>>2];e=a;while(1){if(e){g=y[d+4|0]|y[d+5|0]<<8|(y[d+6|0]<<16|y[d+7|0]<<24);l(0,y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24));l(1,g|0);q=Ig(+n());q=F(zf(q)?q>=0?1:-1:q);H=q>H?q:H;e=e-1|0;d=d+8|0;continue}else{Ga:{if(H==0){break Ga}K=1/H;d=x[b+20>>2];e=a;while(1){if(!e){break Ga}g=y[f+4|0]|y[f+5|0]<<8|(y[f+6|0]<<16|y[f+7|0]<<24);l(0,y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24));l(1,g|0);q=Ig(+n());M=i,V=K*(zf(q)?q>=0?1:-1:q),C[M+24>>3]=V;x[i+16>>2]=0;x[i+20>>2]=-1074790400;x[i+8>>2]=0;x[i+12>>2]=1072693248;q=Ee(C[Yg(i+24|0,i+16|0,i+8|0)>>3]*32768);Ha:{if(F(q)<2147483648){g=~~q;break Ha}g=-2147483648}M=d,O=ed(g),w[M>>1]=O;e=e-1|0;f=f+8|0;d=d+2|0;continue}}if(h){C[h>>3]=H}fb=i+32|0;e=a<<3}break}break Fa}o=s+48|0;G=fb-32|0;fb=G;M=G,O=D(x[b>>2],_d(z[b+34>>1])),x[M+4>>2]=O;wc(G+4|0,j>>>3|0);d=f;a=x[G+4>>2];e=a;while(1){if(e){k=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);j=k<<24|(k&65280)<<8;g=k&-16777216;h=g>>>24|0;t=g<<8;g=k&16711680;i=y[d+4|0]|y[d+5|0]<<8|(y[d+6|0]<<16|y[d+7|0]<<24);l(0,t|g<<24|(((i&255)<<24|k>>>8)&-16777216|((i&16777215)<<8|k>>>24)&16711680|(i>>>8&65280|i>>>24)));l(1,j|(h|g>>>8));q=Ig(+n());q=F(zf(q)?q>=0?1:-1:q);H=q>H?q:H;e=e-1|0;d=d+8|0;continue}else{Ia:{if(H==0){break Ia}K=1/H;d=x[b+20>>2];e=a;while(1){if(!e){break Ia}t=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);k=t<<24|(t&65280)<<8;i=t&16711680;j=i>>>8|0;h=t&-16777216;g=h>>>24|0;i=h<<8|i<<24;h=y[f+4|0]|y[f+5|0]<<8|(y[f+6|0]<<16|y[f+7|0]<<24);l(0,i|(((h&255)<<24|t>>>8)&-16777216|((h&16777215)<<8|t>>>24)&16711680|(h>>>8&65280|h>>>24)));l(1,k|(g|j));q=Ig(+n());M=G,V=K*(zf(q)?q>=0?1:-1:q),C[M+24>>3]=V;x[G+16>>2]=0;x[G+20>>2]=-1074790400;x[G+8>>2]=0;x[G+12>>2]=1072693248;q=Ee(C[Yg(G+24|0,G+16|0,G+8|0)>>3]*32768);Ja:{if(F(q)<2147483648){g=~~q;break Ja}g=-2147483648}M=d,O=ed(g),w[M>>1]=O;e=e-1|0;f=f+8|0;d=d+2|0;continue}}if(o){C[o>>3]=H}fb=G+32|0;e=a<<3}break}}if(!e){break u}q=C[s+48>>3];if(q==1){break u}M=b,O=HD(Uv(q*+z[b+32>>1],1,64)),w[M+32>>1]=O;w[b+34>>1]=z[b+34>>1]|8192;break u}Ka:{La:{Ma:{Na:{d=(e&255)!=32;Oa:{if(!(d|(y[a+1|0]!=1|(h|0)!=12))){u=E(30517578125e-15);if(!y[a+2|0]){break Oa}break Ka}if(!(y[a+1|0]!=2|(h|0)!=12|d)){u=E(30517578125e-15);if(!y[a+2|0]){break Ma}break La}d=(e&255)!=32;if(d|(y[a+1|0]!=1|(h|0)!=13)){break Na}u=E(1.1920928955078125e-7);if(y[a+2|0]){break Ka}}a=x[b>>2];e=x[b+20>>2];d=fb-16|0;fb=d;x[d+12>>2]=j>>>2;x[d+8>>2]=a;a=x[Gb(d+12|0,d+8|0)>>2];b=a;while(1){if(b){m=cg((l(2,y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24)),r()));m=ri(E(Pd(E((Jg(m)?m>=E(0)?E(1):E(-1):m)*u),E(-1))*E(32768)));Pa:{if(E(F(m))<E(2147483648)){g=~~m;break Pa}g=-2147483648}M=e,O=ed(g),w[M>>1]=O;e=e+2|0;f=f+4|0;b=b-1|0;continue}break}fb=d+16|0;e=a<<2;break u}e=0;if(y[a+1|0]!=2|(h|0)!=13|d){break u}u=E(1.1920928955078125e-7);if(y[a+2|0]){break La}}a=x[b>>2];e=x[b+20>>2];d=fb-16|0;fb=d;x[d+12>>2]=j>>>3;x[d+8>>2]=a;a=x[Gb(d+12|0,d+8|0)>>2];b=a;while(1){if(b){m=cg((l(2,y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24)),r()));m=ri(E(Pd(E((Jg(m)?m>=E(0)?E(1):E(-1):m)*u),E(-1))*E(32768)));Qa:{if(E(F(m))<E(2147483648)){g=~~m;break Qa}g=-2147483648}M=e,O=ed(g),w[M>>1]=O;m=cg((l(2,y[f+4|0]|y[f+5|0]<<8|(y[f+6|0]<<16|y[f+7|0]<<24)),r()));m=ri(E(Pd(E((Jg(m)?m>=E(0)?E(1):E(-1):m)*u),E(-1))*E(32768)));Ra:{if(E(F(m))<E(2147483648)){g=~~m;break Ra}g=-2147483648}M=e,O=ed(g),w[M+2>>1]=O;e=e+4|0;f=f+8|0;b=b-1|0;continue}break}fb=d+16|0;e=a<<3;break u}a=x[b>>2];g=x[b+20>>2];d=fb-16|0;fb=d;x[d+12>>2]=j>>>3;x[d+8>>2]=a;a=x[Gb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){b=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);m=cg((l(2,b<<24|(b&65280)<<8|(b>>>8&65280|b>>>24)),r()));m=ri(E(Pd(E((Jg(m)?m>=E(0)?E(1):E(-1):m)*u),E(-1))*E(32768)));Sa:{if(E(F(m))<E(2147483648)){b=~~m;break Sa}b=-2147483648}M=g,O=ed(b),w[M>>1]=O;b=y[f+4|0]|y[f+5|0]<<8|(y[f+6|0]<<16|y[f+7|0]<<24);m=cg((l(2,b<<24|(b&65280)<<8|(b>>>8&65280|b>>>24)),r()));m=ri(E(Pd(E((Jg(m)?m>=E(0)?E(1):E(-1):m)*u),E(-1))*E(32768)));Ta:{if(E(F(m))<E(2147483648)){b=~~m;break Ta}b=-2147483648}M=g,O=ed(b),w[M+2>>1]=O;g=g+4|0;f=f+8|0;e=e-1|0;continue}break}fb=d+16|0;e=a<<3;break u}a=x[b>>2];g=x[b+20>>2];d=fb-16|0;fb=d;x[d+12>>2]=j>>>2;x[d+8>>2]=a;a=x[Gb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){b=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);m=cg((l(2,b<<24|(b&65280)<<8|(b>>>8&65280|b>>>24)),r()));m=ri(E(Pd(E((Jg(m)?m>=E(0)?E(1):E(-1):m)*u),E(-1))*E(32768)));Ua:{if(E(F(m))<E(2147483648)){b=~~m;break Ua}b=-2147483648}M=g,O=ed(b),w[M>>1]=O;g=g+2|0;f=f+4|0;e=e-1|0;continue}break}fb=d+16|0;e=a<<2;break u}a=T(28896)|0}if((gb|0)!=($(28896)|0)){break e}Y(a|0)|0;x[31737]=0;X(26);a=x[31737];x[31737]=0;if((a|0)==1){break v}}ub(o);break u}a=N()|0;break e}x[31737]=0;P(150,c|0,e+L|0)|0;a=x[31737];x[31737]=0;if((a|0)==1){break g}}Kc(I)}fb=s+2240|0;return e|0}a=N()|0;break a}a=N()|0}ub(o);break a}a=N()|0;break a}a=N()|0;break a}a=N()|0}Kc(I);Q(a|0);p()}function qsa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,T=0;e=fb-608|0;fb=e;xc(b);d=fb-16|0;fb=d;g=e+416|0;ow(d+8|0,g);j=x[d+12>>2];lc(d,x[b>>2],x[b+8>>2],x[d+8>>2],x[d+12>>2]);h=x[d+4>>2];if((h|0)==(j|0)){Vb(b,x[d+12>>2])}fb=d+16|0;d=(h|0)==(j|0);if(!d){WZ(g)}a:{b:{c:{if(!d){break c}if(!YZ(g)){break c}if(!Mb(x[b>>2],x[b+8>>2],Bc(XZ(g),hb))){break c}f=1;if((c|0)==64){break c}Bd(a,32);v[e+415|0]=0;j=Fb(e+400|0);d:{e:{f:{g:{h:{i:{if((y[e+416|0]|y[e+417|0]<<8|(y[e+418|0]<<16|y[e+419|0]<<24))==778924148){x[31737]=0;O(418,a|0,16777216);d=x[31737];x[31737]=0;if((d|0)==1){break b}d=x[b>>2];x[31737]=0;d=R(155,d|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break b}x[31737]=0;P(150,b|0,d-4|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break b}x[31737]=0;u=R(152,b|0)|0;d=x[31737];x[31737]=0;if((d|0)!=1){break i}break b}j:{k:{l:{m:{n:{o:{if(((y[e+456|0]|y[e+457|0]<<8)-2185&65535)>>>0>1910){break o}d=x[b>>2];x[31737]=0;d=R(155,d|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break b}x[31737]=0;P(150,b|0,d-4|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break b}x[31737]=0;u=R(152,b|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break b}if(u>>>0<256){break o}d=x[b>>2];x[31737]=0;d=R(155,d|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break b}if(d>>>0<=u>>>0){break o}x[31737]=0;d=P(150,b|0,u|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break b}if(!d){break o}x[31737]=0;d=R(419,b|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break b}if(!d){break o}x[31737]=0;O(418,a|0,16777216);d=x[31737];x[31737]=0;if((d|0)==1){break b}d=y[e+456|0]|y[e+457|0]<<8;if(d>>>0>=4096){x[31737]=0;c=P(1,e+160|0,16564)|0;b=x[31737];x[31737]=0;if((b|0)==1){break h}a=x[a+1298472>>2];x[31737]=0;S(386,a|0,1,c|0);a=x[31737];x[31737]=0;if((a|0)!=1){tb(c);f=0;break d}b=N()|0;tb(c);break a}if(d>>>0<2194){break o}x[31737]=0;d=P(1,e+388|0,16093)|0;f=x[31737];x[31737]=0;if((f|0)==1){break n}f=x[a+1298472>>2];x[31737]=0;S(386,f|0,4,d|0);f=x[31737];x[31737]=0;if((f|0)==1){break m}tb(d)}if(x[a+480180>>2]!=32){break i}d=y[e+456|0]|y[e+457|0]<<8;if((d&61440)!=20480){break j}d=d&4095;f=d<<16;if((y[e+476|0]|y[e+477|0]<<8|(y[e+478|0]<<16|y[e+479|0]<<24))!=1414548815){break l}v[e+415|0]=1;break k}b=N()|0;break a}b=N()|0;tb(d);break a}if(d>>>0<297){break k}f=y[e+476|0]|y[e+477|0]<<8|f}x[a+1074308>>2]=f;break i}f=y[e+458|0]|y[e+459|0]<<8;if(!((f|0)!=2184&(d|0)!=2184)){v[e+415|0]=1;x[a+1074308>>2]=18284544;break i}if((d|0)!=768){if((d|0)!=532|(f|0)!=514|(y[e+476|0]|y[e+477|0]<<8|(y[e+478|0]<<16|y[e+479|0]<<24))){break i}x[a+1074308>>2]=17367040;x[31737]=0;d=P(1,e+376|0,14761)|0;f=x[31737];x[31737]=0;if((f|0)!=1){Ab(j,d);tb(d);v[e+415|0]=1;break i}b=N()|0;break a}if(y[e+476|0]|y[e+477|0]<<8|(y[e+478|0]<<16|y[e+479|0]<<24)|(f|0)!=768|((y[e+448|0]|y[e+449|0]<<8)!=256|y[e+468|0]!=128)){break i}if(y[e+469|0]){break i}x[a+1074308>>2]=18285088;v[e+415|0]=1}d=y[e+460|0]|y[e+461|0]<<8;f=d>>>2|0;x[a+480208>>2]=d<<3&32768|(f&8|(f&4|(x[a+480208>>2]&-32797|d<<1&16)));f=e+280|0;as(f,e+420|0);x[31737]=0;d=e+160|0;O(219,d|0,f|0);f=x[31737];x[31737]=0;if((f|0)==1){break g}Ab(a+1298308|0,d);tb(d);if(!(!(y[e+462|0]&4)|x[a+1074308>>2]-18285314>>>0>4276681982)){x[a+480216>>2]=y[e+446|0];x[a+480220>>2]=y[e+447|0]}d=y[e+464|0];x[a+480200>>2]=d>>>0>128?256:d<<1;d=y[e+466|0];if(d){x[a+480196>>2]=d}v[e+160|0]=31;v[e+280|0]=y[e+467|0];d=e+160|0;f=e+280|0;M=a,T=D(y[df(d,f)|0],1e4),x[M+480204>>2]=T;v[e+160|0]=y[e+465|0];v[e+280|0]=128;M=a,T=y[Qb(d,f)|0],x[M+480228>>2]=T;f=0;while(1){if((f|0)==64){p:{x[31737]=0;P(150,b|0,192)|0;d=x[31737];x[31737]=0;if((d|0)==1){break b}if(x[a+480180>>2]==16777216){if(((y[e+456|0]|y[e+457|0]<<8)-2187&65535)>>>0<=2){break p}}d=y[a+484376|0];f=x[a+484360>>2];x[31737]=0;aa(349,Xb(f,d)|0,b|0,y[e+448|0]|y[e+449|0]<<8,255,254);d=x[31737];x[31737]=0;if((d|0)==1){break b}break e}}else{h=(e+416|0)+f|0;i=h- -64|0;q:{if(y[i|0]==255){break q}g=(f<<5)+a|0;d=g+480280|0;We(d);M=g+480286|0,T=Kd(y[h+128|0],0,64),w[M>>1]=T;h=v[i|0];if((h|0)<0){x[d>>2]=x[d>>2]|1024}h=h&127;if(h>>>0<=64){w[g+480284>>1]=h<<2;break q}if((h|0)!=100){break q}x[d>>2]=x[d>>2]|256}f=f+1|0;continue}break}f=0;x[31737]=0;d=R(190,b|0)|0;g=x[31737];x[31737]=0;if((g|0)==1){break f}if(d){break d}x[31737]=0;d=R(152,b|0)|0;g=x[31737];x[31737]=0;r:{if((g|0)==1){break r}if(d>>>0>4e3){break d}g=y[a+484376|0];h=x[a+484360>>2];x[31737]=0;d=U(420,Xb(h,g)|0,b|0,d|0)|0;g=x[31737];x[31737]=0;if((g|0)==1){break r}if(!d){break d}break e}b=N()|0;break a}b=N()|0;break a}b=N()|0;break a}b=N()|0;break a}r=Nb(e+364|0);q=Nb(e+352|0);f=0;o=Nb(e+340|0);x[31737]=0;d=U(421,b|0,r|0,y[e+450|0]|y[e+451|0]<<8)|0;g=x[31737];x[31737]=0;s:{t:{u:{if((g|0)==1){break u}if(!d){break s}x[31737]=0;d=U(421,b|0,q|0,y[e+452|0]|y[e+453|0]<<8)|0;g=x[31737];x[31737]=0;if((g|0)==1){break u}if(!d){break s}x[31737]=0;d=U(421,b|0,o|0,y[e+454|0]|y[e+455|0]<<8)|0;g=x[31737];x[31737]=0;if((g|0)==1){break u}if(!d){break s}x[e+336>>2]=-1;M=e,T=wb(x[r>>2]),x[M+160>>2]=T;g=wb(x[r+4>>2]);d=x[e+336>>2];while(1){f=x[e+160>>2];if(Ib(f,g)){f=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);if(!(!f|d>>>0<=f>>>0)){x[e+336>>2]=f;d=f}Je(e+160|0);continue}else{M=e,T=wb(x[q>>2]),x[M+160>>2]=T;g=wb(x[q+4>>2]);d=x[e+336>>2];while(1){f=x[e+160>>2];if(Ib(f,g)){f=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);if(!(!f|d>>>0<=f>>>0)){x[e+336>>2]=f;d=f}Je(e+160|0);continue}else{M=e,T=wb(x[o>>2]),x[M+160>>2]=T;g=wb(x[o+4>>2]);d=x[e+336>>2];v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{while(1){f=x[e+160>>2];if(Ib(f,g)){f=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);if(!(!f|d>>>0<=f>>>0)){x[e+336>>2]=f;d=f}Je(e+160|0);continue}else{if(v[e+462|0]&1){x[e+160>>2]=y[e+472|0]|y[e+473|0]<<8|(y[e+474|0]<<16|y[e+475|0]<<24);d=x[Gb(e+336|0,e+160|0)>>2];x[e+336>>2]=d}f=0;if((y[e+458|0]|y[e+459|0]<<8)!=532){break D}g=y[e+456|0]|y[e+457|0]<<8;if(y[e+447|0]|(g?(g|0)!=532:0)|(y[e+446|0]|y[e+469|0])){break D}if(y[e+460|0]&192|(y[e+476|0]|y[e+477|0]<<8|(y[e+478|0]<<16|y[e+479|0]<<24))){break D}if(y[e+450|0]|y[e+451|0]<<8){break E}g=y[e+452|0]|y[e+453|0]<<8;if(!g){break E}if((x[b+8>>2]+(oc(x[q>>2],x[q+4>>2])<<2)|0)+2>>>0>d>>>0){break E}}break}while(1){d=f&65535;if(d>>>0<(g&65535)>>>0){x[31737]=0;g=R(152,b|0)|0;h=x[31737];x[31737]=0;F:{if((h|0)!=1){if(!g){break F}Gh(b,(d<<2)+4|0);break E}b=N()|0;break t}f=f+1|0;g=y[e+452|0]|y[e+453|0]<<8;continue}break}x[31737]=0;d=P(1,e+324|0,15076)|0;f=x[31737];x[31737]=0;if((f|0)==1){break C}Ab(j,d);tb(d)}f=1;if(y[e+456|0]|y[e+457|0]<<8){break D}x[31737]=0;d=P(1,e+312|0,15529)|0;g=x[31737];x[31737]=0;if((g|0)==1){break B}Ab(j,d);tb(d)}d=y[e+462|0]|y[e+463|0]<<8;G:{if(d&2){x[31737]=0;g=R(190,b|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break w}d=x[b+8>>2];h=x[b>>2];x[31737]=0;i=d;d=g<<3;h=U(151,h|0,i|0,d|0)|0;i=x[31737];x[31737]=0;if((i|0)==1){break w}if(!(!h|A[e+336>>2]<d+x[b+8>>2]>>>0)){x[31737]=0;O(422,a+1298412|0,g|0);d=x[31737];x[31737]=0;if((d|0)==1){break w}M=e,T=wb(x[a+1298412>>2]),x[M+280>>2]=T;h=wb(x[a+1298416>>2]);H:{I:{while(1){d=x[e+280>>2];if(!Ib(d,h)){if(!(!g&f)){break G}if(!(y[e+462|0]&4)){break H}x[31737]=0;d=P(1,e+300|0,15562)|0;f=x[31737];x[31737]=0;if((f|0)==1){break I}Ab(j,d);tb(d);break G}x[31737]=0;O(423,b|0,e+160|0);i=x[31737];x[31737]=0;if((i|0)!=1){x[d>>2]=0;x[d+4>>2]=0;x[d+24>>2]=0;x[d+28>>2]=0;x[d+8>>2]=0;x[d+12>>2]=0;x[d+16>>2]=0;i=y[e+160|0]|y[e+161|0]<<8;if(i|(y[e+162|0]|y[e+163|0]<<8)){x[d>>2]=((i&65024)>>>9|0)+1980;M=d,T=Yb((y[e+160|0]|y[e+161|0]<<8)>>>5&15,1,12),x[M+4>>2]=T;M=d,T=Yb((y[e+160|0]|y[e+161|0]<<8)&31,1,31),x[M+8>>2]=T;M=d,T=Yb((y[e+162|0]|y[e+163|0]<<8)>>>11|0,0,23),x[M+12>>2]=T;M=d,T=Yb((y[e+162|0]|y[e+163|0]<<8)>>>5&63,0,59),x[M+16>>2]=T;i=Yb((y[e+162|0]|y[e+163|0]<<8)<<1&62,0,59);x[d+24>>2]=i;x[d+28>>2]=i>>31}x[d+32>>2]=y[e+164|0]|y[e+165|0]<<8|(y[e+166|0]<<16|y[e+167|0]<<24);x[e+280>>2]=x[e+280>>2]+40;continue}break}b=N()|0;break t}b=N()|0;break t}x[31737]=0;d=P(1,e+300|0,15098)|0;f=x[31737];x[31737]=0;if((f|0)!=1){Ab(j,d);tb(d);break G}b=N()|0;break t}Gh(b,2);break G}if(f^1|d>>>0>1){break G}x[31737]=0;d=R(190,b|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break v}if(!d){x[31737]=0;d=P(1,e+300|0,15076)|0;f=x[31737];x[31737]=0;if((f|0)!=1){Ab(j,d);tb(d);break G}b=N()|0;break t}Gh(b,2)}J:{if(!(y[e+460|0]&128|y[e+462|0]&8)){break J}x[31737]=0;d=a+901404|0;f=P(424,b|0,d|0)|0;g=x[31737];x[31737]=0;if((g|0)==1){break A}if(!f){break J}zD(d)}if((y[e+456|0]|y[e+457|0]<<8)>>>0<=531){pr(a+901404|0)}x[31737]=0;B=R(169,e+280|0)|0;d=x[31737];x[31737]=0;K:{L:{M:{if((d|0)!=1){x[31737]=0;f=P(413,b|0,13951)|0;d=x[31737];x[31737]=0;if((d|0)==1){break M}if(f){x[31737]=0;g=R(152,b|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break L}x[31737]=0;d=e+260|0;S(186,d|0,b|0,g|0);g=x[31737];x[31737]=0;if((g|0)==1){break L}g=ic(e+160|0,d);hd(B,g);ub(g);ub(d)}w[a+480188>>1]=1;x[31737]=0;d=P(413,b|0,13956)|0;g=x[31737];x[31737]=0;if((g|0)==1){break M}if(!d){break y}x[31737]=0;d=R(152,b|0)|0;f=x[31737];x[31737]=0;if((f|0)!=1){x[31737]=0;S(186,e+260|0,b|0,d|0);d=x[31737];x[31737]=0;if((d|0)!=1){break K}}b=N()|0;break x}b=N()|0;break t}b=N()|0;break x}b=N()|0;break x}f=e+260|0;d=ic(e+160|0,f);ub(f);g=x[d>>2];x[31737]=0;g=R(155,g|0)|0;h=x[31737];x[31737]=0;if((h|0)==1){break z}w[e+260>>1]=(g>>>0)/20;g=z[Nc(25060,f)>>1];w[a+480188>>1]=g;f=0;while(1){if((f|0)==(g|0)){ub(d);f=1;break y}x[31737]=0;S(425,d|0,((f<<5)+a|0)+480289|0,20);h=x[31737];x[31737]=0;if((h|0)!=1){f=f+1|0;continue}break}break z}b=N()|0;break t}b=N()|0;break t}b=N()|0;break t}b=N()|0;ub(d);break x}N:{O:{P:{Q:{R:{S:{T:{U:{V:{d=x[e+336>>2];g=x[b+8>>2];W:{if(d>>>0>=g>>>0){d=d-g|0;break W}x[31737]=0;d=R(203,b|0)|0;g=x[31737];x[31737]=0;if((g|0)==1){break V}}x[31737]=0;g=e+160|0;S(186,g|0,b|0,d|0);d=x[31737];x[31737]=0;if((d|0)==1){break V}C=ic(e+260|0,g);ub(g);x[31737]=0;d=e+258|0;S(426,d|0,a|0,C|0);g=x[31737];x[31737]=0;if((g|0)==1){break U}E=Jc(d);F=y[e+258|0]!=0|f;if((y[e+456|0]|y[e+457|0]<<8)!=535|(y[e+458|0]|y[e+459|0]<<8)!=512|(y[E|0]|(y[e+476|0]|y[e+477|0]<<8|(y[e+478|0]<<16|y[e+479|0]<<24)))){break Q}X:{if(F){break X}f=Xb(x[a+484360>>2],y[a+484376|0]);d=x[f+4>>2];if(!mc(x[f>>2],d)){if(z[Mn(d)>>1]==65535){break X}}if(!fu(e+480|0,255,64)){break S}}x[a+1074308>>2]=18219008;x[31737]=0;d=P(1,e+244|0,14933)|0;f=x[31737];x[31737]=0;if((f|0)==1){break T}break R}b=N()|0;break x}b=N()|0;break N}b=N()|0;break N}x[a+1074308>>2]=18284544;x[31737]=0;d=P(1,e+244|0,16915)|0;f=x[31737];x[31737]=0;if((f|0)==1){break P}}Ab(j,d);tb(d);v[e+415|0]=1}Y:{if(!(v[e+462|0]&1)|!(y[e+470|0]|y[e+471|0]<<8)){break Y}x[31737]=0;d=P(150,b|0,y[e+472|0]|y[e+473|0]<<8|(y[e+474|0]<<16|y[e+475|0]<<24))|0;f=x[31737];x[31737]=0;if((f|0)==1){break O}if(!d){break Y}x[31737]=0;V(337,a+1298332|0,b|0,y[e+470|0]|y[e+471|0]<<8,4);d=x[31737];x[31737]=0;if((d|0)==1){break O}}w[a+480192>>1]=0;d=0;if(y[e+460|0]&4){w[e+160>>1]=y[e+450|0]|y[e+451|0]<<8;w[e+100>>1]=255;d=z[Nc(e+160|0,e+100|0)>>1];w[a+480192>>1]=d}f=0;Z:{while(1){if((d&65535)>>>0<=f>>>0){x[e+240>>2]=0;f=y[e+452|0]|y[e+453|0]<<8;if(f){d=yb(x[q>>2],f-1|0);x[e+240>>2]=(y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24))+80}w[e+160>>1]=f;w[e+100>>1]=3999;d=z[Nc(e+160|0,e+100|0)>>1];w[a+480190>>1]=d;n=c&2;s=e+180|0;f=0;while(1){_:{$:{aa:{ba:{ca:{da:{ea:{fa:{ga:{if((d&65535)>>>0>f>>>0){d=yb(x[q>>2],f);d=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);if(!d){break $}x[31737]=0;d=P(150,b|0,d|0)|0;g=x[31737];x[31737]=0;ha:{ia:{ja:{ka:{la:{if((g|0)==1){break la}if(!d){break $}x[31737]=0;d=e+160|0;g=P(427,b|0,d|0)|0;h=x[31737];x[31737]=0;if((h|0)==1){break la}if(!g){break $}x[31737]=0;g=f+1|0;h=D(g,104)+a|0;i=h+484380|0;k=P(428,d|0,i|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break ka}l=e+148|0;as(l,s);x[31737]=0;d=e+100|0;O(219,d|0,l|0);l=x[31737];x[31737]=0;if((l|0)==1){break ja}zc(((g<<5)+a|0)+946304|0,d);tb(d);x[31737]=0;k=P(150,b|0,k|0)|0;l=x[31737];x[31737]=0;if((l|0)==1){break ka}if(!k){break $}h=z[h+484414>>1];if(!(h&512)){break ia}x[31737]=0;d=P(429,b|0,d|0)|0;g=x[31737];x[31737]=0;if((g|0)==1){break ga}if(!d){break ha}x[e+16>>2]=y[e+108|0]|y[e+109|0]<<8|(y[e+110|0]<<16|y[e+111|0]<<24);d=y[e+104|0]|y[e+105|0]<<8|(y[e+106|0]<<16|y[e+107|0]<<24);x[e+8>>2]=y[e+100|0]|y[e+101|0]<<8|(y[e+102|0]<<16|y[e+103|0]<<24);x[e+12>>2]=d;Yk(i,1,e+8|0);break ha}b=N()|0;break N}b=N()|0;break N}b=N()|0;break N}if(!(h&16384)){l=y[e+456|0]|y[e+457|0]<<8;t=e+100|0;h=y[e+178|0];k=h&2;d=y[e+206|0];g=Xc(t,k?16:8,1,0,(d^-1)&1);if(!(!(h&4)|l>>>0<532)){Bp(g,3)}ma:{na:{if(h&8){h=d&4?5:4;break na}if(!k){h=10;if((d|0)==255){break na}}if(d&2){v[g+2|0]=1}if(d&4){yg(g,2)}if(!(d&8)){break ma}h=9;if(!k){break ma}}yg(g,h)}if(n){d=0;x[31737]=0;U(216,t|0,i|0,b|0)|0;g=x[31737];x[31737]=0;if((g|0)!=1){break ca}break _}d=1;g=y[e+103|0];if(g>>>0>17){break ba}h=1<<g;if(!(h&63503)){if(!(h&198144)){break ba}break da}if(y[e+100|0]){break da}break ca}x[31737]=0;O(430,b|0,e+88|0);d=x[31737];x[31737]=0;if((d|0)==1){break ea}h=x[e+88>>2];if(!(!n|!h)){d=Fb(e+100|0);x[31737]=0;S(271,b|0,d|0,h|0);h=x[31737];x[31737]=0;oa:{pa:{qa:{ra:{sa:{ta:{ua:{if((h|0)!=1){x[31737]=0;h=e+136|0;O(384,h|0,16486);i=x[31737];x[31737]=0;if((i|0)==1){break ua}x[e+76>>2]=g;x[31737]=0;g=e+124|0;S(259,g|0,0,d|0);i=x[31737];x[31737]=0;if((i|0)==1){break ta}x[31737]=0;i=e+148|0;V(431,i|0,h|0,e+76|0,g|0);k=x[31737];x[31737]=0;if((k|0)==1){break sa}k=x[a+1298472>>2];x[31737]=0;S(386,k|0,2,i|0);k=x[31737];x[31737]=0;if((k|0)==1){break ra}tb(i);tb(g);Eb(h);tb(d);break ha}b=N()|0;break oa}b=N()|0;break oa}b=N()|0;break pa}b=N()|0;break qa}b=N()|0;tb(e+148|0)}tb(e+124|0)}Eb(e+136|0)}tb(d);break N}x[31737]=0;P(184,b|0,h|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break ea}}d=0;break aa}w[e+160>>1]=1;w[e+100>>1]=d;M=a,T=z[pe(e+160|0,e+100|0)>>1],w[M+480190>>1]=T;if(!((y[e+456|0]|y[e+457|0]<<8)==516&m)|(y[e+458|0]|y[e+459|0]<<8)!=512|(y[e+462|0]|y[e+463|0]<<8|(y[e+476|0]|y[e+477|0]<<8|(y[e+478|0]<<16|y[e+479|0]<<24)))){break fa}if(((y[e+460|0]|y[e+461|0]<<8)&65527)!=21|y[e+464|0]!=128|(y[e+465|0]!=48|y[e+468|0]!=128)){break fa}if(y[e+469|0]|(y[e+470|0]|y[e+471|0]<<8)){break fa}d=e+544|0;g=e+480|0;f=1;while(1)if((d|0)==(g|0)){g=e+608|0;while(1)if((d|0)==(g|0)){d=20;while(1){if((d|0)==26){va:{if(!(f&1)){break fa}x[31737]=0;d=P(1,e+148|0,9895)|0;f=x[31737];x[31737]=0;if((f|0)==1){break va}Ab(j,d);tb(d);break fa}}else{f=!y[(e+d|0)+420|0]&f;d=d+1|0;continue}break}b=N()|0;break N}else{f=y[d|0]==64&f;d=d+1|0;continue}}else{f=(y[g|0]&127)==32&f;g=g+1|0;continue}}b=N()|0;break N}x[a+480260>>2]=0;x[a+480264>>2]=2147483647;f=oc(x[o>>2],x[o+4>>2]);w[e+160>>1]=f;d=e+160|0;s=z[Nc(d,x[a+8>>2]+10|0)>>1];w[e+122>>1]=s;wa:{xa:{ya:{za:{if((f|0)!=(s|0)){x[31737]=0;f=e+100|0;W(432,f|0);g=x[31737];x[31737]=0;if((g|0)==1){break wa}g=x[o+4>>2];h=x[o>>2];x[31737]=0;M=e,T=oc(h,g),x[M+136>>2]=T;V(433,d|0,f|0,e+136|0,e+122|0);g=x[31737];x[31737]=0;if((g|0)==1){break ya}g=x[a+1298472>>2];x[31737]=0;S(386,g|0,2,d|0);g=x[31737];x[31737]=0;if((g|0)==1){break za}tb(d);Eb(f)}if(!(c&1)){w[e+122>>1]=0;s=0}h=0;Aa:{Ba:{Ca:{Da:{Ea:{Fa:{Ga:{Ha:{Ia:{Ja:{Ka:{La:{Ma:{Na:{Oa:{Pa:{Qa:{while(1){Ra:{if((h|0)==(s|0)){c=x[e+240>>2];if(!c){break Oa}x[31737]=0;P(150,b|0,c|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break Qa}if(!t){break Oa}while(1){Sa:{c=x[b+8>>2];d=x[b>>2];x[31737]=0;c=U(151,d|0,c|0,4)|0;d=x[31737];x[31737]=0;if((d|0)==1){break Sa}if(!c){break Oa}x[31737]=0;c=P(413,b|0,13930)|0;d=x[31737];x[31737]=0;if((d|0)==1){break Sa}Ta:{if(!c){x[31737]=0;c=P(413,b|0,13935)|0;d=x[31737];x[31737]=0;if((d|0)==1){break Sa}if(!c){break Ta}}x[31737]=0;c=R(152,b|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break Pa}Gh(b,8);if(c&-2139062144){break Ta}if(c&1616928864){break Oa}}x[31737]=0;c=R(190,b|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break Sa}x[31737]=0;P(184,b|0,c|0)|0;c=x[31737];x[31737]=0;if((c|0)!=1){continue}}break}b=N()|0;break N}Ua:{c=yb(x[o>>2],h);c=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);Va:{if(!c){break Va}x[31737]=0;c=P(150,b|0,c|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break Na}if(!c){break Va}x[31737]=0;d=R(190,b|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break Aa}x[31737]=0;n=R(190,b|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break Ba}if((n-1025&65535)>>>0<64512){break Va}x[31737]=0;c=P(184,b|0,4)|0;f=x[31737];x[31737]=0;if((f|0)==1){break Ba}if(!c){break Va}x[31737]=0;c=e+100|0;S(186,c|0,b|0,d|0);d=x[31737];x[31737]=0;if((d|0)==1){break Ca}d=ic(e+160|0,c);ub(c);c=z[a+480188>>1];m=0;x[31737]=0;g=P(434,e+136|0,c|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break Ea}Wa:{Xa:while(1){k=m>>>0>=n>>>0;while(1){if(k){break Wa}c=x[d>>2];x[31737]=0;c=U(151,c|0,x[e+168>>2],1)|0;f=x[31737];x[31737]=0;if((f|0)==1){break Ua}if(!c){break Wa}x[31737]=0;c=R(198,d|0)|0;f=x[31737];x[31737]=0;Ya:{if((f|0)!=1){c=c<<24>>24;if(c){break Ya}m=m+1|0;continue Xa}break Ra}Za:{f=c&127;l=f?f+65535|0:0;i=l&65535;if(Vc(x[g>>2],x[e+140>>2])>>>0>i>>>0){break Za}x[31737]=0;v[e+100|0]=0;S(435,g|0,i+1|0,e+100|0);f=x[31737];x[31737]=0;if((f|0)!=1){break Za}break Ra}_a:{if((c|0)<0){x[31737]=0;c=R(198,d|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break _a}M=xb(x[g>>2],i),T=c,v[M|0]=T}f=xb(x[g>>2],i);c=y[f|0];if(!(!(c&15)|i>>>0<z[a+480188>>1])){w[a+480188>>1]=l+1;c=y[f|0]}if(c&1){x[31737]=0;P(184,d|0,1)|0;c=x[31737];x[31737]=0;if((c|0)==1){break _a}f=xb(x[g>>2],i)}if(y[f|0]&2){x[31737]=0;P(184,d|0,1)|0;c=x[31737];x[31737]=0;if((c|0)==1){break _a}f=xb(x[g>>2],i)}if(y[f|0]&4){x[31737]=0;P(184,d|0,1)|0;c=x[31737];x[31737]=0;if((c|0)==1){break _a}f=xb(x[g>>2],i)}if(!(y[f|0]&8)){continue}x[31737]=0;P(184,d|0,2)|0;c=x[31737];x[31737]=0;if((c|0)!=1){continue}}break}break}break Ra}x[e+100>>2]=x[b+8>>2];M=e,T=x[ad(e+240|0,e+100|0)>>2],x[M+240>>2]=T;dc(g);ub(d)}h=h+1|0;continue}}break}b=N()|0;dc(g);break Da}b=N()|0;break N}b=N()|0;break N}x[31737]=0;t=P(436,a|0,b|0)|0;c=x[31737];x[31737]=0;if((c|0)!=1){c=t|y[e+415|0];v[e+415|0]=c;if(!(y[E|0]|!(c&255))){Qv(a+1074312|0);v[a+1074368|0]=0}x[31737]=0;H=ba(437,a|0,b|0,0,e+415|0)|0;c=x[31737];x[31737]=0;$a:{if((c|0)==1){break $a}x[31737]=0;l=a+484344|0;O(224,l|0,s|0);c=x[31737];x[31737]=0;if((c|0)==1){break $a}L=a+480183|0;h=0;while(1){ab:{bb:{cb:{db:{eb:{fb:{gb:{hb:{ib:{jb:{kb:{lb:{mb:{nb:{ob:{pb:{qb:{rb:{sb:{tb:{if((h|0)!=(s|0)){c=yb(x[o>>2],h);c=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);if(c){x[31737]=0;c=P(150,b|0,c|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break ob}if(c){break nb}}x[31737]=0;c=U(197,l|0,h&65535,64)|0;d=x[31737];x[31737]=0;if((d|0)==1){break ob}if(c){break pb}w[e+64>>1]=h;x[31737]=0;c=e+100|0;W(438,c|0);d=x[31737];x[31737]=0;if((d|0)==1){break tb}x[31737]=0;d=e+160|0;S(439,d|0,c|0,e- -64|0);f=x[31737];x[31737]=0;if((f|0)==1){break sb}f=x[a+1298472>>2];x[31737]=0;S(386,f|0,2,d|0);f=x[31737];x[31737]=0;if((f|0)==1){break rb}tb(d);Eb(c)}if(!x[a+1074308>>2]){f=y[e+456|0]|y[e+457|0]<<8;if((f|0)!=2184){break lb}x[a+1074308>>2]=18284544}if(!Ad(x[j+4>>2],y[j+11|0])){break mb}x[31737]=0;c=P(1,e+100|0,18273)|0;d=x[31737];x[31737]=0;if((d|0)==1){break cb}f=x[a+1074308>>2];x[31737]=0;d=e+76|0;O(135,d|0,f|0);f=x[31737];x[31737]=0;if((f|0)==1){break eb}x[31737]=0;f=e+160|0;S(2,f|0,c|0,d|0);g=x[31737];x[31737]=0;if((g|0)==1){break fb}g=Ab(j,f);tb(f);tb(d);tb(c);f=x[a+1074308>>2];if((y[e+476|0]|y[e+477|0]<<8|(y[e+478|0]<<16|y[e+479|0]<<24))==1414548815){break kb}if((f|0)!=18284544){break jb}f=18284544;if(!(t|(F|H))){break ib}break hb}b=N()|0;break N}b=N()|0;break qb}b=N()|0;tb(e+160|0)}Eb(e+100|0);break N}c=x[l>>2];x[31737]=0;O(440,Wb(c,h)|0,B|0);c=x[31737];x[31737]=0;if((c|0)!=1){break ab}}b=N()|0;break N}x[31737]=0;d=R(190,b|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break Fa}x[31737]=0;I=R(190,b|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break Ga}x[31737]=0;c=P(184,b|0,4)|0;f=x[31737];x[31737]=0;if((f|0)==1){break Ga}if(!c){break ab}x[31737]=0;c=U(197,l|0,h&65535,I|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break Ga}if(!c){break ab}x[31737]=0;c=e+100|0;S(186,c|0,b|0,d|0);d=x[31737];x[31737]=0;if((d|0)==1){break Ha}n=ic(e+160|0,c);ub(c);d=x[l>>2];x[31737]=0;O(440,Wb(d,h)|0,B|0);d=x[31737];x[31737]=0;if((d|0)==1){break Ja}d=z[a+480188>>1];x[31737]=0;k=P(434,e+124|0,d|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break Ka}d=z[a+480188>>1];w[e+104>>1]=0;x[31737]=0;x[e+100>>2]=0;m=U(441,e+88|0,d|0,c|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break Ma}M=e,T=wb(x[Wb(x[l>>2],h)>>2]),x[M+76>>2]=T;G=0;while(1){ub:{vb:{wb:{xb:{if(G>>>0>=I>>>0){break xb}c=x[n>>2];x[31737]=0;c=U(151,c|0,x[e+168>>2],1)|0;d=x[31737];x[31737]=0;if((d|0)==1){break bb}if(!c){break xb}x[31737]=0;c=R(198,n|0)|0;d=x[31737];x[31737]=0;yb:{if((d|0)!=1){c=c<<24>>24;if(c){break yb}J_(e+76|0,z[a+480188>>1]);G=G+1|0;continue}break bb}zb:{d=c&127;i=d?d-1&65535:0;if(Vc(x[k>>2],x[e+128>>2])>>>0>i>>>0){break zb}x[31737]=0;v[e+100|0]=0;d=i+1|0;f=e+100|0;S(435,k|0,d|0,f|0);g=x[31737];x[31737]=0;if((g|0)==1){break bb}w[e+104>>1]=0;x[31737]=0;x[e+100>>2]=0;S(442,m|0,d|0,f|0);d=x[31737];x[31737]=0;if((d|0)!=1){break zb}break bb}if((c|0)<0){x[31737]=0;c=R(198,n|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break bb}M=xb(x[k>>2],i),T=c,v[M|0]=T}w[e+104>>1]=0;x[e+100>>2]=0;d=e+100|0;if(i>>>0<z[a+480188>>1]){d=Wc(x[e+76>>2],i)}g=xb(x[k>>2],i);f=y[g|0];if(f&16){M=d,T=y[Wc(x[m>>2],i)|0],v[M|0]=T;f=y[g|0]}if(f&32){M=d,T=y[Wc(x[m>>2],i)+1|0],v[M+1|0]=T;f=y[g|0]}if(f&64){c=Wc(x[m>>2],i);v[d+2|0]=y[c+2|0];v[d+4|0]=y[c+4|0];f=y[g|0]}if(f<<24>>24<0){c=Wc(x[m>>2],i);v[d+3|0]=y[c+3|0];v[d+5|0]=y[c+5|0];f=y[g|0]}if(f&1){x[31737]=0;c=R(198,n|0)|0;f=x[31737];x[31737]=0;Ab:{Bb:{if((f|0)!=1){c=c<<24>>24;c=(((c^-1)&128)>>>7|0)+c|0;if(!(v[L|0]&1)){break Bb}f=c;break Ab}break bb}f=253;if((c-121&255)>>>0<132){break Ab}f=(c&255)!=253?c:0}v[d|0]=f;M=Wc(x[m>>2],i),T=f,v[M|0]=T;g=xb(x[k>>2],i)}if(y[g|0]&2){x[31737]=0;c=R(198,n|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break bb}v[d+1|0]=c;M=Wc(x[m>>2],i),T=c,v[M+1|0]=T;g=xb(x[k>>2],i)}if(!(y[g|0]&4)){break ub}x[31737]=0;g=R(198,n|0)|0;c=x[31737];x[31737]=0;Cb:{Db:{if((c|0)!=1){if(g>>>0>64){break Db}v[d+4|0]=g;f=1;break Cb}break bb}if(g<<24>>24<=-64){f=2;v[d+2|0]=2;g=g^-128;v[d+4|0]=g;break vb}if(g>>>0<=74){f=5;v[d+2|0]=5;g=g-65|0;v[d+4|0]=g;break vb}if(g>>>0<=84){f=6;v[d+2|0]=6;g=g-75|0;v[d+4|0]=g;break vb}if(g>>>0<=94){f=3;v[d+2|0]=3;g=g-85|0;v[d+4|0]=g;break vb}if(g>>>0<=104){f=4;v[d+2|0]=4;g=g-95|0;v[d+4|0]=g;break vb}if(g>>>0<=114){f=13;v[d+2|0]=13;g=g-105|0;v[d+4|0]=g;break vb}if(g>>>0<=124){f=12;v[d+2|0]=12;g=g-115|0;v[d+4|0]=g;break vb}c=g+63|0;if((c&255)>>>0<=9){v[d+4|0]=c;f=11;v[d+2|0]=11;g=c;break vb}c=g+53|0;J=c&255;if(J>>>0<=9){v[d+4|0]=c;f=8;v[d+2|0]=8;if(!J){g=0;break vb}if(x[a+1074308>>2]-1>>>0>18285139){break wb}f=7;v[d+2|0]=7;break wb}g=g+33|0;if((g&255)>>>0>=10){g=y[d+4|0];f=y[d+2|0];break vb}v[d+4|0]=g;f=15}v[d+2|0]=f;break vb}Qk(m);dc(k);ub(n);break ab}g=c}c=Wc(x[m>>2],i);v[c+4|0]=g;v[c+2|0]=f;g=xb(x[k>>2],i)}if(!(y[g|0]&8)){continue}x[31737]=0;c=e+52|0;O(199,c|0,n|0);f=x[31737];x[31737]=0;if((f|0)!=1){xD(d,y[e+52|0],y[Jc(c)|0],1);c=Wc(x[m>>2],i);v[c+3|0]=y[d+3|0];v[c+5|0]=y[d+5|0];continue}break}break bb}f=y[e+456|0]|y[e+457|0]<<8}Eb:{Fb:{Gb:{Hb:{Ib:{Jb:{Kb:{Lb:{Mb:{Nb:{Ob:{Pb:{c=f&65535;switch(c>>>12|0){case 13:break Jb;case 7:break Kb;case 6:break Lb;case 4:break Mb;case 1:break Ob;case 0:break Pb;default:break gb}}if(y[E|0]){x[31737]=0;c=P(1,e+160|0,8340)|0;d=x[31737];x[31737]=0;if((d|0)!=1){Ab(j,c);tb(c);break gb}b=N()|0;break N}Qb:{Rb:{Sb:{Tb:{Ub:{Vb:{Wb:{Xb:{Yb:{c=f&65535;if((c|0)!=532){break Yb}d=y[e+458|0]|y[e+459|0]<<8;if((d|0)!=512){break Xb}if(y[e+462|0]|y[e+463|0]<<8|(y[e+460|0]|y[e+461|0]<<8)!=9|(y[e+447|0]|y[e+446|0])){break Yb}if(y[e+450|0]|y[e+451|0]<<8|((y[e+454|0]|y[e+455|0]<<8)+1|0)!=(y[e+448|0]|y[e+449|0]<<8)|(y[e+464|0]!=128|y[e+465|0]!=100)){break Yb}if(y[e+466|0]!=1|y[e+468|0]!=128|(y[e+469|0]|(y[e+470|0]|y[e+471|0]<<8))){break Yb}if(y[e+472|0]|y[e+473|0]<<8|(y[e+474|0]<<16|y[e+475|0]<<24)|(y[e+476|0]|y[e+477|0]<<8|(y[e+478|0]<<16|y[e+479|0]<<24))){break Yb}x[31737]=0;c=P(1,e+160|0,9876)|0;d=x[31737];x[31737]=0;if((d|0)!=1){Ab(j,c);tb(c);break gb}b=N()|0;break N}Zb:{if((c|0)!=514|(y[e+458|0]|y[e+459|0]<<8)!=512|(y[e+447|0]|y[e+446|0])){break Zb}if(y[e+476|0]|y[e+477|0]<<8|(y[e+478|0]<<16|y[e+479|0]<<24)){break Zb}c=x[o>>2];if(mc(c,x[o+4>>2])){break Vb}d=x[q>>2];if(mc(d,x[q+4>>2])){break Vb}c=yb(c,0);g=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);if(!g){break Vb}c=yb(d,0);if(g>>>0>=(y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24))>>>0){break Vb}x[a+1074308>>2]=16777376;x[31737]=0;c=P(1,e+160|0,13487)|0;d=x[31737];x[31737]=0;if((d|0)!=1){Ab(j,c);tb(c);v[e+415|0]=1;break gb}b=N()|0;break N}if((f&65535)!=532){break Wb}d=y[e+458|0]|y[e+459|0]<<8;if((d|0)!=512){break Xb}f=532;if(y[e+447|0]|y[e+446|0]){break Fb}d=512;if(y[e+476|0]|y[e+477|0]<<8|(y[e+478|0]<<16|y[e+479|0]<<24)){break Eb}_b:{if(y[e+462|0]&6){$b:{d=x[r>>2];if(oc(d,x[r+4>>2])>>>0<2){break $b}c=yb(d,1);f=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);c=yb(d,0);if((f-(y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24))|0)!=557){break $b}x[a+1074308>>2]=16777394;x[31737]=0;c=P(1,e+160|0,15309)|0;d=x[31737];x[31737]=0;if((d|0)!=1){break _b}b=N()|0;break N}x[a+1074308>>2]=16777393;x[31737]=0;c=P(1,e+160|0,13377)|0;d=x[31737];x[31737]=0;if((d|0)!=1){break _b}b=N()|0;break N}x[a+1074308>>2]=16777381;x[31737]=0;c=P(1,e+160|0,15014)|0;d=x[31737];x[31737]=0;if((d|0)==1){break Ib}}Ab(j,c);tb(c);v[e+415|0]=1;break gb}f=532;if((d|0)!=532){break Ub}if((y[e+476|0]|y[e+477|0]<<8|(y[e+478|0]<<16|y[e+479|0]<<24))==1229080643){x[31737]=0;c=P(1,e+160|0,8378)|0;d=x[31737];x[31737]=0;if((d|0)!=1){Ab(j,c);tb(c);f=a+1074312|0;d=38;break Nb}b=N()|0;break N}if(y[e+469|0]|(y[e+462|0]|y[e+463|0]<<8)>>>0>1|(y[e+476|0]|y[e+477|0]<<8|(y[e+478|0]<<16|y[e+479|0]<<24)|((y[e+460|0]|y[e+461|0]<<8)&4294)!=4)){break Vb}if(!z[a+480190>>1]){break Vb}x[31737]=0;f=P(36,e+100|0,13620)|0;c=x[31737];x[31737]=0;if((c|0)==1){break Sb}c=fb-32|0;fb=c;d=fb-16|0;fb=d;Pw(d+8|0,a+484527|0);AZ(c+24|0,x[d+8>>2],x[d+12>>2]);fb=d+16|0;ee(c+16|0,f);d=x[c+20>>2];x[c+8>>2]=x[c+16>>2];x[c+12>>2]=d;d=Ic(x[c+24>>2],x[c+28>>2],c+8|0);fb=c+32|0;tb(f);if(d){break Tb}f=y[e+456|0]|y[e+457|0]<<8}if(f&65535){break Vb}if(Ad(x[j+4>>2],y[j+11|0])){break Qb}}d=y[e+458|0]|y[e+459|0]<<8}if((d&65535)>>>0>767){break gb}break Eb}x[31737]=0;c=P(1,e+160|0,8404)|0;d=x[31737];x[31737]=0;if((d|0)==1){break Rb}Ab(j,c);tb(c);break gb}b=N()|0;break N}b=N()|0;break N}x[31737]=0;c=P(1,e+160|0,9766)|0;d=x[31737];x[31737]=0;if((d|0)!=1){Ab(j,c);tb(c);break gb}b=N()|0;break N}f=y[e+476|0]|y[e+477|0]<<8|(y[e+478|0]<<16|y[e+479|0]<<24);x[31737]=0;d=e+160|0;S(443,d|0,c|0,y[e+476|0]|y[e+477|0]<<8|(y[e+478|0]<<16|y[e+479|0]<<24));g=x[31737];x[31737]=0;ac:{bc:{cc:{dc:{ec:{fc:{gc:{hc:{ic:{jc:{kc:{lc:{mc:{nc:{if((g|0)!=1){Ab(j,d);tb(d);c=(c|0)==8191?f:c-4176|0;if((c|0)>1915){break nc}d=x[a+480208>>2];if(!(d&16)){break mc}x[31737]=0;P(268,a+1074312|0,7)|0;c=x[31737];x[31737]=0;if((c|0)!=1){break lc}break Gb}b=N()|0;break N}if(c>>>0>4200){break jc}d=x[a+480208>>2]}if(!(d&16)){x[31737]=0;P(268,a+1074312|0,7)|0;d=x[31737];x[31737]=0;if((d|0)==1){break Gb}}if((c|0)>2385){break kc}}x[31737]=0;P(268,a+1074312|0,38)|0;c=x[31737];x[31737]=0;if((c|0)==1){break Gb}}x[31737]=0;c=P(268,a+1074312|0,102)|0;d=x[31737];x[31737]=0;if((d|0)==1){break Gb}x[31737]=0;P(268,c|0,48)|0;c=x[31737];x[31737]=0;if((c|0)==1){break Gb}break ic}if(c>>>0>4383){break hc}}x[31737]=0;c=U(267,a+1074312|0,116,1)|0;d=x[31737];x[31737]=0;if((d|0)==1){break Gb}x[31737]=0;P(268,c|0,115)|0;c=x[31737];x[31737]=0;if((c|0)==1){break Gb}break gc}if(c>>>0>4563){break fc}}x[31737]=0;c=P(268,a+1074312|0,43)|0;d=x[31737];x[31737]=0;if((d|0)==1){break Gb}x[31737]=0;c=P(268,c|0,42)|0;d=x[31737];x[31737]=0;if((d|0)==1){break Gb}x[31737]=0;P(268,c|0,87)|0;c=x[31737];x[31737]=0;if((c|0)==1){break Gb}break ec}if(c>>>0>4876){break dc}}x[31737]=0;P(268,a+1074312|0,120)|0;c=x[31737];x[31737]=0;if((c|0)==1){break Gb}break cc}if(c>>>0>5100){break bc}}x[31737]=0;c=P(268,a+1074312|0,47)|0;d=x[31737];x[31737]=0;if((d|0)==1){break Gb}x[31737]=0;P(268,c|0,39)|0;c=x[31737];x[31737]=0;if((c|0)==1){break Gb}break ac}if(c>>>0>5103){break gb}}x[31737]=0;f=P(268,a+1074312|0,44)|0;c=x[31737];x[31737]=0;d=87;if((c|0)==1){break Gb}}x[31737]=0;P(268,f|0,d|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break Gb}break gb}x[31737]=0;c=e+100|0;W(444,c|0);d=x[31737];x[31737]=0;oc:{pc:{qc:{if((d|0)!=1){d=y[e+456|0]|y[e+457|0]<<8;x[e+64>>2]=d>>>8&15;x[31737]=0;x[e+52>>2]=d&255;d=e+76|0;O(445,d|0,e+52|0);f=x[31737];x[31737]=0;if((f|0)==1){break qc}x[31737]=0;f=e+160|0;V(431,f|0,c|0,e- -64|0,d|0);g=x[31737];x[31737]=0;if((g|0)==1){break pc}Ab(j,f);tb(f);tb(d);Eb(c);break gb}b=N()|0;break N}b=N()|0;break oc}b=N()|0;tb(e+76|0)}Eb(e+100|0);break N}x[31737]=0;c=P(1,e+160|0,8340)|0;d=x[31737];x[31737]=0;if((d|0)!=1){Ab(j,c);tb(c);break gb}b=N()|0;break N}if(!((c|0)!=32767|(y[e+458|0]|y[e+459|0]<<8)!=533)){x[31737]=0;c=P(1,e+160|0,5042)|0;d=x[31737];x[31737]=0;if((d|0)!=1){Ab(j,c);tb(c);break gb}b=N()|0;break N}x[31737]=0;c=e+100|0;O(132,c|0,4150);d=x[31737];x[31737]=0;rc:{if((d|0)!=1){d=y[e+456|0]|y[e+457|0]<<8;x[e+76>>2]=d>>>8&15;x[e+64>>2]=d>>>4&15;x[31737]=0;x[e+52>>2]=d&15;d=e+160|0;aa(133,d|0,c|0,e+76|0,e- -64|0,e+52|0);f=x[31737];x[31737]=0;if((f|0)==1){break rc}Ab(j,d);tb(d);Eb(c);break gb}b=N()|0;break N}b=N()|0;Eb(e+100|0);break N}x[31737]=0;c=P(1,e+160|0,6123)|0;d=x[31737];x[31737]=0;if((d|0)==1){break Hb}Ab(j,c);tb(c);break gb}b=N()|0;break N}b=N()|0;break N}b=N()|0;break N}d=512}if(!Ad(x[j+4>>2],y[j+11|0])){break gb}sc:{tc:{uc:{vc:{wc:{if((d&65535)>>>0>=533){x[31737]=0;c=P(1,e+76|0,15046)|0;d=x[31737];x[31737]=0;if((d|0)!=1){Ab(j,c);tb(c);break wc}b=N()|0;break N}if((f&65535)>>>0>=533){x[31737]=0;c=e+76|0;O(446,c|0,4015);d=x[31737];x[31737]=0;xc:{if((d|0)!=1){x[31737]=0;x[e+64>>2]=(y[e+456|0]|y[e+457|0]<<8)-532;d=e+160|0;S(447,d|0,c|0,e- -64|0);f=x[31737];x[31737]=0;if((f|0)==1){break xc}Ab(j,d);tb(d);Eb(c);break wc}b=N()|0;break N}b=N()|0;Eb(e+76|0);break N}x[31737]=0;c=e+76|0;O(269,c|0,4314);d=x[31737];x[31737]=0;if((d|0)==1){break vc}d=y[e+456|0]|y[e+457|0]<<8;x[e+52>>2]=d>>>8&15;x[31737]=0;x[e+40>>2]=d&255;d=e- -64|0;O(445,d|0,e+40|0);f=x[31737];x[31737]=0;if((f|0)==1){break uc}x[31737]=0;f=e+160|0;V(431,f|0,c|0,e+52|0,d|0);g=x[31737];x[31737]=0;if((g|0)==1){break tc}Ab(j,f);tb(f);tb(d);Eb(c)}if(!mc(x[a+1298412>>2],x[a+1298416>>2])){break gb}c=y[e+476|0]|y[e+477|0]<<8|(y[e+478|0]<<16|y[e+479|0]<<24);if(!c){break gb}c=HF(y[e+456|0]|y[e+457|0]<<8,c);d=op(e+160|0);x[d+32>>2]=c;x[31737]=0;O(448,a+1298412|0,d|0);c=x[31737];x[31737]=0;if((c|0)!=1){break gb}b=N()|0;break N}b=N()|0;break N}b=N()|0;break sc}b=N()|0;tb(e- -64|0)}Eb(e+76|0);break N}if(!(t|((f|0)!=18284544|H|F))){break ib}break hb}if(((y[e+456|0]|y[e+457|0]<<8)&61440)!=20480){break hb}}x[31737]=0;c=P(1,e+160|0,16927)|0;d=x[31737];x[31737]=0;yc:{if((d|0)!=1){x[31737]=0;P(75,g|0,c|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break yc}tb(c);break gb}b=N()|0;break N}b=N()|0;tb(c);break N}if(!ZG(f)){break gb}x[31737]=0;c=P(1,e+160|0,17163)|0;d=x[31737];x[31737]=0;zc:{if((d|0)!=1){x[31737]=0;P(75,g|0,c|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break zc}tb(c);break gb}b=N()|0;break N}b=N()|0;tb(c);break N}Ac:{Bc:{Cc:{Dc:{Ec:{Fc:{Gc:{Hc:{Ic:{if(K&1){x[31737]=0;c=P(1,e- -64|0,17177)|0;d=x[31737];x[31737]=0;if((d|0)==1){break Ic}x[31737]=0;P(75,j|0,c|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break Hc}tb(c)}f=x[a+480180>>2];if(!((f|0)!=16777216|(y[e+456|0]|y[e+457|0]<<8)>>>0<2186)){x[31737]=0;c=P(150,b|0,u|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break $a}if(c){x[31737]=0;S(449,a|0,b|0,y[e+456|0]|y[e+457|0]<<8);b=x[31737];x[31737]=0;if((b|0)==1){break $a}}f=x[a+480180>>2]}if((f|0)!=16777216){break Gc}x[31737]=0;P(1,e+52|0,13913)|0;b=x[31737];x[31737]=0;if((b|0)!=1){break Fc}b=N()|0;break N}b=N()|0;break N}b=N()|0;tb(c);break N}x[31737]=0;b=e+40|0;O(269,b|0,4314);c=x[31737];x[31737]=0;if((c|0)==1){break Ec}c=y[e+458|0]|y[e+459|0]<<8;x[e+36>>2]=c>>>8;x[31737]=0;x[e+20>>2]=c&255;c=e+24|0;O(445,c|0,e+20|0);d=x[31737];x[31737]=0;if((d|0)==1){break Dc}x[31737]=0;V(431,e+52|0,b|0,e+36|0,c|0);b=x[31737];x[31737]=0;if((b|0)==1){break Cc}}b=e+52|0;Ab(a+1298344|0,b);tb(b);if((f|0)!=16777216){tb(e+24|0);Eb(e+40|0)}b=x[a+480180>>2];x[31737]=0;b=P(1,e+52|0,((b|0)==16777216?10140:6127)|0)|0;c=x[31737];x[31737]=0;f=1;if((c|0)==1){break Ac}Ab(a+1298356|0,b);tb(b);Ab(a+1298368|0,j);M=a+1298404|0,T=x[Fc(e+36|0,x[a+1074308>>2]?22:4)>>2],x[M>>2]=T;x[a+1298408>>2]=0;ub(C);ub(B);break s}b=N()|0;break N}b=N()|0;break Bc}b=N()|0;tb(e+24|0)}Eb(e+40|0);break N}b=N()|0;break N}b=N()|0;tb(e+76|0);break db}b=N()|0}tb(c);break N}b=N()|0;break N}b=N()|0;Qk(m);break La}h=h+1|0;continue}}b=N()|0;break N}b=N()|0;break N}b=N()|0;break N}b=N()|0}dc(k);break Ia}b=N()|0;break Ia}b=N()|0}ub(n);break N}b=N()|0;break N}b=N()|0;break N}b=N()|0;break N}b=N()|0}ub(d);break N}b=N()|0;break N}b=N()|0;break N}b=N()|0;break N}b=N()|0;tb(e+160|0);break xa}b=N()|0}Eb(e+100|0);break N}b=N()|0;break N}b=N()|0;break N}d=0;g=wD(e+100|0,x[i>>2]);x[31737]=0;P(184,b|0,g|0)|0;g=x[31737];x[31737]=0;if((g|0)==1){break _}}g=y[e+103|0];if(!x[i>>2]|(g|0)!=1){break ba}m=1;break aa}K=(g|0)==10|K}x[e+100>>2]=x[b+8>>2];M=e,T=x[ad(e+240|0,e+100|0)>>2],x[M+240>>2]=T;t=(d|0)!=0}f=f+1|0;d=z[a+480190>>1];continue}break}b=N()|0;break N}Jc:{d=yb(x[r>>2],f);d=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);Kc:{if(!d){break Kc}x[31737]=0;d=P(150,b|0,d|0)|0;g=x[31737];x[31737]=0;if((g|0)==1){break Jc}if(!d){break Kc}d=x[b+8>>2];g=x[b>>2];x[31737]=0;d=U(151,g|0,d|0,554)|0;g=x[31737];x[31737]=0;if((g|0)==1){break Jc}if(!d){break Kc}x[31737]=0;d=U(252,a|0,f+1&65535,0)|0;g=x[31737];x[31737]=0;if((g|0)==1){break Z}if(!d){break Kc}x[31737]=0;V(450,a|0,b|0,d|0,y[e+458|0]|y[e+459|0]<<8);g=x[31737];x[31737]=0;if((g|0)==1){break Z}v[d+33|0]=y[e+469|0]}f=f+1|0;d=z[a+480192>>1];continue}break}b=N()|0;break N}b=N()|0;break N}b=N()|0;break N}b=N()|0}ub(C)}ub(B);break t}b=N()|0;break t}b=N()|0;break t}}}}}b=N()|0}vc(o);vc(q);vc(r);break a}vc(o);vc(q);vc(r)}tb(j)}fb=e+608|0;return f|0}b=N()|0}tb(j);Q(b|0);p()}function Uqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,T=0;d=fb-1712|0;fb=d;xc(b);h=d+1704|0;a:{if(!Bi(b,h)){break a}if(!GY(h)){break a}g=1;if((c|0)==64){break a}m=y[d+1707|0];v[d+1703|0]=m;x[d+1696>>2]=-1;x[d+1692>>2]=1048576;if(m>>>0>=5){h=Pg(b);x[d+1696>>2]=h;g=0;if(!Mb(x[b>>2],x[b+8>>2],h)){break a}x[d+288>>2]=134217727;M=d,T=x[Gb(d+288|0,d+1696|0)>>2]<<5,x[M+1692>>2]=T}C=Nb(d+1680|0);x[d+288>>2]=y[d+1708|0]|y[d+1709|0]<<8|(y[d+1710|0]<<16|y[d+1711|0]<<24);h=x[Gb(d+1692|0,d+288|0)>>2];x[31737]=0;O(554,C|0,h|0);h=x[31737];x[31737]=0;b:{c:{d:{e:{f:{if((h|0)!=1){x[31737]=0;h=U(555,b|0,C|0,y[d+1708|0]|y[d+1709|0]<<8|(y[d+1710|0]<<16|y[d+1711|0]<<24))|0;e=x[31737];x[31737]=0;g:{if((e|0)==1){break g}g=0;if(!h){break b}if(m>>>0>=5){x[31737]=0;P(150,b|0,x[d+1696>>2]+12|0)|0;h=x[31737];x[31737]=0;if((h|0)==1){break g}}x[31737]=0;O(247,a|0,0);h=x[31737];x[31737]=0;if((h|0)==1){break g}gg(a);re(d+1648|0,x[C>>2],x[C+4>>2]);h=Nd(d+1640|0);x[31737]=0;e=x[h+4>>2];x[d+88>>2]=x[h>>2];x[d+92>>2]=e;n=jg(556,d+1660|0,x[d+1648>>2],x[d+1652>>2],d+88|0);h=x[31737];x[31737]=0;h:{i:{j:{if((h|0)!=1){x[31737]=0;S(359,n|0,a+1298308|0,-1);h=x[31737];x[31737]=0;if((h|0)==1){break j}x[31737]=0;S(359,n|0,a+1298332|0,-1);h=x[31737];x[31737]=0;if((h|0)==1){break j}x[31737]=0;h=P(557,n|0,d+1218|0)|0;e=x[31737];x[31737]=0;if((e|0)==1){break f}if(!h){break c}h=v[d+1218|0];if((h|0)<=0|(y[d+1227|0]|y[d+1228|0]<<8)>>>0>255|(y[d+1229|0]|y[d+1230|0]<<8)>>>0>3999){break c}w[a+480188>>1]=h&255;af(Xb(x[a+484360>>2],y[a+484376|0]),y[d+1221|0]|y[d+1222|0]<<8);w[a+480192>>1]=y[d+1227|0]|y[d+1228|0]<<8;w[a+480190>>1]=y[d+1229|0]|y[d+1230|0]<<8;h=y[d+1231|0];x[a+480196>>2]=h?h:6;h=y[d+1232|0];x[a+480204>>2]=D(h?h:125,1e4);e=y[d+1233|0]|y[d+1234|0]<<8|(y[d+1235|0]<<16|y[d+1236|0]<<24);h=32;k:{if(e&256){break k}h=2;if(e&2){break k}h=1;if(e&128){break k}h=e&8?16:4}x[31737]=0;O(418,a|0,h|0);h=x[31737];x[31737]=0;if((h|0)==1){break f}h=x[a+480208>>2];e=h|16777216;x[a+480208>>2]=e;f=y[d+1233|0]|y[d+1234|0]<<8|(y[d+1235|0]<<16|y[d+1236|0]<<24);if(f&1){e=h|16777232;x[a+480208>>2]=e}h=x[a+480180>>2];j=(h|0)==32;i=j&!(f&1024);l=(h|0)==2;g=l&f>>>4;s=f&2097152;l=l&f>>>2;j=j&!(f&2048);if(i|(s|l|(j|g))){e=g?e|65536:e;e=l?e|2:e;e=j?e|4:e;x[a+480208>>2]=s>>>6|(i?e|8:e)}if(f&524288){x[31737]=0;U(267,a+1074312|0,5,1)|0;h=x[31737];x[31737]=0;if((h|0)==1){break f}h=x[a+480180>>2]}if((h|0)==2){break i}if((h|0)!=32){break h}v[d+288|0]=y[d+1237|0];v[d+220|0]=128;M=a,T=y[Qb(d+288|0,d+220|0)|0]<<1,x[M+480200>>2]=T;break h}f=N()|0;break d}f=N()|0;break e}v[d+288|0]=y[d+1237|0];v[d+220|0]=64;M=a,T=y[Qb(d+288|0,d+220|0)|0]<<2,x[M+480200>>2]=T}E=a+480188|0;e=v[d+1239|0];l:{if((e|0)<0){f=e+52|0;break l}G=Ft(+(e|0)*3.1/20);m:{if(G<4294967296&G>=0){f=~~G>>>0;break m}f=0}f=f+51|0}x[a+480228>>2]=f;w[d+288>>1]=64;i=z[Nc(E,d+288|0)>>1];e=0;j=(h|0)!=32;l=(h|0)==4;g=0;while(1)if((g|0)==(i|0)){g=0;j=0;while(1){if((e|0)!=16){j=y[(d+e|0)+1368|0]!=0|j;e=e+1|0;continue}break}while(1){if((g|0)!=128){j=y[((g<<1)+d|0)+1385|0]!=0|j;g=g+1|0;continue}break}n:{if(!(j&1)){break n}h=a+901692|0;g=0;while(1){if((g|0)==16){h=a+902204|0;g=0;while(1){if((g|0)!=128){e=(d+1218|0)+(g<<1)|0;o:{if(y[e+167|0]){x[31737]=0;f=d+220|0;W(558,f|0);i=x[31737];x[31737]=0;p:{q:{r:{s:{t:{if((i|0)!=1){i=y[e+167|0];x[31737]=0;x[d+244>>2]=i-1;i=d+1164|0;O(559,i|0,d+244|0);j=x[31737];x[31737]=0;if((j|0)==1){break t}e=y[e+166|0];x[31737]=0;v[d+192|0]=e;e=d+1144|0;O(560,e|0,d+192|0);j=x[31737];x[31737]=0;if((j|0)==1){break s}x[31737]=0;j=d+288|0;V(561,j|0,f|0,i|0,e|0);l=x[31737];x[31737]=0;if((l|0)==1){break r}ee(d+1192|0,j);qf(Oe(h,g),x[d+1192>>2],x[d+1196>>2]);tb(j);tb(e);tb(i);Eb(f);break o}f=N()|0;break e}f=N()|0;break p}f=N()|0;break q}f=N()|0;tb(d+1144|0)}tb(d+1164|0)}Eb(d+220|0);break e}e=qc(d+1184|0,22303);qf(Oe(h,g),x[e>>2],x[d+1188>>2])}g=g+1|0;continue}break}h=x[a+480180>>2];break n}f=(d+g|0)+1368|0;u:{if(y[f|0]){x[31737]=0;e=d+220|0;W(562,e|0);i=x[31737];x[31737]=0;v:{w:{x:{if((i|0)!=1){f=y[f|0];x[31737]=0;x[d+1144>>2]=f-1;f=d+1164|0;O(559,f|0,d+1144|0);i=x[31737];x[31737]=0;if((i|0)==1){break x}x[31737]=0;i=d+288|0;S(291,i|0,e|0,f|0);j=x[31737];x[31737]=0;if((j|0)==1){break w}ee(d+1208|0,i);qf(Oe(h,g),x[d+1208>>2],x[d+1212>>2]);tb(i);tb(f);Eb(e);break u}f=N()|0;break e}f=N()|0;break v}f=N()|0;tb(d+1164|0)}Eb(d+220|0);break e}e=qc(d+1200|0,22303);qf(Oe(h,g),x[e>>2],x[d+1204>>2])}g=g+1|0;continue}}e=y[a+484376|0];f=x[a+484360>>2];x[31737]=0;h=h&5;aa(349,Xb(f,e)|0,n|0,y[d+1219|0]|y[d+1220|0]<<8,(h?65535:255)|0,(h?65535:254)|0);h=x[31737];x[31737]=0;if((h|0)!=1){x[31737]=0;h=d+288|0;S(186,h|0,n|0,D(y[d+1218|0],y[d+1223|0]|y[d+1224|0]<<8)<<1);e=x[31737];x[31737]=0;if((e|0)!=1){H=ic(d+1164|0,h);ub(h);x[31737]=0;S(186,h|0,n|0,(y[d+1223|0]|y[d+1224|0]<<8)<<1);e=x[31737];x[31737]=0;y:{if((e|0)!=1){I=ic(d+1144|0,h);ub(h);x[31737]=0;s=P(215,d+1132|0,y[d+1225|0]|y[d+1226|0]<<8)|0;h=x[31737];x[31737]=0;z:{if((h|0)!=1){M=d,T=wb(x[s>>2]),x[M+244>>2]=T;e=wb(x[s+4>>2]);A:{B:{C:{while(1){f=x[d+244>>2];if(!Ib(f,e)){h=x[a+480180>>2];t=c&1;if(!t){break B}x[31737]=0;O(224,a+484344|0,y[d+1223|0]|y[d+1224|0]<<8);e=x[31737];x[31737]=0;if((e|0)!=1){break B}f=N()|0;break A}x[31737]=0;i=R(152,n|0)|0;h=x[31737];x[31737]=0;if((h|0)!=1){x[31737]=0;h=d+220|0;S(186,h|0,n|0,i|0);i=x[31737];x[31737]=0;if((i|0)==1){break C}i=f;f=ic(d+288|0,h);hd(i,f);ub(f);ub(h);Sf(d+244|0);continue}break}f=N()|0;break A}f=N()|0;break A}r=(h|0)==16?14:(h|0)==32?1:13;J=a+484344|0;l=1;while(1){D:{E:{F:{G:{H:{I:{if((y[d+1223|0]|y[d+1224|0]<<8)>>>0<=q>>>0){switch(x[a+480180>>2]-1|0){case 0:break G;case 3:break I;default:break F}}x[31737]=0;h=R(190,I|0)|0;e=x[31737];x[31737]=0;if((e|0)==1){break H}x[d+220>>2]=h;if(!t){break D}x[31737]=0;e=U(197,J|0,q&65535,h|0)|0;h=x[31737];x[31737]=0;if((h|0)==1){break H}h=0;if(!e){break D}while(1){f=h&65535;if(f>>>0>=y[d+1218|0]){break D}x[31737]=0;e=R(190,H|0)|0;i=x[31737];x[31737]=0;J:{if((i|0)!=1){i=x[s>>2];if(Uf(i,x[s+4>>2])>>>0<=e>>>0){break J}k=dh(i,e);xc(k);e=0;i=Wb(x[J>>2],q);g=jd(x[i>>2],x[x[i+48>>2]+12>>2],0,f);K:while(1){if(A[d+220>>2]<=e>>>0){break J}x[31737]=0;f=R(198,k|0)|0;i=x[31737];x[31737]=0;if((i|0)!=1){if(!f){break J}u=f>>>4|0;B=f&15;j=0;i=bh(d+288|0);while(1){L:{M:{N:{if(B>>>0>(j&255)>>>0){x[31737]=0;f=d+244|0;O(199,f|0,k|0);o=x[31737];x[31737]=0;if((o|0)==1){break N}O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{ca:{da:{ea:{f=y[xb(f,0)|0];switch(f-1|0){case 2:case 3:case 4:case 7:case 8:case 9:case 11:case 12:case 13:case 16:case 18:case 21:case 22:case 23:case 24:case 25:case 27:case 32:break O;case 33:break S;case 30:case 31:break T;case 29:break U;case 28:break V;case 26:break W;case 19:case 20:break X;case 17:break Y;case 15:break Z;case 14:break _;case 10:break $;case 6:break aa;case 5:break ba;case 1:break ca;case 0:break da;default:break ea}}switch(f-48|0){case 4:break P;case 1:case 2:break Q;case 0:break R;default:break O}}f=y[xb(d+244|0,1)|0];fa:{if(f>>>0<=119){f=f+r|0;break fa}ga:{switch(f-254|0){case 1:f=255;break fa;case 0:f=254;break fa;default:break ga}}f=253}v[i|0]=f;l=KD(f)&l;break L}M=d,T=y[xb(d+244|0,1)|0]+1|0,v[M+289|0]=T;break L}ha:{if(y[d+290|0]){break ha}f=x[a+480180>>2];if((f|0)!=32){if((f|0)!=4){break ha}f=y[xb(d+244|0,1)|0];if(f&15){break ha}v[d+290|0]=11;v[d+292|0]=f>>>4;break L}f=0;o=y[xb(d+244|0,1)|0];while(1){if((f|0)==10){break ha}if((o|0)==y[f+42256|0]){v[d+292|0]=f;v[d+290|0]=11;break L}else{f=f+1|0;continue}}}M=d,T=y[xb(d+244|0,1)|0],v[M+293|0]=T;v[d+291|0]=4;break L}f=xb(d+244|0,1);ia:{if(y[d+290|0]){break ia}o=y[f|0];if(x[a+480180>>2]!=32|o>>>0>9){break ia}v[d+292|0]=o;v[d+290|0]=8;break L}v[d+293|0]=y[f|0];v[d+291|0]=5;break L}ja:{if(y[d+290|0]){break ja}ka:{f=x[a+480180>>2];if((f|0)!=4){if((f|0)!=32){break ja}f=xb(d+244|0,1);o=y[f|0];if((o|0)!=255){break ka}v[d+292|0]=64;v[d+290|0]=2;break L}f=xb(d+244|0,1);if(y[f|0]&15){break ja}break M}if(!(o&3)){break M}}M=d,T=y[xb(d+244|0,1)|0],v[M+293|0]=T;v[d+291|0]=9;break L}o=y[d+290|0];f=xb(d+244|0,1);la:{if(o|x[a+480180>>2]==1){break la}o=y[f|0];if(o>>>0>64){break la}v[d+292|0]=o;v[d+290|0]=1;break L}v[d+293|0]=y[f|0];v[d+291|0]=13;break L}f=y[xb(d+244|0,1)|0];v[d+293|0]=f;v[d+291|0]=14;if(x[a+480180>>2]==32){break L}v[d+293|0]=D((f&240)>>>4|0,10)+(f&15);break L}f=y[xb(d+244|0,1)|0];v[d+293|0]=f;v[d+291|0]=f>>>0<32?16:17;break L}o=y[xb(d+244|0,1)|0];if(o>>>0>=16){v[d+292|0]=o>>>4;v[d+290|0]=(f|0)==20?3:5;break L}v[d+292|0]=o&15;v[d+290|0]=(f|0)==20?4:6;break L}f=y[xb(d+244|0,1)|0];if(f>>>0>=16){v[d+290|0]=10;v[d+292|0]=f>>>4;break L}v[d+290|0]=9;v[d+292|0]=f&15;break L}f=y[xb(d+244|0,1)|0];v[d+291|0]=28;v[d+293|0]=f|16;break L}f=y[xb(d+244|0,1)|0];v[d+291|0]=28;v[d+293|0]=f|32;break L}M=d,T=y[xb(d+244|0,1)|0],v[M+292|0]=T;v[d+290|0]=(f|0)==31?7:8;break L}f=y[d+291|0];v[d+291|0]=(f|0)==4?6:(f|0)==5?7:11;M=d,T=y[xb(d+244|0,1)|0],v[M+293|0]=T;break L}f=xb(d+244|0,1);v[d+292|0]=y[f|0]%10;f=y[f|0];if(f>>>0<=9){v[d+290|0]=5;break L}if(f>>>0<=19){v[d+290|0]=6;break L}if(f>>>0<=29){v[d+290|0]=3;break L}if(f>>>0>39){break L}v[d+290|0]=4;break L}M=d,T=y[xb(d+244|0,1)|0],v[M+292|0]=T;v[d+290|0]=(f|0)==49?13:12;break L}f=y[xb(d+244|0,1)|0]+33|0;if((f&255)>>>0>9){break L}v[d+290|0]=15;v[d+292|0]=f;break L}if(f>>>0>57){break L}M=d,T=y[xb(d+244|0,1)|0],v[M+293|0]=T;v[d+291|0]=y[f+25232|0];break L}x[d+244>>2]=e+u;f=x[Gb(d+244|0,d+220|0)>>2];f=e>>>0>f>>>0?e:f;while(1){if((e|0)!=(f|0)){j=y[i|0]|y[i+1|0]<<8|(y[i+2|0]<<16|y[i+3|0]<<24);v[g|0]=j;v[g+1|0]=j>>>8;v[g+2|0]=j>>>16;v[g+3|0]=j>>>24;j=y[i+4|0]|y[i+5|0]<<8;v[g+4|0]=j;v[g+5|0]=j>>>8;e=e+1|0;g=D(y[d+1218|0],6)+g|0;continue}break}e=f;continue K}f=N()|0;break A}f=y[f|0];v[d+290|0]=2;v[d+292|0]=f>>>2}j=j+1|0;continue}}break}f=N()|0;break A}f=N()|0;break A}h=h+1|0;continue}}g=z[a+480192>>1];h=0;break E}f=N()|0;break A}if(!(z[E>>1]==4&l)){break F}x[a+480208>>2]=x[a+480208>>2]|8454144}g=0;h=!((y[d+1233|0]|y[d+1234|0]<<8|(y[d+1235|0]<<16|y[d+1236|0]<<24))&512)}x[31737]=0;o=P(563,d+1120|0,g|0)|0;e=x[31737];x[31737]=0;ma:{na:{oa:{pa:{qa:{if((e|0)!=1){g=m>>>0<5;j=1;ra:{while(1){i=j&65535;if(i>>>0>z[a+480192>>1]){break ra}sa:{ta:{ua:{va:{if(!h){x[31737]=0;f=U(252,a|0,i|0,0)|0;e=x[31737];x[31737]=0;if((e|0)==1){break va}if(f){break ua}}while(1){x[31737]=0;e=R(198,n|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break na}if(e){continue}break}if(!g){while(1){x[31737]=0;e=R(198,n|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){f=N()|0;break ma}if(e){continue}break}}x[31737]=0;P(184,n|0,826)|0;e=x[31737];x[31737]=0;if((e|0)!=1){break ta}}f=N()|0;break ma}e=Fb(d+220|0);x[31737]=0;S(359,n|0,e|0,-1);l=x[31737];x[31737]=0;if((l|0)==1){break sa}zc(f+492|0,e);if(!g){x[31737]=0;S(359,n|0,e|0,-1);l=x[31737];x[31737]=0;if((l|0)==1){break sa}zc(f+524|0,e)}x[31737]=0;l=d+288|0;q=P(564,n|0,l|0)|0;m=x[31737];x[31737]=0;if((m|0)==1){break oa}if(!q){break qa}q=x[a+480180>>2];x[31737]=0;S(565,l|0,f|0,q|0);f=x[31737];x[31737]=0;if((f|0)==1){break oa}if(x[a+480180>>2]==4){f=yb(x[o>>2],i-1|0);i=y[d+1090|0]|y[d+1091|0]<<8|(y[d+1092|0]<<16|y[d+1093|0]<<24);v[f|0]=i;v[f+1|0]=i>>>8;v[f+2|0]=i>>>16;v[f+3|0]=i>>>24}tb(e)}j=j+1|0;continue}break}break oa}if(!h){break pa}w[a+480192>>1]=0;break pa}f=N()|0;break A}tb(e)}h=z[a+480190>>1];x[31737]=0;q=P(566,d+276|0,h|0)|0;h=x[31737];x[31737]=0;if((h|0)!=1){B=y[d+1703|0];L=!(v[d+1233|0]&1)|B>>>0>4;t=c&2;j=1;c=0;while(1){h=c;wa:{xa:{ya:{za:{Aa:{Ba:{Ca:{Da:{Ea:{Fa:{Ga:{Ha:{Ia:{Ja:{Ka:{La:{Ma:{Na:{Oa:{Pa:{Qa:{l=j&65535;if(l>>>0<=z[a+480190>>1]){g=Fb(d+264|0);x[31737]=0;S(359,n|0,g|0,-1);c=x[31737];x[31737]=0;Ra:{Sa:{if((c|0)!=1){zc(((l<<5)+a|0)+946304|0,g);c=B>>>0<5;if(c){break Sa}x[31737]=0;S(359,n|0,g|0,-1);e=x[31737];x[31737]=0;if((e|0)!=1){break Ra}}f=N()|0;break za}sf(g)}x[31737]=0;e=d+288|0;f=P(567,n|0,e|0)|0;i=x[31737];x[31737]=0;Ta:{Ua:{if((i|0)==1){break Ua}if(!f){break Ta}i=x[a+480180>>2];x[31737]=0;k=e;f=D(l,104)+a|0;e=f+484380|0;V(568,k|0,e|0,i|0,L|0);i=x[31737];x[31737]=0;if((i|0)==1){break Ua}ze(f+484423|0,g);r=0;Va:{if(((y[d+308|0]|y[d+309|0]<<8)&61440)!=28672|c){break Va}x[31737]=0;r=R(569,n|0)|0;c=x[31737];x[31737]=0;if((c|0)!=1){break Va}f=N()|0;break za}if(!t){break xa}i=y[d+323|0]|y[d+324|0]<<8|(y[d+325|0]<<16|y[d+326|0]<<24);c=y[d+308|0]|y[d+309|0]<<8;m=c&61440;if(!(i|m)){c=Xc(d+220|0,c&1?16:8,c&1024?3:1,0,0);x[31737]=0;U(216,c|0,e|0,b|0)|0;c=x[31737];x[31737]=0;if((c|0)!=1){break xa}f=N()|0;break za}if((i|0)<0){c=i+l|0;if((c|0)<=0){break xa}EY(e,(D(c,104)+a|0)+484380|0);break xa}if((i|0)<=0){break xa}if(c&1){k=f+484414|0;w[k>>1]=z[k>>1]|1}if(c&1024){k=f+484414|0;w[k>>1]=z[k>>1]|64}x[31737]=0;k=d+220|0;S(186,k|0,b|0,i|0);i=x[31737];x[31737]=0;Wa:{Xa:{Ya:{Za:{_a:{$a:{if((i|0)!=1){i=ic(d+244|0,k);ub(k);k=_d(z[e+34>>1]);K=(m|0)==16384;if(!K&(m|0)!=8192){break Za}u=x[i>>2];x[31737]=0;u=R(155,u|0)|0;F=x[31737];x[31737]=0;if((F|0)==1){break Wa}F=4/(k>>>0)|0;Sua(F,0,u,0);wc(e,hb?-1:D(u,F));if((m|0)==8192){break $a}if(!K){break Za}if(!Eh(e)){break Ya}c=x[f+484400>>2];e=x[e>>2];if(!(v[d+308|0]&1)){break _a}x[31737]=0;V(570,i|0,c|0,e|0,k|0);e=x[31737];x[31737]=0;c=h;if((e|0)==1){break Ba}break Xa}f=N()|0;break za}if(!Eh(e)){break Ya}c=x[f+484400>>2];e=x[e>>2];if(v[d+308|0]&1){x[31737]=0;V(571,i|0,c|0,e|0,k|0);e=x[31737];x[31737]=0;c=h;if((e|0)!=1){break Xa}break Ba}x[31737]=0;V(572,i|0,c|0,e|0,k|0);e=x[31737];x[31737]=0;c=h;if((e|0)==1){break Ba}break Xa}x[31737]=0;V(573,i|0,c|0,e|0,k|0);e=x[31737];x[31737]=0;c=h;if((e|0)==1){break Ba}break Xa}if((c&45056)==12288){c=DY(d+220|0,i,y[d+327|0]|y[d+328|0]<<8,r);M=hd(wf(x[q>>2],l-1|0),c),T=x[c+20>>2],x[M+20>>2]=T;ub(c);break Ya}if((m|0)!=32768){c=1;if((m|0)!=4096){break Xa}m=Ge(d+220|0,i);x[31737]=0;c=P(574,d+214|0,i|0)|0;k=x[31737];x[31737]=0;if((k|0)!=1){ab:{bb:{if(!y[d+219|0]){break bb}r=y[d+327|0]|y[d+328|0]<<8;k=z[d+216>>1]<<1;if(r>>>0<(k&65535)>>>0){break bb}k=r-k|0;v[d+327|0]=k;v[d+328|0]=k>>>8;c=z[c>>1];x[31737]=0;P(150,i|0,c|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break ab}x[31737]=0;k=R(203,i|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break ab}x[31737]=0;c=d+172|0;S(186,c|0,i|0,k|0);k=x[31737];x[31737]=0;if((k|0)==1){break ab}k=ic(d+192|0,c);hd(m,k);ub(k);ub(c)}x[31737]=0;l=U(575,a|0,l|0,m|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break ab}c=1;if(l){c=y[d+327|0]|y[d+328|0]<<8;cb:{if(!c){break cb}l=z[e+34>>1];k=Vk(x[e>>2],l);if(k>>>0<=c>>>0){break cb}l=cl(l);f=x[f+484400>>2];ml(f,c+f|0,k-c|0);x[e>>2]=x[e>>2]-((c>>>0)/(l>>>0)|0)}wc(e,y[d+296|0]|y[d+297|0]<<8|(y[d+298|0]<<16|y[d+299|0]<<24));c=h}ub(m);break Xa}}f=N()|0;ub(m);break Aa}x[31737]=0;c=P(429,i|0,d+220|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break Qa}if(!c){break Ya}x[d+80>>2]=y[d+228|0]|y[d+229|0]<<8|(y[d+230|0]<<16|y[d+231|0]<<24);c=y[d+224|0]|y[d+225|0]<<8|(y[d+226|0]<<16|y[d+227|0]<<24);x[d+72>>2]=y[d+220|0]|y[d+221|0]<<8|(y[d+222|0]<<16|y[d+223|0]<<24);x[d+76>>2]=c;Yk(e,1,d+72|0)}c=h}ub(i);break wa}f=N()|0;break Aa}f=N()|0;break za}tb(g)}db:{if(!t){break db}l=1;while(1){i=l&65535;if(i>>>0>z[a+480190>>1]){break db}b=wf(x[q>>2],i-1|0);c=x[b>>2];x[31737]=0;c=R(173,c|0)|0;e=x[31737];x[31737]=0;if((e|0)==1){break Pa}eb:{fb:{if(!c){break fb}c=i+w[b+22>>1]|0;c=((c|0)>0?c:l)&65535;j=z[b+20>>1];g=(c|0)!=(i|0)&(c|0)!=0&c>>>0<=z[a+480190>>1]&(j|0)!=0;gb:{if(g){e=wf(x[q>>2],c-1|0);break gb}c=x[b>>2];x[31737]=0;j=R(155,c|0)|0;c=x[31737];x[31737]=0;e=b;if((c|0)==1){break Oa}}xc(e);hb:{if(g){c=x[e+8>>2];f=x[e>>2];m=z[b+20>>1];x[31737]=0;c=U(151,f|0,c|0,m|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break Oa}if(!c){break fb}x[d+220>>2]=0;x[d+244>>2]=0;x[31737]=0;c=d+288|0;S(187,c|0,e|0,j|0);f=x[31737];x[31737]=0;ib:{if((f|0)!=1){f=ZC(_e(c),th(x[d+288>>2]),d+220|0,d+244|0);x[31737]=0;P(184,e|0,x[d+220>>2])|0;e=x[31737];x[31737]=0;if((e|0)==1){break ib}Kc(c);break hb}f=N()|0;break ya}f=N()|0;Kc(d+288|0);break ya}f=0;x[d+220>>2]=0;x[d+244>>2]=0}x[31737]=0;c=d+288|0;O(576,c|0,b|0);e=x[31737];x[31737]=0;jb:{kb:{if((e|0)!=1){c=_e(c);j=x[d+288>>2];if(!g){f=ZC(c,th(j),d+220|0,d+244|0);x[31737]=0;e=x[d+220>>2];P(184,b|0,e|0)|0;g=x[31737];x[31737]=0;if((g|0)==1){break eb}j=j-e|0;c=c+e|0}if(f){break kb}h=1;break jb}f=N()|0;break ya}e=D(i,104)+a|0;m=e+484380|0;Eh(m);u=e+484400|0;e=0;g=x[d+244>>2];while(1){lb:{if(!j|(g|0)!=1?g:0){break lb}i=x[m>>2];if(i>>>0<=e>>>0){break lb}if(!je(i,x[m+20>>2])){break lb}x[d+192>>2]=0;x[d+172>>2]=0;i=d+172|0;k=CY(f,c,th(j),d+192|0,d+264|0,i);x[31737]=0;x[d+220>>2]=k;P(184,b|0,k|0)|0;g=x[31737];x[31737]=0;if((g|0)==1){break Ca}Ai(i,th(x[m>>2]-e|0));i=x[d+172>>2];mb:{if((i|0)<=0){break mb}g=x[d+192>>2];B=z[m+34>>1];if((_d(B)|0)!=(g|0)){break mb}t=D(e,g);r=x[u>>2];if(B&1){x[d+168>>2]=i;x[d+156>>2]=i;x[d- -64>>2]=i;x[d+48>>2]=i;x[d+152>>2]=g;x[d+148>>2]=x[d+264>>2];x[d+164>>2]=g;x[d+160>>2]=r+(t<<1);x[31737]=0;g=x[d+152>>2];x[d+40>>2]=x[d+148>>2];x[d+44>>2]=g;g=x[d+164>>2];x[d+56>>2]=x[d+160>>2];x[d+60>>2]=g;O(577,d+56|0,d+40|0);g=x[31737];x[31737]=0;if((g|0)!=1){break mb}break Ca}x[d+144>>2]=i;x[d+132>>2]=i;x[d+32>>2]=i;x[d+16>>2]=i;x[d+128>>2]=g;x[d+124>>2]=x[d+264>>2];x[d+140>>2]=g;x[d+136>>2]=r+t;x[31737]=0;g=x[d+128>>2];x[d+8>>2]=x[d+124>>2];x[d+12>>2]=g;g=x[d+140>>2];x[d+24>>2]=x[d+136>>2];x[d+28>>2]=g;O(578,d+24|0,d+8|0);g=x[31737];x[31737]=0;if((g|0)==1){break Ca}}j=j-k|0;c=c+k|0;g=BY(f);x[d+244>>2]=g;e=e+i|0;continue}break}AY(f)}Kc(d+288|0)}l=l+1|0;continue}break}break Ca}nb:{if(x[a+480180>>2]!=4){break nb}g=0;while(1){if(z[a+480192>>1]<=g>>>0){break nb}b=yb(x[o>>2],g);c=y[b+3|0];e=y[b+2|0];f=y[b+1|0];b=y[b|0];x[31737]=0;g=g+1|0;ja(401,a|0,g&65535,b|0,f|0,e|0,c|0);b=x[31737];x[31737]=0;if((b|0)!=1){continue}break}f=N()|0;break ya}if(!(y[d+1235|0]&16)){break Ka}b=x[n+8>>2];c=x[n>>2];x[31737]=0;b=U(151,c|0,b|0,1)|0;c=x[31737];x[31737]=0;if((c|0)==1){break Ma}if(!b){break Ka}g=0;x[31737]=0;b=R(198,n|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break Na}if(!(b&1)){break La}while(1){if(z[E>>1]<=g>>>0){break La}x[31737]=0;b=R(152,n|0)|0;c=x[31737];x[31737]=0;if((c|0)!=1){v[((g<<5)+a|0)+480288|0]=b;g=g+1|0;continue}break}f=N()|0;break ya}f=N()|0;break Aa}f=N()|0;break ya}f=N()|0;break ya}f=N()|0;break ya}f=N()|0;break ya}f=a+906300|0;while(1){b=x[n+8>>2];c=x[n>>2];x[31737]=0;b=U(151,c|0,b|0,1)|0;c=x[31737];x[31737]=0;if((c|0)==1){break Da}if(!b){break Ka}x[31737]=0;b=R(198,n|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break Ia}if(!b){break Ka}x[31737]=0;c=R(152,n|0)|0;e=x[31737];x[31737]=0;if((e|0)==1){break Ja}x[31737]=0;e=d+220|0;S(186,e|0,n|0,c|0);c=x[31737];x[31737]=0;if((c|0)==1){break Ja}c=ic(d+288|0,e);ub(e);ob:{if(b>>>0<=250){b=vd(f,b-1|0);x[31737]=0;O(451,c|0,b|0);b=x[31737];x[31737]=0;if((b|0)==1){break ob}}ub(c);continue}break}f=N()|0;ub(c);break ya}i=a+901404|0;c=Fb(d+192|0);f=0;l=0;while(1){b=x[n+8>>2];e=x[n>>2];x[31737]=0;b=U(151,e|0,b|0,8)|0;e=x[31737];x[31737]=0;pb:{qb:{rb:{sb:{tb:{if((e|0)!=1){if(b){x[31737]=0;e=R(152,n|0)|0;b=x[31737];x[31737]=0;ub:{vb:{wb:{xb:{yb:{zb:{Ab:{Bb:{if((b|0)!=1){x[31737]=0;b=R(152,n|0)|0;g=x[31737];x[31737]=0;if((g|0)==1){break Bb}x[31737]=0;g=d+288|0;S(186,g|0,n|0,b|0);b=x[31737];x[31737]=0;if((b|0)==1){break Ab}b=ic(d+220|0,g);ub(g);if((e|0)==1229211981){break xb}if((e|0)==1229476432){break yb}if((e|0)==1397900630){break zb}if((e|0)!=1414548815){break pb}x[31737]=0;e=P(413,b|0,13951)|0;j=x[31737];x[31737]=0;if((j|0)==1){break Ha}if(!e){break qb}x[31737]=0;e=R(152,b|0)|0;j=x[31737];x[31737]=0;if((j|0)!=1){x[31737]=0;S(186,g|0,b|0,e|0);e=x[31737];x[31737]=0;if((e|0)!=1){break wb}}f=N()|0;break Ga}f=N()|0;break Ea}f=N()|0;break Ea}f=N()|0;break Ea}Cb:{Db:{Eb:{e=x[a+480180>>2];switch(e-2|0){case 1:break pb;case 0:break vb;case 2:break Db;default:break Eb}}if((e|0)==16){break Cb}if((e|0)!=32){break pb}x[31737]=0;f=R(190,b|0)|0;e=x[31737];x[31737]=0;if((e|0)==1){break Ha}x[31737]=0;l=R(190,b|0)|0;e=x[31737];x[31737]=0;if((e|0)!=1){break pb}break Ha}e=Fc(d+120|0,4);x[d+288>>2]=32;g=x[b>>2];x[31737]=0;g=R(155,g|0)|0;j=x[31737];x[31737]=0;if((j|0)!=1){x[d+244>>2]=g;e=x[e>>2];g=x[Gb(d+288|0,d+244|0)>>2];x[31737]=0;V(579,b|0,c|0,e|0,g|0);e=x[31737];x[31737]=0;if((e|0)!=1){break pb}}f=N()|0;break Ga}x[31737]=0;e=R(198,b|0)|0;g=x[31737];x[31737]=0;if((g|0)==1){break ub}x[31737]=0;g=d+244|0;O(580,g|0,4211);j=x[31737];x[31737]=0;Fb:{if((j|0)!=1){x[d+264>>2]=e>>>4;x[31737]=0;x[d+104>>2]=e&15;e=d+288|0;V(308,e|0,g|0,d+264|0,d+104|0);j=x[31737];x[31737]=0;if((j|0)==1){break Fb}Ab(c,e);tb(e);Eb(g);break pb}f=N()|0;break Ga}f=N()|0;Eb(d+244|0);break Ga}x[31737]=0;e=R(198,b|0)|0;g=x[31737];x[31737]=0;if((g|0)==1){break Ha}x[a+480216>>2]=e;x[31737]=0;e=R(198,b|0)|0;g=x[31737];x[31737]=0;if((g|0)==1){break Ha}x[a+480220>>2]=e;break pb}x[31737]=0;P(424,b|0,i|0)|0;e=x[31737];x[31737]=0;if((e|0)==1){break Ha}zD(i);break pb}g=d+288|0;e=ic(d+244|0,g);ub(g);j=x[e>>2];x[31737]=0;j=R(155,j|0)|0;m=x[31737];x[31737]=0;if((m|0)==1){break rb}w[d+288>>1]=j>>>5;M=d,T=ck(x[a+484344>>2],x[a+484348>>2]),w[M+264>>1]=T;j=z[Nc(g,d+264|0)>>1];g=0;while(1){if((g|0)==(j|0)){ub(e);break qb}x[31737]=0;m=d+288|0;O(581,e|0,m|0);k=x[31737];x[31737]=0;Gb:{if((k|0)==1){break Gb}k=x[J>>2];x[31737]=0;O(582,Wb(k,g)|0,m|0);m=x[31737];x[31737]=0;if((m|0)==1){break Gb}g=g+1|0;continue}break}break rb}x[31737]=0;f=R(190,b|0)|0;e=x[31737];x[31737]=0;if((e|0)==1){break Ha}break pb}f=N()|0;break Ga}b=x[a+480180>>2];Hb:{Ib:{Jb:{if((b|0)!=32){break Jb}e=f&65535;if(e>>>0<256){break Jb}if(e>>>0<532){break Ib}}b=(b|0)!=2;Kb:{if(b){break Kb}e=f&65535;if(e>>>0<12544){break Kb}if(e>>>0<12820){break Ib}}if(b){break Hb}b=f&65535;if(b>>>0<4864|b>>>0>4895){break Hb}}pr(i)}g=1;Lb:{if(!(v[d+1235|0]&1)){break Lb}e=x[a+1074308>>2];if(!e){while(1){b=g&65535;if(b>>>0<=z[a+480192>>1]){b=x[((b<<2)+a|0)+900380>>2];if(b){e=x[a+480180>>2];x[31737]=0;O(583,Zh(b,2)|0,e|0);e=x[31737];x[31737]=0;if((e|0)==1){break tb}v[b+19|0]=y[b+19|0]+3>>>2}g=g+1|0;continue}break}e=x[a+1074308>>2]}if(e>>>0<=18350079){x[31737]=0;b=P(268,a+1074312|0,27)|0;e=x[31737];x[31737]=0;if((e|0)==1){break Fa}x[31737]=0;P(268,b|0,57)|0;b=x[31737];x[31737]=0;if((b|0)==1){break Fa}e=x[a+1074308>>2]}if(e>>>0<=19070975){x[31737]=0;P(268,a+1074312|0,73)|0;b=x[31737];x[31737]=0;if((b|0)==1){break Fa}e=x[a+1074308>>2]}if(e>>>0>19267583){break Lb}x[31737]=0;P(268,a+1074312|0,50)|0;b=x[31737];x[31737]=0;if((b|0)==1){break Fa}}Mb:{Nb:{Ob:{Pb:{Qb:{Rb:{Sb:{Tb:{Ub:{Vb:{Wb:{Xb:{Yb:{Zb:{if(Ad(x[c+4>>2],y[c+11|0])){x[31737]=0;e=d+220|0;W(584,e|0);b=x[31737];x[31737]=0;_b:{if((b|0)!=1){x[31737]=0;f=d+288|0;S(552,f|0,e|0,d+1703|0);b=x[31737];x[31737]=0;if((b|0)==1){break _b}break Zb}f=N()|0;break Ea}f=N()|0;Eb(d+220|0);break Ea}x[31737]=0;e=d+220|0;W(585,e|0);b=x[31737];x[31737]=0;if((b|0)==1){break Yb}x[31737]=0;f=d+288|0;V(586,f|0,e|0,d+1703|0,c|0);b=x[31737];x[31737]=0;if((b|0)==1){break Xb}}Ab(c,f);tb(f);Eb(e);x[31737]=0;e=d+220|0;O(551,e|0,3977);b=x[31737];x[31737]=0;if((b|0)==1){break Vb}x[31737]=0;b=d+288|0;S(552,b|0,e|0,d+1703|0);f=x[31737];x[31737]=0;if((f|0)==1){break Ub}Ab(a+1298344|0,b);tb(b);Eb(e);x[31737]=0;b=P(1,b|0,15094)|0;e=x[31737];x[31737]=0;if((e|0)==1){break Tb}Ab(a+1298356|0,b);tb(b);b=x[a+480180>>2];switch(b-1|0){case 2:break sb;case 1:break Pb;case 3:break Qb;case 0:break Rb;default:break Wb}}f=N()|0;break Ea}f=N()|0;Eb(d+220|0);break Ea}if((b|0)==16){break Sb}if((b|0)==32){break Ob}if((b|0)!=16777216){break sb}x[31737]=0;b=P(1,d+220|0,10140)|0;e=x[31737];x[31737]=0;if((e|0)==1){break Nb}Ab(a+1298392|0,b);tb(b);x[31737]=0;b=P(1,d+244|0,13913)|0;e=x[31737];x[31737]=0;if((e|0)==1){break Mb}Ab(a+1298380|0,b);tb(b);break sb}f=N()|0;break Ea}f=N()|0;Eb(d+220|0);break Ea}f=N()|0;break Ea}x[31737]=0;b=P(1,d+220|0,10145)|0;e=x[31737];x[31737]=0;$b:{if((e|0)!=1){Ab(a+1298392|0,b);tb(b);x[31737]=0;b=P(1,d+244|0,8365)|0;e=x[31737];x[31737]=0;if((e|0)==1){break $b}Ab(a+1298380|0,b);tb(b);break sb}f=N()|0;break Ea}f=N()|0;break Ea}x[31737]=0;b=P(1,d+220|0,12402)|0;e=x[31737];x[31737]=0;ac:{if((e|0)!=1){Ab(a+1298392|0,b);tb(b);x[31737]=0;b=P(1,d+244|0,14309)|0;e=x[31737];x[31737]=0;if((e|0)==1){break ac}Ab(a+1298380|0,b);tb(b);break sb}f=N()|0;break Ea}f=N()|0;break Ea}x[31737]=0;b=P(1,d+220|0,10118)|0;e=x[31737];x[31737]=0;bc:{if((e|0)!=1){Ab(a+1298392|0,b);tb(b);x[31737]=0;b=P(1,d+244|0,15395)|0;e=x[31737];x[31737]=0;if((e|0)==1){break bc}Ab(a+1298380|0,b);tb(b);break sb}f=N()|0;break Ea}f=N()|0;break Ea}x[31737]=0;b=P(1,d+220|0,10490)|0;e=x[31737];x[31737]=0;cc:{if((e|0)!=1){Ab(a+1298392|0,b);tb(b);x[31737]=0;b=P(1,d+244|0,15136)|0;e=x[31737];x[31737]=0;if((e|0)==1){break cc}Ab(a+1298380|0,b);tb(b);break sb}f=N()|0;break Ea}f=N()|0;break Ea}x[31737]=0;b=P(1,d+220|0,6127)|0;e=x[31737];x[31737]=0;dc:{ec:{fc:{gc:{hc:{if((e|0)!=1){Ab(a+1298392|0,b);tb(b);if(!(l&65535)){break dc}x[31737]=0;b=d+264|0;O(269,b|0,4314);e=x[31737];x[31737]=0;if((e|0)==1){break hc}x[d+116>>2]=(l&65280)>>>8;x[31737]=0;x[d+100>>2]=l&255;e=d+104|0;O(445,e|0,d+100|0);f=x[31737];x[31737]=0;if((f|0)==1){break gc}x[31737]=0;f=d+244|0;V(431,f|0,b|0,d+116|0,e|0);i=x[31737];x[31737]=0;if((i|0)==1){break fc}Ab(a+1298380|0,f);tb(f);tb(e);Eb(b);break sb}f=N()|0;break Ea}f=N()|0;break Ea}f=N()|0;break ec}f=N()|0;tb(d+104|0)}Eb(d+264|0);break Ea}x[31737]=0;b=P(1,d+244|0,8573)|0;e=x[31737];x[31737]=0;if((e|0)!=1){Ab(a+1298380|0,b);tb(b);break sb}f=N()|0;break Ea}f=N()|0;break Ea}f=N()|0;break Ea}f=N()|0;break Ea}f=N()|0;break Ea}Ab(a+1298368|0,c);ic:{if(x[a+1074308>>2]){M=a,T=x[Fc(d+264|0,22)>>2],x[M+1298404>>2]=T;break ic}if(x[a+480180>>2]==1){M=a,T=x[Fc(d+264|0,28)>>2],x[M+1298404>>2]=T;break ic}M=a,T=x[Fc(d+264|0,4)>>2],x[M+1298404>>2]=T}g=1;jc:{kc:{if(h&1){x[31737]=0;b=P(1,d+264|0,16698)|0;h=x[31737];x[31737]=0;if((h|0)==1){break kc}a=x[a+1298472>>2];x[31737]=0;S(386,a|0,2,b|0);a=x[31737];x[31737]=0;if((a|0)==1){break jc}tb(b)}tb(c);zY(q);vc(o);Qc(s);ub(I);ub(H);break c}f=N()|0;break Ea}f=N()|0;tb(b);break Ea}f=N()|0;ub(e);break Ga}x[31737]=0;e=P(413,b|0,13956)|0;g=x[31737];x[31737]=0;if((g|0)==1){break Ha}lc:{if(!e){break lc}x[31737]=0;e=R(152,b|0)|0;g=x[31737];x[31737]=0;mc:{if((g|0)!=1){x[31737]=0;S(186,d+244|0,b|0,e|0);e=x[31737];x[31737]=0;if((e|0)!=1){break mc}}f=N()|0;break Ga}g=d+244|0;e=ic(d+288|0,g);ub(g);j=x[e>>2];x[31737]=0;j=R(155,j|0)|0;m=x[31737];x[31737]=0;if((m|0)!=1){w[d+244>>1]=(j>>>0)/20;w[d+264>>1]=z[E>>1];j=z[Nc(g,d+264|0)>>1];g=0;while(1){if((g|0)==(j|0)){ub(e);break lc}x[31737]=0;S(425,e|0,((g<<5)+a|0)+480289|0,20);m=x[31737];x[31737]=0;if((m|0)!=1){g=g+1|0;continue}break}}f=N()|0;ub(e);break Ga}x[31737]=0;P(436,a|0,b|0)|0;e=x[31737];x[31737]=0;if((e|0)==1){break Ha}x[31737]=0;ba(437,a|0,b|0,1,0)|0;e=x[31737];x[31737]=0;if((e|0)==1){break Ha}if((f-2186&65535)>>>0<=117){x[a+480180>>2]=16777216;x[31737]=0;S(449,a|0,b|0,f&65535);e=x[31737];x[31737]=0;if((e|0)==1){break Ha}}if(!x[a+1074308>>2]){break pb}x[31737]=0;e=P(1,d+172|0,18273)|0;g=x[31737];x[31737]=0;nc:{oc:{pc:{if((g|0)!=1){j=x[a+1074308>>2];x[31737]=0;g=d+244|0;O(135,g|0,j|0);j=x[31737];x[31737]=0;if((j|0)==1){break pc}x[31737]=0;j=d+288|0;S(2,j|0,e|0,g|0);m=x[31737];x[31737]=0;if((m|0)==1){break oc}Ab(c,j);tb(j);tb(g);tb(e);break pb}f=N()|0;break Ga}f=N()|0;break nc}f=N()|0;tb(d+244|0)}tb(e);break Ga}ub(b);continue}}f=N()|0;break ya}f=N()|0;break ya}f=N()|0}ub(b);break Ea}f=N()|0}tb(c);break ya}f=N()|0;break ya}f=N()|0;Kc(d+288|0);break ya}f=N()|0}ub(i)}tb(g)}zY(q);break ma}c=h}tb(g);j=j+1|0;continue}}f=N()|0;break ma}f=N()|0;tb(e);break ma}f=N()|0}vc(o);break A}q=q+1|0;continue}}Qc(s);break z}f=N()|0}ub(I);break y}f=N()|0}ub(H);break e}f=N()|0;break e}f=N()|0;break e}else{qc:{rc:{if(!j){v[d+288|0]=y[(d+g|0)+1240|0];v[d+220|0]=64;M=((g<<5)+a|0)+480286|0,T=y[Qb(d+288|0,d+220|0)|0],w[M>>1]=T;break rc}if(l){break qc}}sc:{f=y[(d+g|0)+1304|0];if((f|0)!=255){if((f|0)!=127){break sc}x[((g<<5)+a|0)+480280>>2]=256;break qc}w[((g<<5)+a|0)+480284>>1]=256;break qc}w[((g<<5)+a|0)+480284>>1]=f}g=g+1|0;continue}}f=N()|0;break d}f=N()|0;break d}f=N()|0}ub(n)}dc(C);Q(f|0);p()}ub(n)}dc(C)}fb=d+1712|0;return g|0}function era(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,T=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0;e=fb-944|0;fb=e;xc(b);f=e+892|0;a:{if(!RY(b,f)){break a}if(!WY(f)){break a}if(!Mb(x[b>>2],x[b+8>>2],Bc(VY(f),hb))){break a}d=1;if((c|0)==64){break a}Bd(a,8);gg(a);h=y[e+895|0]-48|0;v[e+891|0]=h;cd(b,$b(y[e+900|0]|y[e+901|0]<<8|(y[e+902|0]<<16|y[e+903|0]<<24)));f=e+584|0;fe(f,b,504);L=ic(e+868|0,f);ub(f);d=0;x[31737]=0;O(525,b|0,f|0);f=x[31737];x[31737]=0;b:{c:{d:{e:{f:{g:{if((f|0)!=1){if(y[e+867|0]>63){break b}if(Bb(z[e+584>>1])<<16>>16<0){break b}f=e+504|0;Rb(f,0,80);h:{d=$b(y[e+924|0]|y[e+925|0]<<8|(y[e+926|0]<<16|y[e+927|0]<<24));if(!d){break h}x[31737]=0;d=P(150,b|0,d|0)|0;g=x[31737];x[31737]=0;if((g|0)!=1){if(!d){break h}x[31737]=0;O(526,b|0,f|0);f=x[31737];x[31737]=0;if((f|0)!=1){break h}}i=N()|0;break e}x[31737]=0;f=e+500|0;S(527,f|0,b|0,h&255);d=x[31737];x[31737]=0;if((d|0)!=1){X=$e(f);d=0;f=z[e+500>>1];if((f-128&65535)>>>0<65409){break b}w[a+480188>>1]=f;H=Nb(e+488|0);f=$b(y[e+916|0]|y[e+917|0]<<8|(y[e+918|0]<<16|y[e+919|0]<<24));i:{if(f){x[31737]=0;P(150,b|0,f|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break g}x[31737]=0;S(528,b|0,H|0,y[e+867|0]);f=x[31737];x[31737]=0;if((f|0)==1){break g}g=y[e+867|0];break i}g=y[e+867|0];if(g){break c}}F=a+480188|0;g=g&255;w[a+480192>>1]=g;w[a+480190>>1]=g;Y=(h&255)>>>0<2|v[e+848|0]>=0;B=!Y;u=c&2;k=1;n=1;while(1){j:{k:{l:{m:{n:{o:{d=n&65535;if(d>>>0<=(g&65535)>>>0){x[31737]=0;q=k&65535;f=U(252,a|0,d|0,q|0)|0;g=x[31737];x[31737]=0;p:{if((g|0)!=1){if(f){break p}break d}i=N()|0;break f}f=x[((d<<2)+a|0)+900380>>2];w[e+92>>1]=0;x[e+88>>2]=0;x[31737]=0;j=R(169,e+468|0)|0;g=x[31737];x[31737]=0;q:{if((g|0)!=1){d=yb(x[H>>2],d-1|0);d=$b(y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24));r:{if(!d){break r}x[31737]=0;d=P(150,b|0,d|0)|0;g=x[31737];x[31737]=0;if((g|0)==1){break k}if(!d){break r}x[31737]=0;O(529,b|0,e+88|0);d=x[31737];x[31737]=0;if((d|0)==1){break k}g=x[e+88>>2];h=w[e+92>>1];x[31737]=0;d=e+128|0;i=$b(g);g=xe(h);S(186,d|0,b|0,i<<((g|0)>0&(g&65504)>>>5));g=x[31737];x[31737]=0;if((g|0)==1){break k}g=ic(e+188|0,d);hd(j,g);ub(g);ub(d)}g=xe(w[e+92>>1]);d=g&15;if((g|0)>=0){break q}Iv(f,0);$=1;break o}i=N()|0;break f}if(d>>>0>6){break o}l=y[d+25110|0];if(!d){break m}w[a+480190>>1]=(z[a+480190>>1]+l|0)-1;t=f+108|0;m=f+236|0;i=4;r=l-2<<3;s:while(1){h=1;if((i|0)==10){break n}h=D(i,12);d=i+r|0;o=y[d+25116|0]+k|0;s=y[d+25164|0];d=0;while(1)if((d|0)==12){i=i+1|0;continue s}else{A=d+h|0;ia=_b(m,A),ja=o,w[ia>>1]=ja;A=xb(t,A);v[A|0]=s+y[A|0];d=d+1|0;continue}}}t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{f=$b(x[e+508>>2]);if(!f){break D}if(!Bb(z[e+512>>1])){break D}x[31737]=0;f=P(150,b|0,f|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break C}if(!f){break D}ia=e,ja=Bb(z[e+512>>1]),w[ia+188>>1]=ja;w[e+128>>1]=y[e+867|0];k=z[Nc(e+188|0,e+128|0)>>1];f=e+136|0;l=e+132|0;h=Bb(z[e+514>>1]);n=h>>>0<5;m=h>>>0<19;q=h>>>0<21;r=h>>>0<15;B=h>>>0<6;g=0;while(1){if((g|0)==(k|0)){break D}x[31737]=0;S(530,b|0,e+188|0,h|0);d=x[31737];x[31737]=0;E:{F:{G:{if((d|0)!=1){g=g+1|0;d=x[((g<<2)+a|0)+900380>>2];j=y[e+188|0];if(j){t=em(e+128|0,0,64);em(l,j-1&65535,64);i=y[e+189|0];if(i){i=64/(i>>>0)|0}else{i=0}em(f,i+j|0,0);x[31737]=0;j=d+48|0;S(531,j|0,t|0,3);i=x[31737];x[31737]=0;if((i|0)==1){break G}if(y[e+188|0]==1){i=x[vb(e+464|0,wb(x[j>>2]))>>2];t=wb(x[j>>2]);i=x[j>>2]+(Gv(i,t)<<2)|0;Ih(j,Wg(i+4|0,x[j+4>>2],i));wb(i)}j=y[e+189|0];x[d>>2]=j?j<<9:32767;v[d+60|0]=y[d+60|0]|1;t=1}H:{if(n){break H}j=y[e+192|0];if(j){ia=xb(d+108|0,24),ja=j+24|0,v[ia|0]=ja;t=1}if(m){break H}x[d+4>>2]=y[e+206|0]+1>>>1;if(q){break H}w[d+28>>1]=y[e+208|0]|y[e+209|0]<<8}d=D(z[_b(d+236|0,61)>>1],104)+a|0;v[d+484417|0]=y[e+191|0]<<4;if(r){break F}j=$b(y[e+198|0]|y[e+199|0]<<8|(y[e+200|0]<<16|y[e+201|0]<<24));x[d+484384>>2]=j;ia=d+484388|0,ja=$b(y[e+202|0]|y[e+203|0]<<8|(y[e+204|0]<<16|y[e+205|0]<<24))+j|0,x[ia>>2]=ja;break E}i=N()|0;break f}i=N()|0;break f}if(B){continue}}j=d+484414|0;i=j;o=z[j>>1]&65529;j=y[e+193|0];w[i>>1]=o|j<<1&2|j>>>1&4;if(!(j&4)){continue}w[d+484412>>1]=0;continue}}I:{f=$b(x[e+524>>2]);if(!f){break I}if(!Bb(z[e+528>>1])){break I}x[31737]=0;f=P(150,b|0,f|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break C}if(!f){break I}ia=e,ja=Bb(z[e+528>>1]),w[ia+188>>1]=ja;w[e+128>>1]=y[e+867|0];j=z[Nc(e+188|0,e+128|0)>>1];i=Bb(z[e+530>>1]);d=0;J:while(1){if((d|0)==(j|0)){break I}x[31737]=0;f=e+188|0;S(532,b|0,f|0,i|0);g=x[31737];x[31737]=0;if((g|0)==1){break t}g=e+88|0;R_(g,f);x[31737]=0;f=e+128|0;O(219,f|0,g|0);g=x[31737];x[31737]=0;if((g|0)==1){break u}d=d+1|0;h=((d<<2)+a|0)+900380|0;zc(x[h>>2]+492|0,f);tb(f);g=x[h>>2];x[31737]=0;O(390,f|0,g|0);g=x[31737];x[31737]=0;if((g|0)==1){break v}ia=e,ja=_i(x[e+128>>2]),x[ia+88>>2]=ja;k=Rf(f);while(1){f=x[e+88>>2];if(Ib(f,k)){g=(z[hp(f)>>1]<<5)+a|0;l=g+946328|0;f=x[h>>2];n=x[f+520>>2];x[l>>2]=x[f+516>>2];x[l+4>>2]=n;n=x[f+512>>2];l=g+946320|0;x[l>>2]=x[f+508>>2];x[l+4>>2]=n;n=x[f+504>>2];l=g+946312|0;x[l>>2]=x[f+500>>2];x[l+4>>2]=n;l=x[f+496>>2];g=g+946304|0;x[g>>2]=x[f+492>>2];x[g+4>>2]=l;ah(e+88|0);continue}else{Tv(e+128|0);continue J}}}}pr(a+901404|0);f=qc(e+456|0,4940);qf(Oe(a+901692|0,0),x[f>>2],x[f+4>>2]);xc(b);aa=c&1;r=a+484344|0;B=a+1298332|0;Z=a+1298308|0;M=a+484360|0;j=0;n=0;while(1){K:{c=j&255;if(c>>>0>=y[X|0]){break K}x[31737]=0;V(533,b|0,e+892|0,e+504|0,e+584|0);f=x[31737];x[31737]=0;L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{if((f|0)==1){break X}Y:{if(!c){d=0;break Y}x[31737]=0;c=R(275,M|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break X}d=j;if((c|0)==255){break d}}k=Tj(x[M>>2],d&255);m=qg(e+444|0);kj(k);if(y[e+891|0]<=1){c=Bb(z[e+586>>1]);if(c>>>0>256){break Q}f=e+188|0;PY(f,e+584|0);x[31737]=0;S(534,k|0,f|0,c|0);c=x[31737];x[31737]=0;if((c|0)==1){break W}ia=e,ja=wb(x[k>>2]),x[ia+188>>2]=ja;f=wb(x[k+4>>2]);while(1){c=x[e+188>>2];if(Ib(c,f)){w[c>>1]=z[c>>1]+n;Md(e+188|0);continue}break}Xh(a,1);w[e+188>>1]=16;c=z[Nc(F,e+188|0)>>1];d=0;while(1)if((c|0)==(d|0)){c=32;break M}else{v[e+188|0]=y[(d+e|0)+850|0];v[e+128|0]=64;ia=((d<<5)+a|0)+480286|0,ja=y[Qb(e+188|0,e+128|0)|0],w[ia>>1]=ja;d=d+1|0;continue}}PY(e+188|0,e+584|0);c=Bb(z[e+200>>1]);if(!c|c>>>0>64|z[F>>1]>64){break Q}l=$b(x[e+208>>2]);c=Bb(z[e+212>>1]);if(c){w[e+128>>1]=c;w[e+88>>1]=800;c=Bc(((z[Nc(e+128|0,e+88|0)>>1]<<5)+50>>>0)/100|0,0)}else{c=32}f=x[e+196>>2];x[31737]=0;f=P(150,b|0,$b(f)|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break V}d=0;Z:{if(!f){break Z}while(1){if(z[F>>1]<=d>>>0){break Z}x[31737]=0;f=R(198,b|0)|0;g=x[31737];x[31737]=0;if((g|0)!=1){v[e+128|0]=f;v[e+88|0]=64;ia=((d<<5)+a|0)+480286|0,ja=y[Qb(e+128|0,e+88|0)|0],w[ia>>1]=ja;d=d+1|0;continue}break}i=N()|0;break w}_:{$:{f=$b(x[e+204>>2]);if(!f){break $}x[31737]=0;f=P(150,b|0,f|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break V}d=0;if(!f){break $}while(1){if(z[F>>1]<=d>>>0){break _}x[31737]=0;f=R(535,b|0)|0;g=x[31737];x[31737]=0;if((g|0)!=1){ia=((d<<5)+a|0)+480284|0,ja=(Yb(f,-16,16)<<3)+128|0,w[ia>>1]=ja;d=d+1|0;continue}break}i=N()|0;break w}Xh(a,1)}f=Nb(e+176|0);d=x[e+192>>2];x[31737]=0;h=P(150,b|0,$b(d)|0)|0;d=x[31737];x[31737]=0;aa:{if((d|0)==1){break aa}g=33;d=0;if(!h){break N}h=z[e+586>>1];i=x[b+8>>2];q=x[b>>2];x[31737]=0;h=U(151,q|0,i|0,Bb(h)<<1)|0;i=x[31737];x[31737]=0;if((i|0)==1){break aa}if(!h){break N}h=z[e+586>>1];x[31737]=0;h=U(536,b|0,f|0,Bb(h)|0)|0;i=x[31737];x[31737]=0;if((i|0)==1){break aa}if(!h){break N}ia=e,ja=wb(x[f>>2]),x[ia+172>>2]=ja;q=wb(x[e+180>>2]);u=x[e+188>>2];o=z[e+202>>1];while(1){d=x[e+172>>2];if(!Ib(d,q)){g=0;d=1;break N}d=Bb(y[d|0]|y[d+1|0]<<8);ba:{if(Bb(o)>>>0<d>>>0){break ba}x[31737]=0;P(150,b|0,$b(u)+(d<<2)|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break U}x[31737]=0;d=R(282,b|0)|0;g=x[31737];x[31737]=0;if((g|0)==1){break U}x[31737]=0;d=P(150,b|0,d|0)|0;g=x[31737];x[31737]=0;if((g|0)==1){break U}if(!d){break ba}d=x[b+8>>2];g=x[b>>2];x[31737]=0;d=U(151,g|0,d|0,42)|0;g=x[31737];x[31737]=0;if((g|0)==1){break U}if(!d){break ba}x[31737]=0;O(537,b|0,e+128|0);d=x[31737];x[31737]=0;ca:{if((d|0)!=1){if(mc(x[k>>2],x[k+4>>2])){break ca}x[31737]=0;O(538,k|0,65534);d=x[31737];x[31737]=0;if((d|0)!=1){break ca}}i=N()|0;break O}d=Bb(y[e+168|0]|y[e+169|0]<<8);x[e+124>>2]=d;g=x[b+8>>2];h=x[b>>2];x[31737]=0;d=U(151,h|0,g|0,d|0)|0;g=x[31737];x[31737]=0;if((g|0)==1){break T}if(!d){x[31737]=0;d=R(203,b|0)|0;g=x[31737];x[31737]=0;if((g|0)==1){break T}wc(e+124|0,d)}wc(e+124|0,65534);g=x[k+4>>2];h=x[k>>2];d=0;x[31737]=0;i=x[e+124>>2];s=Zc(h,g);O(539,k|0,i+s|0);g=x[31737];x[31737]=0;if((g|0)==1){break P}while(1){da:{if((d|0)==(i|0)){if(y[e+128|0]){Kn(e+88|0,e+128|0);x[31737]=0;d=e+112|0;S(540,d|0,x[e+88>>2],x[e+92>>2]);g=x[31737];x[31737]=0;if((g|0)==1){break S}tp(k,d);tb(d)}d=$b(y[e+160|0]|y[e+161|0]<<8|(y[e+162|0]<<16|y[e+163|0]<<24));if(!d){break ba}x[31737]=0;d=P(150,b|0,d|0)|0;g=x[31737];x[31737]=0;if((g|0)!=1){break da}break P}x[31737]=0;g=R(274,b|0)|0;h=x[31737];x[31737]=0;ea:{if((h|0)!=1){g=g<<16>>16;if((g|0)<0){break ea}x[31737]=0;O(538,k|0,g+n&65535);g=x[31737];x[31737]=0;if((g|0)!=1){break ea}}i=N()|0;break O}d=d+1|0;continue}break}if(!d){break ba}while(1){fa:{x[31737]=0;d=P(541,b|0,e+108|0)|0;g=x[31737];x[31737]=0;ga:{ha:{ia:{ja:{if((g|0)!=1){if(!d){break ba}x[31737]=0;d=e+68|0;S(186,d|0,b|0,y[e+111|0]);g=x[31737];x[31737]=0;if((g|0)==1){break ja}g=ic(e+88|0,d);ub(d);h=Bb(z[e+108>>1]);d=jm(h+s|0);w[e+68>>1]=d;if((h|0)==65535){break fa}i=x[k>>2];if(Zc(i,x[k+4>>2])>>>0<=d>>>0){break fa}h=65535;switch(y[e+110|0]-1|0){case 0:break ha;case 1:break ia;default:break ga}}i=N()|0;break O}i=N()|0;break O}x[31737]=0;d=R(274,g|0)|0;h=x[31737];x[31737]=0;if((h|0)==1){break R}x[31737]=0;h=P(542,m|0,e+68|0)|0;i=x[31737];x[31737]=0;if((i|0)==1){break R}w[h>>1]=d;i=x[k>>2];h=65534;d=z[e+68>>1]}ia=_b(i,d),ja=h,w[ia>>1]=ja}ub(g);continue}break}ub(g)}Md(e+172|0);continue}}i=N()|0;break O}i=N()|0;break f}i=N()|0;break w}i=N()|0;break w}i=N()|0;break O}i=N()|0;break O}i=N()|0;break O}i=N()|0;ub(g);break O}cD(m);break d}i=N()|0}md(f);break w}md(f);if(!d){break L}c=c>>>(l>>>1&1)|0}d=Bb(z[e+844>>1]);g=y[e+847|0];_=g&64;f=y[e+848|0];T=f&32;I=(f&31)+1|0;ia=a,ja=LY(d,_>>>6|0,T>>>5|0,I),x[ia+480204>>2]=ja;ia=a,ja=Kd(y[e+849|0],1,32),x[ia+480196>>2]=ja;if(T){x[a+480216>>2]=I;x[a+480220>>2]=I<<2}f=y[e+866|0];if(f){v[e+188|0]=f;v[e+128|0]=64;ia=a,ja=y[Qb(e+188|0,e+128|0)|0]<<2,x[ia+480200>>2]=ja}x[a+480228>>2]=c;x[a+480232>>2]=c;x[a+480208>>2]=x[a+480208>>2]&-3|(g^-1)>>>4&2;ka:{la:{ma:{na:{oa:{pa:{qa:{ra:{sa:{ta:{c=$b(x[e+548>>2]);ua:{if(!c){break ua}x[31737]=0;c=P(150,b|0,c|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break ta}if(!c){break ua}c=x[e+552>>2];x[31737]=0;S(271,b|0,Z|0,$b(c)|0);c=x[31737];x[31737]=0;if((c|0)==1){break ta}if(y[X|0]<2){break ua}x[31737]=0;c=e+56|0;S(259,c|0,28,Z|0);f=x[31737];x[31737]=0;if((f|0)==1){break ta}tp(k,c);tb(c)}va:{if($b(x[e+520>>2])>>>0<2){break va}c=x[e+516>>2];x[31737]=0;c=P(150,b|0,$b(c)|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break ta}if(!c){break va}c=x[e+520>>2];x[31737]=0;V(337,B|0,b|0,$b(c)-1|0,4);c=x[31737];x[31737]=0;if((c|0)==1){break ta}}c=$b(x[e+560>>2]);if(!c){break ka}x[31737]=0;c=P(150,b|0,c|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break ta}if(!c){break ka}c=x[b+8>>2];f=x[b>>2];x[31737]=0;c=U(151,f|0,c|0,12)|0;f=x[31737];x[31737]=0;if((f|0)==1){break ta}if(!c){break ka}x[31737]=0;P(184,b|0,6)|0;c=x[31737];x[31737]=0;if((c|0)==1){break ta}x[31737]=0;c=R(274,b|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break ta}if((c|0)!=1){break ka}x[31737]=0;c=R(282,b|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break ra}if(!c){break ka}f=x[b+8>>2];d=x[b>>2];x[31737]=0;f=U(151,d|0,f|0,c|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break ra}if(f){break sa}break ka}i=N()|0;break w}f=$G(e+188|0,B);x[31737]=0;V(337,B|0,b|0,c|0,4);c=x[31737];x[31737]=0;if((c|0)==1){break ma}if(!Ad(x[e+192>>2],y[e+199|0])){x[31737]=0;c=U(543,e+32|0,2,13)|0;d=x[31737];x[31737]=0;if((d|0)==1){break qa}x[31737]=0;d=e+128|0;S(544,d|0,f|0,c|0);h=x[31737];x[31737]=0;if((h|0)==1){break pa}x[31737]=0;h=e+44|0;S(545,h|0,d|0,B|0);i=x[31737];x[31737]=0;if((i|0)==1){break oa}Ab(B,h);tb(h);tb(d);tb(c)}tb(f);break ka}i=N()|0;break w}i=N()|0;break la}i=N()|0;break na}i=N()|0;tb(e+128|0)}tb(c);break la}i=N()|0}tb(f);break w}wa:{J=y[e+891|0];if(J>>>0<2){break wa}i=0;if(!$b(x[e+572>>2])){break wa}while(1){if(z[F>>1]<=i>>>0){break wa}c=x[e+572>>2];x[31737]=0;c=P(150,b|0,$b(c)+(i<<2)|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break x}xa:{if(!c){break xa}x[31737]=0;c=R(282,b|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break x}x[31737]=0;c=P(150,b|0,c|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break x}h=0;d=0;if(!c){break xa}while(1){ya:{c=x[b+8>>2];f=x[b>>2];x[31737]=0;c=U(151,f|0,c|0,8)|0;f=x[31737];x[31737]=0;za:{Aa:{Ba:{if((f|0)!=1){if(!c){break ya}x[31737]=0;O(546,b|0,e+188|0);c=x[31737];x[31737]=0;if((c|0)==1){break Ba}c=$b(x[e+188>>2]);if(!c){break ya}switch((c&536870911)-1|0){case 1:break za;case 0:break Aa;default:continue}}i=N()|0;break w}i=N()|0;break w}h=$b(x[e+192>>2]);continue}d=$b(x[e+192>>2]);continue}break}if(!h|!d){break xa}x[31737]=0;c=P(150,b|0,h|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break y}if(!c){break xa}x[31737]=0;S(425,b|0,((i<<5)+a|0)+480289|0,d|0);c=x[31737];x[31737]=0;if((c|0)==1){break y}}i=i+1|0;continue}}ia=e,ja=Bb(z[e+584>>1]),w[ia+172>>1]=ja;Gf(e+172|0,(n^-1)&65535);x[31737]=0;u=z[e+172>>1];O(224,r|0,u+n&65535);c=x[31737];x[31737]=0;Ca:{if((c|0)==1){break Ca}ba=n&65535;o=0;ca=(g&16)!=0;Da:{Ea:{while(1){if((o|0)==(u|0)){ia=e,ja=_i(x[m>>2]),x[ia+128>>2]=ja;g=Rf(m);while(1){Fa:{Ga:{Ha:{Ia:{Ja:{Ka:{c=x[e+128>>2];if(!Zg(c,g)){c=$b(x[e+504>>2]);if(c){break Ka}g=31;break Ja}c=hp(c);f=$e(c);d=z[c>>1];if(!d){d=0;break Ia}h=d-1&65535;if(!bj(k,h)){break Ia}x[31737]=0;d=P(369,k|0,h|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break Fa}break Ha}x[31737]=0;c=P(150,b|0,c|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break Ca}g=c?0:31}n=n+u|0;break L}if(z[f>>1]==(d+1|0)){break Ga}x[31737]=0;d=P(368,r|0,1)|0;h=x[31737];x[31737]=0;if((h|0)==1){break Fa}if((d|0)==65535){break Ga}ia=_b(x[k>>2],z[c>>1]),ja=d,w[ia>>1]=ja}c=Wb(x[r>>2],d);ye(c,Gn(Xe(Ne(e+188|0,12,$v(z[f>>1])),x[c+12>>2]-1|0)));u=(u&65535)>>>0>d>>>0?u:d+1|0}ah(e+128|0);continue}break}i=N()|0;break w}La:{Ma:{if(!aa){break Ma}c=y[e+908|0]|y[e+909|0]<<8|(y[e+910|0]<<16|y[e+911|0]<<24);x[31737]=0;c=P(150,b|0,$b(c)+(o<<2)|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break Ea}if(!c){break Ma}x[31737]=0;c=R(282,b|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break Ea}x[31737]=0;c=P(150,b|0,c|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break Ea}if(!c){break Ma}A=Fb(e+68|0);x[31737]=0;c=v[e+846|0];K=R(169,e+12|0)|0;f=x[31737];x[31737]=0;Na:{Oa:{if((f|0)!=1){l=c+48|0;if(J){break Oa}x[31737]=0;O(547,b|0,e+188|0);c=x[31737];x[31737]=0;if((c|0)==1){break La}w[e+124>>1]=y[e+188|0];s=y[e+189|0]+1|0;break Na}i=N()|0;break z}x[31737]=0;O(548,b|0,e+176|0);f=x[31737];x[31737]=0;Pa:{Qa:{if((f|0)!=1){d=Bb(z[e+176>>1]);w[e+124>>1]=d;s=Bb(z[e+178>>1])+1|0;f=$b(z[e+180>>1]|z[e+182>>1]<<16);if(!f){break Pa}g=x[b+8>>2];x[31737]=0;P(150,b|0,f|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break A}x[31737]=0;O(549,b|0,e+188|0);f=x[31737];x[31737]=0;if((f|0)==1){break A}f=y[e+192|0]|y[e+193|0]<<8|(y[e+194|0]<<16|y[e+195|0]<<24);x[31737]=0;f=P(150,b|0,$b(f)|0)|0;h=x[31737];x[31737]=0;if((h|0)==1){break A}if(!f){break Qa}f=y[e+196|0]|y[e+197|0]<<8|(y[e+198|0]<<16|y[e+199|0]<<24);x[31737]=0;S(271,b|0,A|0,$b(f)|0);f=x[31737];x[31737]=0;if((f|0)!=1){break Qa}break A}break A}f=$b(y[e+204|0]|y[e+205|0]<<8|(y[e+206|0]<<16|y[e+207|0]<<24));Ra:{if(!f){break Ra}x[31737]=0;f=P(150,b|0,f|0)|0;h=x[31737];x[31737]=0;if((h|0)==1){break A}if(!f){break Ra}x[31737]=0;f=R(282,b|0)|0;h=x[31737];x[31737]=0;if((h|0)==1){break A}x[31737]=0;f=P(150,b|0,f|0)|0;h=x[31737];x[31737]=0;if((h|0)==1){break A}if(!f){break Ra}x[31737]=0;f=e+88|0;S(186,f|0,b|0,D(d,s)|0);d=x[31737];x[31737]=0;if((d|0)==1){break A}d=ic(e+128|0,f);hd(K,d);ub(d);ub(f)}x[31737]=0;P(150,b|0,g|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break A}}l=J>>>0>2?c+24|0:l}x[31737]=0;c=o+ba|0;f=U(197,r|0,c&65535,s|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break A}Sa:{if(!f){break Sa}f=x[r>>2];x[31737]=0;q=Wb(f,c);O(284,q|0,A|0);c=x[31737];x[31737]=0;if((c|0)==1){break Da}Gf(e+124|0,z[F>>1]);da=s-1|0;c=0;ea=z[e+124>>1];Ta:while(1){if((c|0)==(s|0)){break Sa}f=c+1|0;fa=c-1|0;i=0;d=jd(x[q>>2],x[x[q+48>>2]+12>>2],c,0);ga=c>>>0>=da>>>0;while(1){G=i&65535;if(ea>>>0<=G>>>0){c=f;continue Ta}vD(e+128|0,y[d+3|0],d+5|0);Ua:{if(!J){x[31737]=0;g=e+188|0;O(550,g|0,b|0);h=x[31737];x[31737]=0;if((h|0)!=1){h=y[e+188|0];C=Jc(g);v[d+1|0]=h>>>3&16|y[C|0]>>>4|h>>>1&32;C=y[C|0];ia=d,ja=y[$e(g)|0],v[ia+5|0]=ja;g=h&63;g=g?g+l|0:0;h=C&15;break Ua}break A}x[31737]=0;g=e+188|0;O(358,g|0,b|0);h=x[31737];x[31737]=0;Va:{Wa:{if((h|0)!=1){h=Jc(g);C=$e(g);W=dj(g);x[31737]=0;g=R(198,K|0)|0;E=x[31737];x[31737]=0;if((E|0)==1){break A}v[d+4|0]=g;E=y[e+188|0];g=E&127;if(!g){break Wa}g=g+l|0;break Va}break A}g=0;if((E|0)!=128){break Va}v[d|0]=254}v[d+1|0]=y[h|0]&63;h=y[C|0];v[d+5|0]=y[W|0]}if(g-1>>>0<=119){v[d|0]=g}W=(g|0)>84;C=e+188|0;E=(_|0)!=0;ha=(T|0)!=0;g=fb-16|0;fb=g;v[d+3|0]=0;Xa:{Ya:{Za:{_a:{$a:{ab:{bb:{cb:{db:{eb:{fb:{gb:{hb:{ib:{jb:{kb:{lb:{mb:{nb:{ob:{pb:{qb:{rb:{sb:{tb:{h=h&255;switch(h-4|0){case 4:case 10:break Ya;case 42:break _a;case 37:break $a;case 28:break ab;case 27:break bb;case 26:break cb;case 25:break db;case 24:break eb;case 23:break fb;case 22:break gb;case 21:break hb;case 20:break ib;case 18:break jb;case 17:break kb;case 16:break lb;case 14:break mb;case 13:break nb;case 12:break ob;case 11:break pb;case 9:break qb;case 8:break rb;case 5:break sb;case 0:break tb;default:break Za}}v[d+3|0]=5;h=y[d+5|0];v[g+15|0]=h>>>3;v[g+14|0]=15;E=y[Qb(g+15|0,g+14|0)|0];v[g+13|0]=h<<1&30;v[g+12|0]=15;ia=d,ja=y[Qb(g+13|0,g+12|0)|0]|E<<4,v[ia+5|0]=ja;break Ya}if((y[d+5|0]-1&255)>>>0>19){break Ya}v[d+3|0]=16;break Ya}v[d+3|0]=13;h=y[d+5|0];ub:{if(!ca){if(h>>>0>152){break ub}v[d+5|0]=D((h&240)>>>4|0,10)+(h&15);break Ya}v[d+5|0]=(h&127)+1>>>1;break Ya}v[d+3|0]=0;break Ya}v[d+3|0]=11;break Ya}h=y[d+5|0];if(!h){v[d+3|0]=14;break Ya}if(h>>>0>240){break Ya}v[d+3|0]=17;if(h>>>0<=2){v[d+5|0]=112;break Ya}h=HD(+(LY(h,E,ha,I)>>>0)/1e4);if(h>>>0<=255){v[d+5|0]=h;break Ya}v[d+5|0]=h>>>8;v[g+11|0]=h;de(C,34,g+11|0);break Xa}v[d+3|0]=31;v[d+5|0]=y[d+5|0]|128;break Ya}v[d+3|0]=19;v[g+10|0]=15;ia=d,ja=y[Qb(d+5|0,g+10|0)|0]|16,v[ia+5|0]=ja;break Ya}v[d+3|0]=19;v[g+9|0]=15;ia=d,ja=y[Qb(d+5|0,g+9|0)|0]|32,v[ia+5|0]=ja;break Ya}v[d+3|0]=5;h=y[d+5|0];v[g+8|0]=(h>>>4|0)+1;v[g+7|0]=15;ia=d,ja=h&15|y[Qb(g+8|0,g+7|0)|0]<<4,v[ia+5|0]=ja;break Ya}v[d+3|0]=19;v[d+5|0]=y[d+5|0]&15|80;break Ya}v[d+3|0]=19;v[g+6|0]=15;ia=d,ja=y[Qb(d+5|0,g+6|0)|0]|96,v[ia+5|0]=ja;break Ya}v[d+3|0]=19;v[g+5|0]=15;ia=d,ja=y[Qb(d+5|0,g+5|0)|0]|192,v[ia+5|0]=ja;break Ya}v[d+3|0]=10;break Ya}v[d+3|0]=19;v[g+4|0]=15;ia=d,ja=y[Qb(d+5|0,g+4|0)|0]|160,v[ia+5|0]=ja;break Ya}v[d+3|0]=19;v[g+3|0]=15;ia=d,ja=y[Qb(d+5|0,g+3|0)|0]|176,v[ia+5|0]=ja;break Ya}h=y[d+5|0]-1<<24>>24;if((h|0)<0){break Ya}v[d+5|0]=h;v[d+3|0]=31;break Ya}v[d+3|0]=14;break Ya}v[d+3|0]=19;v[g+2|0]=15;ia=d,ja=y[Qb(d+5|0,g+2|0)|0]|224,v[ia+5|0]=ja;break Ya}h=y[d+5|0];if(h>>>0>=16){v[d+3|0]=19;v[d+5|0]=h>>>4|208;break Ya}if(!h){break Ya}v[d+3|0]=19;v[d+5|0]=h|144;break Ya}if(y[d+5|0]|y[d+4|0]){break Ya}if(!Sc(y[d|0])){break Ya}v[d+5|0]=159;v[d+3|0]=20;break Ya}h=y[d+4|0];if(!h){break Ya}v[d+3|0]=44;ia=d,ja=yi(Bc(((y[d+5|0]<<8&65280)>>>0)/(h>>>0)|0,0)),v[ia+5|0]=ja;break Ya}h=y[d+5|0];if((h+16&255)>>>0>32){break Ya}v[d+3|0]=9;ia=d,ja=Ch(((h^128)<<3)-896|0),v[ia+5|0]=ja;break Ya}if(h>>>0>15){break Ya}Bf(d,h,y[d+5|0])}v[g+1|0]=0;vD(C,0,g+1|0)}fb=g+16|0;vb:{if(y[e+128|0]!=34){break vb}if(!y[d+3|0]){g=z[e+128>>1];v[d+3|0]=g;v[d+5|0]=g>>>8;break vb}if(!c){break vb}ia=jd(x[q>>2],x[x[q+48>>2]+12>>2],fa,G),ja=255,v[ia+5|0]=ja}g=W&Y;wb:{if(!y[e+188|0]){break wb}if(!ga){h=jd(x[q>>2],x[x[q+48>>2]+12>>2],f,G);G=z[e+188>>1];v[h+3|0]=G;v[h+5|0]=G>>>8;break wb}v[d+5|0]=255}t=g|t;d=d+6|0;i=i+1|0;continue}}}ub(K);tb(A)}o=o+1|0;continue}break}break A}i=N()|0;break w}break A}i=N()|0;break w}cD(m);d=0;xb:{switch(g-31|0){default:if(g){break c}break;case 2:break xb;case 1:break c;case 0:break K}}j=j+1|0;continue}break}ak(M,0);d=1;if(t&1){break B}while(1){b=d&65535;if(b>>>0>z[a+480192>>1]){w[a+480192>>1]=0;break B}b=((b<<2)+a|0)+900380|0;c=x[b>>2];if(c){Db(Hv(c))}x[b>>2]=0;d=d+1|0;continue}}i=N()|0;break f}yb:{if(!$){break yb}x[31737]=0;b=P(1,e+188|0,16439)|0;c=x[31737];x[31737]=0;zb:{if((c|0)!=1){c=x[a+1298472>>2];x[31737]=0;S(386,c|0,2,b|0);c=x[31737];x[31737]=0;if((c|0)==1){break zb}tb(b);break yb}i=N()|0;break f}i=N()|0;tb(b);break f}g=22303;Ab:{Bb:{switch(y[e+891|0]){case 0:g=z[F>>1]>4?17327:17313;break Ab;case 1:g=17295;break Ab;case 2:g=17277;break Ab;case 3:break Bb;default:break Ab}}g=17250}x[31737]=0;b=e+88|0;O(551,b|0,16849);c=x[31737];x[31737]=0;Cb:{Db:{Eb:{if((c|0)!=1){x[31737]=0;c=e+128|0;S(552,c|0,b|0,e+891|0);f=x[31737];x[31737]=0;if((f|0)==1){break Eb}Ab(a+1298344|0,c);tb(c);Eb(b);x[31737]=0;c=P(1,c|0,12722)|0;f=x[31737];x[31737]=0;if((f|0)==1){break Db}Ab(a+1298356|0,c);tb(c);x[31737]=0;O(131,a+1298368|0,g|0);c=x[31737];x[31737]=0;if((c|0)==1){break Cb}ia=a+1298404|0,ja=x[Fc(b,28)>>2],x[ia>>2]=ja;d=1;break c}i=N()|0;break f}i=N()|0;Eb(e+88|0);break f}i=N()|0;break f}i=N()|0;break f}i=N()|0;ub(K)}tb(A);break w}i=N()|0;break w}i=N()|0}cD(m);break f}i=N()|0;break f}i=N()|0;break f}i=N()|0;break f}l=1;if((d|0)!=7){break m}d=f+108|0;h=MC(d);while(1){if((d|0)!=(h|0)){ia=d,ja=dw(y[d|0]-24|0),v[ia|0]=ja;d=d+1|0;continue}break}h=0}t=1;break l}h=0;Fb:{if(B|(g|0)<0){break Fb}m=f+108|0;i=7;Gb:while(1){if((i|0)==10){break Fb}r=D(i,12);o=D(i,-12)+72|0;d=0;while(1)if((d|0)==12){i=i+1|0;continue Gb}else{s=xb(m,d+r|0);v[s|0]=o+y[s|0];d=d+1|0;continue}}}}x[31737]=0;O(553,L|0,e+188|0);d=x[31737];x[31737]=0;if((d|0)!=1){Hb:{d=y[e+192|0];if((d-1&255)>>>0<=15){v[f+31|0]=d;t=1}d=y[e+193|0];if(d-1<<24>>24>=0){v[f+30|0]=d}d=0;Ib:{while(1){if((d|0)==(l|0)){if(!u){break j}if((g|0)>=0){break Ib}break j}x[31737]=0;f=D(d+q|0,104)+a|0;O(280,f+484380|0,8);i=x[31737];x[31737]=0;if((i|0)!=1){v[e+128|0]=y[e+194|0];v[e+68|0]=64;ia=f+484410|0,ja=y[Qb(e+128|0,e+68|0)|0]<<2,w[ia>>1]=ja;v[f+484416|0]=y[e+195|0];d=d+1|0;continue}break}break k}f=Xc(e+128|0,8,1,1,0);r=Bb(z[e+190>>1]);i=Bb(z[e+188>>1]);d=x[j>>2];x[31737]=0;g=R(155,d|0)|0;d=x[31737];x[31737]=0;if((d|0)!=1){d=xe(w[e+92>>1]);if(d&16){fd(f,16);g=g>>>1|0}if(d&32){Bp(f,3);g=g>>>1|0}if(d&64){yg(f,2)}if(h){g=(g>>>0)/((-1<<l^-1)>>>0)|0}h=i+r|0;d=0;while(1){if((d|0)==(l|0)){break j}m=D(d+q|0,104)+a|0;o=m+484380|0;x[o>>2]=g;x[31737]=0;U(216,f|0,o|0,j|0)|0;o=x[31737];x[31737]=0;if((o|0)==1){break Hb}i=i<<1;h=h<<1;if(r>>>0>=2){x[m+484388>>2]=h;x[m+484384>>2]=i;m=m+484414|0;w[m>>1]=z[m>>1]|2}d=d+1|0;g=g<<1;continue}}}}}i=N()|0;ub(j);break f}ub(j);n=n+1|0;k=k+l|0;g=z[a+480192>>1];continue}}i=N()|0;break e}i=N()|0;break e}i=N()|0}vc(H)}ub(L);Q(i|0);p()}d=0}vc(H)}ub(L)}fb=e+944|0;return d|0}function Joa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=E(0),k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,C=0,F=E(0),G=0,H=0,I=0,J=0,K=0,L=0,M=0,T=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=E(0),fa=0,ga=0,ia=0,ja=0,ka=0;e=fb-608|0;fb=e;xc(b);a:{b:{c:{f=e+600|0;if(!Bi(b,f)){break c}if(!BW(f)){break c}if((sp(b)|0)>=0){break c}d=1;if((c|0)==64){break c}Bd(a,16777216);x[a+480208>>2]=x[a+480208>>2]|1681e4;vr(e+256|0,32);f=x[e+268>>2];d=a+1074320|0;x[d>>2]=x[e+264>>2];x[d+4>>2]=f;d=x[e+260>>2];x[a+1074312>>2]=x[e+256>>2];x[a+1074316>>2]=d;dg(a+1074312|0,38);q=Nb(e+588|0);r=Nb(e+576|0);u=Nb(e+564|0);k=Nb(e+552|0);Gh(b,4);i=a+480190|0;K=c&1;H=a+1298332|0;s=2500;I=!(c&2);d:{e:{f:{while(1){c=x[b+8>>2];d=x[b>>2];x[31737]=0;c=U(151,d|0,c|0,4)|0;d=x[31737];x[31737]=0;g:{h:{i:{j:{k:{l:{m:{if((d|0)!=1){n:{if(c){x[31737]=0;c=R(713,b|0)|0;d=x[31737];x[31737]=0;o:{if((d|0)==1){break o}n=4;d=0;p:{q:{r:{switch(c+21|0){case 20:x[31737]=0;c=R(282,b|0)|0;d=x[31737];x[31737]=0;if((d|0)!=1){d=c&65535;if(z[a+480188>>1]|d-1>>>0>126){continue}w[a+480188>>1]=c;ja=a,ka=Yb(512/(d>>>0)|0,16,128),x[ja+480228>>2]=ka;continue}c=N()|0;break a;case 19:x[31737]=0;M=R(282,b|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break o}if(M>>>0<=1024){continue}break m;case 16:x[31737]=0;c=R(282,b|0)|0;f=x[31737];x[31737]=0;if((f|0)!=1){if((c&65535)==4){continue}break m}c=N()|0;break a;case 15:x[31737]=0;c=R(282,b|0)|0;d=x[31737];x[31737]=0;if((d|0)!=1){x[e+256>>2]=c;x[e+152>>2]=800;ja=a,ka=Ze(+A[Gb(e+256|0,e+152|0)>>2]*1.24*1e4),x[ja+480204>>2]=ka;continue}c=N()|0;break a;case 31:x[31737]=0;c=R(282,b|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break o}Z=1;s=Kd(c,0,1e4);continue;case 32:case 33:x[31737]=0;c=R(282,b|0)|0;d=x[31737];x[31737]=0;s:{t:{if((d|0)!=1){Z=1;if(!c){continue}x[31737]=0;d=P(1,e+540|0,12631)|0;c=x[31737];x[31737]=0;if((c|0)==1){break t}c=x[a+1298472>>2];x[31737]=0;S(386,c|0,2,d|0);c=x[31737];x[31737]=0;if((c|0)==1){break s}tb(d);continue}c=N()|0;break a}c=N()|0;break a}c=N()|0;tb(d);break a;case 14:x[31737]=0;P(184,b|0,4)|0;c=x[31737];x[31737]=0;if((c|0)==1){break o}g=!z[i>>1]|g;continue;case 11:if(!K){break q}if(!mc(x[q>>2],x[q+4>>2])){break q}x[31737]=0;c=e+256|0;O(714,c|0,b|0);d=x[31737];x[31737]=0;if((d|0)!=1){if(x[q>>2]){iY(q);d=x[q>>2];ap(q);Db(d);ja=zb(q),ka=0,x[ja>>2]=ka;x[q>>2]=0;x[q+4>>2]=0}x[q>>2]=x[c>>2];x[q+4>>2]=x[c+4>>2];d=zb(c);ja=zb(q),ka=x[d>>2],x[ja>>2]=ka;x[d>>2]=0;x[c>>2]=0;x[c+4>>2]=0;Xi(c);continue}c=N()|0;break a;case 3:case 4:case 10:f=Th(x[k>>2],x[k+4>>2]);d=z[i>>1];if(f>>>0<=d>>>0){continue}if((g|I)&1){break q}if(!ui(d)){break q}d=d+1|0;w[i>>1]=d;t=Nb(e+528|0);x[31737]=0;m=R(169,e+508|0)|0;g=x[31737];x[31737]=0;u:{v:{w:{if((g|0)!=1){if((c|0)==-17){break w}if((c|0)!=-11){break v}x[31737]=0;g=R(282,b|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break u}x[31737]=0;c=e+152|0;S(186,c|0,b|0,g|0);g=x[31737];x[31737]=0;if((g|0)==1){break u}g=ic(e+256|0,c);hd(m,g);ub(g);break g}c=N()|0;break d}x[31737]=0;c=e+256|0;O(715,c|0,b|0);g=x[31737];x[31737]=0;x:{if((g|0)!=1){g=Fn(t,c);dc(c);re(e+480|0,x[g>>2],x[e+532>>2]);c=Nd(e+472|0);x[31737]=0;g=x[c+4>>2];x[e+16>>2]=x[c>>2];x[e+20>>2]=g;c=jg(328,e+488|0,x[e+480>>2],x[e+484>>2],e+16|0);g=x[31737];x[31737]=0;if((g|0)==1){break x}hd(m,c);break g}c=N()|0;break e}c=N()|0;break e}x[31737]=0;c=e+256|0;O(716,c|0,b|0);g=x[31737];x[31737]=0;y:{if((g|0)!=1){g=Fn(t,c);dc(c);re(e+440|0,x[g>>2],x[e+532>>2]);c=Nd(e+432|0);x[31737]=0;g=x[c+4>>2];x[e+8>>2]=x[c>>2];x[e+12>>2]=g;c=jg(328,e+452|0,x[e+440>>2],x[e+444>>2],e+8|0);g=x[31737];x[31737]=0;if((g|0)==1){break y}hd(m,c);break g}c=N()|0;break e}c=N()|0;break e}c=N()|0;break e;case 9:c=z[i>>1];if(!ui(c)){continue}w[i>>1]=c+1;continue;case 8:if(!K){break q}if(!mc(x[u>>2],x[u+4>>2])){break q}x[31737]=0;c=e+256|0;O(717,c|0,b|0);d=x[31737];x[31737]=0;if((d|0)!=1){AW(u,c);vc(c);continue}c=N()|0;break a;case 7:if(!mc(x[k>>2],x[k+4>>2])){break q}x[31737]=0;c=e+256|0;O(718,c|0,b|0);d=x[31737];x[31737]=0;if((d|0)!=1){if(x[k>>2]){VV(k);d=x[k>>2];lC(k);Db(d);ja=zb(k),ka=0,x[ja>>2]=ka;x[k>>2]=0;x[k+4>>2]=0}x[k>>2]=x[c>>2];x[k+4>>2]=x[c+4>>2];d=zb(c);ja=zb(k),ka=x[d>>2],x[ja>>2]=ka;x[d>>2]=0;x[c>>2]=0;x[c+4>>2]=0;qv(c);continue}c=N()|0;break a;case 6:if(!K){break q}if(!mc(x[r>>2],x[r+4>>2])){break q}x[31737]=0;c=e+256|0;O(719,c|0,b|0);d=x[31737];x[31737]=0;if((d|0)!=1){if(x[r>>2]){$V(r);d=x[r>>2];hv(r);Db(d);ja=zb(r),ka=0,x[ja>>2]=ka;x[r>>2]=0;x[r+4>>2]=0}x[r>>2]=x[c>>2];x[r+4>>2]=x[c+4>>2];d=zb(c);ja=zb(r),ka=x[d>>2],x[ja>>2]=ka;x[d>>2]=0;x[c>>2]=0;x[c+4>>2]=0;pn(c);continue}c=N()|0;break a;case 17:case 18:break p;case 0:case 1:case 2:break q;case 5:break r;default:break m}}x[31737]=0;d=e+256|0;O(720,d|0,b|0);c=x[31737];x[31737]=0;if((c|0)==1){break n}z:{c=x[e+256>>2];f=x[e+260>>2];if(mc(c,f)){break z}x[31737]=0;V(344,H|0,c|0,Vc(c,f)|0,1);c=x[31737];x[31737]=0;if((c|0)!=1){break z}c=N()|0;dc(d);break a}dc(e+256|0);continue}x[31737]=0;n=R(282,b|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break o}}x[31737]=0;P(184,b|0,n|0)|0;c=x[31737];x[31737]=0;if((c|0)!=1){continue}}c=N()|0;break a}d=0;if(!z[a+480188>>1]|!M){break m}b=x[k>>2];c=x[k+4>>2];if(mc(b,c)){break m}if(K){if(mc(x[q>>2],x[q+4>>2])){break m}if(mc(x[u>>2],x[u+4>>2])){break m}if(mc(x[r>>2],x[r+4>>2])){break m}}b=Th(b,c);if(b>>>0>=256){x[31737]=0;O(721,k|0,255);b=x[31737];x[31737]=0;if((b|0)==1){break b}b=Th(x[k>>2],x[k+4>>2])}w[a+480192>>1]=b;n=a+480192|0;ja=a,ka=z[pe(i,n)>>1],w[ja+480190>>1]=ka;if(g&1){x[31737]=0;b=P(1,e+528|0,16528)|0;c=x[31737];x[31737]=0;if((c|0)==1){break h}c=x[a+1298472>>2];x[31737]=0;S(386,c|0,2,b|0);c=x[31737];x[31737]=0;if((c|0)==1){break i}tb(b)}g=0;A:while(1){if((g|0)!=2){d=1;while(1){h=d&65535;if(h>>>0>z[n>>1]){g=g+1|0;continue A}B:{f=nn(x[k>>2],h-1|0);if(!y[f|0]|v[f+128|0]<0){break B}if((nv(f)|0)==((g|0)!=1|0)){break B}C:{D:{E:{c=0;F:{if(!nv(f)){break F}if(Bb(y[f+6|0]|y[f+7|0]<<8)){break F}if(Bb(y[f+14|0]|y[f+15|0]<<8)>>>0>20){break F}c=(Bb(y[f+18|0]|y[f+19|0]<<8)|0)==4}G:{H:{if(c){c=y[f+23|0];b=y[f+140|0];x[31737]=0;b=ha(722,f|0,a|0,(b&2)>>>1|0,(D(h,104)+a|0)+484380|0,s&65535)|0;l=x[31737];x[31737]=0;I:{J:{if((l|0)!=1){if(!b){break I}x[31737]=0;b=P(36,e+384|0,10771)|0;l=x[31737];x[31737]=0;if((l|0)==1){break J}zc(((h<<5)+a|0)+946304|0,b);tb(b);l=x[k>>2];b=d;if(Th(l,x[k+4>>2])>>>0<=c>>>0){break G}ja=f,ka=y[f+143|0]+y[nn(l,c)+143|0]|0,v[ja+143|0]=ka;break H}c=N()|0;break a}c=N()|0;break a}b=c+1|0;break G}c=0;K:{if(!nv(f)){break K}if((Bb(y[f+6|0]|y[f+7|0]<<8)|0)!=1){break K}if((Bb(y[f+14|0]|y[f+15|0]<<8)|0)!=2){break K}c=(Bb(y[f+18|0]|y[f+19|0]<<8)|0)==10}b=d;if(!c){break G}c=e+256|0;rW(c,f);b=Bb(y[e+276|0]|y[e+277|0]<<8);if(b>>>0>=z[i>>1]){break H}x[31737]=0;l=R(711,e+152|0)|0;m=x[31737];x[31737]=0;if((m|0)==1){break E}m=y[e+292|0]|y[e+293|0]<<8;o=z[a+480190>>1];x[31737]=0;t=c;C=D(b,104);b=a+484380|0;c=Bb(m);b=ba(723,t|0,(C+b|0)+104|0,(c>>>0<o>>>0?(b+D(c,104)|0)+104|0:l)|0,b+D(h,104)|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break D}if(!b){break H}x[31737]=0;b=P(36,e+140|0,11269)|0;c=x[31737];x[31737]=0;if((c|0)==1){break C}zc(((h<<5)+a|0)+946304|0,b);tb(b);v[f+139|0]=y[f+139|0]+12}b=d}x[31737]=0;b=b&65535;c=U(252,a|0,h|0,b|0)|0;h=x[31737];x[31737]=0;if((h|0)!=1){if(!c|b>>>0>z[i>>1]){break B}x[31737]=0;V(724,f|0,c|0,(D(b,104)+a|0)+484380|0,a|0);b=x[31737];x[31737]=0;if((b|0)!=1){break B}}c=N()|0;break a}c=N()|0;break a}c=N()|0;break a}c=N()|0;break a}d=d+1|0;continue}}break}I=qg(e+128|0);t=qg(e+116|0);b=oc(x[u>>2],x[u+4>>2]);_=D(z[a+480188>>1],M);$=jm((b>>>0)/(_>>>0)|0);x[31737]=0;X=a+484344|0;O(224,X|0,$|0);b=x[31737];x[31737]=0;if((b|0)==1){break k}kj(Xb(x[a+484360>>2],y[a+484376|0]));b=z[a+480188>>1];x[31737]=0;C=P(725,e+104|0,b|0)|0;b=x[31737];x[31737]=0;if((b|0)==1){break l}ja=e,ka=wb(x[r>>2]),x[ja+52>>2]=ka;fa=a+902204|0;ga=wb(x[r+4>>2]);while(1){L:{M:{N:{m=x[e+52>>2];if(!Ib(m,ga)){break N}b=xe((y[m+6|0]|y[m+7|0]<<8)<<16>>16);if((b|0)==1){break L}if((b&65535)==65535){break N}g=Bb(y[m|0]|y[m+1|0]<<8);b=x[q>>2];f=x[q+4>>2];c=Lg(b,f);if(g>>>0>=c>>>0){break L}d=Bb(y[m+2|0]|y[m+3|0]<<8);if(d>>>0>c>>>0|!d|g>>>0>c-d>>>0){break L}c=b+(Lg(b,f)<<5)|0;x[e+256>>2]=b;x[e+260>>2]=c-b>>5;b=x[e+256>>2];gc(e+76|0,b+(Bb(y[m|0]|y[m+1|0]<<8)<<5)|0,Bb(y[m+2|0]|y[m+3|0]<<8));O:{G=Xb(x[a+484360>>2],y[a+484376|0]);if(mc(x[G>>2],x[G+4>>2])){break O}x[31737]=0;O(538,G|0,65534);b=x[31737];x[31737]=0;if((b|0)!=1){break O}break M}ja=e,ka=wb(x[e+76>>2]),x[ja+40>>2]=ka;b=fb-16|0;fb=b;ia=x[vb(b+12|0,x[e+76>>2]+(x[e+80>>2]<<5)|0)>>2];fb=b+16|0;while(1){i=x[e+40>>2];if(!Ib(i,ia)){break L}b=xe(xe((y[m+8|0]|y[m+9|0]<<8)<<16>>16)+xe((y[i+16|0]|y[i+17|0]<<8)<<16>>16)<<16>>16);v[i+16|0]=b;v[i+17|0]=b>>>8;b=ce(I);while(1){P:{c=0;if(!b){break P}d=b+14|0;if(!jv(i,d)){c=1;if(!jv(d,i)){break P}b=b+4|0}b=x[b>>2];continue}break}Q:{R:{S:{if(c){x[31737]=0;b=P(726,I|0,i|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break M}H=z[b>>1];break S}H=0;if(!K){break S}b=y[i+12|0]|y[i+13|0]<<8;x[31737]=0;H=P(368,X|0,Bb(b)|0)|0;b=x[31737];x[31737]=0;if((b|0)==1){break M}if((H|0)==65535){break L}x[31737]=0;b=P(726,I|0,i|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break M}w[b>>1]=H;if(Bb(y[i+8|0]|y[i+9|0]<<8)>>>0>=$>>>0){break R}if(Bb(y[i+10|0]|y[i+11|0]<<8)>>>0>=M>>>0){break R}l=Bb(y[i+14|0]|y[i+15|0]<<8);c=Jk(wb(x[u>>2]),D(Bb(y[i+8|0]|y[i+9|0]<<8),_));b=z[a+480188>>1];ja=e,ka=Jk(c,D(b,Bb(y[i+10|0]|y[i+11|0]<<8))),x[ja+28>>2]=ka;T=0;x[e+100>>2]=0;o=bh(e- -64|0);T:while(1){U:{d=Bb(y[i+12|0]|y[i+13|0]<<8);c=Wb(x[X>>2],H);if(d>>>0<=T>>>0){break U}n=0;Y=jd(x[c>>2],x[x[c+48>>2]+12>>2],T,0);c=0;while(1){if((b&65535)>>>0<=n>>>0){T=T+1|0;continue T}b=wb(x[u+4>>2]);d=x[e+28>>2];h=Ib(d,b)?d:e+100|0;b=wb(x[u+4>>2]);if(Ib(x[e+28>>2],b)){yW(e+28|0)}d=Y+D(n,6)|0;g=y[h+1|0];b=(g>>>0>=85?-1:g+25|0)<<24>>24;s=0;f=x[k>>2];L=Th(f,x[k+4>>2]);J=y[h+3|0];V:{if(L>>>0<=J>>>0){break V}s=J+1|0;if(v[nn(f,J)+142|0]&1|(b|0)<0){break V}b=xe((y[i+16|0]|y[i+17|0]<<8)<<16>>16)+b<<24>>24;aa=b&255;b=(b|0)<=0?1:aa>>>0>=120?120:aa}W:{if(!y[d|0]|!(y[h|0]|(g|0)!=255|J|y[h+2|0])){break W}g=y[d+1|0];if(!g|g>>>0>L>>>0){break W}if(y[nn(f,g-1|0)+132|0]!=2){break W}_o(d)}f=pv(x[C>>2],n);X:{Y:{if(!(c&1)){g=y[h|0];break Y}c=y[o|0]|y[o+1|0]<<8|(y[o+2|0]<<16|y[o+3|0]<<24);v[d|0]=c;v[d+1|0]=c>>>8;v[d+2|0]=c>>>16;v[d+3|0]=c>>>24;c=y[o+4|0]|y[o+5|0]<<8;v[d+4|0]=c;v[d+5|0]=c>>>8;Z:{if(y[d+3|0]){break Z}g=y[f+21|0];c=y[pv(x[C>>2],n-1|0)+21|0];if((g|0)==(c|0)){break Z}v[d+3|0]=21;v[f+21|0]=c;v[d+5|0]=c}c=0;g=y[h|0];if(!(g-24>>>0<2|(g|0)==9|!g&(y[h+2|0]+7&255)>>>0<2)){break X}}_:{$:{aa:{ba:{ca:{da:{switch(g|0){case 5:c=y[f+17|0];break ca;case 0:ea:{c=y[h+2|0];if(c>>>0>=201){g=0;fa:{switch(c-242|0){case 11:v[d+4|0]=1;v[d+2|0]=14;v[f+16|0]=0;break $;case 9:if(!y[d|0]){v[d|0]=y[f+17|0]}v[d+4|0]=1;v[d+2|0]=15;break $;case 8:if((l&255)>>>0<2){break $}l=l-1|0;break aa;case 7:if((l&255)==255){l=255;break $}l=l+1|0;break aa;case 6:v[f+17|0]=b;if(y[f+18|0]!=(s&255)){break $}v[d|0]=b;v[d+5|0]=255;v[d+3|0]=4;w[f+32>>1]=0;x[f+8>>2]=0;break $;case 5:v[d+5|0]=242;v[d+3|0]=2;break $;case 4:v[d+5|0]=242;v[d+3|0]=3;break $;case 3:v[d+5|0]=244;v[d+3|0]=2;break $;case 2:v[d+5|0]=244;v[d+3|0]=3;break $;case 1:v[d+5|0]=248;v[d+3|0]=2;break $;case 12:break ea;case 0:break fa;default:break $}}v[d+5|0]=248;v[d+3|0]=3;break $}g=0;L=v[h+1|0];if((L|0)<0&c>>>0>99){break $}if((L|0)>=0){v[f+17|0]=b;v[d|0]=b;v[f+18|0]=s;v[d+1|0]=s;w[f+32>>1]=0;x[f+8>>2]=0;c=y[h+2|0]}b=c&255;if(!b){break $}ja=f,ka=fm(+(b>>>0)*.64),v[ja+19|0]=ka;j=B[f>>2];x[f>>2]=0;g=j!=E(0);break $}v[d+4|0]=0;v[d+2|0]=14;v[f+16|0]=1;break $;case 1:x[f+4>>2]=0;B[f>>2]=E(y[h+2|0])*E(.0333000011742115);break _;case 2:x[f+4>>2]=0;B[f>>2]=E(y[h+2|0])*E(-.0333000011742115);break _;case 12:v[e+256|0]=15;v[e+96|0]=y[h+3|0]>>>3;b=y[Qb(e+256|0,e+96|0)|0];v[e+256|0]=15;v[e+96|0]=y[h+2|0]>>>3;ja=f,ka=y[Qb(e+256|0,e+96|0)|0]|b<<4,v[ja+24|0]=ka;break _;case 3:x[f+12>>2]=0;b=y[h+2|0];w[f+32>>1]=0;B[f+8>>2]=E(b>>>0)*E(.0333000011742115);break _;case 4:x[f+12>>2]=0;b=y[h+2|0];w[f+32>>1]=0;B[f+8>>2]=E(b>>>0)*E(-.0333000011742115);break _;case 15:if(!y[h+2|0]|(b|0)<0){break _}g=b-y[f+17|0]<<5;c=g>>31;c=(c^g)-c|0;x[e+256>>2]=c;v[f+17|0]=b;x[f+8>>2]=0;v[d|0]=b;v[d+3|0]=4;b=Ch((c>>>0)/(y[h+2|0]<<1>>>0)|0);v[d+5|0]=b;v[f+27|0]=b;x[e+96>>2]=D(b,(l&255)-1|0);ja=f,ka=c-x[ud(e+256|0,e+96|0)>>2]|0,w[ja+32>>1]=ka;break _;case 13:v[e+256|0]=15;v[e+96|0]=y[h+3|0]>>>3;b=y[Qb(e+256|0,e+96|0)|0];v[e+256|0]=15;v[e+96|0]=y[h+2|0];ja=f,ka=y[Qb(e+256|0,e+96|0)|0]|b<<4,v[ja+23|0]=ka;break _;case 18:b=y[h+2|0]+y[f+17|0]&255;b=b?b>>>0>=120?120:b:1;v[f+17|0]=b;v[d|0]=b;v[d+5|0]=255;v[d+3|0]=4;break ba;case 23:case 24:case 25:b=ce(t);while(1){ga:{c=0;if(!b){break ga}g=b+13|0;if(!lv(h,g)){c=1;if(!lv(g,h)){break ga}b=b+4|0}b=x[b>>2];continue}break};if(c){v[d+3|0]=31;x[31737]=0;b=P(727,t|0,h|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break M}v[d+5|0]=y[b|0];break _}b=x[zb(t)>>2];if(b>>>0>127){break _}x[e+92>>2]=y[h|0]|y[h+1|0]<<8|(y[h+2|0]<<16|y[h+3|0]<<24);c=Oe(fa,b&255);g=x[a+480208>>2];x[31737]=0;x[e+24>>2]=x[e+92>>2];c=U(728,e+24|0,c|0,g|0)|0;g=x[31737];x[31737]=0;ha:{if((g|0)==1){break ha}if(!c){break _}v[d+3|0]=31;x[31737]=0;c=P(727,t|0,h|0)|0;g=x[31737];x[31737]=0;if((g|0)==1){break ha}b=b|-128;v[c|0]=b;v[d+5|0]=b;ca=(y[h|0]&254)==24|ca;break _}break M;case 16:if(!y[h+2|0]){break _}v[d+3|0]=15;x[e+256>>2]=15;x[e+96>>2]=y[h+3|0]+1;ja=d,ka=x[ud(e+256|0,e+96|0)>>2],v[ja+5|0]=ka;w[f+30>>1]=D(y[h+2|0],y[h+3|0]+1|0);break _;case 9:v[d+3|0]=16;b=y[h+2|0];l=b?b:4;v[d+5|0]=l;break _;case 19:ia:{b=y[h+1|0];switch(b|0){case 0:case 4:break ia;default:break _}}g=128;g=(b|0)==4?y[h+3|0]:g;v[e+91|0]=g;v[e+256|0]=y[h+2|0];v[e+96|0]=100;b=e+256|0;s=e+96|0;c=y[Qb(b,s)|0];x[e+256>>2]=128;x[e+96>>2]=256-(g&255);g=x[ud(b,s)>>2];v[e+256|0]=128;b=y[Qb(b,e+91|0)|0];g=(D(c,g)|0)/128|0;s=g&255;if((s|0)!=y[f+20|0]){v[f+20|0]=g;v[d+3|0]=21;g=Bc(((D(s,y[f+19|0])+50&65535)>>>0)/100|0,0);v[f+21|0]=g;v[d+5|0]=g}if(y[h+1|0]!=4|(z[a+480188>>1]-1|0)<=(n|0)){break _}g=n+1|0;h=pv(x[C>>2],g);b=D(b,c)>>>7|0;if(y[h+20|0]==(b&255)){break _}v[h+20|0]=b;b=Y+D(g,6)|0;v[b+3|0]=21;c=Bc(((D(y[f+20|0],y[f+19|0])+50&65535)>>>0)/100|0,0);v[f+21|0]=c;v[b+5|0]=c;break _;case 10:case 11:case 17:case 20:v[d+3|0]=0;break _;case 7:b=y[h+2|0];v[f+25|0]=0;v[f+26|0]=0;v[f+22|0]=b;break _;case 8:v[f+22|0]=y[f+22|0]+y[h+2|0];break _;case 14:v[f+25|0]=y[h+3|0];v[f+26|0]=y[h+2|0];break _;case 6:break da;default:break _}}v[f+18|0]=s;v[f+17|0]=b;v[d+1|0]=s;c=b}v[d|0]=c;if((b|0)>=0){v[f+18|0]=s;v[d+1|0]=s}if(y[h|0]==5){v[d+4|0]=1;v[d+2|0]=11}b=y[f+26|0];c=y[f+22|0];if(!(b|(c|y[h+2|0]))){break ba}if(b){da=(Wi(+z[f+28>>1]*.006135923151542565+4.71238898038469)+-1)*+(b>>>0)*.25}else{da=0}v[d+3|0]=44;ja=d,ka=fm(da+ +(c+y[h+2|0]|0)),v[ja+5|0]=ka}w[f+32>>1]=0;break _}v[d+5|0]=l;v[d+3|0]=16}b=Bc(((D(y[f+20|0],y[f+19|0])+50&65535)>>>0)/100|0,0);if(!(!g&y[f+21|0]==(b&255))){v[f+21|0]=b;v[d+5|0]=b;v[d+3|0]=21}if(n&1|v[h+1|0]<=0|(z[a+480188>>1]-1|0)<=(n|0)){break _}b=x[k>>2];if(Th(b,x[k+4>>2])>>>0<=J>>>0){break _}if(y[nn(b,J)+132|0]!=1){break _}g=n+1|0;b=Y+D(g,6)|0;c=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);v[b|0]=c;v[b+1|0]=c>>>8;v[b+2|0]=c>>>16;v[b+3|0]=c>>>24;c=y[d+4|0]|y[d+5|0]<<8;v[b+4|0]=c;v[b+5|0]=c>>>8;v[b+1|0]=y[b+1|0]+1;b=pv(x[C>>2],g);v[b+19|0]=y[f+19|0];B[b>>2]=B[f>>2];B[b+4>>2]=B[f+4>>2];B[b+8>>2]=B[f+8>>2];B[b+12>>2]=B[f+12>>2];w[b+30>>1]=z[f+30>>1]}ja:{if(y[d|0]){v[f+16|0]=0;break ja}c=0;if(y[f+16|0]){break X}}ka:{if(!z[f+30>>1]){break ka}b=l&255;w[e+256>>1]=b;c=f+30|0;ja=c,ka=z[pe(c,e+256|0)>>1]-b|0,w[ja>>1]=ka;if(y[d+3|0]){break ka}v[d+3|0]=15;v[d+5|0]=0}j=B[f>>2];la:{if(j==E(0)){break la}b=l&255;j=E(E(j*E(b>>>0))+B[f+4>>2]);B[f+4>>2]=j;if(y[d+3|0]){break la}ma:{na:{oa:{pa:{if(b>>>0>=2){g=b-1|0;F=E(g|0);if(!(F<=j)){break pa}v[e+256|0]=15;ja=e,ka=zh(E(j/F)),v[ja+96|0]=ka;b=y[Qb(e+256|0,e+96|0)|0];B[f+4>>2]=j-E(D(b,g)|0);v[d+3|0]=22;c=b<<4;break ma}if(!(j>=E(1))){break oa}break na}if(j>=E(1)){break na}if(!(j<=E(1-b|0))){break oa}v[e+256|0]=15;ja=e,ka=zh(E(E(-j)/F)),v[ja+96|0]=ka;c=y[Qb(e+256|0,e+96|0)|0];B[f+4>>2]=j+E(D(g,c)|0);v[d+3|0]=22;break ma}if(!(j<=E(-1))){break la}v[e+256|0]=14;ja=e,ka=zh(E(-j)),v[ja+96|0]=ka;b=y[Qb(e+256|0,e+96|0)|0];B[f+4>>2]=j+E(b>>>0);v[d+3|0]=22;c=b|-16;break ma}v[e+256|0]=15;ja=e,ka=zh(j),v[ja+96|0]=ka;b=y[Qb(e+256|0,e+96|0)|0];B[f+4>>2]=j-E(b>>>0);v[d+3|0]=22;c=b<<4|15}v[d+5|0]=c}j=B[f+8>>2];qa:{if(j==E(0)){break qa}b=l&255;j=E(E(j*E(b>>>0))+B[f+12>>2]);B[f+12>>2]=j;ra:{if(!y[d+3|0]){sa:{ta:{if(b>>>0>=2){c=b-1|0;F=E(c|0);if(!(F<=j)){break ta}v[e+256|0]=223;ja=e,ka=zh(E(j/F)),v[ja+96|0]=ka;b=y[Qb(e+256|0,e+96|0)|0];B[f+12>>2]=j-E(D(b,c)|0);v[d+3|0]=2;v[d+5|0]=b;break qa}if(!(j>=E(1))){break sa}break ra}if(j>=E(1)){break ra}if(!(E(1-b|0)>=j)){break sa}v[e+256|0]=223;ja=e,ka=zh(E(E(-j)/F)),v[ja+96|0]=ka;b=y[Qb(e+256|0,e+96|0)|0];B[f+12>>2]=j+E(D(b,c)|0);v[d+3|0]=3;v[d+5|0]=b;break qa}if(!(j<=E(-1))){break qa}v[e+256|0]=14;ja=e,ka=zh(E(-j)),v[ja+96|0]=ka;b=y[Qb(e+256|0,e+96|0)|0];B[f+12>>2]=j+E(b>>>0);v[d+3|0]=3;v[d+5|0]=b|240;break qa}if(y[d+2|0]|b>>>0<2){break qa}ea=E(j*E(.25));c=b-1|0;F=E(c|0);if(ea>=F){v[e+256|0]=9;ja=e,ka=zh(E(j/F))>>>2|0,v[ja+96|0]=ka;b=y[Qb(e+256|0,e+96|0)|0];B[f+12>>2]=j-E(D(b,c)<<2);v[d+2|0]=12;v[d+4|0]=b;break qa}if(!(ea<=E(1-b|0))){break qa}v[e+256|0]=9;ja=e,ka=zh(E(E(-j)/F))>>>2|0,v[ja+96|0]=ka;b=y[Qb(e+256|0,e+96|0)|0];B[f+12>>2]=j+E(D(b,c)<<2);v[d+2|0]=13;v[d+4|0]=b;break qa}v[e+256|0]=15;ja=e,ka=zh(j),v[ja+96|0]=ka;b=y[Qb(e+256|0,e+96|0)|0];B[f+12>>2]=j-E(b>>>0);v[d+3|0]=2;v[d+5|0]=b|240}ua:{va:{wa:{xa:{ya:{za:{Aa:{b=y[d+3|0];switch(b|0){case 4:break ua;case 0:break Aa;default:break za}}Ba:{b=y[f+23|0];if(!b){b=y[f+24|0];if(b){break Ba}if(!z[f+32>>1]){break ua}c=f+32|0;break ya}v[d+3|0]=5;v[d+5|0]=b;if(!z[f+32>>1]){break ua}break xa}v[d+3|0]=8;v[d+5|0]=b;if(z[f+32>>1]){break xa}break ua}if(!z[f+32>>1]){break ua}c=f+32|0;if(b){break wa}}v[d+3|0]=4;break va}c=f+32|0}v[d+2|0]=11}w[e+256>>1]=D(y[f+27|0],(l&255)-1|0);ja=f,ka=z[f+32>>1]-z[Nc(c,e+256|0)>>1]|0,w[ja+32>>1]=ka}w[f+28>>1]=z[f+28>>1]+D(y[f+25|0],l&255)&1023;c=0;if(n&1){break X}b=y[f+18|0];if(!b){break X}g=x[k>>2];if(Th(g,x[k+4>>2])>>>0<b>>>0){break X}g=nn(g,b-1|0);if(!(y[g+142|0]&4)){break X}b=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);v[o|0]=b;v[o+1|0]=b>>>8;v[o+2|0]=b>>>16;v[o+3|0]=b>>>24;b=y[d+4|0]|y[d+5|0]<<8;v[o+4|0]=b;v[o+5|0]=b>>>8;c=1;b=y[e+65|0];if(!b|y[g+132|0]!=1){break X}v[e+65|0]=b+1}n=n+1|0;b=z[a+480188>>1];continue}}break}ye(c,Yh(Xe(Ne(e+256|0,16,Bb(y[i+14|0]|y[i+15|0]<<8)&255),0)))}b=km(x[G>>2],x[G+4>>2]);ja=e,ka=Bb(y[i+4|0]|y[i+5|0]<<8),w[ja+256>>1]=ka;w[e+64>>1]=1;c=z[pe(e+256|0,e- -64|0)>>1];x[31737]=0;V(729,G|0,b|0,c|0,H&65535);b=x[31737];x[31737]=0;if((b|0)==1){break Q}b=xe((y[m+8|0]|y[m+9|0]<<8)<<16>>16);b=xe(xe((y[i+16|0]|y[i+17|0]<<8)<<16>>16)-b<<16>>16);v[i+16|0]=b;v[i+17|0]=b>>>8}br(e+40|0);continue}break}break M}d=ca&1;if(d){g=a+906300|0;b=vd(g,0);x[31737]=0;W(287,b|0);c=x[31737];x[31737]=0;if((c|0)==1){break M}x[b+16>>2]=1299020115;x[b+20>>2]=1869112133;x[b+24>>2]=655376;x[b+28>>2]=0;x[e+256>>2]=0;f=b+48|0;c=e+256|0;s0(b+32|0,f,c);x[31737]=0;c=P(36,c|0,9587)|0;h=x[31737];x[31737]=0;if((h|0)==1){break M}uE(f,c);tb(c);x[31737]=0;c=P(36,e+76|0,9580)|0;f=x[31737];x[31737]=0;if((f|0)==1){break M}nw(b+80|0,c);tb(c);x[31737]=0;b=P(36,e- -64|0,9572)|0;c=x[31737];x[31737]=0;if((c|0)==1){break M}uE(vd(g,1)+48|0,b);tb(b)}b=0;while(1){if(z[a+480188>>1]>b>>>0){ZD(a,b&65535);c=(b<<5)+a|0;v[c+480288|0]=d;w[c+480284>>1]=b<<8&256;b=b+1|0;continue}break}x[31737]=0;b=P(1,e+52|0,12181)|0;c=x[31737];x[31737]=0;Ca:{Da:{Ea:{if((c|0)!=1){Ab(a+1298344|0,b);tb(b);x[31737]=0;b=P(1,e+40|0,12399)|0;c=x[31737];x[31737]=0;if((c|0)==1){break M}Ab(a+1298356|0,b);tb(b);if(Z){break Ea}x[31737]=0;b=P(1,e+28|0,12181)|0;c=x[31737];x[31737]=0;if((c|0)==1){break M}break Da}break M}if(Th(x[k>>2],x[k+4>>2])>>>0<=128){x[31737]=0;b=P(1,e+28|0,9314)|0;c=x[31737];x[31737]=0;if((c|0)!=1){break Da}break M}x[31737]=0;b=P(1,e+28|0,14905)|0;c=x[31737];x[31737]=0;if((c|0)==1){break Ca}}Ab(a+1298368|0,b);tb(b);ja=a+1298404|0,ka=x[Fc(e+100|0,28)>>2],x[ja>>2]=ka;xW(C);lW(t);kW(I);d=1;break m}}c=N()|0;xW(C);break j}Zo(e+52|0);continue}}c=N()|0;break a}c=N()|0;break a}qv(k);vc(u);pn(r);Xi(q);break c}c=N()|0;break j}c=N()|0}lW(t);kW(I);break a}c=N()|0;tb(b);break a}c=N()|0;break a}ub(c);x[31737]=0;c=d&65535;d=U(730,a|0,c|0,m|0)|0;g=x[31737];x[31737]=0;Fa:{Ga:{Ha:{Ia:{if((g|0)==1){break Ia}if(d){break Fa}x[31737]=0;d=U(731,a|0,c|0,m|0)|0;g=x[31737];x[31737]=0;if((g|0)==1){break Ia}if(d){break Fa}x[31737]=0;d=U(732,a|0,c|0,m|0)|0;g=x[31737];x[31737]=0;if((g|0)==1){break Ia}if(d){break Fa}x[31737]=0;d=P(733,(D(c,104)+a|0)+484380|0,m|0)|0;g=x[31737];x[31737]=0;if((g|0)==1){break Ia}if(d){break Fa}x[31737]=0;d=P(1,e+420|0,16239)|0;g=x[31737];x[31737]=0;if((g|0)==1){break Ha}g=x[a+1298472>>2];x[31737]=0;S(386,g|0,2,d|0);g=x[31737];x[31737]=0;if((g|0)==1){break Ga}tb(d);break Fa}c=N()|0;break e}c=N()|0;break e}c=N()|0;tb(d);break e}Ja:{Ka:{La:{C=D(c,104)+a|0;if(y[C+484414|0]&64){d=z[i>>1];if(ui(d)){break La}}d=x[k>>2];if(Th(d,x[k+4>>2])>>>0<=c>>>0){break Ka}if(y[nn(d,c)+132|0]!=2){break Ka}c=z[i>>1];if(!ui(c)){break Ka}w[i>>1]=c+1;break Ka}c=d+1|0;w[a+480190>>1]=c;G=D(c&65535,104)+a|0;o=G+484380|0;h=C+484380|0;d=x[h>>2];g=x[h+20>>2];Ma:{if(!je(d,g)){break Ma}c=(h|0)==(o|0);f=z[h+34>>1];if(c|(_d(f)|0)!=2){break Ma}if(!(je(x[o>>2],x[o+20>>2])?c:1)){break Ma}je(x[h>>2],x[h+20>>2]);if(!c){g=mv(d,On(f))}f=x[h+20>>2];if(!(f?g:0)){if(!c){aC(g)}break Ma}Na:{Oa:{switch(On(z[h+34>>1])-1|0){case 1:d=g;c=f;n=x[h+20>>2];l=x[h>>2];while(1){if(l){w[d>>1]=z[n>>1];w[c>>1]=z[n+2>>1];n=n+4|0;c=c+2|0;d=d+2|0;l=l-1|0;continue}break};break Na;case 0:break Oa;default:break Na}}d=g;c=f;n=x[h+20>>2];l=x[h>>2];while(1){if(l){v[d|0]=y[n|0];v[c|0]=y[n+1|0];n=n+2|0;c=c+1|0;d=d+1|0;l=l-1|0;continue}break}}d=$o(o,h);w[d+34>>1]=z[d+34>>1]&65471;x[o+20>>2]=g;g=$o(h,h);w[g+34>>1]=z[g+34>>1]&65471;x[h+20>>2]=f;f=a+1298224|0;c=a+1074992|0;while(1){if((c|0)!=(f|0)){h=x[c+104>>2];if(!((h|0)!=(d|0)&(g|0)!=(h|0))){x[c+88>>2]=x[c+88>>2]&-65}c=c+872|0;continue}break}Pj(d,a);Pj(g,a)}x[31737]=0;c=P(36,e+408|0,6320)|0;d=x[31737];x[31737]=0;if((d|0)==1){break Ja}ze(G+484423|0,c);tb(c);x[31737]=0;c=P(36,e+396|0,6223)|0;d=x[31737];x[31737]=0;if((d|0)==1){break f}ze(C+484423|0,c);tb(c)}ub(m);dc(t);g=0;continue}break}c=N()|0;break e}c=N()|0}ub(m)}dc(t);break a}fb=e+608|0;return d|0}c=N()|0}qv(k);vc(u);pn(r);Xi(q);Q(c|0);p()}function Bv(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,k=0,l=0,m=0,n=0,q=0,r=0,s=0,t=0,u=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,R=0,T=0,X=0,Y=0,Z=0,_=0,$=0,ba=0,ca=0,da=0,ea=0,fa=0,ia=0,ka=E(0),la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,xa=0,ya=E(0);h=fb-192|0;fb=h;X=Nb(a);s=h+160|0;v[s+26|0]=0;w[s+24>>1]=0;x[s+16>>2]=0;x[s+20>>2]=-1;x[s+8>>2]=-1;x[s+12>>2]=-1;x[s>>2]=0;x[s+4>>2]=0;fa=x[d+16>>2];a=y[d+6|0];l=x[b+484360>>2];la=(ua=a,va=y[b+484376|0],xa=Nj(l,x[b+484364>>2])>>>0>a>>>0,xa?ua:va);a=la&255;K=Tj(l,a);x[31737]=0;t=P(604,h+128|0,b|0)|0;l=x[31737];x[31737]=0;a:{b:{c:{d:{e:{f:{if((l|0)!=1){i=x[t+4>>2];x[31737]=0;J=U(605,h+92|0,b|0,a|0)|0;a=x[31737];x[31737]=0;if((a|0)==1){break f}qa=b+484360|0;ba=c&7;k=x[d>>2];a=z[d+4>>1];l=Zc(x[K>>2],x[K+4>>2]);while(1){q=a&65535;if(q>>>0>=l>>>0){break e}if(bj(K,q)){break e}a=a+1|0;k=0;continue}}a=N()|0;break c}a=N()|0;break d}x[d>>2]=k;w[d+4>>1]=a;x[i+52>>2]=k;x[i+48>>2]=k;x[s+16>>2]=k;w[i+74>>1]=a;w[i+72>>1]=a;w[s+24>>1]=a;ma=Nd(h+84|0);g:{if((ba|0)!=7){break g}a=fb-16|0;fb=a;l=a+8|0;Kb(l,ma,1);fp(l);fb=a+16|0;if((fa|0)!=2){break g}a=x[K>>2];f=Zc(a,x[K+4>>2]);l=z[d+12>>1];if(f>>>0<=l>>>0){break g}q=x[b+484344>>2];f=x[b+484348>>2];a=z[_b(a,l)>>1];if(!He(q,f,a)){break g}l=Wb(q,a);q=x[d+8>>2];if(A[l+12>>2]<=q>>>0){break g}a=0;m=jd(x[l>>2],x[x[l+48>>2]+12>>2],q,0);l=x[t+8>>2];q=z[b+480188>>1];f=z[b+480192>>1];while(1){if((a|0)==(q|0)){break g}h:{i:{j:{k:{e=y[m|0];switch(e-253|0){case 1:case 2:break i;case 0:break k;default:break j}}if(f){break i}}if(!Sc(e)|!y[m+1|0]){break h}if(Ql(y[m+2|0],y[m+3|0])){break h}}ua=Ue(l,a),va=-1,x[ua>>2]=va}m=m+6|0;a=a+1|0;continue}}Y=c&1;if(Y){MT(i+223860|0)}M=i+74|0;L=i+48|0;ra=i+223872|0;R=i+80|0;sa=b+901692|0;ta=b+902204|0;ca=i+44|0;ia=i+223860|0;Z=i+20|0;I=b+1074312|0;na=i+616|0;da=32768;oa=(ba|0)!=7;a=0;l=0;l:{m:{n:{o:{p:{q:{r:{s:{t:while(1){G=a&1;u:while(1){pa=C[d+8>>3];o(+pa);q=j(1)|0;f=j(0)|0;g=x[d+16>>2];H=(g|0)!=3;v:{w:{x:{y:{while(1){LT(h+24|0,x[b+480180>>2],z[b+480188>>1],i,G);r=y[h+24|0];if(!H&C[t+24>>3]>=pa){break y}a=65535;e=x[K>>2];n=Zc(e,x[K+4>>2]);k=z[i+72>>1];if(n>>>0>k>>>0){a=z[_b(e,k)>>1]}w[i+70>>1]=a;n=x[b+484344>>2];e=x[b+484348>>2];m=a&65535;if(!(He(n,e,m)|(g|0)!=2|(m|0)==65535)&(k|0)==(q&65535)){break y}z:{while(1){_=ck(n,e);u=x[K>>2];while(1){k=a&65535;if(k>>>0<_>>>0){break z}a=z[i+72>>1];A:{B:{if((k|0)!=65535){k=Zc(u,x[K+4>>2]);if(a>>>0<k>>>0){break B}}m=z[K+28>>1];if((a|0)==(m|0)){break z}k=Zc(u,x[K+4>>2]);break A}m=a+1|0}w[i+72>>1]=m;a=65535;F=k;k=m&65535;if(F>>>0>k>>>0){a=z[_b(u,k)>>1]}w[i+74>>1]=m;w[i+70>>1]=a;if(He(n,e,a&65535)){continue}break}a=Mq(h+24|0,na);x[31737]=0;a=ha(606,J|0,m&65535,0,a|0,(r|0)!=0|0)|0;e=x[31737];x[31737]=0;if((e|0)==1){break p}if(!a){e=x[b+484348>>2];n=x[b+484344>>2];a=z[i+70>>1];continue}break}if(fa>>>0<=1){a=z[i+72>>1];x[s+8>>2]=0;w[s+20>>1]=a}if(!g){break z}if(!Vu(J,M,L)){break z}C[s>>3]=C[t+24>>3];x[31737]=0;O(607,X|0,s|0);a=x[31737];x[31737]=0;if((a|0)==1){break q}x[s+16>>2]=x[L>>2];w[s+24>>1]=z[M>>1];x[31737]=0;W(608,t|0);a=x[31737];x[31737]=0;if((a|0)==1){break q}a=z[i+74>>1];w[i+72>>1]=a;ua=i,va=z[_b(x[K>>2],a)>>1],w[ua+70>>1]=va;x[i+52>>2]=x[i+48>>2]}if(z[M>>1]==65535){break m}a=x[b+484344>>2];e=z[i+70>>1];if(!He(a,x[b+484348>>2],e)){a=z[i+72>>1];if((a|0)==z[K+28>>1]){if(!g){break n}if(!Vu(J,M,L)){break o}C[s>>3]=C[t+24>>3];x[31737]=0;O(607,X|0,s|0);a=x[31737];x[31737]=0;if((a|0)==1){break q}x[s+16>>2]=x[L>>2];w[s+24>>1]=z[M>>1];x[31737]=0;W(608,t|0);a=x[31737];x[31737]=0;if((a|0)==1){break q}x[i+52>>2]=x[i+48>>2];continue}w[M>>1]=a+1;continue}break}k=x[L>>2];if(k>>>0>=A[Wb(a,e)+12>>2]){x[L>>2]=0;k=0}if((g|0)!=2){break x}if(z[i+72>>1]!=(q&65535)|(f|0)!=(k|0)){break w}}g=1;v[s+26|0]=1;break m}a=0;if((g|0)==3){break v}}a=0;if(A[J+28>>2]<da>>>0){break v}x[t+24>>2]=0;x[t+28>>2]=2146435072;x[J+28>>2]=0;da=da>>>(da>>>0>256)|0;k=x[L>>2];a=1}q=z[i+72>>1];f=Mq(h+24|0,na);x[31737]=0;q=ha(606,J|0,q|0,k|0,f|0,(r|0)!=0|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break s}if((a|q)==1){if(fa>>>0<=1){w[s+20>>1]=z[i+72>>1];x[s+8>>2]=x[i+48>>2]}if(!g){break n}if(!Vu(J,M,L)){break o}C[s>>3]=C[t+24>>3];x[31737]=0;O(607,X|0,s|0);a=x[31737];x[31737]=0;if((a|0)==1){break r}x[s+16>>2]=x[L>>2];w[s+24>>1]=z[M>>1];x[31737]=0;W(608,t|0);a=x[31737];x[31737]=0;if((a|0)==1){break r}x[i+52>>2]=x[i+48>>2];continue}w[s+22>>1]=z[i+72>>1];x[s+12>>2]=x[i+48>>2];KT(b,i,0);m=x[i+48>>2];q=Wb(x[b+484344>>2],z[i+70>>1]);if(m>>>0>=A[q+12>>2]){x[L>>2]=0;m=0}if(r){continue}a=0;m=jd(x[q>>2],x[x[q+48>>2]+12>>2],m,0);Kb(h+24|0,I,77);n=Hb(x[x[h+24>>2]>>2],x[h+28>>2]);C:{while(1){if(z[b+480188>>1]>a>>>0){D:{E:{if(!xB(m)){if(!n|!(y[((a<<5)+b|0)+480281|0]&4)){break E}}_o((i+D(a,872)|0)+1404|0);break D}if(Vg(y[m|0])){F:{if(!Gd(y[i+223884|0])){break F}q=y[m+1|0];if(q-251>>>0<5|!q){break F}e=y[m+5|0];g=y[m+3|0];k=Jj(y[m+2|0],y[m+4|0]);f=h+24|0;v[f|0]=q-1;x[f+4>>2]=k&65535;x[31737]=0;q=P(609,ra|0,f|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break C}ua=q,ya=E(E(Jj(g,e)>>>0)/E(999)),B[ua>>2]=ya}_o((i+D(a,872)|0)+1404|0);break D}q=i+D(a,872)|0;f=q+1408|0;e=y[m+4|0]|y[m+5|0]<<8;v[f|0]=e;v[f+1|0]=e>>>8;f=q+1404|0;e=y[m|0]|y[m+1|0]<<8|(y[m+2|0]<<16|y[m+3|0]<<24);v[f|0]=e;v[f+1|0]=e>>>8;v[f+2|0]=e>>>16;v[f+3|0]=e>>>24;G:{H:{I:{J:{switch(y[m+3|0]-16|0){case 0:e=y[m+5|0];break I;case 3:break G;case 4:break H;case 1:break J;default:break D}}Kb(h+24|0,I,5);if(!Hb(x[x[h+24>>2]>>2],x[h+28>>2])){break D}e=y[m+5|0];if(!e){break D}}IT(b,i,e&255);break D}f=q+1409|0;e=y[f|0];K:{if(!(e|!(x[b+480180>>2]&16777250))){v[f|0]=y[q+1449|0];break K}v[q+1449|0]=e}q=y[m+5|0];f=q&240;if((f|0)!=224){if((f|0)!=96){break D}x[i+24>>2]=x[i+24>>2]+(q&15);break D}if(x[Z>>2]){break D}q=q&15;if(q?0:y[b+480180|0]&2){break D}x[Z>>2]=q+1;break D}q=y[m+5|0];if((q&240)!=224){break D}x[Z>>2]=(q&15)+1}m=m+6|0;a=a+1|0;continue}break}q=Pl(i);x[h+24>>2]=1;a=x[ad(Z,h+24|0)>>2];w[i+68>>1]=65535;x[i+60>>2]=-1;x[i+64>>2]=-1;_=q-1|0;a=q-a|0;T=D(a,1e4);m=0;while(1){L:{M:{N:{O:{P:{if(z[b+480188>>1]<=m>>>0){if(x[b+480180>>2]!=4|x[i+40>>2]!=65535){break P}x[i+52>>2]=x[i+48>>2];w[i+74>>1]=z[i+72>>1];continue u}g=i+D(m,872)|0;k=g+1404|0;if(xB(k)){break L}r=g+616|0;ea=g+1409|0;e=y[ea|0];$=g+1407|0;u=y[$|0];if(!Y){break N}H=y[k|0];f=H;n=g+1405|0;F=y[n|0];if(F){v[g+1415|0]=0;v[g+1419|0]=F;ua=Ue(x[t+8>>2],m),va=255,v[ua+5|0]=va;f=y[k|0]}Q:{if(!Sc(f)){break Q}v[g+1415|0]=H;sV(r);if(!oa){if(x[Ue(x[t+8>>2],m)>>2]!=-1){break Q}}F=g+1272|0;f=y[g+1419|0];f=x[(f?f>>>0>z[b+480192>>1]?F:((f<<2)+b|0)+900380|0:F)>>2];if(!f){break Q}F=y[f+21|0];if(Cd(F)){ua=g+1453|0,va=Fh(F),v[ua|0]=va}f=y[f+22|0];if(!Cd(f)){break Q}ua=g+1454|0,va=Fh(f),v[ua|0]=va}R:{if(!(Sc(y[k|0])|y[n|0])){break R}F=g+1419|0;n=y[F|0];S:{if(!n){n=0;break S}if(z[b+480192>>1]<n>>>0){break S}f=x[((n<<2)+b|0)+900380>>2];if(!f|!(v[f+15|0]&1)){break S}Vq(r,x[f+8>>2],b);n=y[F|0]}f=ur(b,H,n&255);if(!f){break R}f=D(f,104)+b|0;if(!(y[f+484414|0]&32)){break R}Vq(r,z[f+484408>>1],b)}T:{U:{V:{f=y[g+1406|0];switch(f-1|0){case 1:break N;case 2:case 3:break U;case 0:break V;default:break T}}ua=Ue(x[t+8>>2],m),va=y[g+1408|0],v[ua+5|0]=va;break N}f=y[g+1408|0];if(!f){break N}v[g+1450|0]=f;break N}if((f|0)==11){break O}break N}x[i+32>>2]=x[b+480216>>2];a=Wb(x[b+484344>>2],z[i+70>>1]);f=x[a+16>>2];if(HT(f,x[a+20>>2])){x[i+32>>2]=f}f=GT(b,i);a=D(f,q);C[t+24>>3]=C[t+24>>3]+ +(a>>>0)/+A[b+24620>>2];x[i>>2]=a+x[i>>2];W:{X:{Y:{if(oa){break Y}m=0;_=(l|0)!=0&(f|0)!=(l|0);while(1){if(z[b+480188>>1]<=m>>>0){break Y}G=Ue(x[t+8>>2],m);Z:{if(x[G>>2]==-1){break Z}r=i+D(m,872)|0;H=r+1404|0;T=x[r+1316>>2];if(!T){if(xB(H)){break Z}}u=r+1409|0;k=y[u|0];e=Ql(y[H+2|0],y[H+3|0]);if(y[r+1405|0]){x[r+1276>>2]=0}g=r+616|0;a=k&15;n=0;_:{if(!Sc(y[H|0])){break _}if(e&y[G+4|0]!=0){wB(h+24|0,b,g,T,0);n=x[h+28>>2];x[r+624>>2]=x[h+24>>2];x[r+628>>2]=n}v[r+1418|0]=y[r+1415|0];T=r+1308|0;ea=x[T>>2];n=y[r+1419|0];if(n){Po(b,g,n,e,1,1)}n=y[H|0];x[31737]=0;ga(610,b|0,g|0,n|0,e|0,1,0,65535);n=x[31737];x[31737]=0;if((n|0)==1){break X}k=k>>>4|0;FT(b,g);ET(x[b+480180>>2],z[b+480188>>1],i,m&65535);$=Ue(x[t+8>>2],m);v[$+4|0]=1;G=y[r+1407|0];$:{if(!((y[u|0]&240)!=208|(G-19&255)>>>0>1)){n=a;if(a>>>0<q>>>0){break $}}n=(G|0)==33?k>>>0<q>>>0?k:0:0}F=x[Z>>2];if(!(!(x[b+480180>>2]&16777250)|(!n|F>>>0<2))){n=D(F-1|0,x[i+24>>2]+x[i+40>>2]|0)+n|0}if(!e){x[$>>2]=0}aa:{if((G|0)==9){break aa}ba:{if((G|0)!=19){if((G|0)!=20|(k|0)!=8){break ba}break aa}if((k|0)==8){break aa}}if(y[r+1406|0]!=2){break _}}x[T>>2]=ea}ca:{if(!Sc(y[H|0])){Kb(h+24|0,I,114);if(!Hb(x[x[h+24>>2]>>2],x[h+28>>2])){break ca}}da:{ea:{fa:{ga:{e=y[r+1407|0];switch(e-42|0){case 1:break da;case 0:break ea;case 2:break fa;default:break ga}}if((e|0)!=10){break da}e=z[i+70>>1];k=x[i+48>>2];x[31737]=0;aa(611,b|0,g|0,m&65535,k|0,e|0);e=x[31737];x[31737]=0;if((e|0)!=1){break ca}break W}k=Sua(y[u|0],0,x[r+692>>2],0);e=hb;G=e>>>8|0;Oo(b,g,Bc((e&255)<<24|k>>>8,G));break ca}if(!x[r+720>>2]){break da}x[31737]=0;V(612,t|0,m&65535,l|0,-1);e=x[31737];x[31737]=0;if((e|0)==1){break W}CT(g,y[u|0]);n=x[i+40>>2]-1|0;break ca}if(y[r+1406|0]!=15){break ca}k=x[r+720>>2];if(!k){break ca}e=y[r+1408|0];if(e>>>0>9){break ca}ha:{if(!e){e=x[r+1280>>2];break ha}e=x[yb(k+68|0,e-1|0)>>2];x[r+1280>>2]=e}Oo(b,g,e)}ia:{ja:{ka:{switch(y[H|0]-253|0){case 0:if(z[b+480192>>1]){break ja}break;case 1:case 2:break ja;default:break ka}}e=y[r+1407|0];if(!((y[u|0]&240)!=192|(e-19&255)>>>0>1)&a>>>0<q>>>0){break ja}G=e&255;if((G|0)==25){break ja}k=0;if(!((G|0)==33&(a|0)!=0&q>>>0>a+n>>>0)){break ia}}e=y[r+1407|0];k=1}G=r+1304|0;la:{ma:{na:{a=e&255;if((a|0)!=46){if((a|0)!=13){break na}F=y[u|0]<<2;break ma}F=y[u|0];break ma}if(y[r+1406|0]!=1){break la}F=y[r+1408|0]<<2}x[G>>2]=F}G=r+1407|0;oa:{pa:{qa:{if(k|(!x[r+720>>2]|a>>>0>46)){break qa}Kb(h+24|0,ma,a);if(Hb(x[x[h+24>>2]>>2],x[h+28>>2])){break pa}e=y[G|0];if((e|0)!=19){break qa}a=y[u|0]&240;if((a|0)==16){break pa}e=19;if((a|0)==32){break pa}}if(!k){break oa}}tV(g);ua=Ue(x[t+8>>2],m),va=0,x[ua>>2]=va;break Z}if(_){x[31737]=0;V(612,t|0,m&65535,l|0,-1);a=x[31737];x[31737]=0;if((a|0)==1){break W}e=y[G|0]}ra:{sa:{ta:{ua:{va:{a=e&255;if(a-6>>>0>=2){wa:{switch(a-19|0){case 1:break ua;case 0:break va;default:break wa}}if(a-35>>>0<2){break sa}if((a|0)==45){break ta}if((a|0)!=11){break ra}}if(!y[u|0]&x[b+480180>>2]==1){break ra}a=r+1467|0;e=0;while(1){if((e|0)==(q|0)){break ra}v[a|0]=!e|y[a|0]&254;No(b,g,y[u|0]);e=e+1|0;continue}}e=y[u|0];a=e&15;if(!(a|x[b+480180>>2]&1048580)){break ra}k=r+1467|0;v[k|0]=y[k|0]|1;e=e&240;if((e|0)!=176){if((e|0)!=160){break ra}Mo(b,g,a,0);break ra}Lo(b,g,a,0);break ra}xa:{ya:{za:{a=y[u|0];switch(a-158|0){case 1:break ya;case 0:break za;default:break xa}}x[31737]=0;V(612,t|0,m&65535,l|0,-1);a=x[31737];x[31737]=0;if((a|0)==1){break W}x[r+704>>2]=x[r+704>>2]&-129;break ra}x[31737]=0;V(612,t|0,m&65535,l|0,-1);a=x[31737];x[31737]=0;if((a|0)==1){break W}a=x[r+704>>2];x[r+704>>2]=a|128;if(x[g+4>>2]){break ra}e=x[r+692>>2];if(!e){break ra}if(!(ua=Sc(y[H|0]),va=1,xa=a&2,xa?ua:va)){break ra}x[g>>2]=-1;x[g+4>>2]=e-1;break ra}if((a&240)!=112|a>>>0<115){break ra}qV(g,a,x[b+480180>>2]);break ra}BT(g,y[u|0]);break ra}x[31737]=0;a=m&65535;V(612,t|0,a|0,l|0,-1);e=x[31737];x[31737]=0;if((e|0)==1){break W}ua=r+1390|0,va=AT(b,z[i+70>>1],x[i+48>>2],a),w[ua>>1]=va}k=r+1467|0;a=y[k|0]|1;v[k|0]=a;Aa:{Ba:{Ca:{Da:{Ea:{u=r+1406|0;switch(y[u|0]-3|0){case 11:break Ba;case 0:case 1:break Ca;case 3:break Da;case 2:break Ea;default:break Aa}}a=y[r+1408|0];Kb(h+24|0,I,41);Mo(b,g,a,Hb(x[x[h+24>>2]>>2],x[h+28>>2]));break Aa}a=y[r+1408|0];Kb(h+24|0,I,41);Lo(b,g,a,Hb(x[x[h+24>>2]>>2],x[h+28>>2]));break Aa}e=y[r+1408|0];Fa:{if(e){break Fa}Kb(h+24|0,I,41);e=0;if(!Hb(x[x[h+24>>2]>>2],x[h+28>>2])){break Fa}e=y[r+1450|0];if(!e){break Aa}}a=0;e=(y[u|0]==3?e<<4:e)&255;while(1){if((a|0)==(q|0)){break Aa}v[k|0]=!a|y[k|0]&254;No(b,g,e);a=a+1|0;continue}}e=y[r+1408|0];if(e>>>0>1){break Aa}v[k|0]=a&247|!e<<3}if(y[k|0]&8){break Z}a=1;Ga:{Ha:{Ia:{e=y[H+3|0];if(e>>>0>28){break Ia}g=1<<e;if(g&92){break Ga}if(!(g&268959744)){break Ia}if((y[H+5|0]-16&255)>>>0<32){break Ga}break Ha}if(e-38>>>0<4){break Ga}}a=(y[H+2|0]-11&255)>>>0<3}if(a){e=Ue(x[t+8>>2],m);a=x[e>>2];x[e>>2]=a+q;x[31737]=0;V(612,t|0,m&65535,f|0,a+n|0);a=x[31737];x[31737]=0;if((a|0)!=1){break Z}a=N()|0;break l}a=Ue(x[t+8>>2],m);x[a>>2]=x[a>>2]+(q-n|0)}m=m+1|0;continue}}a=zT(b,i,K,0);l=f;continue t}a=N()|0;break l}a=N()|0;break l}f=y[g+1408|0];if(!f){break N}n=h+24|0;vB(n,b,y[k+3|0],f,0);w[g+1384>>1]=z[h+24>>1];if(y[$e(n)|0]){break M}}Ja:{Ka:{La:{Ma:{Na:{switch(u-12|0){case 0:yT(b,i,m&65535);break Ja;case 2:f=xT(b,i,m&65535,e);if((f|0)==-1){break Ja}x[i+60>>2]=f;break Ja;case 5:Kb(h+24|0,I,5);if(Hb(x[x[h+24>>2]>>2],x[h+28>>2])){break Ja}k=D(Ko(b,z[i+70>>1],x[i+48>>2],m&65535,0),1e4);x[h+56>>2]=k;Oa:{if(!Y|!(x[b+480180>>2]&16777250)){break Oa}if(k>>>0>=1e4){v[g+1451|0]=(k>>>0)/1e4;break Oa}k=D(y[g+1451|0],1e4);x[h+56>>2]=k}f=x[b+8>>2];if(k>>>0>=32e4){x[h+24>>2]=D(x[f+24>>2],1e4);ua=ca,va=x[Gb(h+56|0,h+24|0)>>2],x[ua>>2]=va;break Ja}n=x[ca>>2];H=(k>>>0)/1e4|0;F=D(T,H&15);k=n-F|0;x[ca>>2]=(H&240)==16?n+F|0:k>>>0<=n>>>0?k:0;n=x[f+20>>2];f=x[f+24>>2];Kb(h+24|0,I,8);Kp(ca,D(n,1e4),Hb(x[x[h+24>>2]>>2],x[h+28>>2])?255e4:D(f,1e4));break Ja;case 8:Pa:{switch(e-144>>>4|0){case 0:if(e>>>0>145){break Ja}x[g+704>>2]=x[g+704>>2]&-257|((e|0)==145)<<8;break Ja;case 1:v[g+1452|0]=e&15;break Ja;case 2:break Ma;case 6:break Pa;default:break Ja}}v[g+1460|0]=e&15;break Ja;case 1:case 3:case 4:case 6:break Ja;case 7:break Na;default:break Ka}}f=e&240;if((f|0)==240){break La}if((f|0)!=96){break Ja}}uB(b,i,m&65535,e&15);break Ja}v[g+1460|0]=e&15;break Ja}if((u|0)!=28|(e&240)!=160){break Ja}Kb(h+24|0,I,58);if(Hb(x[x[h+24>>2]>>2],x[h+28>>2])){break Ja}v[g+1452|0]=e&15}if(!Y){break L}Qa:{Ra:{Sa:{Ta:{Ua:{Va:{Wa:{Xa:{Ya:{switch(u-2|0){case 0:if(!e){break Qa}Kb(h+24|0,I,90);if(!Hb(x[x[h+24>>2]>>2],x[h+28>>2])){v[g+1428|0]=e}v[g+1427|0]=e;break M;case 1:if(!e){break Qa}Kb(h+24|0,I,90);if(!Hb(x[x[h+24>>2]>>2],x[h+28>>2])){v[g+1427|0]=e}v[g+1428|0]=e;break M;case 2:if(!e){break Qa}w[g+1384>>1]=e;break M;case 8:if(!e){break Qa}x[g+1280>>2]=e<<8;break M;case 4:case 9:if(!e){break Qa}v[g+1425|0]=e;break M;case 11:ua=Ue(x[t+8>>2],m),va=e,v[ua+5|0]=va;break M;case 44:ua=Ue(x[t+8>>2],m),va=e+3>>>2|0,v[ua+5|0]=va;break M;case 21:f=x[b+480180>>2];e=e<<(!(f&59593760)&e<<24>>24>=0);n=e&255;if(n>>>0<=128){x[R>>2]=n<<1;break M}if(f&16777250){break M}x[R>>2]=256;break M;case 22:Kb(h+24|0,I,9);Za:{if(Hb(x[x[h+24>>2]>>2],x[h+28>>2])){f=g+1433|0;if(e){v[f|0]=e;break Za}e=y[f|0];break Za}if(e){v[i+1433|0]=e;break Za}e=y[i+1433|0]}f=e&15;n=e&255;_a:{if(!((f|0)!=15|n>>>0<16)){e=(e&240)>>>4<<!(x[b+480180>>2]&59593760);f=x[R>>2]+(e<<1)|0;break _a}n=n&240;if(!(!f|(n|0)!=240)){e=f<<(x[b+480180>>2]&59593760?1:2);f=x[R>>2]-e|0;break _a}if(n){e=(e>>>3&30)<<!(x[b+480180>>2]&59593760);f=x[R>>2]+D(a,e)|0;break _a}e=f<<(x[b+480180>>2]&59593760?1:2);f=x[R>>2]-D(a,e)|0}x[R>>2]=f;Fe(R,0,256);break M;case 19:if(e>>>0>64){break M}x[g+1364>>2]=e;break M;case 20:f=g+1432|0;$a:{if(e){v[f|0]=e;break $a}e=y[f|0]}u=g+1364|0;f=x[u>>2];n=e&15;k=e&255;ab:{if(!((n|0)!=15|k>>>0<16)){x[h+24>>2]=f+(k>>>4|0);break ab}if(!(!n|(k&240)!=240)){x[h+24>>2]=f-n;break ab}if(n){x[h+24>>2]=f-D(a,n);break ab}x[h+24>>2]=f+D(a,k>>>4|0)}Fe(h+24|0,0,64);x[u>>2]=x[h+24>>2];break M;case 7:dn(b,r,e,8);break M;case 29:case 30:break Ra;case 25:break Sa;case 6:break Ta;case 24:break Ua;case 3:break Va;case 5:break Wa;case 18:break Xa;case 17:break Ya;default:break M}}if(e>>>0>15){break Xa}f=(e&1)<<14;n=z[b+480188>>1];k=0;while(1){if((k|0)==(n|0)){break Xa}u=i+D(k,872)|0;x[u+704>>2]=(f|x[u+704>>2]&-16385)^16384;k=k+1|0;continue}}if((e&240)!=128){break M}dn(b,r,e&15,4);break M}if(e){v[g+1425|0]=e}e=0}Ol(r,e);break M}wT(b,r,e);break M}vT(r,e);break M}uT(r,e);break M}bb:{if(e<<24>>24>=0){f=Oe(sa,y[g+1460|0]);break bb}f=Oe(ta,e&127)}n=y[ea|0];x[31737]=0;ja(613,b|0,i|0,m&65535,0,f|0,n|0);f=x[31737];x[31737]=0;if((f|0)!=1){break M}a=N()|0;break l}e=0}cb:{db:{switch(y[g+1406|0]-2|0){case 0:dn(b,r,y[g+1408|0],6);break cb;case 5:Kb(h+24|0,I,53);f=y[g+1408|0];if(Hb(x[x[h+24>>2]>>2],x[h+28>>2])){v[g+1439|0]=f&15;break cb}Ol(r,f<<4);break cb;case 6:break db;default:break cb}}Ol(r,y[g+1408|0])}eb:{fb:{gb:{hb:{ib:{f=y[$|0];switch(f-5|0){case 1:break eb;case 3:break gb;case 0:case 2:break hb;default:break ib}}switch(f-26|0){case 1:break fb;case 0:break hb;default:break eb}}jb:{if(x[b+480180>>2]&16777248){f=q;if(!(y[b+480208|0]&4)){break jb}}f=a}n=y[g+1439|0];Kb(h+24|0,I,21);g=g+1435|0;k=y[g|0];f=D(f,n);ua=g,va=(Hb(x[x[h+24>>2]>>2],x[h+28>>2])?f<<2:f)+k|0,v[ua|0]=va;break eb}kb:{if(x[b+480180>>2]&16777248){f=q;if(!(y[b+480208|0]&4)){break kb}}f=a}n=y[g+1442|0];Kb(h+24|0,I,21);g=g+1436|0;k=y[g|0];f=D(f,n);ua=g,va=(Hb(x[x[h+24>>2]>>2],x[h+28>>2])?f<<2:f)+k|0,v[ua|0]=va;break eb}f=g+1437|0;v[f|0]=y[f|0]+D(_,y[g+1445|0]);sT(b,r)}Kb(h+24|0,I,78);if(!Hb(x[x[h+24>>2]>>2],x[h+28>>2])){break L}f=e&255;if(!f){break L}rT(r,f)}m=m+1|0;continue}}break}break}a=N()|0;break l}a=N()|0;break l}a=N()|0;break l}a=N()|0;break l}a=N()|0;break l}g=1;break m}g=0}lb:{if((ba|0)!=7){break lb}a=0;while(1){if(z[b+480188>>1]<=a>>>0){break lb}mb:{if(x[Ue(x[t+8>>2],a)>>2]==-1){break mb}x[31737]=0;V(612,t|0,a&65535,l|0,-1);d=x[31737];x[31737]=0;if((d|0)!=1){break mb}a=N()|0;break l}a=a+1|0;continue}}if(y[s+26|0]){w[s+20>>1]=z[i+72>>1];x[s+8>>2]=x[i+48>>2]}C[s>>3]=C[t+24>>3];x[31737]=0;O(607,X|0,s|0);a=x[31737];x[31737]=0;nb:{ob:{pb:{qb:{if((a|0)!=1){if(!Y){break a}if(!(g?y[s+26|0]:1)){break pb}q=hB(h+56|0);if(Gd(y[ia+24|0])){eT(q,ia)}tB(ia);a=yc(b+1074376|0,i,614);l=0;while(1){if((l|0)==256){Fn(a+223848|0,i+223848|0);d=a+223860|0;f=y[d+24|0];l=i+223860|0;rb:{if((Gd(y[l+24|0])|0)==(f|0)){if(!f){break rb}f=ec(d);Lu(d,x[f>>2]);x[d>>2]=x[l>>2];x[d+4>>2]=x[l+4>>2];x[d+8>>2]=x[l+8>>2];sb:{if(!x[zb(d)>>2]){x[d>>2]=f;break sb}x[x[f>>2]+8>>2]=f;f=ec(l);x[l>>2]=f;x[f>>2]=0;ua=zb(l),va=0,x[ua>>2]=va}d=d+12|0;f=ec(d);Ku(d,x[f>>2]);l=l+12|0;x[d>>2]=x[l>>2];x[d+4>>2]=x[l+4>>2];x[d+8>>2]=x[l+8>>2];tb:{if(!x[zb(d)>>2]){x[d>>2]=f;break tb}x[x[f>>2]+8>>2]=f;d=ec(l);x[l>>2]=d;x[d>>2]=0;ua=zb(l),va=0,x[ua>>2]=va}break rb}if(f){tB(d);break rb}eT(d,l)}}else{d=D(l,872);Kq((d+a|0)+616|0,(d+i|0)+616|0);l=l+1|0;continue}break}sB(a);x[b+1074400>>2]=0;v[b+1074476|0]=1;a=b+1074392|0;x[a>>2]=-2;x[a+4>>2]=0;x[b+1074428>>2]=x[b+1074424>>2];a=x[b+1298300>>2];if(!Mj(a)){break qb}break ob}a=N()|0;break l}x[31737]=0;W(614,a|0);a=x[31737];x[31737]=0;if((a|0)!=1){break ob}break nb}if((c|0)==3){break b}x[b+1074416>>2]=x[b+480196>>2];x[b+1074420>>2]=x[b+480204>>2];x[b+1074456>>2]=x[b+480200>>2];break b}f=(ba|0)==7;a=0;while(1){if(z[b+480188>>1]<=a>>>0){d=FC(h+24|0);a=_i(x[q+12>>2]);x[h+20>>2]=a;f=b+906300|0;n=Rf(q+12|0);while(1){if(!Zg(a,n)){ub:{a=250;l=d;vb:{while(1){if(a>>>0>=32){if(x[l>>2]){a=1;break vb}else{a=a-32|0;l=l+4|0;continue}}break}a=(x[d+28>>2]&67108863)!=0}if(!a){break ub}a=0;while(1){if((a|0)==250){break ub}Kb(h+12|0,d,a);wb:{if(!Hb(x[x[h+12>>2]>>2],x[h+16>>2])){break wb}l=x[vd(f,a)>>2];e=x[x[l>>2]+180>>2];x[31737]=0;W(e|0,l|0);l=x[31737];x[31737]=0;if((l|0)!=1){break wb}break nb}a=a+1|0;continue}}a=_i(x[q>>2]);x[h+12>>2]=a;d=Rf(q);while(1)if(Zg(a,d)){a=td(a);ka=B[ec(a)>>2];ua=vd(f,y[a|0]),ya=ka,B[ua+144>>2]=ya;a=x[ah(h+12|0)>>2];continue}else{Lq(q);break b}}l=td(a);g=zb(l);xb:{e=y[l|0];a=x[vd(f,e)>>2];if(a){Kb(h+12|0,d,e);if(!Hb(x[x[h+12>>2]>>2],x[h+16>>2])){x[31737]=0;P(615,d|0,e|0)|0;e=x[31737];x[31737]=0;if((e|0)==1){break xb}e=x[x[a>>2]+176>>2];x[31737]=0;O(e|0,a|0,-1);e=x[31737];x[31737]=0;if((e|0)==1){break xb}}ka=B[g>>2];l=x[l+4>>2];e=x[x[a>>2]+44>>2];x[31737]=0;wa(e|0,a|0,l|0,E(ka));a=x[31737];x[31737]=0;if((a|0)==1){break xb}}a=x[ah(h+20|0)>>2];continue}break}break nb}d=D(a,872)+b|0;l=y[d+1075791|0];if(l){v[d+1075794|0]=l}l=Ue(x[t+8>>2],a);if(!(y[l+5|0]==255|f)){v[h+24|0]=64;ua=d+1075680|0,va=y[Qb(l+5|0,h+24|0)|0]<<2,x[ua>>2]=va}yb:{zb:{if(x[d+1075080>>2]&67109888){break zb}l=x[d+1075096>>2];if(!l|!(y[l+35|0]&2)){break zb}e=x[b+1298300>>2];if(!Dd(e)){break zb}x[31737]=0;k=e;e=a&65535;S(616,k|0,e|0,l+68|0);l=x[31737];x[31737]=0;if((l|0)==1){break yb}l=x[b+1298300>>2];x[31737]=0;S(617,l|0,e|0,1);l=x[31737];x[31737]=0;if((l|0)==1){break yb}}x[d+1075008>>2]=0;a=a+1|0;continue}break}}a=N()|0;Lq(q)}Pu(J)}qT(t)}Xi(X);Q(a|0);p()}a=la&255;if((a|0)==y[b+484376|0]){break a}ak(qa,a)}if(c&9){a=b+1298264|0;if(x[a>>2]){jU(a);b=x[a>>2];jl(a);Db(b);ua=zb(a),va=0,x[ua>>2]=va;x[a>>2]=0;x[a+4>>2]=0}x[a>>2]=x[J>>2];x[a+4>>2]=x[J+4>>2];b=zb(J);ua=zb(a),va=x[b>>2],x[ua>>2]=va;x[b>>2]=0;x[J>>2]=0;x[J+4>>2]=0;a=a+12|0;c=ec(a);Qq(a,x[c>>2]);b=J+12|0;x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];x[a+8>>2]=x[b+8>>2];Ab:{if(!x[zb(a)>>2]){x[a>>2]=c;break Ab}x[x[c>>2]+8>>2]=c;a=ec(b);x[b>>2]=a;x[a>>2]=0;ua=zb(b),va=0,x[ua>>2]=va}}Pu(J);qT(t);fb=h+192|0}function CY(a,b,c,d,e,f){var g=0,h=0,i=0,j=0,k=0,l=0,m=E(0),n=0,o=0,q=0,r=0,s=0,t=0,u=E(0),C=E(0),F=0,G=0,H=E(0),I=E(0),J=0,K=0,L=E(0),M=E(0),N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=E(0),X=E(0),Y=0,Z=0,$=0,aa=0,ba=E(0),ca=E(0),da=E(0),ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0;aa=fb-16|0;fb=aa;a:{if(x[a+1420>>2]>=0){x[f>>2]=0;P=x[a+1420>>2];d=(P|0)>0?P:0;while(1){if((d|0)!=(h|0)){x[(D(h,20)+a|0)+1436>>2]=0;h=h+1|0;continue}break}b:{c:{d:{if((P|0)>3){break d}h=0;if((c|0)<4){break c}c=c-3|0;d=0;while(1){if((c|0)==(d|0)){break d}e:{f:{e=b+d|0;if(y[e|0]!=79|(y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24))!=(y[125972]|y[125973]<<8|(y[125974]<<16|y[125975]<<24))){break f}l=d+26|0;if((l|0)>=(c|0)){break e}g=d+27|0;n=b+l|0;f=y[n|0];if((g+f|0)>=(c|0)){break e}i=b+g|0;k=f+27|0;h=0;while(1)if((f|0)==(h|0)){h=0;g=0;while(1){f=22;if((h|0)!=22){g=ez(g,y[e+h|0]);h=h+1|0;continue}break}while(1){if((f|0)!=26){f=f+1|0;g=ez(g,0);continue}break}x[a+1420>>2]=P+1;f=D(P,20)+a|0;x[f+1432>>2]=g;x[f+1428>>2]=k-26;x[f+1424>>2]=y[e+22|0]|y[e+23|0]<<8|(y[e+24|0]<<16|y[e+25|0]<<24);g=-1;if(y[(i+y[n|0]|0)-1|0]!=255){g=y[e+6|0]|y[e+7|0]<<8|(y[e+8|0]<<16|y[e+9|0]<<24)}x[f+1436>>2]=l;x[f+1440>>2]=g;P=x[a+1420>>2];if((P|0)!=4){break f}P=4;break d}else{k=y[h+i|0]+k|0;h=h+1|0;continue}}d=d+1|0;continue}break}c=d}d=0;g:while(1){n=(d|0)>(P|0)?d:P;while(1){if((d|0)==(n|0)){break b}h=0;e=D(d,20)+a|0;j=e+1428|0;f=x[j>>2];k=x[e+1436>>2];i=c-k|0;l=(f|0)<(i|0)?f:i;o=(l|0)>0?l:0;s=b+k|0;Z=e+1432|0;g=x[Z>>2];while(1){if((h|0)!=(o|0)){g=ez(g,y[h+s|0]);h=h+1|0;continue}break}x[j>>2]=f-l;x[Z>>2]=g;if((f|0)<=(i|0)){e=e+1424|0;if(x[e>>2]==(g|0)){x[a+1380>>2]=-1;x[a+992>>2]=0;x[a+1420>>2]=-1;b=x[(D(d,20)+a|0)+1440>>2];x[a+1060>>2]=b;x[a+1064>>2]=(b|0)!=-1;h=k+l|0;break c}f=P-1|0;x[a+1420>>2]=f;f=D(f,20)+a|0;x[e+16>>2]=x[f+1440>>2];g=f+1432|0;h=x[g+4>>2];x[e+8>>2]=x[g>>2];x[e+12>>2]=h;f=f+1424|0;g=x[f+4>>2];x[e>>2]=x[f>>2];x[e+4>>2]=g;P=x[a+1420>>2];continue g}else{d=d+1|0;continue}}}}c=h}break a}x[a+100>>2]=0;x[a+32>>2]=b;x[a+40>>2]=b+c;if(!_L(a)){x[f>>2]=0;c=0;break a}ga=fb-16|0;fb=ga;ja=aa+4|0;x[a+1504>>2]=0;x[a+1508>>2]=0;h:{if(x[a+96>>2]){break h}i:{j:{k:{if(x[a+1380>>2]!=-1){break k}c=gf(a);if(x[a+96>>2]){break i}if((c|0)!=79){break j}if((gf(a)|0)!=103){break j}if((gf(a)|0)!=103){break j}if((gf(a)|0)!=83){break j}if(!XL(a)){break i}if(!(v[a+1375|0]&1)){break k}v[a+1376|0]=0;x[a+1384>>2]=0;fc(a,32);break i}h=bz(a);break i}fc(a,30)}if(!h){break h}if(rc(a,1)){fc(a,35);break h}l:{m:{if(!(x[a+84>>2]!=x[a+92>>2]?x[a+80>>2]:0)){c=rc(a,Om(x[a+408>>2]-1|0));if((c|0)==-1|(c|0)>=x[a+408>>2]){break h}x[ga+12>>2]=c;l=D(c,6)+a|0;if(!y[l+412|0]){g=x[a+112>>2];h=g>>1;break m}g=x[a+116>>2];h=g>>1;c=rc(a,1);k=(rc(a,1)|0)!=0;if(c|!y[l+412|0]){break m}x[ja>>2]=g-x[a+112>>2]>>2;c=x[a+112>>2]+g>>2;break l}_(6325,13274,3152,10779);p()}x[ja>>2]=0;c=h}x[ga+8>>2]=c;n:{if(!(!y[l+412|0]|k)){c=D(g,3);x[aa+8>>2]=c-x[a+112>>2]>>2;g=c+x[a+112>>2]>>2;break n}x[aa+8>>2]=h}x[ga+4>>2]=g;g=1}if(g){Z=x[ja>>2];ma=x[aa+8>>2];ka=x[ga+4>>2];Q=fb-2368|0;fb=Q;F=x[a+404>>2];pa=D(x[ga+12>>2],6)+a|0;r=y[pa+413|0];S=F+D(r,40)|0;T=x[((y[pa+412|0]<<2)+a|0)+104>>2];ea=T>>1;ra=0-ea|0;o:{while(1){c=x[a+4>>2];if((c|0)>(q|0)){c=y[(x[S+4>>2]+D(q,3)|0)+2|0];g=q<<2;t=g+(Q+1344|0)|0;x[t>>2]=0;h=y[(c+S|0)+9|0];if(z[((h<<1)+a|0)+132>>1]){l=x[a+260>>2];p:{q:{if(!rc(a,1)){break q}c=2;k=x[(a+g|0)+996>>2];l=l+D(h,1596)|0;j=x[(y[l+1588|0]<<2)+89180>>2];g=Om(j)-1|0;sa=k,ta=rc(a,g),w[sa>>1]=ta;sa=k,ta=rc(a,g),w[sa+2>>1]=ta;i=0;while(1){if(y[l|0]>i>>>0){O=y[(i+l|0)+1|0];g=O+l|0;s=y[g+49|0];n=-1<<s;o=y[g+33|0];r:{if(!s){h=0;break r}g=x[a+124>>2]+D(y[g+65|0],2096)|0;if(x[a+1396>>2]<=9){Cl(a)}h=x[a+1392>>2];J=w[(g+((h&1023)<<1)|0)+36>>1];s:{if((J|0)>=0){G=h;J=J&65535;h=y[J+x[g+8>>2]|0];x[a+1392>>2]=G>>>h;h=x[a+1396>>2]-h|0;x[a+1396>>2]=(h|0)>0?h:0;h=(h|0)<0?-1:J;break s}h=Nm(a,g)}if(!y[g+23|0]){break r}h=x[x[g+2088>>2]+(h<<2)>>2]}J=n^-1;g=c+o|0;while(1){if((c|0)!=(g|0)){o=0;n=w[((l+(O<<4)|0)+((h&J)<<1)|0)+82>>1];t:{if((n|0)<0){break t}n=x[a+124>>2]+D(n&65535,2096)|0;if(x[a+1396>>2]<=9){Cl(a)}o=x[a+1392>>2];R=w[(n+((o&1023)<<1)|0)+36>>1];u:{if((R|0)>=0){G=o;R=R&65535;o=y[R+x[n+8>>2]|0];x[a+1392>>2]=G>>>o;o=x[a+1396>>2]-o|0;x[a+1396>>2]=(o|0)>0?o:0;o=(o|0)<0?-1:R;break u}o=Nm(a,n)}if(!y[n+23|0]){break t}o=x[x[n+2088>>2]+(o<<2)>>2]}h=h>>s;w[k+(c<<1)>>1]=o;c=c+1|0;continue}break}i=i+1|0;c=g;continue}break}if(x[a+1396>>2]==-1){break q}w[Q+320>>1]=257;c=2;g=l+338|0;while(1){o=x[l+1592>>2];if((o|0)<=(c|0)){c=0;while(1){if((c|0)>=(o|0)){break p}if(!y[(Q+320|0)+c|0]){w[k+(c<<1)>>1]=65535;o=x[l+1592>>2]}c=c+1|0;continue}}else{h=c<<1;n=h+l|0;s=y[n+1088|0];o=s<<1;i=z[o+g>>1];t=y[n+1089|0];O=t<<1;J=w[k+o>>1];n=w[O+k>>1]-J|0;o=n>>31;i=(D((o^n)-o|0,z[g+h>>1]-i|0)|0)/(z[g+O>>1]-i|0)|0;o=J+((n|0)<0?0-i|0:i)|0;O=h+k|0;i=z[O>>1];v:{w:{if(i){h=Q+320|0;v[h+t|0]=1;v[h+s|0]=1;v[c+h|0]=1;h=i<<16>>16;n=j-o|0;if((h|0)>=((o|0)>(n|0)?n:o)<<1){if((o|0)<(n|0)){break v}o=j+(i^-1)|0;break w}if(h&1){o=o-(h+1>>>1|0)|0;break w}o=(h>>1)+o|0;break w}v[(Q+320|0)+c|0]=0}w[O>>1]=o}c=c+1|0;continue}}}x[t>>2]=1}q=q+1|0;continue}else{fc(a,21);c=0;break o}}break}if(!(x[a+84>>2]!=x[a+92>>2]?x[a+80>>2]:0)){yc(Q+320|0,Q+1344|0,c<<2);h=z[S>>1];c=0;while(1){if((c|0)==(h|0)){N=F+D(r,40)|0}else{l=x[S+4>>2]+D(c,3)|0;g=y[l+1|0];i=y[l|0]<<2;o=Q+1344|0;l=o;k=i+l|0;g=g<<2;if(!(x[l+g>>2]?x[k>>2]:0)){x[g+l>>2]=0;x[k>>2]=0}c=c+1|0;continue}break}h=0;while(1){x:{if(y[N+8|0]>h>>>0){o=0;c=x[a+4>>2];k=(c|0)>0?c:0;c=0;while(1){if((c|0)==(k|0)){break x}if(y[(x[S+4>>2]+D(c,3)|0)+2|0]==(h|0)){i=o+Q|0;l=c<<2;y:{if(x[l+(Q+1344|0)>>2]){l=0;g=1;break y}l=x[(a+l|0)+800>>2];g=0}v[i|0]=g;x[(Q+256|0)+(o<<2)>>2]=l;o=o+1|0}c=c+1|0;continue}}if(!(x[a+84>>2]!=x[a+92>>2]?x[a+80>>2]:0)){l=(ea|0)>0?ea:0;g=z[S>>1];h=a+800|0;z:while(1){if((g|0)<=0){O=ea<<2;o=0;c=0;while(1){h=x[a+4>>2];if((h|0)<=(c|0)){while(1){if((h|0)>(o|0)){O=y[pa+412|0];S=T>>1;g=S<<2;la=x[a+92>>2];q=T>>3;R=T>>2;k=x[((o<<2)+a|0)+800>>2];c=S<<2;t=k+c|0;A:{if(x[a+80>>2]){l=ro(a,g);break A}l=Ed(g)}c=(l+c|0)-8|0;s=x[((O<<2)+a|0)+1068>>2];j=s;h=k;while(1){if((h|0)!=(t|0)){B[c+4>>2]=E(B[h>>2]*B[j>>2])-E(B[j+4>>2]*B[h+8>>2]);B[c>>2]=E(B[h>>2]*B[j+4>>2])+E(B[h+8>>2]*B[j>>2]);h=h+16|0;j=j+8|0;c=c-8|0;continue}break}h=t-12|0;while(1){if(c>>>0>=l>>>0){B[c+4>>2]=E(B[h>>2]*B[j+4>>2])-E(B[h+8>>2]*B[j>>2]);B[c>>2]=E(E(-B[h+8>>2])*B[j+4>>2])-E(B[j>>2]*B[h>>2]);h=h-16|0;j=j+8|0;c=c-8|0;continue}break}c=R<<2;h=c+k|0;j=c+l|0;g=s+(S<<2)|0;c=l;i=k;while(1){n=g-32|0;if(n>>>0>=s>>>0){m=B[c>>2];u=B[j>>2];C=B[j+4>>2];H=B[c+4>>2];B[h+4>>2]=C+H;B[h>>2]=B[j>>2]+B[c>>2];C=E(C-H);r=g-16|0;F=g-12|0;m=E(u-m);B[i+4>>2]=E(C*B[r>>2])-E(B[F>>2]*m);B[i>>2]=E(m*B[r>>2])+E(C*B[F>>2]);m=B[c+8>>2];u=B[j+8>>2];C=B[j+12>>2];H=B[c+12>>2];B[h+12>>2]=C+H;B[h+8>>2]=B[j+8>>2]+B[c+8>>2];C=E(C-H);g=g-28|0;m=E(u-m);B[i+12>>2]=E(C*B[n>>2])-E(B[g>>2]*m);B[i+8>>2]=E(m*B[n>>2])+E(C*B[g>>2]);c=c+16|0;j=j+16|0;i=i+16|0;h=h+16|0;g=n;continue}break}h=Om(T);c=T>>4;g=S-1|0;i=0-q|0;UL(c,k,g,i,s);UL(c,k,g-R|0,i,s);J=T>>5;c=0-c|0;oq(J,k,g,c,s,16);oq(J,k,g-q|0,c,s,16);oq(J,k,g-(q<<1)|0,c,s,16);oq(J,k,g+D(q,-3)|0,c,s,16);c=h-4>>1;q=(c|0)<=2?2:c;c=2;while(1){B:{C:{D:{if((c|0)==(q|0)){na=h-7|0;break D}j=0;i=2<<c;i=(i|0)>0?i:0;n=8<<c;r=T>>c+4;F=T>>c+2;Y=0-(F>>1)|0;while(1){if((i|0)==(j|0)){break C}oq(r,k,g-D(j,F)|0,Y,s,n);j=j+1|0;continue}}while(1){E:{if((q|0)<(na|0)){n=2<<q;Y=8<<q;j=T>>q+6;U=T>>q+2;fa=0-(U>>1)|0;V=32<<q<<2;c=g;h=s;while(1){if((j|0)<=0){break E}i=n;r=(c<<2)+k|0;F=r+(fa<<2)|0;$=D(Y,12)+h|0;m=B[$>>2];N=(Y<<3)+h|0;u=B[N>>2];G=(Y<<2)+h|0;C=B[G>>2];H=B[$+4>>2];L=B[N+4>>2];W=B[G+4>>2];X=B[h+4>>2];da=B[h>>2];$=0-U<<2;while(1){if((i|0)>0){N=F-4|0;M=B[N>>2];ba=B[r>>2];ca=B[F>>2];B[r>>2]=ba+ca;G=r-4|0;I=B[G>>2];B[G>>2]=I+B[N>>2];I=E(I-M);M=E(ba-ca);B[N>>2]=E(I*da)+E(X*M);B[F>>2]=E(M*da)-E(X*I);N=F-12|0;ba=B[N>>2];G=r-8|0;I=B[G>>2];K=G;G=F-8|0;ca=B[G>>2];B[K>>2]=I+ca;K=r-12|0;M=B[K>>2];B[K>>2]=M+B[N>>2];M=E(M-ba);I=E(I-ca);B[N>>2]=E(M*C)+E(W*I);B[G>>2]=E(I*C)-E(W*M);N=F-20|0;ba=B[N>>2];G=r-16|0;I=B[G>>2];K=G;G=F-16|0;ca=B[G>>2];B[K>>2]=I+ca;K=r-20|0;M=B[K>>2];B[K>>2]=M+B[N>>2];M=E(M-ba);I=E(I-ca);B[N>>2]=E(M*u)+E(L*I);B[G>>2]=E(I*u)-E(L*M);N=F-28|0;ba=B[N>>2];G=r-24|0;I=B[G>>2];K=G;G=F-24|0;ca=B[G>>2];B[K>>2]=I+ca;K=r-28|0;M=B[K>>2];B[K>>2]=M+B[N>>2];M=E(M-ba);I=E(I-ca);B[N>>2]=E(M*m)+E(H*I);B[G>>2]=E(I*m)-E(H*M);i=i-1|0;F=F+$|0;r=r+$|0;continue}break}j=j-1|0;c=c-8|0;h=h+V|0;continue}}c=(g<<2)+k|0;h=c-(J<<6)|0;m=B[s+(T>>3<<2)>>2];da=E(-m);while(1){if(c>>>0>h>>>0){L=B[c>>2];g=c-32|0;W=B[g>>2];B[c>>2]=L+W;i=c-4|0;u=B[i>>2];n=i;i=c-36|0;X=B[i>>2];B[n>>2]=u+X;n=c-8|0;C=B[n>>2];G=n;n=c-40|0;I=B[n>>2];B[G>>2]=C+I;j=c-12|0;H=B[j>>2];G=j;j=c-44|0;M=B[j>>2];B[G>>2]=H+M;B[g>>2]=L-W;B[i>>2]=u-X;i=c-16|0;u=B[i>>2];G=i;i=c-48|0;ba=B[i>>2];B[G>>2]=u+ba;C=E(C-I);H=E(H-M);B[n>>2]=m*E(C+H);B[j>>2]=m*E(H-C);n=c-28|0;C=B[n>>2];j=c-60|0;H=B[j>>2];s=c-24|0;L=B[s>>2];q=c-56|0;W=B[q>>2];r=c-20|0;X=B[r>>2];G=r;r=c-52|0;I=B[r>>2];B[G>>2]=X+I;B[s>>2]=L+W;B[n>>2]=C+H;B[i>>2]=X-I;B[r>>2]=-E(u-ba);u=E(C-H);C=E(L-W);B[q>>2]=m*E(u-C);B[j>>2]=E(C+u)*da;TL(c);TL(g);c=c+-64|0;continue}break}n=S-4|0;c=l+(n<<2)|0;j=(l+(R<<2)|0)-16|0;h=x[((O<<2)+a|0)+1100>>2];while(1){if(j>>>0>=l>>>0){g=(z[h>>1]<<2)+k|0;B[c+12>>2]=B[g>>2];B[c+8>>2]=B[g+4>>2];B[j+12>>2]=B[g+8>>2];B[j+8>>2]=B[g+12>>2];g=(z[h+2>>1]<<2)+k|0;B[c+4>>2]=B[g>>2];B[c>>2]=B[g+4>>2];B[j+4>>2]=B[g+8>>2];B[j>>2]=B[g+12>>2];h=h+4|0;c=c-16|0;j=j-16|0;continue}break}h=x[((O<<2)+a|0)+1084>>2];j=l;c=j+(S<<2)|0;g=c;while(1){i=g-16|0;if(i>>>0>j>>>0){m=B[j+4>>2];s=g-4|0;u=B[s>>2];C=E(m-u);H=B[h+4>>2];m=E(m+u);u=B[j>>2];q=g-8|0;L=B[q>>2];W=E(u-L);X=B[h>>2];da=E(E(H*m)-E(W*X));B[j+4>>2]=C+da;u=E(u+L);m=E(E(H*W)+E(m*X));B[j>>2]=u+m;B[s>>2]=da-C;B[q>>2]=u-m;m=B[j+8>>2];u=B[i>>2];C=E(m+u);H=B[h+12>>2];m=E(m-u);u=B[j+12>>2];g=g-12|0;L=B[g>>2];W=E(u+L);X=B[h+8>>2];da=E(E(H*m)+E(W*X));B[j+8>>2]=C+da;u=E(u-L);m=E(E(H*W)-E(m*X));B[j+12>>2]=u+m;B[i>>2]=C-da;B[g>>2]=m-u;j=j+16|0;h=h+16|0;g=i;continue}break}j=x[((O<<2)+a|0)+1076>>2]+(S<<2)|0;g=(T<<2)+k|0;h=(n<<2)+k|0;while(1){i=c-32|0;if(i>>>0>=l>>>0){m=B[c-8>>2];u=B[j-4>>2];C=B[j-8>>2];H=B[c-4>>2];L=E(E(m*u)-E(C*H));B[k>>2]=L;B[h+12>>2]=-L;m=E(E(C*E(-m))-E(u*H));B[t>>2]=m;B[g-4>>2]=m;m=B[c-16>>2];u=B[j-12>>2];C=B[j-16>>2];H=B[c-12>>2];L=E(E(m*u)-E(C*H));B[k+4>>2]=L;B[h+8>>2]=-L;m=E(E(C*E(-m))-E(u*H));B[t+4>>2]=m;B[g-8>>2]=m;m=B[c-24>>2];u=B[j-20>>2];C=B[j-24>>2];H=B[c-20>>2];L=E(E(m*u)-E(C*H));B[k+8>>2]=L;B[h+4>>2]=-L;m=E(E(C*E(-m))-E(u*H));B[t+8>>2]=m;B[g-12>>2]=m;m=B[i>>2];u=B[j-28>>2];j=j-32|0;C=B[j>>2];H=B[c-28>>2];L=E(E(m*u)-E(C*H));B[k+12>>2]=L;B[h>>2]=-L;m=E(E(C*E(-m))-E(u*H));B[t+12>>2]=m;g=g-16|0;B[g>>2]=m;h=h-16|0;t=t+16|0;k=k+16|0;c=i;continue}break}if(!x[a+80>>2]){Db(l)}x[a+92>>2]=la;break B}q=q+1|0;continue}}c=c+1|0;continue}break}o=o+1|0;h=x[a+4>>2];continue}break}}else{g=c<<2;h=g+a|0;n=x[h+800>>2];F:{if(x[g+(Q+320|0)>>2]){Rb(n,0,O);break F}t=x[h+996>>2];G:{g=y[(y[(x[S+4>>2]+D(c,3)|0)+2|0]+S|0)+9|0];if(!z[((g<<1)+a|0)+132>>1]){fc(a,21);break G}j=T>>1;s=x[a+260>>2]+D(g,1596)|0;h=D(y[s+1588|0],w[t>>1]);i=1;g=0;while(1){if(x[s+1592>>2]>(i|0)){l=y[(i+s|0)+838|0]<<1;k=w[l+t>>1];if((k|0)>=0){k=D(y[s+1588|0],k&65535);l=z[(l+s|0)+338>>1];if((l|0)!=(g|0)){q=k-h|0;r=l-g|0;F=(q|0)/(r|0)|0;H:{J=(j|0)>(l|0)?l:j;if((J|0)<=(g|0)){break H}G=q;q=q>>31;R=F>>31;R=((G^q)-q|0)-D(r,(R^F)-R|0)|0;Y=q|1;q=n+(g<<2)|0;B[q>>2]=B[((h&255)<<2)+89200>>2]*B[q>>2];J=J-1|0;q=0;while(1){if((g|0)==(J|0)){break H}g=g+1|0;$=n+(g<<2)|0;q=q+R|0;N=(q|0)<(r|0);h=(h+F|0)+(N?0:Y)|0;B[$>>2]=B[((h&255)<<2)+89200>>2]*B[$>>2];q=q-(N?0:r)|0;continue}}g=l}h=k}i=i+1|0;continue}break}if((g|0)>=(j|0)){break G}h=(h<<2)+89200|0;while(1){if((g|0)==(j|0)){break G}l=n+(g<<2)|0;B[l>>2]=B[h>>2]*B[l>>2];g=g+1|0;continue}}}c=c+1|0;continue}break}WL(a);I:{if(y[a+1377|0]){x[a+1060>>2]=ra;v[a+1377|0]=0;x[a+1064>>2]=1;x[a+1412>>2]=T-ka;break I}c=x[a+1412>>2];if(!c){break I}g=ma-Z|0;if((g|0)<=(c|0)){x[a+1412>>2]=c-g;x[ja>>2]=ma;Z=ma;break I}Z=c+Z|0;x[ja>>2]=Z;x[a+1412>>2]=0}c=x[a+1064>>2];J:{K:{L:{M:{if(x[a+1388>>2]==x[a+1404>>2]){N:{if(!c|!(y[a+1375|0]&4)){break N}c=x[a+1408>>2];g=x[a+1060>>2];if(c>>>0>=g+(ka-Z|0)>>>0){break N}g=c-g|0;c=(c>>>0>=g>>>0?g:0)+Z|0;c=(c|0)<(ka|0)?c:ka;x[aa+12>>2]=c;x[a+1060>>2]=c+x[a+1060>>2];break K}x[a+1064>>2]=1;c=x[a+1408>>2]+(Z-ea|0)|0;break M}if(!c){break L}c=x[a+1060>>2]}x[a+1060>>2]=c+(ma-Z|0)}if(x[a+84>>2]!=x[a+92>>2]?x[a+80>>2]:0){break J}x[aa+12>>2]=ka}c=1;break o}_(6325,13274,3451,5634);p()}g=g-1|0;c=x[S+4>>2]+D(g,3)|0;k=x[h+(y[c+1|0]<<2)>>2];i=x[h+(y[c|0]<<2)>>2];c=0;while(1){if((c|0)==(l|0)){continue z}n=c<<2;j=n+k|0;C=B[j>>2];n=i+n|0;m=B[n>>2];O:{if(m>E(0)){if(C>E(0)){u=E(m-C);break O}u=m;m=E(m+C);break O}if(C>E(0)){u=E(m+C);break O}u=m;m=E(m-C)}B[n>>2]=m;B[j>>2]=u;c=c+1|0;continue}}}_(6325,13274,3335,5634);p()}R=Q+256|0;F=fb-16|0;fb=F;j=x[a+4>>2];r=x[a+396>>2];k=y[(h+N|0)+24|0];s=r+D(k,24)|0;g=x[s+4>>2];la=z[((k<<1)+a|0)+268>>1];c=ea<<((la|0)==2);i=c>>>0>g>>>0?g:c;g=x[s>>2];O=(i-(c>>>0>g>>>0?g:c)>>>0)/A[s+8>>2]|0;l=O<<2;c=D(j,l+4|0);$=x[x[a+124>>2]+D(y[s+13|0],2096)>>2];G=x[a+92>>2];P:{if(x[a+80>>2]){g=ro(a,c);j=x[a+4>>2];break P}g=Ed(c)}n=(o|0)>0?o:0;t=ea<<2;q=0;c=(j|0)>0?j:0;i=(j<<2)+g|0;while(1){if((c|0)!=(q|0)){x[(q<<2)+g>>2]=i;q=q+1|0;i=i+l|0;continue}break}l=g;c=0;while(1){if((c|0)!=(n|0)){if(!y[c+Q|0]){Rb(x[R+(c<<2)>>2],0,t)}c=c+1|0;continue}break}Q:{if(!((o|0)==1|(la|0)!=2)){c=0;while(1){R:{if((c|0)!=(n|0)){if(y[c+Q|0]){break R}}else{c=n}if((c|0)==(o|0)){break Q}n=r+D(k,24)|0;q=(o|0)!=2;r=(o|0)<3;j=0;while(1){if((j|0)==8){break Q}S:{if(!q){k=0;g=0;while(1){if((g|0)>=(O|0)){break S}c=x[s>>2]+D(x[s+8>>2],g)|0;x[F+12>>2]=c&1;x[F+8>>2]=c>>1;if(!j){i=x[a+124>>2]+D(y[s+13|0],2096)|0;if(x[a+1396>>2]<=9){Cl(a)}c=x[a+1392>>2];t=w[(i+((c&1023)<<1)|0)+36>>1];T:{if((t|0)>=0){K=c;t=t&65535;c=y[t+x[i+8>>2]|0];x[a+1392>>2]=K>>>c;c=x[a+1396>>2]-c|0;x[a+1396>>2]=(c|0)>0?c:0;c=(c|0)<0?-1:t;break T}c=Nm(a,i)}c=y[i+23|0]?x[x[i+2088>>2]+(c<<2)>>2]:c;if((c|0)==-1){break Q}x[x[l>>2]+(k<<2)>>2]=x[x[n+16>>2]+(c<<2)>>2]}c=0;while(1){if(!((c|0)>=($|0)|(g|0)>=(O|0))){i=x[s+8>>2];t=w[(x[n+20>>2]+(y[x[x[l>>2]+(k<<2)>>2]+c|0]<<4)|0)+(j<<1)>>1];U:{if((t|0)>=0){if(!VL(a,x[a+124>>2]+D(t&65535,2096)|0,R,2,F+12|0,F+8|0,ea,i)){break Q}g=g+1|0;break U}g=g+1|0;i=x[s>>2]+D(i,g)|0;x[F+8>>2]=i>>1;x[F+12>>2]=i&1}c=c+1|0;continue}break}k=k+1|0;continue}}if(r){break S}k=0;g=0;while(1){if((g|0)>=(O|0)){break S}i=x[s>>2]+D(x[s+8>>2],g)|0;c=(i|0)/(o|0)|0;x[F+12>>2]=i-D(c,o);x[F+8>>2]=c;if(!j){i=x[a+124>>2]+D(y[s+13|0],2096)|0;if(x[a+1396>>2]<=9){Cl(a)}c=x[a+1392>>2];t=w[(i+((c&1023)<<1)|0)+36>>1];V:{if((t|0)>=0){K=c;t=t&65535;c=y[t+x[i+8>>2]|0];x[a+1392>>2]=K>>>c;c=x[a+1396>>2]-c|0;x[a+1396>>2]=(c|0)>0?c:0;c=(c|0)<0?-1:t;break V}c=Nm(a,i)}c=y[i+23|0]?x[x[i+2088>>2]+(c<<2)>>2]:c;if((c|0)==-1){break Q}x[x[l>>2]+(k<<2)>>2]=x[x[n+16>>2]+(c<<2)>>2]}c=0;while(1){if(!((c|0)>=($|0)|(g|0)>=(O|0))){i=x[s+8>>2];t=w[(x[n+20>>2]+(y[x[x[l>>2]+(k<<2)>>2]+c|0]<<4)|0)+(j<<1)>>1];W:{if((t|0)>=0){if(!VL(a,x[a+124>>2]+D(t&65535,2096)|0,R,o,F+12|0,F+8|0,ea,i)){break Q}g=g+1|0;break W}g=g+1|0;i=x[s>>2]+D(i,g)|0;t=(i|0)/(o|0)|0;x[F+8>>2]=t;x[F+12>>2]=i-D(o,t)}c=c+1|0;continue}break}k=k+1|0;continue}}j=j+1|0;continue}}c=c+1|0;continue}}na=r+D(k,24)|0;j=0;while(1){if((j|0)==8){break Q}k=0;o=0;while(1){if((k|0)<(O|0)){X:{if(j){break X}c=0;while(1){if((c|0)==(n|0)){break X}if(!y[c+Q|0]){i=x[a+124>>2]+D(y[s+13|0],2096)|0;if(x[a+1396>>2]<=9){Cl(a)}g=x[a+1392>>2];q=w[(i+((g&1023)<<1)|0)+36>>1];Y:{if((q|0)>=0){r=g;q=q&65535;g=y[q+x[i+8>>2]|0];x[a+1392>>2]=r>>>g;g=x[a+1396>>2]-g|0;x[a+1396>>2]=(g|0)>0?g:0;g=(g|0)<0?-1:q;break Y}g=Nm(a,i)}g=y[i+23|0]?x[x[i+2088>>2]+(g<<2)>>2]:g;if((g|0)==-1){break Q}x[x[l+(c<<2)>>2]+(o<<2)>>2]=x[x[na+16>>2]+(g<<2)>>2]}c=c+1|0;continue}}g=0;while(1){Z:{if((g|0)>=($|0)){break Z}c=0;if((k|0)>=(O|0)){break Z}while(1){if((c|0)!=(n|0)){_:{if(y[c+Q|0]){break _}i=c<<2;q=w[(x[na+20>>2]+(y[x[x[i+l>>2]+(o<<2)>>2]+g|0]<<4)|0)+(j<<1)>>1];if((q|0)<0){break _}t=x[a+124>>2]+D(q&65535,2096)|0;U=x[i+R>>2];Y=x[s+8>>2];J=x[s>>2]+D(Y,k)|0;$:{aa:{if(la){q=0;while(1){i=1;if((q|0)>=(Y|0)){break $}fa=U+(J<<2)|0;i=Y-q|0;r=0;m=E(0);ba:{K=SL(a,t);if((K|0)<0){break ba}V=x[t>>2];r=(i|0)>(V|0)?V:i;V=D(V,K);if(y[t+22|0]){i=0;K=(r|0)>0?r:0;r=1;while(1){if((i|0)==(K|0)){break ba}ha=i<<2;ia=ha+fa|0;m=E(m+B[ha+(x[t+28>>2]+(V<<2)|0)>>2]);B[ia>>2]=B[ia>>2]+m;m=E(m+B[t+12>>2]);i=i+1|0;continue}}i=0;K=(r|0)>0?r:0;r=1;while(1){if((i|0)==(K|0)){break ba}ha=i<<2;ia=ha+fa|0;B[ia>>2]=B[ia>>2]+E(B[ha+(x[t+28>>2]+(V<<2)|0)>>2]+E(0));i=i+1|0;continue}}if(!r){break aa}i=x[t>>2];J=i+J|0;q=i+q|0;continue}}q=0;fa=(Y|0)/x[t>>2]|0;K=(fa|0)>0?fa:0;ha=U+(J<<2)|0;i=1;while(1){if((q|0)==(K|0)){break $}r=q+J|0;U=q<<2;q=q+1|0;ia=U+ha|0;U=Y-r|0;V=0;m=E(0);ca:{oa=SL(a,t);if((oa|0)<0){break ca}r=0;V=x[t>>2];U=(U|0)>(V|0)?V:U;U=(U|0)>0?U:0;oa=D(V,oa)<<2;V=1;while(1){if((r|0)==(U|0)){break ca}qa=ia+(D(r,fa)<<2)|0;u=E(m+B[(oa+x[t+28>>2]|0)+(r<<2)>>2]);B[qa>>2]=B[qa>>2]+u;m=y[t+22|0]?u:m;r=r+1|0;continue}}if(V){continue}break}}i=0}if(!i){break Q}}c=c+1|0;continue}break}k=k+1|0;g=g+1|0;continue}break}o=o+1|0;continue}break}j=j+1|0;continue}}if(!x[a+80>>2]){Db(l)}x[a+92>>2]=G;fb=F+16|0;h=h+1|0;continue}}_(6325,13274,3302,5634);p()}fb=Q+2368|0}else{c=0}fb=ga+16|0;if(!c){da:{ea:{fa:{c=x[a+100>>2];switch(c-32|0){case 0:break ea;case 3:break fa;default:break da}}x[a+100>>2]=0;while(1){if((Ph(a)|0)!=-1&!x[a+96>>2]){continue}break}x[f>>2]=0;c=x[a+32>>2]-b|0;break a}if(x[a+992>>2]){break da}x[a+100>>2]=0;while(1){if((Ph(a)|0)!=-1&!x[a+96>>2]){continue}break}x[f>>2]=0;c=x[a+32>>2]-b|0;break a}x[a+1420>>2]=0;x[a+992>>2]=0;x[a+1504>>2]=0;x[a+1508>>2]=0;x[a+1412>>2]=0;x[a+1416>>2]=0;v[a+1377|0]=0;x[a+1064>>2]=0;x[a+100>>2]=c;x[f>>2]=0;c=1;break a}l=x[aa+12>>2];i=x[aa+4>>2];h=x[aa+8>>2];c=1;k=x[a+992>>2];ga:{if(k){g=k<<1;ha:{if((g|0)==x[a+112>>2]){c=a+1092|0}else{c=0;if((g|0)!=x[a+116>>2]){break ha}c=a+1096|0}c=x[c>>2]}g=0;if(!c){break ga}j=(k|0)>0?k:0;o=c+(k<<2)|0;while(1){if(x[a+4>>2]>(P|0)){k=(P<<2)+a|0;g=0;while(1){if((g|0)!=(j|0)){n=g<<2;s=(n+x[k+800>>2]|0)+(i<<2)|0;B[s>>2]=E(B[s>>2]*B[c+n>>2])+E(B[n+x[k+928>>2]>>2]*B[o+((g^-1)<<2)>>2]);g=g+1|0;continue}break}P=P+1|0;continue}break}c=!x[a+992>>2]}x[a+992>>2]=l-h;n=(h|0)>(l|0);j=(n?h:l)-h|0;P=0;while(1){if(x[a+4>>2]>(P|0)){k=(P<<2)+a|0;g=0;while(1){if((g|0)!=(j|0)){o=g<<2;B[o+x[k+928>>2]>>2]=B[(o+x[k+800>>2]|0)+(h<<2)>>2];g=g+1|0;continue}break}P=P+1|0;continue}break}g=0;if(!c){g=(n?l:h)-i|0;x[a+1416>>2]=g+x[a+1416>>2]}}c=0;h=x[a+4>>2];l=(h|0)>0?h:0;while(1){if((c|0)!=(l|0)){k=(c<<2)+a|0;x[k+864>>2]=x[k+800>>2]+(i<<2);c=c+1|0;continue}break}if(d){x[d>>2]=h}x[f>>2]=g;x[e>>2]=a+864;c=x[a+32>>2]-b|0}fb=aa+16|0;return c}function aqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0,F=0,G=0,H=0;f=fb-1728|0;fb=f;xc(b);d=fb-16|0;fb=d;g=f+1602|0;YX(d+8|0,g);h=x[d+12>>2];lc(d,x[b>>2],x[b+8>>2],x[d+8>>2],x[d+12>>2]);i=x[d+4>>2];if((i|0)==(h|0)){Vb(b,x[d+12>>2])}fb=d+16|0;d=(h|0)==(i|0);if(!d){XX(g)}a:{b:{c:{d:{e:{f:{g:{if(!d){break g}if(!ZX(g)){break g}if(!Mb(x[b>>2],x[b+8>>2],Bc(256,0))){break g}e=1;if((c|0)==64){break g}Bd(a,1048576);gg(a);d=fb-16|0;fb=d;e=f+1344|0;g=tc(d+4|0,4230);_c(e,g);tb(g);fb=d+16|0;d=y[f+1610|0]|y[f+1611|0]<<8;x[f+144>>2]=d>>>8;x[31737]=0;x[f+12>>2]=d&255;g=f+72|0;O(445,g|0,f+12|0);d=x[31737];x[31737]=0;h:{i:{j:{k:{if((d|0)!=1){x[31737]=0;d=f+256|0;V(431,d|0,e|0,f+144|0,g|0);h=x[31737];x[31737]=0;if((h|0)==1){break k}Ab(a+1298344|0,d);tb(d);tb(g);Eb(e);g=tc(d,15225);Ab(a+1298356|0,g);tb(g);Ve(e,2,f+1612|0);Kr(d,22,e);Ab(a+1298368|0,d);tb(d);G=a+1298404|0,H=x[Fc(d,22)>>2],x[G>>2]=H;HC(e,2,f+1644|0);Cc(d,e);Ab(a+1298308|0,d);tb(d);w[a+480188>>1]=y[f+1714|0]|y[f+1715|0]<<8;g=y[f+1718|0];x[a+480204>>2]=125e4;x[a+480208>>2]=32792;G=a,H=Kd(g,1,31),x[G+480196>>2]=H;w[a+480192>>1]=y[f+1724|0]|y[f+1725|0]<<8;w[a+480190>>1]=y[f+1726|0]|y[f+1727|0]<<8;g=Kd(y[f+1719|0],1,32);x[a+480216>>2]=g;x[a+480228>>2]=96;x[a+480232>>2]=48;x[a+480220>>2]=g<<2;Dw(b,e);g=a+484376|0;Vr(Xb(x[a+484360>>2],y[g|0]),e,y[f+1708|0]|y[f+1709|0]<<8,65535,65535);af(Xb(x[a+484360>>2],y[g|0]),y[f+1710|0]|y[f+1711|0]<<8);r=hh(b);fe(d,b,r?274:0);B=ic(f+1324|0,d);ub(d);x[31737]=0;e=R(152,b|0)|0;g=x[31737];x[31737]=0;if((g|0)==1){break i}x[31737]=0;S(186,d|0,b|0,e|0);e=x[31737];x[31737]=0;if((e|0)==1){break i}t=ic(f+1304|0,d);ub(d);s=z[a+480188>>1];if(r){w[a+480188>>1]=s+8}u=c&1;if(!u){break h}x[31737]=0;O(224,a+484344|0,y[f+1712|0]|y[f+1713|0]<<8);d=x[31737];x[31737]=0;if((d|0)!=1){break h}h=N()|0;break c}h=N()|0;break j}h=N()|0;tb(f+72|0)}Eb(f+1344|0);break a}h=N()|0;break b}o=a+484344|0;h=0;while(1){l:{m:{n:{o:{p:{q:{if((y[f+1712|0]|y[f+1713|0]<<8)>>>0<=q>>>0){d=y[f+1716|0]|y[f+1717|0]<<8;if((d-2&65535)>>>0>=4998){break o}if(!(h&1)){break q}i=0;d=Gc(((d>>>1|0)+11025e5>>>0)/(d>>>0)|0,0);break p}x[31737]=0;d=R(190,b|0)|0;e=x[31737];x[31737]=0;if((e|0)==1){break d}x[f+12>>2]=d;x[31737]=0;e=R(152,b|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break e}x[31737]=0;d=f+72|0;S(186,d|0,b|0,e+1&-2);e=x[31737];x[31737]=0;if((e|0)==1){break e}l=ic(f+256|0,d);ub(d);wc(f+12|0,1024);if(!u){break m}k=x[f+12>>2];if(!k){break m}x[31737]=0;d=U(197,o|0,q&65535,k|0)|0;e=x[31737];x[31737]=0;if((e|0)!=1){if(!d){break m}j=0;e=0;if(v[f+1720|0]&1){break n}r:while(1){if((j|0)==(k|0)){break m}d=Wb(x[o>>2],q);bf(f+72|0,x[d>>2],x[x[d+48>>2]+12>>2],j);e=0;while(1){if((e|0)==(s|0)){j=j+1|0;continue r}x[31737]=0;d=f+144|0;O(624,l|0,d|0);g=x[31737];x[31737]=0;if((g|0)!=1){h=WX(Wc(x[f+72>>2],e),d)|h;e=e+1|0;continue}break}break}break f}break f}i=2;d=Ze(2646e3/+(D(d,D(x[a+480216>>2],x[a+480196>>2]))>>>0)*1e4)}v[a+480224|0]=i;x[a+480204>>2]=d}d=z[a+480188>>1];x[31737]=0;v[f+256|0]=0;q=U(625,f+1292|0,d|0,f+256|0)|0;d=x[31737];x[31737]=0;if((d|0)!=1){j=a+1298320|0;l=a+1298332|0;n=0;s:{t:{u:{v:{w:{x:{while(1){d=x[t+8>>2];e=x[t>>2];x[31737]=0;d=U(151,e|0,d|0,8)|0;e=x[31737];x[31737]=0;y:{if((e|0)!=1){if(d){break y}d=a+906300|0;i=x[q>>2];j=0;while(1){g=z[a+480188>>1];if(g>>>0<=j>>>0){x[f+248>>2]=0;x[f+252>>2]=0;x[f+240>>2]=0;x[f+244>>2]=0;x[f+232>>2]=0;x[f+236>>2]=0;x[f+224>>2]=0;x[f+228>>2]=0;z:{A:{if(!r){break A}e=0;x[31737]=0;O(626,B|0,f+256|0);d=x[31737];x[31737]=0;if((d|0)==1){break z}while(1){if((e|0)==8){e=0;x[31737]=0;j=P(215,f+212|0,z[f+256>>1])|0;d=x[31737];x[31737]=0;if((d|0)!=1){B:{C:{D:{E:{while(1){if(z[f+256>>1]<=e>>>0){x[31737]=0;l=U(627,f+200|0,y[f+1712|0]|y[f+1713|0]<<8,25336)|0;d=x[31737];x[31737]=0;if((d|0)==1){break C}g=0;break D}x[31737]=0;g=R(190,b|0)|0;d=x[31737];x[31737]=0;if((d|0)!=1){x[31737]=0;d=f+144|0;S(186,d|0,b|0,g<<5);g=x[31737];x[31737]=0;if((g|0)==1){break E}g=ic(f+72|0,d);hd(dh(x[j>>2],e),g);ub(g);e=e+1|0;ub(d);continue}break}h=N()|0;break B}h=N()|0;break B}while(1){if((y[f+1708|0]|y[f+1709|0]<<8)>>>0<=g>>>0){md(l);Qc(j);break A}F:{h=f+g|0;e=y[h+274|0];if(e>>>0>=z[f+256>>1]){break F}d=z[_b(x[Xb(x[a+484360>>2],y[a+484376|0])>>2],g)>>1];if(d>>>0>=(y[f+1712|0]|y[f+1713|0]<<8)>>>0){break F}G:{i=_b(x[l>>2],d);k=z[i>>1];H:{if((k|0)==65535){w[i>>1]=e;break H}if((e|0)==(k|0)){break H}x[31737]=0;e=P(628,o|0,d|0)|0;i=x[31737];x[31737]=0;if((i|0)==1){break G}if((e|0)==65535){break H}G=_b(x[Xb(x[a+484360>>2],y[a+484376|0])>>2],g),H=e,w[G>>1]=H;d=e}if(!He(x[a+484344>>2],x[a+484348>>2],d)){break F}k=dh(x[j>>2],y[h+274|0]);xc(k);e=x[k>>2];x[31737]=0;e=R(155,e|0)|0;h=x[31737];x[31737]=0;if((h|0)==1){break G}m=e>>>5|0;i=0;I:while(1){e=Wb(x[o>>2],d);if(A[e+12>>2]<=i>>>0){break F}h=0;e=jd(x[e>>2],x[x[e+48>>2]+12>>2],i,z[a+480188>>1]-8&65535);r=i>>>0>=m>>>0;while(1){if((h|0)==8){i=i+1|0;continue I}v[e|0]=0;v[e+1|0]=0;v[e+2|0]=0;v[e+3|0]=0;v[e+4|0]=0;v[e+5|0]=0;J:{if(r){break J}x[31737]=0;P(629,k|0,f+72|0)|0;u=x[31737];x[31737]=0;if((u|0)==1){break G}if(v[f+72|0]>=0){break J}v[e|0]=61;v[e+1|0]=y[(f+240|0)+(h<<1)|0];u=y[f+72|0]&31;v[f+144|0]=u;if(u){Qf(f+144|0,15);v[e+3|0]=20;v[e+5|0]=y[f+144|0]|208}v[e+2|0]=1;v[e+4|0]=y[f+73|0]+3>>>2}e=e+6|0;h=h+1|0;continue}}}h=N()|0;md(l);break B}g=g+1|0;continue}}h=N()|0}Qc(j);break s}h=N()|0;break s}g=e<<1;h=g+(f+240|0)|0;d=z[a+480192>>1]+1&65535;i=z[x[a+8>>2]+58>>1];while(1){K:{L:{j=d&65535;if(j>>>0<=i>>>0){if(x[((j<<2)+a|0)+900380>>2]){break L}}else{d=65535}d=d&65535;break K}d=d+1|0;continue}break}w[h>>1]=d;i=g+(f+224|0)|0;g=z[(f+g|0)+258>>1];w[i>>1]=g;M:{if((d|0)!=65535){x[31737]=0;d=U(252,a|0,d|0,g+1&65535)|0;g=x[31737];x[31737]=0;N:{O:{if((g|0)!=1){if(!d){break M}x[31737]=0;g=f+144|0;O(289,g|0,4475);h=x[31737];x[31737]=0;if((h|0)==1){break O}x[31737]=0;x[f+12>>2]=e+1;h=f+72|0;S(630,h|0,g|0,f+12|0);i=x[31737];x[31737]=0;if((i|0)==1){break N}zc(d+492|0,h);tb(h);Eb(g);break M}h=N()|0;break s}h=N()|0;break s}h=N()|0;Eb(f+144|0);break s}w[h>>1]=0}e=e+1|0;continue}}P:{Q:{d=y[f+1720|0]|y[f+1721|0]<<8|(y[f+1722|0]<<16|y[f+1723|0]<<24);if(!(d&2)){break Q}d=(((d&8?z[a+480188>>1]:s)&65535)+((y[f+1610|0]|y[f+1611|0]<<8)>>>0>591?n:0)|0)+(d>>>4&1)|0;g=0;R:while(1){e=0;if((y[f+1712|0]|y[f+1713|0]<<8)>>>0<=g>>>0){break Q}while(1){S:{if((d|0)!=(e|0)){h=x[b+8>>2];i=x[b>>2];x[31737]=0;h=U(151,i|0,h|0,4)|0;i=x[31737];x[31737]=0;if((i|0)==1){break P}if(h){break S}}g=g+1|0;continue R}x[31737]=0;O(631,y[f+1610|0]|y[f+1611|0]<<8,b|0);h=x[31737];x[31737]=0;if((h|0)==1){break P}e=e+1|0;continue}}}x[31737]=0;l=P(215,f+188|0,255)|0;d=x[31737];x[31737]=0;if((d|0)!=1){g=0;while(1){T:{d=g;U:{if((d|0)==255){n=FC(f+72|0);o=FC(f+144|0);h=0;while(1){V:{W:{X:{if((h|0)==256){i=0;break X}x[31737]=0;g=f+256|0;O(632,b|0,g|0);d=x[31737];x[31737]=0;if((d|0)==1){break W}x[31737]=0;e=R(152,b|0)|0;d=x[31737];x[31737]=0;Y:{Z:{_:{if((d|0)!=1){x[31737]=0;d=f+12|0;S(186,d|0,b|0,e|0);i=x[31737];x[31737]=0;if((i|0)==1){break _}j=ic(f+52|0,d);ub(d);if((y[f+1726|0]|y[f+1727|0]<<8)>>>0>h>>>0){i=f+40|0;Ve(i,2,g);x[31737]=0;O(219,d|0,i|0);g=x[31737];x[31737]=0;if((g|0)==1){break Y}zc(((h<<5)+a|0)+946336|0,d);tb(d)}if(!e){break V}if((y[f+1726|0]|y[f+1727|0]<<8)>>>0>h>>>0){break Z}break V}h=N()|0;break U}h=N()|0;break U}x[31737]=0;d=D(h+1|0,104)+a|0;e=d+484380|0;O(280,e|0,32);g=x[31737];x[31737]=0;$:{aa:{ba:{if((g|0)!=1){Cp(e);x[31737]=0;O(633,j|0,f+12|0);g=x[31737];x[31737]=0;if((g|0)==1){break Y}g=x[f+12>>2];x[e>>2]=g;x[d+484404>>2]=x[f+16>>2];if(y[f+20|0]>=2){i=d+484414|0;w[i>>1]=z[i>>1]|1;g=g>>>1|0;x[e>>2]=g}if(y[f+21|0]>=2){i=d+484414|0;w[i>>1]=z[i>>1]|64;x[e>>2]=g>>>1}i=2;switch(y[f+23|0]-1|0){case 0:break aa;case 1:break ba;default:break $}}break Y}i=6}e=d+484414|0;w[e>>1]=z[e>>1]|i}x[d+484384>>2]=x[f+24>>2];x[d+484388>>2]=x[f+28>>2];w[d+484410>>1]=z[f+32>>1]>>>7;e=y[f+34|0];ca:{if((e|0)==128){e=d+484414|0;g=z[e>>1]|256;w[e>>1]=g;break ca}w[d+484408>>1]=(e<<24>>24)+128;g=z[d+484414>>1]}i=d+484414|0;w[i>>1]=g|32;v[d+484416|0]=y[f+35|0];e=y[f+22|0];if(e&2){d=f+40|0;Kb(d,o,h);fp(d);e=y[f+22|0]}if(e&5){w[i>>1]=z[i>>1]|16384}if(!(e&8)){break V}d=f+40|0;Kb(d,n,h);fp(d);e=0;while(1){if((e|0)==8){break V}d=e<<1;da:{if(z[d+(f+224|0)>>1]!=(h|0)){break da}d=x[((z[d+(f+240|0)>>1]<<2)+a|0)+900380>>2];if(!d){break da}v[d+14|0]=0}e=e+1|0;continue}}h=N()|0;ub(j);break U}while(1){ea:{fa:{if((y[f+1724|0]|y[f+1725|0]<<8)>>>0<=i>>>0){if(!(c&2)){break fa}h=0;ga:{ha:{ia:{ja:{ka:{la:{ma:{na:{while(1){if(z[a+480190>>1]<=h>>>0){break fa}h=h+1|0;d=D(h,104)+a|0;e=d+484380|0;c=d+484416|0;gm(e,(+(v[c|0]-49|0)+ +v[d+484417|0]*-.0078125)/-12);w[c>>1]=0;c=z[d+484414>>1];if(!(c&16384)){c=Xc(f+256|0,c&1?16:8,c&64?3:1,0,11);x[31737]=0;U(216,c|0,e|0,b|0)|0;c=x[31737];x[31737]=0;if((c|0)!=1){continue}h=N()|0;break U}x[31737]=0;e=R(152,b|0)|0;c=x[31737];x[31737]=0;oa:{if((c|0)==1){break oa}x[31737]=0;P(184,b|0,12)|0;c=x[31737];x[31737]=0;if((c|0)==1){break oa}c=Fb(f+256|0);x[31737]=0;S(271,b|0,c|0,e|0);e=x[31737];x[31737]=0;if((e|0)==1){break na}ze(d+484423|0,c);x[31737]=0;d=f+52|0;O(384,d|0,16486);e=x[31737];x[31737]=0;if((e|0)==1){break ma}x[f+8>>2]=h;g=x[a+1298404>>2];x[31737]=0;e=f+40|0;S(634,e|0,g|0,c|0);g=x[31737];x[31737]=0;if((g|0)==1){break la}x[31737]=0;g=f+12|0;V(431,g|0,d|0,f+8|0,e|0);i=x[31737];x[31737]=0;if((i|0)==1){break ka}i=x[a+1298472>>2];x[31737]=0;S(386,i|0,2,g|0);i=x[31737];x[31737]=0;if((i|0)==1){break ja}tb(g);tb(e);Eb(d);tb(c);continue}break}h=N()|0;break U}h=N()|0;break ga}h=N()|0;break ga}h=N()|0;break ha}h=N()|0;break ia}h=N()|0;tb(f+12|0)}tb(f+40|0)}Eb(f+52|0)}tb(c);break U}d=x[dh(x[l>>2],i)>>2];x[31737]=0;d=R(155,d|0)|0;e=x[31737];x[31737]=0;pa:{qa:{if((e|0)!=1){if(!d){i=i+1|0;continue}d=dh(x[l>>2],i);xc(d);x[31737]=0;O(635,d|0,f+256|0);d=x[31737];x[31737]=0;if((d|0)==1){break qa}j=Nb(f+12|0);x[31737]=0;S(636,b|0,j|0,z[f+256>>1]);d=x[31737];x[31737]=0;if((d|0)==1){break pa}i=i+1|0;d=x[((i<<2)+a|0)+900380>>2];if(!d|y[d+34|0]){break ea}x[d+4>>2]=32;e=0;Iv(d,0);s=d+108|0;m=d+236|0;while(1){if((e|0)==96){break ea}g=y[(f+e|0)+258|0];ra:{if(g>>>0>=z[f+256>>1]){break ra}k=Ue(x[j>>2],g);g=y[k|0];h=g+1|0;r=e+12|0;G=_b(m,r),H=h,w[G>>1]=H;if(g>>>0>=z[a+480190>>1]){break ra}g=D(h,104)+a|0;v[g+484418|0]=y[f+354|0]&3;v[g+484419|0]=y[f+355|0];v[g+484420|0]=y[f+356|0];v[g+484421|0]=y[f+357|0];w[g+484412>>1]=y[k+1|0]<<1;v[g+484417|0]=y[k+2|0];g=h-1|0;Kb(f+52|0,n,g);if(Hb(x[x[f+52>>2]>>2],x[f+56>>2])){v[d+14|0]=0}Kb(f+52|0,o,g);if(!Hb(x[x[f+52>>2]>>2],x[f+56>>2])){break ra}G=xb(s,r),H=61,v[G|0]=H}e=e+1|0;continue}}h=N()|0;break U}h=N()|0;break U}h=N()|0;Ae(j);break U}Qc(l);dc(q);ub(t);ub(B);e=1;break g}Ae(j);continue}}h=N()|0;break U}ub(j);h=h+1|0;continue}}x[31737]=0;O(632,b|0,f+144|0);e=x[31737];x[31737]=0;sa:{ta:{ua:{va:{if((e|0)!=1){x[31737]=0;e=R(152,b|0)|0;g=x[31737];x[31737]=0;if((g|0)==1){break va}x[31737]=0;h=f+72|0;e=(e|0)==32?428:e;i=e?(y[f+1610|0]|y[f+1611|0]<<8)>>>0>513?e+4|0:e:e;S(186,h|0,b|0,i|0);e=x[31737];x[31737]=0;if((e|0)==1){break ua}e=ic(f+256|0,h);j=Ge(f+12|0,hd(dh(x[l>>2],d),e));ub(e);g=d+1|0;ub(h);if(d>>>0>=(y[f+1724|0]|y[f+1725|0]<<8)>>>0){break T}x[31737]=0;d=g&65535;h=U(252,a|0,d|0,d|0)|0;d=x[31737];x[31737]=0;if((d|0)!=1){break ta}break sa}h=N()|0;break U}h=N()|0;break U}h=N()|0;break U}if(!h){break T}e=f+72|0;Ve(e,2,f+144|0);x[31737]=0;d=f+256|0;O(219,d|0,e|0);e=x[31737];x[31737]=0;wa:{if((e|0)!=1){zc(h+492|0,d);tb(d);if(!i){break T}x[31737]=0;O(635,j|0,d|0);d=x[31737];x[31737]=0;if((d|0)!=1){o=3;i=0;if((y[f+1610|0]|y[f+1611|0]<<8)>>>0<513){n=0;break wa}x[31737]=0;n=R(190,j|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break sa}if((y[f+1610|0]|y[f+1611|0]<<8)>>>0<514){break wa}x[31737]=0;o=R(152,j|0)|0;d=x[31737];x[31737]=0;if((d|0)!=1){break wa}break sa}break sa}break sa}x[h>>2]=y[f+358|0]|y[f+359|0]<<8;v[h+16|0]=y[((y[f+360|0]|y[f+361|0]<<8)&3)+25338|0];v[h+17|0]=y[(y[f+361|0]&3)+25338|0];v[h+18|0]=y[((y[f+360|0]|y[f+361|0]<<8)>>>12&3)+25342|0];while(1){xa:{ya:{if((i|0)==4){if(!(v[h+60|0]&1|y[h+16|0]==3)){x[h>>2]=32767}ik(h,127,1);hk(h,0,1);if(!n){break T}x[31737]=0;O(637,j|0,f+72|0);d=x[31737];x[31737]=0;if((d|0)==1){break sa}if(n&2){ik(h,FD(x[a+480208>>2],+((y[f+74|0]|y[f+75|0]<<8)>>>0)),1);hk(h,y[f+76|0],1)}v[h+25|0]=y[f+73|0]==1;if(!(n&4)){break T}v[h+31|0]=y[f+79|0]+1;d=v[f+80|0];v[h+34|0]=d+1;if((d|0)<0){v[h+30|0]=y[f+87|0]+1}if(!y[f+84|0]){break ya}i=h+108|0;e=0;while(1){if((e|0)==128){break ya}d=e+1|0;x[f+52>>2]=d+v[f+84|0];UX(f+52|0);n=x[f+52>>2];G=xb(i,e),H=n,v[G|0]=H;e=d;continue}}if(!(o&1)){break xa}x[31737]=0;O(638,j|0,f+72|0);d=x[31737];x[31737]=0;za:{if((d|0)!=1){d=Zh(h,y[i+25346|0]);e=y[f+72|0];k=e&1;v[d+12|0]=y[d+12|0]&232|((i|0)==3?0-k&16:0)|e<<1&4|e>>>1&2|k;v[f+52|0]=y[f+73|0];v[f+40|0]=16;e=y[Qb(f+52|0,f+40|0)|0];x[31737]=0;O(294,d|0,e|0);e=x[31737];x[31737]=0;if((e|0)==1){break za}e=y[f+74|0];v[d+15|0]=e;v[d+16|0]=e;v[d+13|0]=y[f+75|0];v[d+14|0]=y[f+76|0];e=0;k=x[d>>2];s=Sd(k,x[d+4>>2]);while(1){if((e|0)==(s|0)){break xa}m=yb(k,e);d=(f+72|0)+(e<<2)|0;w[m>>1]=y[d+8|0]|y[d+9|0]<<8;G=m,H=Kd(y[d+10|0]|y[d+11|0]<<8,0,64),v[G+2|0]=H;e=e+1|0;continue}}break sa}break sa}Iv(h,0);break T}i=i+1|0;o=o>>>1|0;continue}}h=N()|0;ub(j)}Qc(l);break s}ub(j);continue}}h=N()|0;break s}h=N()|0;break s}h=N()|0;break s}else{e=v[xb(i,j)|0];Aa:{if((e|0)<=(j|0)|(e|0)>=(g|0)){break Aa}e=y[((e<<5)+a|0)+480288|0];if(!e){break Aa}g=((j<<5)+a|0)+480288|0;h=y[g|0];if(!h){v[g|0]=e;break Aa}h=h-1|0;while(1){g=h&255;h=um(x[vd(d,g)+28>>2]);g=vd(d,g);if((h|0)==255){e=e-1&255;x[g+28>>2]=e>>>0<250?e+128|0:0}else{h=um(x[g+28>>2]);continue}break}}j=j+1|0;continue}}}h=N()|0;break s}x[31737]=0;g=R(152,t|0)|0;d=x[31737];x[31737]=0;Ba:{Ca:{Da:{Ea:{Fa:{Ga:{Ha:{Ia:{Ja:{if((d|0)!=1){x[31737]=0;d=R(152,t|0)|0;e=x[31737];x[31737]=0;if((e|0)==1){break Ja}x[31737]=0;e=f+256|0;S(186,e|0,t|0,d|0);d=x[31737];x[31737]=0;if((d|0)==1){break Ja}d=ic(f+72|0,e);ub(e);if((g|0)==4674381){break Fa}if((g|0)==5068115){break Ea}if((g|0)==726487106){break Ia}if((g|0)==844387158){break Da}e=0;if((g|0)==1280004692){break Ha}if((g|0)==1314144592){break Ga}if((g|0)!=1397445204){break Ca}x[31737]=0;e=R(190,d|0)|0;g=x[31737];x[31737]=0;if((g|0)==1){break u}e=e>>>0<256?48:e>>>8|0;x[a+480228>>2]=e;x[a+480232>>2]=e>>>1;e=0;while(1){if(z[a+480188>>1]<=e>>>0){break Ca}x[31737]=0;g=P(639,d|0,f+256|0)|0;i=x[31737];x[31737]=0;if((i|0)==1){break x}if(g){w[((e<<5)+a|0)+480286>>1]=z[f+256>>1]>>>10;G=xb(x[q>>2],e),H=y[f+259|0],v[G|0]=H}e=e+1|0;continue}}h=N()|0;break s}h=N()|0;break s}if(h&1){break Ca}v[a+480224|0]=2;x[31737]=0;C=+ia(640,d|0);e=x[31737];x[31737]=0;if((e|0)==1){break Ba}if(!(C>1e-8)){break Ca}G=a,H=Ze(2646e3/(C*+(D(x[a+480216>>2],x[a+480196>>2])>>>0))*1e4),x[G+480204>>2]=H;break Ca}while(1){Ka:{if(z[a+480188>>1]<=e>>>0){break Ca}g=x[d>>2];x[31737]=0;g=U(151,g|0,x[f+80>>2],1)|0;i=x[31737];x[31737]=0;if((i|0)==1){break w}if(!g){break Ca}g=Fb(f+256|0);x[31737]=0;S(359,d|0,g|0,-1);i=x[31737];x[31737]=0;if((i|0)!=1){k=f+12|0;wg(k,3,Jb(g),Yc(x[f+260>>2],y[f+267|0]));x[31737]=0;i=f+144|0;O(219,i|0,k|0);k=x[31737];x[31737]=0;if((k|0)==1){break Ka}om(((e<<5)+a|0)+480289|0,i);tb(i);tb(g);e=e+1|0;continue}}break}h=N()|0;tb(g);break t}while(1){if((y[f+1712|0]|y[f+1713|0]<<8)>>>0<=e>>>0){break Ca}g=x[d>>2];x[31737]=0;g=U(151,g|0,x[f+80>>2],1)|0;i=x[31737];x[31737]=0;if((i|0)==1){break v}if(!g){break Ca}if(!vp(x[a+484344>>2],x[a+484348>>2],e&65535)){break Ca}g=Fb(f+256|0);x[31737]=0;S(359,d|0,g|0,-1);i=x[31737];x[31737]=0;La:{if((i|0)==1){break La}i=x[o>>2];x[31737]=0;O(284,Wb(i,e)|0,g|0);i=x[31737];x[31737]=0;if((i|0)==1){break La}tb(g);e=e+1|0;continue}break}h=N()|0;tb(g);break t}x[31737]=0;P(184,d|0,1)|0;e=x[31737];x[31737]=0;if((e|0)==1){break u}x[31737]=0;e=R(203,d|0)|0;g=x[31737];x[31737]=0;if((g|0)==1){break u}x[31737]=0;V(337,l|0,d|0,e|0,2);e=x[31737];x[31737]=0;if((e|0)!=1){break Ca}break u}x[31737]=0;P(641,d|0,f+12|0)|0;e=x[31737];x[31737]=0;Ma:{if((e|0)!=1){e=Fb(f+256|0);x[31737]=0;S(359,d|0,e|0,-1);g=x[31737];x[31737]=0;if((g|0)==1){break Ma}if(!Ld(e,12698)){x[31737]=0;g=f+144|0;S(259,g|0,22,e|0);i=x[31737];x[31737]=0;if((i|0)==1){break Ma}Ab(j,g);tb(g)}tb(e);break Ca}h=N()|0;break t}h=N()|0;tb(e);break t}x[31737]=0;n=R(152,d|0)|0;e=x[31737];x[31737]=0;if((e|0)==1){break u}}ub(d);continue}break}h=N()|0;break t}h=N()|0;break t}h=N()|0;break t}h=N()|0;break t}h=N()|0}ub(d)}dc(q);break c}h=N()|0;break c}while(1){d=x[l>>2];x[31737]=0;d=U(151,d|0,x[f+264>>2],1)|0;g=x[31737];x[31737]=0;Na:{if((g|0)!=1){if(!d){break m}x[31737]=0;i=R(198,l|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break f}n=0;if((i|0)!=255){break Na}x[31737]=0;n=R(198,l|0)|0;d=x[31737];x[31737]=0;if((d|0)!=1){x[31737]=0;i=R(198,l|0)|0;d=x[31737];x[31737]=0;if((d|0)!=1){break Na}}break f}break f}if(i&127){d=Wb(x[o>>2],q);g=jd(x[d>>2],x[x[d+48>>2]+12>>2],e,j&65535);DE(f+72|0);if(i&1){x[31737]=0;d=R(198,l|0)|0;m=x[31737];x[31737]=0;if((m|0)==1){break l}v[f+72|0]=d}if(i&2){x[31737]=0;d=R(198,l|0)|0;m=x[31737];x[31737]=0;if((m|0)==1){break l}v[f+73|0]=d}if(i&4){x[31737]=0;d=R(198,l|0)|0;m=x[31737];x[31737]=0;if((m|0)==1){break l}v[f+74|0]=d}if(i&8){x[31737]=0;d=R(198,l|0)|0;m=x[31737];x[31737]=0;if((m|0)==1){break l}v[f+75|0]=d}if(i&16){x[31737]=0;d=R(198,l|0)|0;m=x[31737];x[31737]=0;if((m|0)==1){break l}v[f+76|0]=d}if(i&32){x[31737]=0;d=R(198,l|0)|0;m=x[31737];x[31737]=0;if((m|0)==1){break l}v[f+77|0]=d}if(i&64){x[31737]=0;d=R(198,l|0)|0;i=x[31737];x[31737]=0;if((i|0)==1){break l}v[f+78|0]=d}E=WX(g,f+72|0);x[f+144>>2]=n;x[f+52>>2]=k+(e^-1);F=x[Gb(f+144|0,f+52|0)>>2];i=0;d=g;while(1){if((i|0)!=(F|0)){d=D(z[a+480188>>1],6)+d|0;m=y[g|0]|y[g+1|0]<<8|(y[g+2|0]<<16|y[g+3|0]<<24);v[d|0]=m;v[d+1|0]=m>>>8;v[d+2|0]=m>>>16;v[d+3|0]=m>>>24;m=y[g+4|0]|y[g+5|0]<<8;v[d+4|0]=m;v[d+5|0]=m>>>8;i=i+1|0;continue}break}h=h|E}e=(e+n|0)+1|0;while(1){if(e>>>0>=k>>>0){j=j+1|0;e=e-k|0;continue}break}if(s>>>0>(j&65535)>>>0){continue}break}}ub(l);q=q+1|0;continue}break}break f}fb=f+1728|0;return e|0}h=N()|0;ub(l);break c}h=N()|0;break c}h=N()|0}ub(t)}ub(B)}Q(h|0);p()}function Wsa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0;d=fb-1120|0;fb=d;xc(b);e=fb-16|0;fb=e;g=d+884|0;v_(e+8|0,g);o=x[e+12>>2];lc(e,x[b>>2],x[b+8>>2],x[e+8>>2],x[e+12>>2]);i=x[e+4>>2];if((i|0)==(o|0)){Vb(b,x[e+12>>2])}fb=e+16|0;e=(i|0)==(o|0);if(!e){u_(g)}a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{if(!e){break o}if(!x_(g)){break o}if(!Mb(x[b>>2],x[b+8>>2],Bc(w_(y[d+888|0]|y[d+889|0]<<8|(y[d+890|0]<<16|y[d+891|0]<<24)),hb))){break o}f=1;if((c|0)==64){break o}Bd(a,16777216);gg(a);x[a+480208>>2]=x[a+480208>>2]|16809984;e=d+448|0;vr(e,32);g=x[d+460>>2];f=a+1074320|0;x[f>>2]=x[d+456>>2];x[f+4>>2]=g;f=x[d+452>>2];x[a+1074312>>2]=x[d+448>>2];x[a+1074316>>2]=f;Lb(Lb(a+1074312|0,57,y[d+887|0]>5),114,1);f=op(d+840|0);C=f,E=Kd(y[d+1084|0],1,31),x[C+8>>2]=E;C=f,E=Kd(y[d+1085|0],1,12),x[C+4>>2]=E;C=f,E=Bb(y[d+1086|0]|y[d+1087|0]<<8),x[C>>2]=E;jE(a+1298412|0,f);w[a+480188>>1]=32;f=d+36|0;t_(f,3,d+1088|0);Kr(e,1,f);Ab(a+1298368|0,e);tb(e);p:{if(y[d+887|0]<=5){ig(f,3924);break p}e=fb-16|0;fb=e;f=tc(e+4|0,3993);_c(d+36|0,f);tb(f);fb=e+16|0}x[31737]=0;e=d+448|0;f=d+36|0;S(371,e|0,f|0,y[d+887|0]);g=x[31737];x[31737]=0;q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{if((g|0)!=1){Ab(a+1298344|0,e);tb(e);Eb(f);g=tc(e,15229);Ab(a+1298356|0,g);tb(g);C=a+1298404|0,E=x[Fc(e,26)>>2],x[C>>2]=E;Ve(f,3,d+892|0);Cc(e,f);Ab(a+1298308|0,e);tb(e);x[a+480228>>2]=256;x[a+480200>>2]=384/(z[a+480188>>1]+3>>>0);G:{if(y[d+887|0]>5){break G}C=d,E=Bb(y[d+1112|0]|y[d+1113|0]<<8),w[C+448>>1]=E;w[d+36>>1]=1;C=a,E=z[pe(e,f)>>1],x[C+480196>>2]=E;C=d,E=Bb(y[d+1114|0]|y[d+1115|0]<<8),w[C+448>>1]=E;w[d+36>>1]=1;C=a,E=D(z[pe(e,f)>>1],1e4),x[C+480204>>2]=E;C=d,E=Bc(((Bb(y[d+1116|0]|y[d+1117|0]<<8)<<8)+2047>>>0)/4095|0,0),x[C+448>>2]=E;x[d+36>>2]=256;C=a,E=x[Gb(e,f)>>2],x[C+480200>>2]=E;C=d,E=Bb(y[d+1118|0]|y[d+1119|0]<<8),w[C+448>>1]=E;Gf(e,127);f=0;e=z[d+448>>1];while(1){if((e|0)==(f|0)){break G}C=d,E=Bc(((Uk(b)<<8)+2047>>>0)/4095|0,0),w[C+36>>1]=E;w[d+344>>1]=256;C=((f<<5)+a|0)+480284|0,E=z[Nc(d+36|0,d+344|0)>>1],w[C>>1]=E;f=f+1|0;continue}}cd(b,$b(y[d+888|0]|y[d+889|0]<<8|(y[d+890|0]<<16|y[d+891|0]<<24)));o=Ge(d+820|0,b);x[31737]=0;e=d+808|0;O(376,e|0,o|0);b=x[31737];x[31737]=0;H:{I:{J:{K:{L:{if((b|0)!=1){x[31737]=0;b=d+448|0;S(377,b|0,e|0,1346458707);f=x[31737];x[31737]=0;if((f|0)==1){break H}x[31737]=0;f=U(151,x[d+448>>2],x[d+456>>2],2)|0;g=x[31737];x[31737]=0;if((g|0)==1){break K}if(!f){break I}x[31737]=0;f=R(274,b|0)|0;g=x[31737];x[31737]=0;if((g|0)==1){break K}if((f-1&65535)>>>0>126){break I}w[a+480188>>1]=f;ub(b);x[31737]=0;S(377,b|0,e|0,1397706311);b=x[31737];x[31737]=0;if((b|0)!=1){break L}a=N()|0;break c}a=N()|0;break b}x[31737]=0;b=U(151,x[d+448>>2],x[d+456>>2],2)|0;e=x[31737];x[31737]=0;if((e|0)==1){break E}if(!b){break I}x[31737]=0;b=d+448|0;e=R(274,b|0)|0;f=x[31737];x[31737]=0;M:{if((f|0)==1){break M}w[d+36>>1]=e;e=y[a+484376|0];f=x[a+484360>>2];x[31737]=0;g=R(274,b|0)|0;i=x[31737];x[31737]=0;if((i|0)==1){break M}af(Xb(f,e),g);x[31737]=0;e=R(203,b|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break M}Gf(d+36|0,jm(e>>>1|0));e=y[a+484376|0];f=x[a+484360>>2];x[31737]=0;S(277,Xb(f,e)|0,b|0,z[d+36>>1]);b=x[31737];x[31737]=0;if((b|0)!=1){break J}}break E}a=N()|0;ub(d+448|0);break c}b=d+448|0;ub(b);x[31737]=0;S(377,b|0,d+808|0,1480806221);b=x[31737];x[31737]=0;if((b|0)==1){break F}x[31737]=0;b=U(151,x[d+448>>2],x[d+456>>2],3)|0;e=x[31737];x[31737]=0;if((e|0)!=1){if(b){break D}f=160;while(1){N:{b=f;if(!b){b=0;break N}f=b-1|0;if(y[(f+d|0)+924|0]==32){continue}}break}x[31737]=0;V(344,a+1298332|0,d+924|0,b|0,4);b=x[31737];x[31737]=0;if((b|0)!=1){break C}break B}break B}ub(d+448|0);f=0;break q}a=N()|0;break c}a=N()|0;Eb(d+36|0);break a}a=N()|0;break c}a=N()|0;ub(d+448|0);break c}x[31737]=0;b=d+448|0;e=R(274,b|0)|0;f=x[31737];x[31737]=0;if((f|0)!=1){x[31737]=0;V(337,a+1298332|0,b|0,e|0,4);b=x[31737];x[31737]=0;if((b|0)!=1){break C}}break B}e=d+448|0;ub(e);x[31737]=0;S(377,e|0,d+808|0,1413697073);b=x[31737];x[31737]=0;if((b|0)==1){break A}x[31737]=0;b=R(198,e|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break y}if(b){break z}x[31737]=0;b=P(150,e|0,2648)|0;f=x[31737];x[31737]=0;if((f|0)==1){break y}if(!b){break z}b=0;x[31737]=0;e=R(282,e|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break y}while(1){if((b|0)==32){break z}f=((b<<5)+a|0)+480280|0;x[f>>2]=x[f>>2]&-1025|!(e>>>b&1)<<10;b=b+1|0;continue}}a=N()|0;ub(d+448|0);break c}a=N()|0;break c}e=d+448|0;ub(e);x[31737]=0;S(377,e|0,d+808|0,1413697074);b=x[31737];x[31737]=0;if((b|0)==1){break x}x[31737]=0;b=U(151,x[d+448>>2],x[d+456>>2],12)|0;f=x[31737];x[31737]=0;if((f|0)==1){break w}O:{if(!b){break O}x[31737]=0;b=d+36|0;O(378,b|0,e|0);f=x[31737];x[31737]=0;if((f|0)==1){break w}f=$e(b);g=ec(b);i=s_(b);h=zb(b);l=r_(b);f=D(Kd(Bb(y[f|0]|y[f+1|0]<<8),32,999),1e4);g=Sua(Bb(y[g|0]|y[g+1|0]<<8),0,1e4,0);b=hb;g=g+32768|0;b=g>>>0<32768?b+1|0:b;C=a,E=((Bc((b&65535)<<16|g>>>16,b>>>16|0)>>>0)%1e4|0)+f|0,x[C+480204>>2]=E;C=a,E=Kd(Bb(y[i|0]|y[i+1|0]<<8),1,255),x[C+480196>>2]=E;b=16/(Kd(Bb(y[l|0]|y[l+1|0]<<8),1,16)>>>0)|0;x[a+480216>>2]=b;C=a,E=D(Kd(Bb(y[h|0]|y[h+1|0]<<8),1,16),b),x[C+480220>>2]=E;if(!Bb(z[d+36>>1])){break O}x[31737]=0;b=R(274,e|0)|0;e=x[31737];x[31737]=0;if((e|0)==1){break w}x[a+480208>>2]=x[a+480208>>2]&-17|!b<<4}b=d+448|0;ub(b);x[31737]=0;S(377,b|0,d+808|0,1414942540);e=x[31737];x[31737]=0;if((e|0)==1){break v}x[31737]=0;e=U(151,x[d+448>>2],x[d+456>>2],2)|0;f=x[31737];x[31737]=0;if((f|0)==1){break t}if(!e){break u}x[31737]=0;b=R(274,b|0)|0;e=x[31737];x[31737]=0;if((e|0)==1){break t}w[d+36>>1]=b;w[d+344>>1]=z[a+480188>>1];e=z[Nc(d+36|0,d+344|0)>>1];b=0;while(1){if((b|0)==(e|0)){break u}x[31737]=0;f=R(274,d+448|0)|0;g=x[31737];x[31737]=0;if((g|0)==1){break t}w[d+36>>1]=f;w[d+344>>1]=4096;C=((b<<5)+a|0)+480286|0,E=z[Nc(d+36|0,d+344|0)>>1]>>>6&255,w[C>>1]=E;b=b+1|0;continue}}a=N()|0;ub(d+448|0);break c}a=N()|0;break c}a=N()|0;ub(d+448|0);break c}a=N()|0;break c}b=d+448|0;ub(b);x[31737]=0;e=d+36|0;S(377,e|0,d+808|0,1296652368);f=x[31737];x[31737]=0;if((f|0)==1){break s}x[31737]=0;f=U(151,x[d+36>>2],x[d+44>>2],56)|0;g=x[31737];x[31737]=0;if((g|0)==1){break d}if(!f){break r}x[31737]=0;O(379,e|0,b|0);b=x[31737];x[31737]=0;if((b|0)==1){break d}if((Bb(y[d+482|0]|y[d+483|0]<<8)|0)!=4){break r}if((Bb(y[d+496|0]|y[d+497|0]<<8)|0)!=257){break r}C=d,E=Bb(y[d+488|0]|y[d+489|0]<<8),w[C+344>>1]=E;w[d+796>>1]=16384;b=z[Nc(d+344|0,d+796|0)>>1];f=b>>>24|0;b=(b<<8)+2048|0;f=b>>>0<2048?f+1|0:f;C=a,E=Bc((f&4095)<<20|b>>>12,f>>>12|0),x[C+480200>>2]=E;b=0;while(1){if(Bb(y[d+486|0]|y[d+487|0]<<8)>>>0<=(b&65535)>>>0){break r}x[31737]=0;O(380,d+36|0,d+344|0);e=x[31737];x[31737]=0;if((e|0)==1){break d}P:{if(y[d+344|0]){break P}e=Bb(y[d+346|0]|y[d+347|0]<<8);if(e>>>0>=z[a+480188>>1]){break P}e=(e<<5)+a|0;C=e+480284|0,E=Bc(((Bb(y[d+350|0]|y[d+351|0]<<8)<<8)+2047>>>0)/4095|0,0),w[C>>1]=E;h=e+480286|0;e=Bb(y[d+348|0]|y[d+349|0]<<8);f=e>>>26|0;g=(e<<6)+2048|0;f=g>>>0<2048?f+1|0:f;C=h,E=Bc((f&4095)<<20|g>>>12,f>>>12|0)&255,w[C>>1]=E}b=b+1|0;continue}}a=N()|0;ub(d+448|0);break c}a=N()|0;break c}b=d+36|0;ub(b);x[31737]=0;S(381,b|0,d+808|0,1396788530);b=x[31737];x[31737]=0;if((b|0)==1){break e}C=d,E=wb(x[d+36>>2]),x[C+760>>2]=E;f=c&2;h=d+450|0;l=wb(x[d+40>>2]);Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{while(1){e=x[d+760>>2];if(!Ib(e,l)){b=d+36|0;Qc(b);x[31737]=0;S(381,b|0,d+808|0,1396788560);b=x[31737];x[31737]=0;if((b|0)==1){break f}C=d,E=wb(x[d+36>>2]),x[C+784>>2]=E;g=d+450|0;i=wb(x[d+40>>2]);break Q}x[31737]=0;b=P(382,e|0,d+448|0)|0;g=x[31737];x[31737]=0;if((g|0)==1){break S}_:{$:{if(!b){break $}b=Bb(z[d+448>>1]);if((b-4e3&65535)>>>0<61537){break $}if(Bb(z[d+496>>1])>>>0>1){break $}if(Bb(z[d+478>>1])>>>0>1){break $}if(b>>>0>z[a+480190>>1]){w[a+480190>>1]=b}x[31737]=0;g=D(b,104)+a|0;i=g+484380|0;O(383,d+448|0,i|0);b=x[31737];x[31737]=0;aa:{ba:{ca:{if((b|0)==1){break ca}j=d+796|0;aj(j,3,h);x[31737]=0;b=d+344|0;O(219,b|0,j|0);j=x[31737];x[31737]=0;if((j|0)==1){break ba}zc(((Bb(z[d+448>>1])<<5)+a|0)+946304|0,b);tb(b);if(!f){break $}j=z[d+522>>1]|z[d+524>>1]<<16;x[31737]=0;j=P(150,e|0,$b(j)-8|0)|0;q=x[31737];x[31737]=0;if((q|0)==1){break ca}if(!j){break $}if(Bb(z[d+478>>1])){break aa}Xc(b,(Bb(y[d+480|0]|y[d+481|0]<<8)|0)==8?8:16,(Bb(y[d+484|0]|y[d+485|0]<<8)|0)==1?1:2,!Bb(y[d+482|0]|y[d+483|0]<<8),0);x[31737]=0;U(216,b|0,i|0,e|0)|0;b=x[31737];x[31737]=0;if((b|0)!=1){break aa}a=N()|0;break R}a=N()|0;break R}a=N()|0;break R}b=Fb(d+344|0);i=z[d+498>>1];x[31737]=0;S(271,e|0,b|0,Bb(i)|0);e=x[31737];x[31737]=0;if((e|0)==1){break U}ze(g+484423|0,b);if((Bb(z[d+478>>1])|0)==1){x[31737]=0;e=d+784|0;O(384,e|0,16486);g=x[31737];x[31737]=0;if((g|0)==1){break _}x[31737]=0;g=d+772|0;S(259,g|0,0,b|0);i=x[31737];x[31737]=0;if((i|0)==1){break Z}x[31737]=0;i=d+796|0;V(385,i|0,e|0,z[d+448>>1],g|0);j=x[31737];x[31737]=0;if((j|0)==1){break Y}j=x[a+1298472>>2];x[31737]=0;S(386,j|0,2,i|0);j=x[31737];x[31737]=0;if((j|0)==1){break X}tb(i);tb(g);Eb(e)}tb(b)}Sf(d+760|0);continue}break}a=N()|0;break T}a=N()|0;break V}a=N()|0;break W}a=N()|0;tb(d+796|0)}tb(d+772|0)}Eb(d+784|0);break T}a=N()|0}tb(b);break R}a=N()|0}Qc(d+36|0);break c}da:{while(1){ea:{e=x[d+784>>2];if(!Ib(e,i)){Qc(d+36|0);x[31737]=0;S(381,d+796|0,d+808|0,1447382614);b=x[31737];x[31737]=0;if((b|0)!=1){break da}a=N()|0;break c}x[31737]=0;b=P(387,e|0,d+448|0)|0;h=x[31737];x[31737]=0;if((h|0)==1){break ea}fa:{ga:{if(!b){break ga}b=Bb(z[d+448>>1]);if((b-4e3&65535)>>>0<61537){break ga}if(Bb(z[d+502>>1])){break ga}if(b>>>0>z[a+480190>>1]){w[a+480190>>1]=b}x[31737]=0;h=(D(b,104)+a|0)+484380|0;O(388,d+448|0,h|0);b=x[31737];x[31737]=0;if((b|0)==1){break ea}l=d+796|0;aj(l,3,g);x[31737]=0;b=d+344|0;O(219,b|0,l|0);l=x[31737];x[31737]=0;if((l|0)==1){break ea}zc(((Bb(z[d+448>>1])<<5)+a|0)+946304|0,b);tb(b);if(!f){break ga}l=z[d+478>>1];Xc(b,(Bb(z[d+482>>1])|0)==8?8:16,Bb(l)&1?2:1,1,0);x[31737]=0;U(216,b|0,h|0,e|0)|0;b=x[31737];x[31737]=0;if((b|0)==1){break fa}}Sf(d+784|0);continue}}break}a=N()|0;Qc(d+36|0);break c}x[31737]=0;b=d+808|0;S(381,d+784|0,b|0,1413828182);e=x[31737];x[31737]=0;if((e|0)==1){break h}x[31737]=0;S(381,d+772|0,b|0,1346719318);e=x[31737];x[31737]=0;if((e|0)==1){break j}x[31737]=0;S(381,d+760|0,b|0,1229869908);b=x[31737];x[31737]=0;if((b|0)==1){break l}C=d,E=wb(x[d+760>>2]),x[C+12>>2]=E;l=d+394|0;j=d+346|0;q=d+450|0;k=wb(x[d+764>>2]);while(1){ha:{ia:{ja:{ka:{g=x[d+12>>2];if(!Ib(g,k)){Qc(d+760|0);x[31737]=0;S(381,d+344|0,d+808|0,1346458692);b=x[31737];x[31737]=0;if((b|0)!=1){break ka}a=N()|0;break k}x[31737]=0;b=P(389,g|0,d+448|0)|0;e=x[31737];x[31737]=0;if((e|0)==1){break n}if(!b){break ha}if(Bb(z[d+478>>1])){break ha}b=z[d+448>>1];x[31737]=0;e=U(252,a|0,Bb(b)|0,0)|0;b=x[31737];x[31737]=0;if((b|0)==1){break n}if(!e){break ha}b=Bb(z[d+448>>1]);if(b>>>0>z[a+480192>>1]){w[a+480192>>1]=b}f=d+344|0;aj(f,3,q);x[31737]=0;b=d+36|0;O(219,b|0,f|0);f=x[31737];x[31737]=0;if((f|0)==1){break ja}zc(e+492|0,b);tb(b);v[e+33|0]=2;if((xe(w[d+482>>1])|0)>0){v[e+15|0]=y[e+15|0]|1;b=xe(w[d+482>>1]);f=b>>>24|0;i=(b<<8&-256)+2047|0;b=f&255;C=e,E=Bc(Uua(i,i>>>0<2047?b+1|0:b,4095,0),hb),x[C+8>>2]=E}i=e+108|0;n=e+236|0;f=0;while(1){la:{x[d+36>>2]=128;x[d+344>>2]=128;b=f&255;h=d+36|0;if(b>>>0>=A[Gb(h,d+344|0)>>2]){x[31737]=0;O(390,h|0,e|0);b=x[31737];x[31737]=0;if((b|0)==1){break la}C=d,E=_i(x[d+36>>2]),x[C+344>>2]=E;b=Rf(h);f=z[a+480190>>1];i=z[d+480>>1];while(1){h=x[d+344>>2];if(Ib(h,b)){h=z[hp(h)>>1];if(f>>>0>(h-1&65535)>>>0){C=(D(h,104)+a|0)+484410|0,E=Bb(i),w[C>>1]=E}ah(d+344|0);continue}break}Tv(d+36|0);ik(e,127,1);hk(e,0,1);b=Bb(z[d+498>>1]);if(!b){x[e>>2]=0;b=z[d+484>>1];x[31737]=0;V(391,e|0,0,Bb(b)|0,d+796|0);b=x[31737];x[31737]=0;if((b|0)==1){break n}b=z[d+488>>1];x[31737]=0;V(391,e|0,1,Bb(b)|0,d+772|0);b=x[31737];x[31737]=0;if((b|0)==1){break n}b=z[d+486>>1];x[31737]=0;V(391,e|0,2,Bb(b)|0,d+784|0);b=x[31737];x[31737]=0;if((b|0)!=1){break ha}break n}x[31737]=0;S(392,g|0,d+344|0,((b|0)==1?98:102)|0);b=x[31737];x[31737]=0;ma:{na:{oa:{if((b|0)!=1){b=Bb(z[d+344>>1]);i=b&1;if(!i){break ia}f=b&24;if(f){break oa}f=0;break na}a=N()|0;break m}if((f|0)!=8){break ma}f=1}v[e+25|0]=f}pa:{qa:{ra:{sa:{if(!(b&2)){break sa}x[31737]=0;b=U(393,d+332|0,j|0,24)|0;f=x[31737];x[31737]=0;if((f|0)==1){break ra}x[31737]=0;s=+ia(394,b|0);f=x[31737];x[31737]=0;if((f|0)==1){break qa}tb(b);if(!(s>20)){break sa}ik(e,FD(x[a+480208>>2],s),1)}if(Bb(z[d+344>>1])&4){break pa}break ia}a=N()|0;break m}a=N()|0;tb(b);break m}x[31737]=0;b=U(393,d+320|0,l|0,24)|0;f=x[31737];x[31737]=0;ta:{if((f|0)!=1){x[31737]=0;s=+ia(394,b|0);f=x[31737];x[31737]=0;if((f|0)==1){break ta}tb(b);hk(e,fm(s*127/24),1);break ia}a=N()|0;break m}a=N()|0;tb(b);break m}else{h=(d+448|0)+(b<<1)|0;m=y[h+52|0];C=_b(n,b),E=m,w[C>>1]=E;m=xb(i,b);h=dw(v[h+53|0]+y[m|0]|0);C=xb(i,b),E=h,v[C|0]=E;f=f+1|0;continue}}break}a=N()|0;break m}b=x[d+348>>2];e=x[d+344>>2];x[31737]=0;i=a+484344|0;O(224,i|0,Uf(e,b)&65535);b=x[31737];x[31737]=0;ua:{if((b|0)!=1){x[d+32>>2]=x[a+480204>>2];x[d+28>>2]=x[a+480196>>2];C=d,E=wb(x[d+344>>2]),x[C+24>>2]=E;n=c&1;m=wb(x[d+348>>2]);while(1){va:{wa:{xa:{ya:{za:{Aa:{c=x[d+24>>2];if(!Ib(c,m)){x[31737]=0;S(377,d+36|0,d+808|0,1414414669);b=x[31737];x[31737]=0;if((b|0)!=1){break Aa}a=N()|0;break ua}if(!n){break va}b=x[c+8>>2];e=x[c>>2];x[31737]=0;b=U(151,e|0,b|0,24)|0;e=x[31737];x[31737]=0;if((e|0)==1){break za}if(!b){break va}x[31737]=0;h=R(274,c|0)|0;b=x[31737];x[31737]=0;Ba:{Ca:{Da:{Ea:{if((b|0)!=1){v[d+464|0]=0;x[d+456>>2]=0;x[d+460>>2]=0;x[d+448>>2]=0;x[d+452>>2]=0;x[31737]=0;b=d+448|0;O(395,c|0,b|0);e=x[31737];x[31737]=0;if((e|0)==1){break Ea}x[31737]=0;q=R(274,c|0)|0;e=x[31737];x[31737]=0;if((e|0)==1){break Da}x[31737]=0;l=R(274,c|0)|0;e=x[31737];x[31737]=0;if((e|0)==1){break Ca}x[31737]=0;j=R(274,c|0)|0;e=x[31737];x[31737]=0;Fa:{if((e|0)==1){break Fa}e=x[c+8>>2];f=x[c>>2];x[31737]=0;e=U(151,f|0,e|0,D(D(j,l),5)|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break Fa}if(!(e&q>>>0<2)){break va}x[31737]=0;e=U(197,i|0,h|0,l|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break Fa}if(!e){break va}e=x[i>>2];x[31737]=0;O(396,Wb(e,h)|0,b|0);b=x[31737];x[31737]=0;if((b|0)!=1){break Ba}}a=N()|0;break ua}a=N()|0;break ua}a=N()|0;break ua}a=N()|0;break ua}a=N()|0;break ua}v[d+12|0]=0;b=de(d+36|0,0,d+12|0);x[31737]=0;e=U(372,d+760|0,j|0,b|0)|0;b=x[31737];x[31737]=0;if((b|0)==1){break wa}g=0;Ga:while(1){if((g|0)==(l|0)){md(e);break va}b=Wb(x[i>>2],h);bf(d+36|0,x[b>>2],x[x[b+48>>2]+12>>2],g);b=0;while(1){if((b|0)==(j|0)){g=g+1|0;continue Ga}f=bh(d+12|0);if(z[a+480188>>1]>b>>>0){f=Wc(x[d+36>>2],b)}x[31737]=0;O(397,c|0,d|0);k=x[31737];x[31737]=0;Ha:{if((k|0)==1){break Ha}k=y[d|0];if((k-1&255)>>>0<=119){k=k+1|0;v[f|0]=k;C=_b(x[e>>2],b),E=k,v[C|0]=E}k=y[d+1|0];if(k){v[f+1|0]=k;C=_b(x[e>>2],b),E=k,v[C+1|0]=E}k=y[d+4|0];if(k){v[f+2|0]=1;v[f+4|0]=q?k-16|0:k>>>2|0}k=y[d+887|0];t=y[d+3|0];u=y[d+2|0];r=_b(x[e>>2],b);B=y[r+1|0];r=y[r|0];x[31737]=0;ya(374,a|0,f|0,u|0,t|0,k|0,r|0,B|0,d+32|0,d+28|0);f=x[31737];x[31737]=0;if((f|0)==1){break Ha}b=b+1|0;continue}break}break}a=N()|0;md(e);break ua}x[31737]=0;b=U(151,x[d+36>>2],x[d+44>>2],38)|0;c=x[31737];x[31737]=0;if((c|0)!=1){if(!b){break xa}x[31737]=0;e=R(274,d+36|0)|0;b=x[31737];x[31737]=0;if((b|0)==1){break ya}f=d+452|0;b=0;Ia:{while(1){if(e>>>0<=(b&65535)>>>0){break xa}x[31737]=0;c=U(151,x[d+36>>2],x[d+44>>2],36)|0;g=x[31737];x[31737]=0;Ja:{if((g|0)!=1){if(c){break Ja}break xa}break ya}x[31737]=0;O(398,d+36|0,d+448|0);c=x[31737];x[31737]=0;if((c|0)!=1){Ka:{if(Bb(z[d+448>>1])){break Ka}if(Bb(z[d+450>>1])>>>0>=z[a+480188>>1]){break Ka}Ve(d,3,f);x[31737]=0;c=d+12|0;O(219,c|0,d|0);g=x[31737];x[31737]=0;if((g|0)==1){break Ia}om(((Bb(z[d+450>>1])<<5)+a|0)+480289|0,c);tb(c)}b=b+1|0;continue}break}break ya}break ya}break ya}a=N()|0;break ua}a=N()|0;ub(d+36|0);break ua}ub(d+36|0);Qc(d+344|0);Qc(d+772|0);Qc(d+784|0);Qc(d+796|0);f=1;break q}a=N()|0;break ua}Sf(d+24|0);continue}}a=N()|0}Qc(d+344|0);break k}a=N()|0;break m}b=0;while(1){if(y[d+445|0]<=b>>>0){break ha}x[31737]=0;h=d+36|0;O(399,g|0,h|0);f=x[31737];x[31737]=0;La:{Ma:{if((f|0)!=1){x[d>>2]=33620480;C=d,E=(Bb(z[d+484>>1])|0)!=0,v[C+32|0]=E;C=d,E=(Bb(z[d+486>>1])|0)!=0,v[C+33|0]=E;C=d,E=(Bb(z[d+488>>1])|0)!=0,v[C+34|0]=E;C=d,E=i&(Bb(z[d+490>>1])|0)!=0,v[C+35|0]=E;if(!y[(d+32|0)+b|0]|b>>>0>3){break La}f=(b|0)!=3;if(!f&(v[e+100|0]&1)){break La}x[31737]=0;m=h;h=y[b+d|0];S(400,m|0,e|0,h|0);n=x[31737];x[31737]=0;if((n|0)==1){break Ma}if(!f){v[e+100|0]=y[e+100|0]|16}Na:{switch(h|0){case 0:if(Bb(y[d+48|0]|y[d+49|0]<<8)&1){f=Bb(y[d+46|0]|y[d+47|0]<<8)&32767}else{f=0}x[e>>2]=f;break La;case 2:break Na;default:break La}}if(!(Bb(y[d+48|0]|y[d+49|0]<<8)&2)){break La}C=d,E=Bb(y[d+42|0]|y[d+43|0]<<8),w[C+28>>1]=E;w[d+24>>1]=1;f=z[pe(d+28|0,d+24|0)>>1];h=yi(Bc(((Bb(y[d+38|0]|y[d+39|0]<<8)<<6|48)>>>0)/100|0,0));C=d,E=Bb(y[d+40|0]|y[d+41|0]<<8),w[C+28>>1]=E;w[d+24>>1]=1;n=Ch(256/z[pe(d+28|0,d+24|0)>>1]|0);m=z[d+448>>1];t=y[d+44|0]|y[d+45|0]<<8;x[31737]=0;r=Bb(m);m=Bb(t);ja(401,a|0,r|0,y[(m>>>0<6?m:0)+25008|0],255/(f>>>0)|0,h|0,n|0);f=x[31737];x[31737]=0;if((f|0)!=1){break La}a=N()|0;break m}a=N()|0;break m}a=N()|0;break m}b=b+1|0;continue}}Sf(d+12|0);continue}}ie(d+808|0);ub(o)}fb=d+1120|0;return f|0}a=N()|0}Qc(d+760|0);break k}a=N()|0}Qc(d+772|0);break i}a=N()|0}Qc(d+784|0);break g}a=N()|0}Qc(d+796|0);break c}a=N()|0;break c}a=N()|0;break c}a=N()|0;ub(d+36|0)}ie(d+808|0)}ub(o)}Q(a|0);p()}function Cja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,O=0,P=0,R=0,S=0,T=0,V=0,W=0,X=0,Y=0,Z=0,$=0,aa=0,ba=0,ca=0,da=0;m=fb-1168|0;fb=m;xc(b);a:{b:{c:{d:{d=m+1144|0;e:{if(!ss(b,d)){break e}if(!zR(d)){break e}if((y[m+1152|0]|y[m+1153|0]<<8|(y[m+1154|0]<<16|y[m+1155|0]<<24))!=(Kh(x[b>>2])|0)){break e}if((y[m+1160|0]|y[m+1161|0]<<8|(y[m+1162|0]<<16|y[m+1163|0]<<24))!=(kf(b)|0)){break e}g=1;if((c|0)==64){break e}g=0;d=m+1088|0;Rb(d,0,56);e=-2;f:{if(!d){break f}x[d+44>>2]=0;x[d+48>>2]=0;x[d+52>>2]=0;x[d+20>>2]=0;x[d+24>>2]=0;x[d+8>>2]=0;h=x[d+32>>2];if(!h){x[d+32>>2]=1172;h=1172}if(!x[d+36>>2]){x[d+36>>2]=1173}h=ib[h|0](x[d+40>>2],1,43784)|0;e=-4;if(!h){break f}x[d+28>>2]=h;x[h+43780>>2]=1;x[h+10992>>2]=0;x[h+10996>>2]=0;x[h>>2]=0;x[h+11008>>2]=15;x[h+11e3>>2]=1;x[h+11004>>2]=0;e=0}if(e){break e}g=y[m+1160|0]|y[m+1161|0]<<8|(y[m+1162|0]<<16|y[m+1163|0]<<24);x[m+1084>>2]=g;K=y[m+1164|0]|y[m+1165|0]<<8|(y[m+1166|0]<<16|y[m+1167|0]<<24);T=VZ(m+1072|0,K);while(1){if(!(!K|!g|(f|0)==1)){x[m+32>>2]=1024;h=m+48|0;f=m+32|0;V=x[Gb(f,m+1084|0)>>2];d=gc(m+40|0,h,V);g=x[d>>2];d=x[d+4>>2];x[31737]=0;ao(160,f,b,g,d);f=x[31737];x[31737]=0;if((f|0)==1){break b}g=h;f=V;d=aa^-1;while(1){if(f>>>0<4){while(1){if(f){d=x[(((y[g|0]^d)&255)<<2)+79616>>2]^d>>>8;f=f-1|0;g=g+1|0;continue}break}aa=d^-1}else{d=x[(((y[g|0]^d)&255)<<2)+79616>>2]^d>>>8;d=d>>>8^x[(((d^y[g+1|0])&255)<<2)+79616>>2];d=d>>>8^x[(((d^y[g+2|0])&255)<<2)+79616>>2];d=d>>>8^x[(((d^y[g+3|0])&255)<<2)+79616>>2];f=f-4|0;g=g+4|0;continue}break}x[m+1092>>2]=V;x[m+1088>>2]=h;x[m+1104>>2]=K;x[m+1100>>2]=x[T>>2]+ba;C=fb-16|0;fb=C;d=-2;q=m+1088|0;g:{if(!q){break g}i=x[q+28>>2];if(!i){break g}da=x[q+4>>2];x[i+11e3>>2]=0;h:{if(x[i+43780>>2]<0){break h}if(x[i+11004>>2]){break g}g=x[i+11008>>2];d=0;x[i+11004>>2]=0;f=x[i+10996>>2];if(!f){X=(g|0)>0?11:10;J=i+11012|0;h=x[q+4>>2];g=x[i+10992>>2];while(1){x[C+12>>2]=h;x[C+8>>2]=32768-g;B=x[q>>2];h=0;E=0;F=0;G=0;L=0;W=0;M=0;Y=0;Z=fb-144|0;fb=Z;i:{j:{O=g+J|0;if(O>>>0>=J>>>0){H=x[C+8>>2]+O|0;I=H-J|0;$=(J^-1)+H|0;if(!(I&$)){break j}}x[C+8>>2]=0;x[C+12>>2]=0;l=-3;break i}k=x[C+12>>2];t=k+B|0;P=x[i+60>>2];s=x[i+40>>2];f=x[i+36>>2];r=x[i+32>>2];g=x[i+56>>2];e=x[i+4>>2];l=-1;n=O;j=B;o=-1;k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{u=x[i>>2];switch(u|0){case 10:case 17:case 21:case 35:case 36:case 37:case 39:break m;case 2:break s;case 53:break w;case 26:break y;case 25:break z;case 24:break A;case 23:break B;case 18:break C;case 16:break D;case 14:break E;case 51:break H;case 6:break I;case 3:break J;case 34:break K;case 42:break L;case 41:break M;case 32:break N;case 27:break O;case 11:break P;case 38:break Q;case 9:break R;case 52:break S;case 7:break T;case 5:break U;case 1:break V;case 0:break W;default:break l}}x[i+28>>2]=1;g=0;x[i+8>>2]=0;x[i+12>>2]=0;x[i+16>>2]=1;s=0;f=0;r=0;e=0;if(X&1){break V}break r}if((k|0)<=0){l=1;x[i>>2]=1;break k}x[i+8>>2]=y[B|0];j=B+1|0;break s}if((k|0)<=0){break t}W=e+8|0;j=B+1|0;g=y[B|0]<<e|g;d=2;break q}d=4;break q}M=g;break G}d=7;break q}d=8;break q}E=f;break F}F=g;break x}l=1;if((k|0)<=0){break u}e=e+8|0;j=B+1|0;break p}h=f;d=e;break v}k=2;break o}o=0;u=34;break m}d=1;break q}d=3;break q}d=5;break q}d=6;break q}d=9;break q}d=10;break q}d=11;break q}d=12;break q}d=13;break q}d=14;break q}d=15;break q}d=16;break q}d=17;break q}d=18;break q}k=1;break o}x[i>>2]=32;break k}x[i>>2]=5;l=1;break k}if(j>>>0>=t>>>0){x[i>>2]=2;l=1;break k}f=y[j|0];x[i+12>>2]=f;j=j+1|0;u=36;d=x[i+8>>2];h=256<<(d>>>4);if(h>>>0>32768|h>>>0>I>>>0|(((f|d<<8)>>>0)%31|f&32)){break n}f=0;if((d&15)!=8){break n}}d=0}X:while(1){Y:{Z:{_:{$:{aa:{ba:{ca:{da:{ea:{fa:{ga:{ha:{ia:{ja:{ka:{la:{ma:{na:{oa:{pa:{qa:{ra:{sa:{ta:{ua:{va:{wa:{xa:{ya:{za:{Aa:{Ba:{Ca:{Da:{switch(d|0){case 0:if(e>>>0>2){break Ca}d=1;continue;case 9:break ha;case 10:break ia;case 11:break ja;case 12:break ka;case 13:break la;case 14:break ma;case 15:break na;case 16:break oa;case 17:break pa;case 8:break va;case 7:break wa;case 6:break xa;case 5:break ya;case 4:break za;case 3:break Aa;case 2:break Ba;case 1:break Da;default:break qa}}while(1){if(j>>>0>=t>>>0){x[i>>2]=3;l=1;break k}g=y[j|0]<<e|g;j=j+1|0;e=e+8|0;if(e>>>0<3){continue}break}}d=g&7;x[i+20>>2]=d;h=d>>>1|0;x[i+24>>2]=h;e=e-3|0;g=g>>>3|0;if(d>>>0>=2){break ua}W=e;break ra}e=W&-8;g=g>>>(W&7)|0;f=0;d=0;break ta}while(1){if(j>>>0>=t>>>0){x[i>>2]=6;l=1;break k}g=y[j|0]<<e|g;d=e>>>0>4294967287;j=j+1|0;e=e+8|0;if(d){continue}break}d=1;break ta}if(j>>>0>=t>>>0){x[i>>2]=7;l=1;break k}v[(f+i|0)+10528|0]=y[j|0];j=j+1|0;d=2;break ta}while(1){if(j>>>0>=t>>>0){x[i>>2]=51;l=1;break k}g=y[j|0]<<e|g;d=e>>>0>4294967287;j=j+1|0;e=e+8|0;if(d){continue}break}break $}if(n>>>0<H>>>0){v[n|0]=r;f=f-1|0;n=n+1|0;g=M;break aa}o=2;u=52;g=M;break m}if(n>>>0<H>>>0){break sa}o=2;u=9;break m}if(j>>>0<t>>>0){d=H-n|0;h=t-j|0;d=d>>>0<h>>>0?d:h;d=d>>>0<f>>>0?d:f;f=f-d|0;n=yc(n,j,d)+d|0;j=d+j|0;break _}x[i>>2]=38;l=1;break k}o=-1;u=10;E=0;Ea:{switch(h-1|0){case 0:x[i+44>>2]=288;x[i+48>>2]=32;d=i+3552|0;x[d>>2]=84215045;x[d+4>>2]=84215045;d=i+3560|0;x[d>>2]=84215045;x[d+4>>2]=84215045;d=i+3568|0;x[d>>2]=84215045;x[d+4>>2]=84215045;d=i+3576|0;x[d>>2]=84215045;x[d+4>>2]=84215045;d=i- -64|0;h=0;while(1){k=144;if((h|0)==144){while(1){h=256;if((k|0)==256){while(1){k=280;if((h|0)==280){while(1){if((k|0)==288){break ea}v[d|0]=8;k=k+1|0;d=d+1|0;continue}}else{v[d|0]=7;h=h+1|0;d=d+1|0;continue}}}else{v[d|0]=9;k=k+1|0;d=d+1|0;continue}}}else{v[d|0]=8;h=h+1|0;d=d+1|0;continue}};case 2:break m;default:break Ea}}d=0;break ga}while(1){Fa:{Ga:{Ha:{Ia:{Ja:{Ka:{switch(d|0){case 0:if(f>>>0>3){break Ja}if(!e){e=0;break Ia}if(e>>>0>7){break Ga}d=3;continue X;case 1:v[(f+i|0)+10528|0]=g;e=e-8|0;g=g>>>8|0;break Fa;default:break Ka}}f=f+1|0;break Ha}f=z[i+10528>>1];if((f^z[i+10530>>1])==65535){break aa}u=39;o=-1;break m}d=4;continue X}d=0;continue}d=1;continue}d=2;continue}}d=8;continue}d=2;continue}if(n>>>0<H>>>0){v[n|0]=y[(P-r&$)+J|0];n=n+1|0;P=P+1|0;d=7;break ba}o=2;u=53;break m}while(1){if(j>>>0>=t>>>0){x[i>>2]=27;l=1;g=F;break k}F=y[j|0]<<e|F;j=j+1|0;e=e+8|0;if(s>>>0>e>>>0){continue}break}d=6;break ba}if(j>>>0>=t>>>0){x[i>>2]=26;l=1;break k}g=y[j|0]<<e|g;j=j+1|0;e=e+8|0;d=4;if(e>>>0<15){break ba}d=5;break ba}while(1){if(j>>>0>=t>>>0){x[i>>2]=25;l=1;break k}g=y[j|0]<<e|g;j=j+1|0;e=e+8|0;if(s>>>0>e>>>0){continue}break}d=3;break ba}if(n>>>0>=H>>>0){o=2;u=24;break m}v[n|0]=f;n=n+1|0;break ca}if(j>>>0>=t>>>0){x[i>>2]=23;l=1;break k}g=y[j|0]<<e|g;j=j+1|0;e=e+8|0;d=0;if(e>>>0<15){break ba}d=1;break ba}while(1){if(j>>>0>=t>>>0){x[i>>2]=18;l=1;break k}g=y[j|0]<<e|g;j=j+1|0;e=e+8|0;if(s>>>0>e>>>0){continue}break}Y=r-16|0;d=3;break da}if(j>>>0>=t>>>0){x[i>>2]=16;l=1;break k}g=y[j|0]<<e|g;j=j+1|0;e=e+8|0;d=1;if(e>>>0<15){break da}d=2;break da}while(1){if(j>>>0>=t>>>0){x[i>>2]=14;l=1;break k}g=y[j|0]<<e|g;j=j+1|0;e=e+8|0;if(e>>>0<3){continue}break}d=1;break fa}d=E+22284|0;while(1){if(j>>>0>=t>>>0){x[i>>2]=11;l=1;f=E;break k}g=y[j|0]<<e|g;j=j+1|0;e=e+8|0;L=v[d|0];if(e>>>0<L>>>0){continue}break}d=1}while(1){La:{Ma:{Na:{if(!d){if(E>>>0>2){break Na}L=v[E+22284|0];if(L>>>0<=e>>>0){break La}d=9;continue X}d=E<<2;x[(d+i|0)+44>>2]=x[d+81152>>2]+((-1<<L^-1)&g);E=E+1|0;e=e-L|0;g=g>>>L|0;break Ma}f=0;Rb(i+7040|0,0,288);d=0;break fa}d=0;continue}d=1;continue}}while(1){Oa:{Pa:{Qa:{if(!d){if(A[i+52>>2]<=f>>>0){break Qa}if(e>>>0>2){break Oa}d=10;continue X}v[(y[f+81168|0]+i|0)+7040|0]=g&7;f=f+1|0;e=e-3|0;g=g>>>3|0;break Pa}x[i+52>>2]=19;break ea}d=0;continue}d=1;continue}}G=x[i+24>>2];d=0}while(1){Ra:{Sa:{Ta:{Ua:{Va:{Wa:{Xa:{Ya:{Za:{switch(d|0){case 0:d=0;if((G|0)<0){break ca}I=Rb(Z,0,64);h=D(G,3488)+i|0;Rb(h+352|0,0,3200);ca=h- -64|0;R=x[i+24>>2];k=x[((R<<2)+i|0)+44>>2];while(1){if((d|0)!=(k|0)){h=(y[d+ca|0]<<2)+I|0;x[h>>2]=x[h>>2]+1;d=d+1|0;continue}break};x[I+64>>2]=0;x[I+68>>2]=0;l=0;d=1;h=0;while(1){if((d|0)!=16){o=d<<2;d=d+1|0;o=x[o+I>>2];h=o+h<<1;x[(I- -64|0)+(d<<2)>>2]=h;l=l+o|0;continue}break};S=0;o=-1;if((h|0)!=65536){u=35;if(l>>>0>1){break m}}while(1){if(k>>>0>S>>>0){l=y[S+ca|0];_a:{if(!l){break _a}d=(I- -64|0)+(l<<2)|0;h=x[d>>2];x[d>>2]=h+1;d=0;k=l;while(1){if(k){d=h&1|d<<1;h=h>>>1|0;k=k-1|0;continue}break}if(l>>>0<=10){h=1<<l;l=l<<9|S;while(1){if(d>>>0>1023){break _a}w[((D(G,3488)+i|0)+(d<<1)|0)+352>>1]=l;d=d+h|0;continue}}h=(D(G,3488)+i|0)+((d&1023)<<1)|0;k=w[h+352>>1];$a:{if(k){h=o;o=k;break $a}w[h+352>>1]=o;h=o-2|0}d=d>>>9|0;while(1){d=d>>>1|0;k=d&1;if(l>>>0>=12){k=((D(G,3488)+i|0)+(k+(o^-1)<<1)|0)+2400|0;o=w[k>>1];if(!o){w[k>>1]=h;o=h;h=h-2|0}l=l-1|0;continue}break}w[((D(G,3488)+i|0)+(k+(o^-1)<<1)|0)+2400>>1]=S;o=h}S=S+1|0;R=x[i+24>>2];k=x[((R<<2)+i|0)+44>>2];continue}break};d=0;if((R|0)!=2){break Sa}break Wa;case 1:d=w[(((g&1023)<<1)+i|0)+7328>>1];ab:{if((d|0)>=0){if(d>>>0<512|d>>>9>>>0>e>>>0){break ab}break Va}if(e>>>0<11){break ab}k=10;while(1){d=w[(((g>>>k&1)+(d^-1)<<1)+i|0)+9376>>1];if((d|0)<0){h=k+2|0;k=k+1|0;if(e>>>0>=h>>>0){continue}}break}if((d|0)>=0){break Va}}d=11;continue X;case 2:r=w[(((g&1023)<<1)+i|0)+7328>>1];if((r|0)>=0){break Ya}d=10;while(1){h=g>>>d|0;d=d+1|0;r=w[(((h&1)+(r^-1)<<1)+i|0)+9376>>1];if((r|0)<0){continue}break};break Xa;default:break Za}}d=v[Y+18479|0]+((-1<<s^-1)&g)|0;e=e-s|0;g=g>>>s|0;h=f+i|0;Rb(h+10532|0,(r|0)==16?y[h+10531|0]:0,d);d=d+f|0;break Wa}d=r>>>9|0;r=r&511}e=e-d|0;g=g>>>d|0;if(r>>>0>15){break Ua}v[(f+i|0)+10532|0]=r;d=f+1|0}h=x[i+48>>2];f=x[i+44>>2];l=h+f|0;if(l>>>0<=d>>>0){break Ta}if(e>>>0<=14){if((t-j|0)<=1){f=d;d=1;continue}g=y[j|0]<<e|y[j+1|0]<<e+8|g;j=j+2|0;e=e+16|0}f=d}d=2;continue}if(!((r|0)!=16|f)){f=0;u=17;r=16;o=-1;break m}Y=r-16|0;s=v[r+22264|0];if(s>>>0<=e>>>0){break Ra}d=12;continue X}if((d|0)!=(l|0)){u=21;f=d;o=-1;break m}l=i+10532|0;yc(i- -64|0,l,f);yc(i+3552|0,f+l|0,h);R=x[i+24>>2];f=d}G=R-1|0;x[i+24>>2]=G;d=0;continue}d=3;continue}}d=2}bb:while(1){cb:{db:{eb:{fb:{gb:{hb:{ib:{jb:{kb:{lb:{mb:{nb:{ob:{pb:{qb:{rb:{switch(d|0){case 0:d=w[(((g&1023)<<1)+i|0)+352>>1];sb:{if((d|0)>=0){if(d>>>0<512|d>>>9>>>0>e>>>0){break sb}break cb}if(e>>>0<11){break sb}k=10;while(1){d=w[(((g>>>k&1)+(d^-1)<<1)+i|0)+2400>>1];if((d|0)<0){h=k+2|0;k=k+1|0;if(e>>>0>=h>>>0){continue}}break}if((d|0)>=0){break cb}}d=13;continue X;case 1:f=w[(((g&1023)<<1)+i|0)+352>>1];if((f|0)>=0){break qb}d=10;while(1){h=g>>>d|0;d=d+1|0;f=w[(((h&1)+(f^-1)<<1)+i|0)+2400>>1];if((f|0)<0){continue}break};break pb;case 3:break fb;case 4:break gb;case 5:break lb;case 6:break mb;case 2:break rb;default:break nb}}while(1){d=t-j|0;if(!((H-n|0)>1&(d|0)>=4)){if(e>>>0>14){break cb}if((d|0)<=1){d=0;continue bb}g=y[j|0]<<e|y[j+1|0]<<e+8|g;e=e+16|0;j=j+2|0;break cb}if(!(e>>>0>14)){g=(y[j|0]|y[j+1|0]<<8)<<e|g;j=j+2|0;e=e+16|0}l=e;f=w[(((g&1023)<<1)+i|0)+352>>1];tb:{if((f|0)<0){d=10;while(1){h=g>>>d|0;d=d+1|0;f=w[(((h&1)+(f^-1)<<1)+i|0)+2400>>1];if((f|0)<0){continue}break}break tb}d=f>>>9|0}e=l-d|0;g=g>>>d|0;if(f&256){break ob}if(!(e>>>0>14)){g=(y[j|0]|y[j+1|0]<<8)<<e|g;j=j+2|0;e=e+16|0}l=e;k=w[(((g&1023)<<1)+i|0)+352>>1];ub:{if((k|0)<0){d=10;while(1){h=g>>>d|0;d=d+1|0;k=w[(((h&1)+(k^-1)<<1)+i|0)+2400>>1];if((k|0)<0){continue}break}break ub}d=k>>>9|0}v[n|0]=f;e=l-d|0;g=g>>>d|0;if(!(k&256)){v[n+1|0]=k;n=n+2|0;continue}break}n=n+1|0;f=k;break ob}d=f>>>9|0;f=f&511}e=e-d|0;g=g>>>d|0;if(f>>>0>255){break ob}d=14;continue X}h=f&511;f=256;if((h|0)==256){break Z}d=h-257<<2;f=x[d+80640>>2];s=0;if(h-285>>>0<4294967276){break eb}s=x[d+80768>>2];if(s>>>0>e>>>0){d=15;continue X}d=3;continue}if(!f){f=-1;break jb}f=f-1|0;d=18;continue X}e=e-s|0;g=F>>>s|0;r=((-1<<s^-1)&F)+r|0;break kb}d=w[(((g&1023)<<1)+i|0)+3840>>1];vb:{if((d|0)<0){k=10;while(1){h=g>>>k|0;k=k+1|0;d=w[(((h&1)+(d^-1)<<1)+i|0)+5888>>1];if((d|0)<0){continue}break}break vb}k=d>>>9|0;d=d&511}e=e-k|0;F=g>>>k|0;h=d<<2;r=x[h+80896>>2];s=0;if(d-30>>>0<4294967270){g=F;break kb}s=x[h+81024>>2];if(s>>>0<=e>>>0){break ib}d=17;continue X}P=n-J|0;d=(P-r&$)+J|0;if((d>>>0<n>>>0?n:d)+f>>>0>H>>>0){break hb}while(1){if(f>>>0>=3){v[n|0]=y[d|0];v[n+1|0]=y[d+1|0];v[n+2|0]=y[d+2|0];f=f-3|0;d=d+3|0;n=n+3|0;continue}break}if(!f){f=0;break jb}v[n|0]=y[d|0];if((f|0)!=1){v[n+1|0]=y[d+1|0]}n=f+n|0}d=2;continue}d=6;continue}d=7;continue}d=w[(((g&1023)<<1)+i|0)+3840>>1];wb:{if((d|0)>=0){if(d>>>0<512|d>>>9>>>0>e>>>0){break wb}break db}if(e>>>0<11){break wb}k=10;while(1){d=w[(((g>>>k&1)+(d^-1)<<1)+i|0)+5888>>1];if((d|0)<0){h=k+2|0;k=k+1|0;if(e>>>0>=h>>>0){continue}}break}if((d|0)>=0){break db}}d=16;continue X}e=e-s|0;f=((-1<<s^-1)&g)+f|0;g=g>>>s|0}if(e>>>0>14){break db}if((t-j|0)<=1){d=4;continue}g=y[j|0]<<e|y[j+1|0]<<e+8|g;e=e+16|0;j=j+2|0}d=5;continue}d=1;continue}}if(!f|!e){break _}if(e>>>0>7){break $}d=5;continue}e=e-8|0;M=g>>>8|0;r=g&255;d=6;continue}if(f){break Y}f=0}if(v[i+20|0]&1){break p}d=0;continue}d=7;continue}}g=0;d=e>>>3|0;h=j-B|0;h=h>>>0<=j>>>0?h:0;d=d>>>0<h>>>0?d:h;if((e&-8)==d<<3){j=j-d|0;u=34;h=0;d=0;e=0;o=0;if(!(X&1)){break m}k=0;break o}_(6874,13252,2797,6884);p()}while(1){xb:{yb:{zb:{Ab:{Bb:{switch(k|0){case 0:if(h>>>0>3){o=0;u=34;f=h;e=d;break m}e=0;if(!d){f=h;break xb}if(d>>>0>7){break Ab}k=1;continue;case 1:break Bb;default:break zb}}while(1){if(j>>>0>=t>>>0){x[i>>2]=41;l=1;f=h;e=d;break k}g=y[j|0]<<d|g;l=d>>>0>4294967287;j=j+1|0;d=d+8|0;if(l){continue}break}}k=g&255;g=g>>>8|0;d=d-8|0;break yb}if(j>>>0>=t>>>0){x[i>>2]=42;l=1;break k}k=y[j|0];j=j+1|0;h=f;d=e}x[i+16>>2]=x[i+16>>2]<<8|k;h=h+1|0;k=0;continue}k=2;continue}}f=1}x[i>>2]=u;l=o}d=e>>>3|0;h=j-B|0;h=h>>>0<=j>>>0?h:0;d=d>>>0<h>>>0?d:h;j=j-d|0;e=e-(d<<3)|0}x[i+4>>2]=e;x[i+60>>2]=P;x[i+40>>2]=s;x[i+36>>2]=f;x[i+32>>2]=r;x[i+56>>2]=(((e&63)>>>0<32?-1<<e:0)^-1)&g;x[C+12>>2]=j-B;e=n-O|0;x[C+8>>2]=e;if((l|0)<0){break i}j=(e>>>0)%5552|0;f=x[i+28>>2];g=f>>>16|0;k=f&65535;Cb:while(1){Db:{h=0;if(!e){break Db}d=O;while(1)if((h|7)>>>0>=j>>>0){h=j&8184;while(1){if((h|0)!=(j|0)){h=h+1|0;k=y[d|0]+k|0;g=k+g|0;d=d+1|0;continue}break}e=e-j|0;g=(g>>>0)%65521|0;k=(k>>>0)%65521|0;O=j+O|0;j=5552;continue Cb}else{f=y[d|0]+k|0;o=f+y[d+1|0]|0;F=o+y[d+2|0]|0;M=F+y[d+3|0]|0;E=M+y[d+4|0]|0;n=E+y[d+5|0]|0;B=n+y[d+6|0]|0;k=B+y[d+7|0]|0;g=k+(B+(n+(E+(M+(F+(o+(g+f|0)|0)|0)|0)|0)|0)|0)|0;d=d+8|0;h=h+8|0;continue}}break}f=g<<16|k;x[i+28>>2]=f;if(l){break i}l=0;if(!(X&1)){break i}l=(f|0)!=x[i+16>>2]?-2:0}fb=Z+144|0;x[i+43780>>2]=l;f=x[C+12>>2];x[q>>2]=f+x[q>>2];x[q+4>>2]=x[q+4>>2]-f;x[q+8>>2]=f+x[q+8>>2];x[q+48>>2]=x[i+28>>2];f=x[C+8>>2];x[i+10996>>2]=f;d=x[q+16>>2];f=d>>>0>f>>>0?f:d;yc(x[q+12>>2],x[i+10992>>2]+J|0,f);x[q+12>>2]=f+x[q+12>>2];x[q+16>>2]=x[q+16>>2]-f;x[q+20>>2]=f+x[q+20>>2];e=x[i+10996>>2];x[i+10996>>2]=e-f;g=f+x[i+10992>>2]&32767;x[i+10992>>2]=g;if((l|0)<0){break h}if(!((l|0)!=1|da)){d=-5;break g}if(l){d=0;h=x[q+4>>2];if(!h|!x[q+16>>2]){break g}if((e|0)==(f|0)){continue}break g}break}d=(e|0)==(f|0);break g}g=x[q+16>>2];f=g>>>0>f>>>0?f:g;yc(x[q+12>>2],(x[i+10992>>2]+i|0)+11012|0,f);x[q+12>>2]=f+x[q+12>>2];x[q+16>>2]=x[q+16>>2]-f;x[q+20>>2]=f+x[q+20>>2];g=x[i+10996>>2];x[i+10996>>2]=g-f;x[i+10992>>2]=f+x[i+10992>>2]&32767;if(x[i+43780>>2]){break g}d=(g|0)==(f|0);break g}d=-3}fb=C+16|0;f=d;g=x[m+1084>>2]-V|0;x[m+1084>>2]=g;d=K+ba|0;K=x[m+1104>>2];ba=d-K|0;continue}break}b=m+1088|0;Eb:{if(!b){break Eb}d=x[b+28>>2];if(!d){break Eb}ib[x[b+36>>2]](x[b+40>>2],d);x[b+28>>2]=0}g=0;if(!((y[m+1156|0]|y[m+1157|0]<<8|(y[m+1158|0]<<16|y[m+1159|0]<<24))!=(aa|0)|(f|0)!=1|K)){re(m+24|0,x[T>>2],x[T+4>>2]);b=Nd(m+16|0);x[31737]=0;f=x[b+4>>2];x[m+8>>2]=x[b>>2];x[m+12>>2]=f;b=jg(556,m+48|0,x[m+24>>2],x[m+28>>2],m+8|0);f=x[31737];x[31737]=0;if((f|0)==1){break d}x[31737]=0;g=U(917,a|0,b|0,c|0)|0;a=x[31737];x[31737]=0;if((a|0)==1){break c}ub(b)}dc(T)}fb=m+1168|0;return g|0}a=N()|0;break a}a=N()|0;ub(b);break a}a=N()|0}dc(T);Q(a|0);p()}function Bqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=E(0),A=0,C=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=E(0),O=E(0),P=0,S=0,V=0,W=0,Z=0,_=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=E(0),na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=E(0);s=fb-96|0;fb=s;xc(c);a:{while(1){b:{if(!Mb(x[c>>2],x[c+8>>2],4)){break b}h=s+76|0;d=fb-16|0;fb=d;c:{if(!Mb(x[c>>2],x[c+8>>2],3)){F=0;while(1){if((F|0)!=3){eh(h+F|0);F=F+1|0;continue}break}break c}$w(d+8|0,h);rd(d,c,x[d+8>>2],x[d+12>>2])}fb=d+16|0;d:{e:{if(!kd(h,15121,3)){h=s+32|0;d=fb-16|0;fb=d;f:{if(!Mb(x[c>>2],x[c+8>>2],7)){F=0;while(1){if((F|0)!=7){eh(h+F|0);F=F+1|0;continue}break}break f}Pr(d+8|0,h);rd(d,c,x[d+8>>2],x[d+12>>2])}fb=d+16|0;F=0;h=3;while(1){if((h|0)==7){break d}d=v[(s+32|0)+h|0];if((d|0)<0){break e}h=h+1|0;F=d&255|F<<7;continue}}g:{if(kd(s+76|0,14256,3)){break g}if(!lY(c,13691)){break g}Vb(c,Pg(c)+16|0);continue}d=s+76|0;if(!kd(d,28638,3)){continue}if(!kd(d,28642,3)){continue}if(!y[s+76|0]){Gh(c,2);continue}if(xV(s+76|0)){break b}}h=0;break a}Vb(c,F);continue}break}xc(c);d=s+76|0;rD(d,c);W=x[s+76>>2];c=_e(d);P=Nb(s- -64|0);x[31737]=0;ca=R(593,s+60|0)|0;d=x[31737];x[31737]=0;h:{i:{j:{if((d|0)!=1){IB(Rb(x[ca>>2],0,6668));x[s+48>>2]=0;x[s+52>>2]=0;x[s+40>>2]=0;x[s+44>>2]=0;x[s+32>>2]=0;x[s+36>>2]=0;x[31737]=0;da=R(594,s+20|0)|0;d=x[31737];x[31737]=0;k:{if((d|0)!=1){F=0;while(1){G=x[ca>>2];g=Gc(W,aa);Z=x[da>>2];L=s+32|0;d=0;m=0;r=fb-17152|0;fb=r;x[r+17148>>2]=0;l:{m:{n:{if(y[G+6152|0]!=255|(g|0)<5){break n}if(!rq(G+6152|0,c)){break n}h=kz(y[c+1|0],y[c+2|0],x[G+6148>>2])+qq(c)|0;x[r+17148>>2]=h;if((g|0)==(h|0)){h=g;break m}o:{if((g|0)>=(h+4|0)){if(rq(c,c+h|0)){break o}}x[r+17148>>2]=0;break n}if(h){break m}}e=c;A=Rb(G,0,6668)+6148|0;q=r+17148|0;n=g-4|0;I=(n|0)>0?n:0;while(1){p:{q:{r:{s:{if((m|0)==(I|0)){m=g;break s}if(!dM(e)){break q}k=kz(y[e+1|0],y[e+2|0],x[A>>2]);h=k+qq(e)|0;i=4;l=m+4|0;t:{while(1){if(!(i>>>0>2303|k)){if((n|0)<=((i<<1)+m|0)){break t}k=0;j=e+i|0;u:{if(!rq(e,j)){break u}f=i-qq(e)|0;o=qq(j)+f|0;if((g|0)<(o+(i+l|0)|0)){break u}if(!rq(e,j+o|0)){break u}x[A>>2]=f;k=f;h=i}i=i+1|0;continue}break}if(!k|(g|0)<(h+m|0)){break t}l=g-m|0;i=0;f=0;while(1){v:{w:{if((f|0)!=10){j=(f|0)!=0;K=i;i=e+i|0;i=(K+kz(y[i+1|0],y[i+2|0],k)|0)+qq(i)|0;if((l|0)<(i+4|0)){break v}if(rq(e,e+i|0)){break w}j=0}else{j=1}break v}f=f+1|0;continue}break}if(!j){break t}d=h;break s}if((g|0)!=(h|0)|m){break r}m=0;d=g}x[q>>2]=d;d=m;break p}x[A>>2]=0}e=e+1|0;m=m+1|0;continue}break}h=x[r+17148>>2];if((g|0)>=(d+h|0)?h:0){break m}x[L>>2]=d;o=0;break l}C=c+d|0;x[G+6152>>2]=y[C|0]|y[C+1|0]<<8|(y[C+2|0]<<16|y[C+3|0]<<24);x[L+4>>2]=d;x[L>>2]=d+h;x[L+8>>2]=y[C+3|0]>191?1:2;sa=L,ta=gM(y[C+1|0],y[C+2|0]),x[sa+12>>2]=ta;x[L+16>>2]=4-(y[C+1|0]>>>1&3);sa=L,ta=jz(y[C+1|0],y[C+2|0]),x[sa+20>>2]=ta;if(!Z){o=iz(y[C+1|0]);break l}d=r+17136|0;fM(d,C+4|0,h-4|0);if(!(v[C+1|0]&1)){ue(d,16)}x:{if(x[L+16>>2]==3){o=0;d=r+17136|0;ja=r+3728|0;e=ja;m=0;h=y[C+1|0];f=D((h>>>3&1)+(h>>>4&1)|0,3)+(y[C+2|0]>>>2&3)|0;f=f-((f|0)!=0)|0;i=y[C+3|0]>191?1:2;y:{if(h&8){j=ue(d,9);i=i<<1;m=ue(d,i+7|0);break y}j=ue(d,i|8)>>>i|0}h=D(f,40);A=h+81488|0;n=h+81808|0;q=D(f,23)+81296|0;h=-1;f=0;z:{while(1){g=y[C+3|0];I=ue(d,12);w[e+4>>1]=I;k=ue(d,9);w[e+6>>1]=k;if((k&65535)>>>0>288){break z}k=g>>>0>191?m<<4:m;sa=e,ta=ue(d,8),v[sa+10|0]=ta;g=ue(d,y[C+1|0]&8?4:9);v[e+13|0]=22;v[e+14|0]=0;x[e>>2]=q;w[e+8>>1]=g;A:{if(ue(d,1)){g=ue(d,2);v[e+11|0]=g;if(!(g&255)){break z}g=ue(d,1);w[e+18>>1]=65287;v[e+12|0]=g;if(y[e+11|0]==2){B:{if(!(g&255)){x[e>>2]=A;v[e+18|0]=8;m=0;g=39;break B}x[e>>2]=n;m=y[C+1|0]&8?8:6;g=30}v[e+14|0]=g;v[e+13|0]=m;k=k&3855}g=ue(d,10);sa=e,ta=ue(d,3),v[sa+21|0]=ta;sa=e,ta=ue(d,3),v[sa+22|0]=ta;sa=e,ta=ue(d,3),v[sa+23|0]=ta;m=g<<5;break A}v[e+11|0]=0;v[e+12|0]=0;m=ue(d,15);sa=e,ta=ue(d,4),v[sa+18|0]=ta;g=ue(d,3);v[e+20|0]=255;v[e+19|0]=g}v[e+17|0]=m&31;v[e+15|0]=m>>>10;v[e+16|0]=m>>>5&31;f=(I&65535)+f|0;C:{if(y[C+1|0]&8){g=ue(d,1);break C}g=z[e+8>>1]>499}v[e+24|0]=g;sa=e,ta=ue(d,1),v[sa+25|0]=ta;g=ue(d,1);v[e+27|0]=k>>>12&15;v[e+26|0]=g;e=e+28|0;m=k<<4;i=i-1|0;if(i){continue}break}h=(x[d+4>>2]+f|0)>(x[d+8>>2]+(j<<3)|0)?-1:j}if(!((h|0)<0|x[r+17140>>2]>x[r+17144>>2])){g=x[d+4>>2];m=x[d+8>>2];i=r+900|0;e=x[G+6144>>2];f=e-h|0;e=(e|0)<(h|0)?e:h;f=yc(i+12|0,(((f|0)>0?f:0)+G|0)+6156|0,e);k=x[d>>2]+(x[d+4>>2]/8|0)|0;d=(m-g|0)/8|0;yc(e+f|0,k,d);fM(i,f,d+e|0);D:{h=x[G+6144>>2]>=(h|0);if(!h){break D}na=G+2304|0;oa=r+8608|0;pa=r+3840|0;while(1){if((y[C+1|0]&8?2:1)>>>0<=o>>>0){break D}qa=Rb(pa,0,4608);e=x[L+8>>2];m=D(D(e,o),28)+ja|0;d=0;ka=(e|0)>0?e:0;A=r+900|0;I=A+7548|0;_=G+6152|0;while(1){if((d|0)!=(ka|0)){g=D(d,28)+m|0;K=z[g+4>>1];V=x[A+4>>2];t=(A+D(d,39)|0)+16156|0;e=I;n=d;f=fb-48|0;fb=f;d=g;J=y[d+25|0];H=D(!y[d+13|0]+(y[d+14|0]!=0)|0,28)+82128|0;E:{if(y[_+1|0]&8){j=y[d+27|0];g=y[z[d+8>>1]+82224|0];i=g&3;v[f+47|0]=i;v[f+46|0]=i;g=g>>>2|0;v[f+45|0]=g;v[f+44|0]=g;break E}g=(y[_+3|0]&16)>>>4&(n|0)!=0;l=g?12:0;q=z[d+8>>1]>>>g|0;while(1){if((q|0)>=0){j=3;i=1;while(1){if((j|0)>=0){g=y[(j+l|0)+82240|0];v[(f+44|0)+j|0]=((q|0)/(i|0)|0)%(g|0);j=j-1|0;i=D(g,i);continue}break}l=l+4|0;q=q-i|0;continue}break}H=l+H|0;j=-16}i=f;ea=f+44|0;q=0;while(1){F:{G:{H:{if((q|0)==4){break H}g=y[q+H|0];if(!g){break H}if(j&8){yc(i,t,g);break G}l=y[q+ea|0];if(!l){Rb(i,0,g);Rb(t,0,g);break G}fa=(j|0)>=0?-1:-1<<l^-1;k=0;while(1){if((g|0)==(k|0)){break G}S=ue(A,l);v[k+t|0]=(S|0)==(fa|0)?-1:S;v[i+k|0]=S;k=k+1|0;continue}}v[i+2|0]=0;v[i|0]=0;v[i+1|0]=0;break F}j=j<<1;q=q+1|0;i=g+i|0;t=g+t|0;continue}break}I:{i=y[d+14|0];if(i){g=2-J|0;k=y[d+23|0]<<g;q=y[d+22|0]<<g;l=y[d+21|0]<<g;t=y[d+13|0];j=0;while(1){if(j>>>0>=i>>>0){break I}g=f+(j+t|0)|0;v[g|0]=l+y[g|0];v[g+1|0]=q+y[g+1|0];v[g+2|0]=k+y[g+2|0];j=j+3|0;continue}}if(!y[d+24|0]){break I}j=0;while(1){if((j|0)==10){break I}g=f+j|0;v[g+11|0]=y[g+11|0]+y[j+82264|0];j=j+1|0;continue}}g=J+1|0;j=0;u=hz(E(2048),((((y[_+3|0]&224)==96)<<1)-y[d+10|0]|0)+258|0);while(1){if(y[d+13|0]+(i&255)>>>0>j>>>0){sa=e+(j<<2)|0,ua=hz(u,y[f+j|0]<<g),B[sa>>2]=ua;j=j+1|0;i=y[d+14|0];continue}break}fb=f+48|0;k=(A+D(n,2304)|0)+2940|0;j=e;ea=K+V|0;u=E(0);g=x[A+4>>2];e=x[A>>2]+((g|0)/8|0)|0;f=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);f=(f<<24|(f&65280)<<8|(f>>>8&65280|f>>>24))<<(g&7);l=g|-8;t=e+4|0;q=d;H=x[d>>2];J=z[d+6>>1];d=0;while(1){J:{K:{if((J|0)>0){g=d+1|0;e=d+q|0;d=y[e+15|0];fa=(w[(d<<1)+86688>>1]<<1)+82304|0;S=y[e+18|0];if(d>>>0>=16){ga=y[d+86752|0];ra=32-ga|0;while(1){ha=y[H|0]>>>1|0;ia=(J|0)<(ha|0)?J:ha;u=B[j>>2];while(1){e=f>>>27|0;d=5;while(1){e=w[fa+(e<<1)>>1];if((e|0)<0){f=f<<d;i=e&7;e=(f>>>32-i|0)-(e>>3)|0;l=d+l|0;d=i;continue}break}d=e>>>8|0;l=d+l|0;f=f<<d;i=0;while(1){if((i|0)!=2){K=e&15;L:{if((K|0)==15){l=l+ga|0;d=f<<ga;while(1){if((l|0)>=0){d=y[t|0]<<l|d;t=t+1|0;l=l-8|0;continue}break}K=(f>>>ra|0)+15|0;f=K;M:{if((f|0)<=128){M=B[(f<<2)+86848>>2];break M}la=f>>>0<1024;f=la?f<<3:f;V=f<<1&64;O=E(E((f&63)-V|0)/E(V+(f&2147483584)|0));M=E((la?E(16):E(256))*E(E(E(O*E(E(O*E(.2222222238779068))+E(1.3333333730697632)))+E(1))*B[(f+V>>>4&268435452)+86848>>2]))}M=E(E(u*M)*E(d>>31|1));break L}d=f;M=E(u*B[(((d>>>27&16|K)^16)<<2)+86784>>2])}B[k>>2]=M;e=e>>>4|0;k=k+4|0;i=i+1|0;f=(K|0)!=0;l=f+l|0;f=d<<f;continue}break}while(1){if((l|0)>=0){f=y[t|0]<<l|f;t=t+1|0;l=l-8|0;continue}break}ia=ia-1|0;if(ia){continue}break}j=j+4|0;H=H+1|0;J=J-ha|0;if((J|0)<=0){break K}d=(S|0)>0;S=S-1|0;if(d){continue}break}break K}while(1){V=y[H|0]>>>1|0;K=(J|0)<(V|0)?J:V;u=B[j>>2];while(1){d=f>>>27|0;e=5;while(1){d=w[fa+(d<<1)>>1];if((d|0)<0){f=f<<e;i=d&7;d=(f>>>32-i|0)-(d>>3)|0;l=e+l|0;e=i;continue}break}e=d>>>8|0;l=e+l|0;f=f<<e;e=0;while(1){if((e|0)!=2){i=d&15;B[k>>2]=u*B[(((i|f>>>27&16)^16)<<2)+86784>>2];d=d>>>4|0;k=k+4|0;e=e+1|0;i=(i|0)!=0;l=i+l|0;f=f<<i;continue}break}while(1){if((l|0)>=0){f=y[t|0]<<l|f;t=t+1|0;l=l-8|0;continue}break}K=K-1|0;if(K){continue}break}j=j+4|0;H=H+1|0;J=J-V|0;if((J|0)<=0){break K}d=(S|0)>0;S=S-1|0;if(d){continue}break}break K}e=1-J|0;while(1){N:{g=y[q+26|0]?86672:86640;d=y[g+(f>>>28|0)|0];if(!(d&8)){d=y[g+(d>>>3|0)+(f<<4>>>32-(d&3))|0]}g=d&7;l=g+l|0;if(((l+(t-x[A>>2]<<3)|0)-24|0)>(ea|0)){break N}e=e-1|0;if(!e){e=y[H|0];if(e>>>0<2){break N}H=H+1|0;u=B[j>>2];j=j+4|0;e=e>>>1|0}f=f<<g;if(d>>>0>=128){B[k>>2]=(f|0)<0?E(-u):u;l=l+1|0;f=f<<1}if(d&64){B[k+4>>2]=(f|0)<0?E(-u):u;l=l+1|0;f=f<<1}e=e-1|0;if(!e){e=y[H|0];if(e>>>0<2){break N}H=H+1|0;u=B[j>>2];j=j+4|0;e=e>>>1|0}if(d&32){B[k+8>>2]=(f|0)<0?E(-u):u;l=l+1|0;f=f<<1}if(d&16){B[k+12>>2]=(f|0)<0?E(-u):u;l=l+1|0;f=f<<1}while(1){if((l|0)>=0){f=y[t|0]<<l|f;t=t+1|0;l=l-8|0;continue}break}k=k+16|0;continue}break}x[A+4>>2]=ea;break J}d=g;continue}break}d=n+1|0;continue}break}d=y[G+6155|0];O:{if(d&16){j=A+16195|0;d=0;g=fb-16|0;fb=g;i=A+2940|0;k=i+2304|0;I=x[m>>2];l=y[m+14|0];t=y[m+13|0];n=l+t|0;e=g+4|0;x[e+8>>2]=-1;x[e>>2]=-1;x[e+4>>2]=-1;while(1){if((d|0)!=(n|0)){H=d+I|0;q=y[H|0];f=0;P:{while(1){if(f>>>0>=q>>>0){break P}J=f<<2;if(B[J+k>>2]==E(0)){f=f+2|0;if(B[(J|4)+k>>2]==E(0)){continue}}break}x[e+((d>>>0)%3<<2)>>2]=d;q=y[H|0]}d=d+1|0;k=(q<<2)+k|0;continue}break}if(t){d=x[g+4>>2];e=x[g+8>>2];d=(d|0)>(e|0)?d:e;e=x[g+12>>2];d=(d|0)>(e|0)?d:e;x[g+12>>2]=d;x[g+8>>2]=d;x[g+4>>2]=d}e=l?3:1;k=n-e|0;d=0;while(1){if((d|0)!=(e|0)){n=d+k|0;f=n-e|0;if((f|0)<=x[(g+4|0)+(d<<2)>>2]){f=y[_+1|0]<<28>>31&3}else{f=y[f+j|0]}v[j+n|0]=f;d=d+1|0;continue}break}n=x[m>>2];q=g+4|0;I=w[m+36>>1]&1;k=0;l=y[_+1|0]&8?7:64;while(1){t=k+n|0;e=y[t|0];if(e){f=y[_+3|0]&32;Q:{R:{if(x[q+((k>>>0)%3<<2)>>2]>=(k|0)){break R}d=y[j+k|0];if(d>>>0>=l>>>0){break R}M=f?E(1.4142135381698608):E(1);S:{if(y[_+1|0]&8){d=d<<3;u=B[d+87380>>2];O=B[d+87376>>2];break S}O=hz(E(1),d+1>>>1<<I);d=d&1;u=d?E(1):O;O=d?O:E(1)}O=E(M*O);M=E(M*u);d=0;while(1){if((d|0)!=(e|0)){f=(d<<2)+i|0;u=B[f>>2];B[f+2304>>2]=u*M;B[f>>2]=u*O;d=d+1|0;continue}break}break Q}if(!f){break Q}cM(i,e)}k=k+1|0;i=(y[t|0]<<2)+i|0;continue}break}fb=g+16|0;break O}if((d&224)!=96){break O}cM(A+2940|0,576)}i=A+7708|0;d=0;while(1){if((d|0)!=(ka|0)){e=y[G+6153|0];e=(y[m+12|0]!=0)<<1<<((D((e>>>3&1)+(e>>>4&1)|0,3)+(y[G+6154|0]>>>2&3)|0)==2);f=A+D(d,2304)|0;k=f+2940|0;j=k;if(y[m+14|0]){q=x[m>>2]+y[m+13|0]|0;t=(f+D(e,72)|0)+2940|0;g=t;f=i;while(1){n=y[q|0];if(n){l=n<<1;I=0;while(1){if((n|0)!=(I|0)){B[f>>2]=B[g>>2];B[f+4>>2]=B[(n<<2)+g>>2];B[f+8>>2]=B[(l<<2)+g>>2];g=g+4|0;I=I+1|0;f=f+12|0;continue}break}q=q+3|0;g=(l<<2)+g|0;continue}break}yc(t,i,f-i|0);f=e-1|0}else{f=31}while(1){g=0;if((f|0)>0){while(1){if((g|0)!=8){n=g<<2;q=n+j|0;u=B[q+72>>2];O=B[n+87440>>2];M=B[n+87472>>2];n=(17-g<<2)+j|0;ma=B[n>>2];B[q+72>>2]=E(u*O)-E(M*ma);B[n>>2]=E(u*M)+E(ma*O);g=g+1|0;continue}break}j=j+72|0;f=f-1|0;continue}break}g=k;f=D(d,1152)+G|0;j=y[m+11|0];if(e){bM(g,f,87504,e);g=D(e,72)+g|0;f=D(e,36)+f|0}T:{if((j|0)==2){j=32-e|0;e=fb-80|0;fb=e;q=e|8;I=e|4;while(1){if((j|0)>0){n=yc(e,g,72);l=x[f+20>>2];x[g+16>>2]=x[f+16>>2];x[g+20>>2]=l;l=x[f+12>>2];x[g+8>>2]=x[f+8>>2];x[g+12>>2]=l;l=x[f+4>>2];x[g>>2]=x[f>>2];x[g+4>>2]=l;K=n;n=f+24|0;gz(K,g+24|0,n);gz(I,g+48|0,n);gz(q,f,n);g=g+72|0;f=f+36|0;j=j-1|0;continue}break}fb=e+80|0;break T}bM(g,f,D((j|0)==3,72)+87504|0,32-e|0)}e=0;k=k+72|0;while(1){g=1;if(e>>>0<=31){while(1){if(g>>>0<=17){f=(g<<2)+k|0;B[f>>2]=-B[f>>2];g=g+2|0;continue}break}k=k+144|0;e=e+2|0;continue}break}m=m+28|0;d=d+1|0;continue}break}eM(na,qa,18,x[L+8>>2],Z,oa);o=o+1|0;Z=D(x[L+8>>2],1152)+Z|0;continue}}e=r+900|0;g=x[e+8>>2]>>>3|0;m=x[e+4>>2]+7>>>3|0;d=g-m|0;f=(d|0)>=511?511:d;if((d|0)>0){ml(G+6156|0,(e+(d>>>0>511?g-511|0:m)|0)+12|0,f)}x[G+6144>>2]=f;break x}IB(G);break l}f=r+17136|0;o=0;m=0;k=0;g=r;d=0;U:{V:{W:{h=y[C+3|0];i=h>>>6|0;switch(i-1|0){case 2:break U;case 0:break W;default:break V}}d=(h>>>2&12)+4|0;break U}d=32}h=y[C+1|0];X:{if((h&6)==6){h=32;e=88908;break X}if(!(h&8)){h=30;e=88911;break X}j=y[C+2|0];e=j>>>2&3;h=jz(h,j)>>>((i|0)!=3)|0;h=h?h:192;if(h>>>0<=55){h=(e|0)==2?12:8;e=88932;break X}h=h>>>0<=95?27:(e|0)!=1?30:27;e=88920}v[g+768|0]=h;v[g+769|0]=(d|0)<(h|0)?d:h;h=e;i=88816;while(1){d=y[g+768|0];if(o>>>0>=d>>>0){o=0;while(1){e=d<<1&510;if(e>>>0>o>>>0){e=g+o|0;Y:{if(!y[e+770|0]){h=6;break Y}h=2;if((y[C+1|0]&6)==6){break Y}h=ue(f,2);d=y[g+768|0]}v[e+834|0]=h;o=o+1|0;continue}break}m=g+770|0;i=g+834|0;h=0;j=e;while(1){if((h|0)!=(j|0)){k=y[m|0];if(k){e=19>>>y[h+i|0]&3|4}else{e=0}m=m+1|0;k=D(k,3)-6|0;u=E(0);d=4;while(1){if(d){if(d&e){A=ue(f,6);n=(A|0)/3|0;u=E(B[(k+(D(n,-3)+A|0)<<2)+88944>>2]*E(2097152>>>n|0))}B[g>>2]=u;d=d>>>1|0;g=g+4|0;continue}break}h=h+1|0;continue}break}o=y[r+769|0];d=y[r+768|0];d=d>>>0<o>>>0?o:d;while(1){if((d|0)!=(o|0)){v[((o<<1)+r|0)+771|0]=0;o=o+1|0;continue}break}}else{if((k|0)==(o|0)){i=y[h|0]+88816|0;k=y[h+2|0]+o|0;m=y[h+1|0];h=h+3|0}e=o<<1;d=y[ue(f,m)+i|0];v[(e+g|0)+770|0]=d;j=y[g+769|0];if(o>>>0<j>>>0){d=y[ue(f,m)+i|0];j=y[g+769|0]}v[((e|1)+g|0)+770|0]=j?d:0;o=o+1|0;continue}break}h=0;g=Rb(r+3840|0,0,4608);I=G+2304|0;l=r+8608|0;o=0;Z:{while(1){if((o|0)==3){break Z}C=g+(h<<2)|0;n=r+17136|0;e=0;A=x[L+16>>2]|1;q=(A|0)>0?A:0;f=576;while(1){if((e|0)!=4){m=C+(D(e,A)<<2)|0;i=0;while(1){if(y[r+768|0]<<1>>>0>i>>>0){_:{j=y[(i+r|0)+770|0];if(!j){break _}if(j>>>0<=16){k=(-1<<j-1)+1|0;d=0;while(1){if((d|0)==(q|0)){break _}sa=(d<<2)+m|0,ua=E(ue(n,j)+k|0),B[sa>>2]=ua;d=d+1|0;continue}}d=2<<j-17;k=ue(n,(d-(d>>>3|0)|0)+3|0);t=d>>>1|0;j=d|1;d=0;while(1){if((d|0)==(q|0)){break _}K=k;k=(k>>>0)/(j>>>0)|0;B[(d<<2)+m>>2]=K-(t+D(j,k)|0)|0;d=d+1|0;continue}}i=i+1|0;m=(f<<2)+m|0;f=18-f|0;continue}break}e=e+1|0;continue}break}h=(A<<2)+h|0;if((h|0)==12){d=(o<<2)+r|0;h=g;e=y[r+769|0];f=g+D(e,72)|0;yc(f+2304|0,f,D(y[r+768|0]-e|0,72));m=0;while(1){if(y[r+768|0]>m>>>0){e=0;while(1){if((e|0)!=12){f=(e<<2)+h|0;B[f>>2]=B[d>>2]*B[f>>2];f=f+2304|0;B[f>>2]=B[d+12>>2]*B[f>>2];e=e+1|0;continue}break}d=d+24|0;h=h+72|0;m=m+1|0;continue}break}eM(I,g,12,x[L+8>>2],Z,l);Rb(g,0,4608);Z=D(x[L+8>>2],768)+Z|0;h=0}o=o+1|0;if(x[r+17140>>2]<=x[r+17144>>2]){continue}break}IB(G);o=0;break l}h=1}o=D(iz(y[G+6153|0]),h)}fb=r+17152|0;d=x[s+32>>2];if((d|0)<0|!d){break h}h=x[s+44>>2];if((h|0)!=(ba|0)?ba:0){break h}d=x[s+40>>2];if((d|0)!=(F|0)?F:0){break h}if(d-3>>>0<4294967294|(h|0)<=0){break i}x[s+16>>2]=0;sa=s,ta=Gc(W,aa),x[sa+12>>2]=ta;e=s+16|0;f=s+12|0;F=x[dk(L,e,f)>>2];x[s+16>>2]=0;sa=s,ta=Gc(W,aa),x[sa+12>>2]=ta;e=x[dk(L,e,f)>>2];g=e>>31;$:{if(!o){break $}f=x[da>>2];x[31737]=0;U(595,P|0,f|0,f+(D(d,o)<<1)|0)|0;f=x[31737];x[31737]=0;if((f|0)!=1){break $}c=T(125048)|0;if((gb|0)==($(125048)|0)){Y(c|0)|0;x[31737]=0;X(26);c=x[31737];x[31737]=0;F=d;ba=h;if((c|0)!=1){break h}c=N()|0}md(da);break k}if((Zc(x[P>>2],x[P+4>>2])>>>0)/(d>>>0)>>>0>268435456){break i}c=c+F|0;ba=h;F=d;aa=aa-(g+(e>>>0>W>>>0)|0)|0;W=W-e|0;if(!!W&(aa|0)>=0|(aa|0)>0){continue}break}break h}c=N()|0}ZT(ca);break j}c=N()|0}md(P);Kc(s+76|0);Q(c|0);p()}F=d;ba=h}h=0;aa:{if(!ba|!F){break aa}c=x[P>>2];d=x[P+4>>2];if(mc(c,d)){break aa}if((Zc(c,d)>>>0)/(F>>>0)>>>0>268435456){break aa}Uu(a,b);b=D(b,104)+a|0;a=b+484380|0;sa=a,ta=(Zc(x[P>>2],x[P+4>>2])>>>0)/(F>>>0)|0,x[sa>>2]=ta;d=b+484414|0;c=z[d>>1];w[d>>1]=(F|0)==2?c|65:c&65470|1;Eh(a);c=b+484400|0;h=je(x[a>>2],x[c>>2]);if(!h){break aa}d=wb(x[P>>2]);h=wb(x[P+4>>2]);b=fb-16|0;fb=b;gV(b+8|0,d,h,x[c>>2]);fb=b+16|0;h=je(x[a>>2],x[a+20>>2])}md(da);ZT(ca);md(P);Kc(s+76|0)}fb=s+96|0;return h|0}function ZC(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,C=0,G=0,H=0,I=E(0),K=E(0),L=0,M=0,N=0,O=E(0);C=fb-1520|0;fb=C;e=C+8|0;M=Rb(e,0,1512),N=-1,x[M+1420>>2]=N;v[C+56|0]=1;x[C+48>>2]=a+b;x[C+40>>2]=a;b=0;q=fb-1024|0;fb=q;v[e+1377|0]=1;a:{if(!Ot(e)){break a}f=y[e+1375|0];if(!(f&2)){fc(e,34);break a}if(f&4){fc(e,34);break a}if(f&1){fc(e,34);break a}if(x[e+1116>>2]!=1){fc(e,34);break a}f=y[e+1120|0];if((f|0)!=30){b:{if((f|0)!=64){break b}if(!cz(e,q+1018|0,6)|y[q+1018|0]!=102|(y[q+1019|0]!=105|y[q+1020|0]!=115)){break b}if(y[q+1021|0]!=104|y[q+1022|0]!=101|y[q+1023|0]!=97){break b}if((gf(e)|0)!=100){break b}if(gf(e)){break b}fc(e,38);break a}fc(e,34);break a}if((gf(e)|0)!=1){fc(e,34);break a}if(!cz(e,q+1018|0,6)){fc(e,10);break a}if(!az(q+1018|0)){fc(e,34);break a}if(Aj(e)){fc(e,34);break a}f=gf(e);x[e+4>>2]=f;if(!f){fc(e,34);break a}if(f>>>0>=17){fc(e,5);break a}f=Aj(e);x[e>>2]=f;if(!f){fc(e,34);break a}Aj(e);Aj(e);Aj(e);g=gf(e);f=g>>>4|0;x[e+116>>2]=1<<f;h=g&15;x[e+112>>2]=1<<h;if(h-14>>>0<=4294967287){fc(e,20);break a}if(g+32<<24>>24>=0){fc(e,20);break a}c:{if(f>>>0<h>>>0){fc(e,20);break c}if(!(gf(e)&1)){fc(e,34);break c}if(!Ot(e)){break a}if(!bz(e)){break a}if(!dz(e)){break a}d:{e:{if((Ph(e)|0)==3){while(1){if((b|0)!=6){M=(q+1018|0)+b|0,N=Ph(e),v[M|0]=N;b=b+1|0;continue}break}if(!az(q+1018|0)){fc(e,20);break c}g=$y(e);b=te(e,g+1|0);x[e+20>>2]=b;if(!b){break e}b=0;h=(g|0)>0?g:0;while(1){if((b|0)!=(h|0)){f=Ph(e);v[x[e+20>>2]+b|0]=f;b=b+1|0;continue}break}v[g+x[e+20>>2]|0]=0;b=$y(e);x[e+28>>2]=0;x[e+24>>2]=b;if((b|0)<=0){break d}b=te(e,b<<2);x[e+28>>2]=b;if(b){break d}fc(e,3);break c}fc(e,20);break c}fc(e,3);break c}while(1){f:{g:{if(x[e+24>>2]>(m|0)){j=$y(e);b=te(e,j+1|0);g=m<<2;x[g+x[e+28>>2]>>2]=b;if(!x[g+x[e+28>>2]>>2]){break g}b=0;h=(j|0)>0?j:0;while(1){if((b|0)==(h|0)){break f}f=Ph(e);v[x[g+x[e+28>>2]>>2]+b|0]=f;b=b+1|0;continue}}if(!(Ph(e)&1)){fc(e,20);break c}RL(e,y[e+1376|0]);v[e+1376|0]=0;while(1){b=dz(e);RL(e,b);v[e+1376|0]=0;if(b){continue}break}b=0;if(!bz(e)){break a}if(!_L(e)){if(x[e+100>>2]!=21){break a}x[e+100>>2]=20;break a}h=0;while(1){if((h|0)!=256){i=h<<24;f=0;while(1){if((f|0)!=8){i=i>>31&79764919^i<<1;f=f+1|0;continue}break}x[(h<<2)+495840>>2]=i;h=h+1|0;continue}break}if((Ph(e)|0)==5){while(1){if((b|0)!=6){M=(q+1018|0)+b|0,N=Ph(e),v[M|0]=N;b=b+1|0;continue}break}if(!az(q+1018|0)){fc(e,20);break c}b=rc(e,8)+1|0;x[e+120>>2]=b;b=te(e,D(b,2096));x[e+124>>2]=b;if(!b){fc(e,3);break c}Rb(b,0,D(x[e+120>>2],2096));h:{i:{while(1){j:{k:{if(x[e+120>>2]>(k|0)){b=x[e+124>>2];if((rc(e,8)&255)!=66){fc(e,20);break c}if((rc(e,8)&255)!=67){fc(e,20);break c}if((rc(e,8)&255)!=86){fc(e,20);break c}g=D(k,2096)+b|0;M=g,N=rc(e,8)&255|rc(e,8)<<8,x[M>>2]=N;M=g,N=rc(e,8)&255|(rc(e,8)<<8&65280|rc(e,8)<<16),x[M+4>>2]=N;t=g+4|0;b=0;f=rc(e,1);if(!f){b=rc(e,1)}v[g+23|0]=b;h=x[t>>2];if(!(x[g>>2]|!h)){fc(e,20);break c}l:{if(b&255){i=ro(e,h);break l}i=te(e,h);x[g+8>>2]=i}if(!i){fc(e,3);break c}r=0;if(f){break k}b=0;while(1){f=x[t>>2];if((f|0)<=(b|0)){break j}m:{n:{if(y[g+23|0]){if(!rc(e,1)){break n}}f=rc(e,5)+1|0;v[b+i|0]=f;if((f&255)!=32){r=r+1|0;break m}fc(e,20);break c}v[b+i|0]=255}b=b+1|0;continue}}f=rc(e,6)+1&255;b=0;o:{while(1){if((b|0)==(f|0)){break o}b=b+1|0;if(!rc(e,16)){continue}break}fc(e,20);break c}b=rc(e,6)+1|0;x[e+128>>2]=b;b=te(e,D(b,1596));x[e+260>>2]=b;p:{q:{if(b){r=0;h=0;r:while(1){if(x[e+128>>2]<=(h|0)){break q}b=rc(e,16);w[((h<<1)+e|0)+132>>1]=b;b=b&65535;if(b>>>0>=2){fc(e,20);break c}if(!b){f=x[e+260>>2]+D(h,1596)|0;M=f,N=rc(e,8),v[M|0]=N;M=f,N=rc(e,16),w[M+2>>1]=N;M=f,N=rc(e,16),w[M+4>>1]=N;M=f,N=rc(e,6),v[M+6|0]=N;M=f,N=rc(e,8),v[M+7|0]=N;k=rc(e,4)+1|0;v[f+8|0]=k;b=0;while(1){if((k&255)>>>0>b>>>0){M=b+f|0,N=rc(e,8),v[M+9|0]=N;b=b+1|0;k=y[f+8|0];continue}break}fc(e,4);break c}n=x[e+260>>2]+D(h,1596)|0;f=rc(e,5);v[n|0]=f;i=0;k=-1;while(1)if((f&255)>>>0<=i>>>0){g=k+1|0;f=0;while(1){if((f|0)!=(g|0)){j=f+n|0;M=j,N=rc(e,3)+1|0,v[M+33|0]=N;b=rc(e,2);v[j+49|0]=b;if(b&255){b=rc(e,8);v[j+65|0]=b;if(x[e+120>>2]<=(b&255)){break p}}i=0;while(1){if(1<<y[j+49|0]>(i|0)){b=rc(e,8)-1|0;w[((n+(f<<4)|0)+(i<<1)|0)+82>>1]=b;i=i+1|0;if(x[e+120>>2]>b<<16>>16){continue}break p}break}f=f+1|0;continue}break}k=2;M=n,N=rc(e,2)+1|0,v[M+1588|0]=N;b=rc(e,4);x[n+1592>>2]=2;m=0;w[n+338>>1]=0;v[n+1589|0]=b;w[n+340>>1]=1<<b;G=n+338|0;l=0;while(1){if(y[n|0]>l>>>0){f=n+y[(l+n|0)+1|0]|0;i=0;while(1){if(y[f+33|0]>i>>>0){b=rc(e,y[n+1589|0]);w[(n+(x[n+1592>>2]<<1)|0)+338>>1]=b;k=x[n+1592>>2]+1|0;x[n+1592>>2]=k;i=i+1|0;continue}break}l=l+1|0;continue}break}while(1){if((k|0)>(m|0)){f=z[(n+(m<<1)|0)+338>>1];b=(q+16|0)+(m<<2)|0;w[b+2>>1]=m;w[b>>1]=f;m=m+1|0;k=x[n+1592>>2];continue}break}QL(q+16|0,k,1174);k=x[n+1592>>2];g=((k|0)<=1?1:k)-1|0;i=0;f=0;while(1){if((f|0)!=(g|0)){b=q+16|0;j=z[b+(f<<2)>>1];f=f+1|0;if((j|0)!=z[b+(f<<2)>>1]){continue}break p}break}while(1){if((i|0)<(k|0)){v[(i+n|0)+838|0]=y[((q+16|0)+(i<<2)|0)+2|0];i=i+1|0;k=x[n+1592>>2];continue}break}i=2;while(1){if((i|0)<(k|0)){x[q+12>>2]=0;x[q+8>>2]=0;f=0;b=(i|0)>0?i:0;o=G+(i<<1)|0;k=65536;j=-1;while(1){if((b|0)!=(f|0)){g=G+(f<<1)|0;l=z[g>>1];if(!((j|0)>=(l|0)|z[o>>1]<=l>>>0)){x[q+12>>2]=f;l=z[g>>1];j=l}if(!((k|0)<=(l|0)|z[o>>1]>=l>>>0)){x[q+8>>2]=f;k=z[g>>1]}f=f+1|0;continue}break}b=n+(i<<1)|0;v[b+1088|0]=x[q+12>>2];v[b+1089|0]=x[q+8>>2];i=i+1|0;k=x[n+1592>>2];continue}break}r=(k|0)>(r|0)?k:r;h=h+1|0;continue r}else{b=rc(e,4);v[(i+n|0)+1|0]=b;b=b&255;k=(b|0)>(k|0)?b:k;i=i+1|0;f=y[n|0];continue}}}fc(e,3);break c}b=rc(e,6)+1|0;x[e+264>>2]=b;b=te(e,D(b,24));x[e+396>>2]=b;if(!b){fc(e,3);break c}f=0;Rb(b,0,D(x[e+264>>2],24));s:{t:{while(1){if(x[e+264>>2]>(f|0)){h=x[e+396>>2];b=rc(e,16);w[((f<<1)+e|0)+268>>1]=b;k=20;if((b&65535)>>>0>2){break s}o=D(f,24)+h|0;M=o,N=rc(e,24),x[M>>2]=N;b=rc(e,24);x[o+4>>2]=b;if(b>>>0<A[o>>2]){break s}M=o,N=rc(e,24)+1|0,x[M+8>>2]=N;M=o,N=rc(e,6)+1|0,v[M+12|0]=N;b=rc(e,8);v[o+13|0]=b;if(x[e+120>>2]<=(b&255)){break s}b=0;while(1){h=y[o+12|0];if(h>>>0>b>>>0){j=(q+16|0)+b|0;l=rc(e,3);if(rc(e,1)){h=rc(e,5)}else{h=0}v[j|0]=l+(h<<3);b=b+1|0;continue}break}b=te(e,h<<4);x[o+20>>2]=b;if(!b){break t}h=0;while(1){if(y[o+12|0]>h>>>0){i=y[(q+16|0)+h|0];b=0;while(1){if((b|0)!=8){u:{if(i>>>b&1){l=rc(e,8);g=b<<1;j=h<<4;w[g+(j+x[o+20>>2]|0)>>1]=l;if(x[e+120>>2]<=w[g+(j+x[o+20>>2]|0)>>1]){break s}break u}w[(x[o+20>>2]+(h<<4)|0)+(b<<1)>>1]=65535}b=b+1|0;continue}break}h=h+1|0;continue}break}b=te(e,x[(x[e+124>>2]+D(y[o+13|0],2096)|0)+4>>2]<<2);x[o+16>>2]=b;if(!b){break t}l=0;Rb(b,0,x[(x[e+124>>2]+D(y[o+13|0],2096)|0)+4>>2]<<2);while(1){b=x[e+124>>2]+D(y[o+13|0],2096)|0;if(x[b+4>>2]>(l|0)){b=x[b>>2];h=te(e,b);g=l<<2;x[g+x[o+16>>2]>>2]=h;i=l;if(!x[g+x[o+16>>2]>>2]){break t}while(1){if((b|0)>0){b=b-1|0;v[b+x[g+x[o+16>>2]>>2]|0]=(i|0)%y[o+12|0];i=(i|0)/y[o+12|0]|0;continue}break}l=l+1|0;continue}break}f=f+1|0;continue}break}b=rc(e,6)+1|0;x[e+400>>2]=b;b=te(e,D(b,40));x[e+404>>2]=b;if(!b){fc(e,3);break c}Rb(b,0,D(x[e+400>>2],40));h=0;while(1){v:{if(x[e+400>>2]>(h|0)){b=x[e+404>>2];if(rc(e,16)){fc(e,20);break c}f=D(h,40)+b|0;b=te(e,D(x[e+4>>2],3));x[f+4>>2]=b;if(!b){fc(e,3);break c}if(rc(e,1)){b=rc(e,4)+1|0}else{b=1}v[f+8|0]=b;w:{if(rc(e,1)){g=rc(e,8)+1|0;w[f>>1]=g;b=0;k=x[e+4>>2];if((k|0)<(g&65535)){fc(e,20);break c}while(1){if(z[f>>1]<=b>>>0){break w}g=rc(e,Om(k-1|0));j=D(b,3);v[j+x[f+4>>2]|0]=g;g=rc(e,Om(x[e+4>>2]-1|0));v[(j+x[f+4>>2]|0)+1|0]=g;k=x[e+4>>2];g=j+x[f+4>>2]|0;j=y[g|0];if((k|0)<=(j|0)){fc(e,20);break c}g=y[g+1|0];if((g|0)>=(k|0)){fc(e,20);break c}b=b+1|0;if((g|0)!=(j|0)){continue}break}fc(e,20);break c}w[f>>1]=0}if(rc(e,2)){fc(e,20);break c}b=0;if(y[f+8|0]>=2){while(1){if(x[e+4>>2]<=(b|0)){break v}j=rc(e,4);g=D(b,3);v[(g+x[f+4>>2]|0)+2|0]=j;b=b+1|0;if(y[(g+x[f+4>>2]|0)+2|0]<y[f+8|0]){continue}break}fc(e,20);break c}while(1){if(x[e+4>>2]<=(b|0)){break v}v[(x[f+4>>2]+D(b,3)|0)+2|0]=0;b=b+1|0;continue}}M=e,N=rc(e,6)+1|0,x[M+408>>2]=N;f=e+412|0;i=0;x:{while(1){if(x[e+408>>2]<=(i|0)){break x}h=f+D(i,6)|0;M=h,N=rc(e,1),v[M|0]=N;M=h,N=rc(e,16),w[M+2>>1]=N;M=h,N=rc(e,16),w[M+4>>1]=N;b=rc(e,8);v[h+1|0]=b;if(z[h+2>>1]){fc(e,20);break c}if(z[h+4>>1]){fc(e,20);break c}i=i+1|0;if(x[e+400>>2]>(b&255)){continue}break}fc(e,20);break c}WL(e);x[e+992>>2]=0;g=r<<1;b=0;while(1){if(x[e+4>>2]>(b|0)){j=(b<<2)+e|0;M=j,N=te(e,x[e+116>>2]<<2),x[M+800>>2]=N;M=j,N=te(e,x[e+116>>2]<<1&2147483646),x[M+928>>2]=N;h=te(e,g);x[j+996>>2]=h;f=x[j+800>>2];if(h?!f|!x[j+928>>2]:1){fc(e,3);break c}Rb(f,0,x[e+116>>2]<<2);b=b+1|0;continue}break}b=0;if(!PL(e,0,x[e+112>>2])){break a}if(!PL(e,1,x[e+116>>2])){break a}x[e+104>>2]=x[e+112>>2];j=x[e+116>>2];x[e+108>>2]=j;f=x[e+264>>2];h=(f|0)>0?f:0;l=(j|0)/2|0;k=0;while(1){if((b|0)!=(h|0)){g=x[e+396>>2]+D(b,24)|0;f=x[g+4>>2];i=f>>>0<l>>>0?f:l;f=x[g>>2];f=(i-(f>>>0<l>>>0?f:l)>>>0)/A[g+8>>2]|0;k=(f|0)>(k|0)?f:k;b=b+1|0;continue}break}f=j<<1&2147483646;b=D(x[e+4>>2],(k<<2)+4|0);f=b>>>0<f>>>0?f:b;x[e+12>>2]=f;y:{z:{if(!x[e+80>>2]){break z}b=x[e+92>>2];if((b|0)!=x[e+84>>2]){break y}if(b>>>0>=(f+x[e+88>>2]|0)+1512>>>0){break z}fc(e,3);break c}A:{if(x[e+1380>>2]==-1){x[e+52>>2]=y[e+48|0]?0:x[e+32>>2]-x[e+36>>2]|0;break A}x[e+52>>2]=0}b=1;break a}_(7344,13274,4196,8845);p()}b=0;B:{while(1){if(y[f+8|0]<=b>>>0){break B}rc(e,8);j=b+f|0;M=j,N=rc(e,8),v[M+9|0]=N;g=rc(e,8);v[j+24|0]=g;if(x[e+128>>2]<=y[j+9|0]){fc(e,20);break c}b=b+1|0;if(x[e+264>>2]>(g&255)){continue}break}fc(e,20);break c}h=h+1|0;continue}}k=3}fc(e,k);break c}fc(e,20);break c}m=rc(e,5);b=0;while(1){f=x[t>>2];if((f|0)<=(b|0)){break j}h=rc(e,Om(f-b|0));m=m+1|0;if((m|0)>=32){fc(e,20);break c}f=b+h|0;if((f|0)>x[t>>2]){fc(e,20);break c}else{Rb(b+i|0,m,h);b=f;continue}}}C:{D:{E:{F:{G:{H:{if(y[g+23|0]){if(f>>2>(r|0)){break H}if(x[e+16>>2]<(f|0)){x[e+16>>2]=f;f=x[t>>2]}b=te(e,f);x[g+8>>2]=b;if(!b){fc(e,3);break c}yc(b,i,x[t>>2]);zj(e,i,x[t>>2]);i=x[g+8>>2];v[g+23|0]=0;f=x[t>>2]}m=0;h=(f|0)>0?f:0;b=0;while(1){if((b|0)==(h|0)){break G}m=((y[b+i|0]-11&255)>>>0<244)+m|0;b=b+1|0;continue}}x[g+2092>>2]=r;l=g+2092|0;if(r){break F}b=0;h=0;break E}x[g+2092>>2]=m;b=te(e,f<<2);x[g+32>>2]=b;if(b){l=g+2092|0;b=0;break D}fc(e,3);break c}b=te(e,r);x[g+8>>2]=b;if(!b){fc(e,3);break c}b=ro(e,x[l>>2]<<2);x[g+32>>2]=b;if(!b){fc(e,3);break c}b=ro(e,x[l>>2]<<2);if(!b){break C}f=x[t>>2];h=x[l>>2]}f=(h<<3)+f|0;if(f>>>0<=A[e+16>>2]){break D}x[e+16>>2]=f}s=x[t>>2];f=0;h=fb-128|0;fb=h;u=Rb(h,0,128);h=(s|0)>0?s:0;while(1){I:{J:{if((f|0)!=(h|0)){if(y[f+i|0]==255){break J}h=f}if((h|0)==(s|0)){f=1;if(!x[g+2092>>2]){break I}_(15807,13274,1103,7588);p()}j=h+i|0;f=y[j|0];if(f>>>0<32){NL(g,0,h,0,f,b);n=1;j=y[j|0]+1|0;f=1;K:{while(1){if((f|0)==(j|0)){L:while(1){M:{f=1;h=h+1|0;if((s|0)<=(h|0)){break I}G=h+i|0;j=y[G|0];if((j|0)==255){continue}f=j;if(f>>>0>=32){break M}while(1){if((f|0)<=0){f=0;break I}o=u+(f<<2)|0;r=x[o>>2];if(!r){f=f-1|0;continue}break}x[o>>2]=0;NL(g,Mm(r),h,n,j,b);n=n+1|0;m=y[G|0];if((m|0)==(f|0)){continue}while(1){if((f|0)>=(m|0)){continue L}j=u+(m<<2)|0;if(x[j>>2]){break K}x[j>>2]=r+(1<<32-m);m=m-1|0;continue}}break}}else{x[u+(f<<2)>>2]=1<<32-f;f=f+1|0;continue}break}_(15340,13274,1118,7588);p()}_(15851,13274,1133,7588);p()}_(15347,13274,1104,7588);p()}f=f+1|0;continue}break}fb=u+128|0;if(!f){if(y[g+23|0]){zj(e,b,0)}fc(e,20);break c}f=x[l>>2];if(f){f=te(e,(f<<2)+4|0);x[g+2084>>2]=f;if(!f){fc(e,3);break c}f=te(e,(x[l>>2]<<2)+4|0);x[g+2088>>2]=f;if(!f){fc(e,3);break c}x[g+2088>>2]=f+4;x[f>>2]=-1;f=0;m=0;N:{O:{P:{if(y[g+23|0]){while(1){m=x[g+2092>>2];if((m|0)<=(f|0)){break P}h=f<<2;M=h+x[g+2084>>2]|0,N=Mm(x[h+x[g+32>>2]>>2]),x[M>>2]=N;f=f+1|0;continue}}while(1){if(x[g+4>>2]>(f|0)){if(ML(y[g+23|0],y[f+i|0])){M=x[g+2084>>2]+(m<<2)|0,N=Mm(x[x[g+32>>2]+(f<<2)>>2]),x[M>>2]=N;m=m+1|0}f=f+1|0;continue}break}if(x[g+2092>>2]!=(m|0)){break O}}QL(x[g+2084>>2],m,1175);x[x[g+2084>>2]+(x[g+2092>>2]<<2)>>2]=-1;h=0;f=x[g+(y[g+23|0]?2092:4)>>2];r=(f|0)>0?f:0;Q:{while(1){if((h|0)!=(r|0)){f=h;j=y[g+23|0];f=j?x[(f<<2)+b>>2]:f;G=y[f+i|0];R:{if(!ML(j,G)){break R}o=h<<2;s=Mm(x[o+x[g+32>>2]>>2]);f=x[g+2092>>2];m=0;while(1){if((f|0)>=2){u=f>>>1|0;j=u+m|0;n=s>>>0<A[x[g+2084>>2]+(j<<2)>>2];f=n?u:f-u|0;m=n?m:j;continue}break}f=m<<2;if((s|0)!=x[f+x[g+2084>>2]>>2]){break Q}if(y[g+23|0]){x[f+x[g+2088>>2]>>2]=x[b+o>>2];v[x[g+8>>2]+m|0]=G;break R}x[f+x[g+2088>>2]>>2]=h}h=h+1|0;continue}break}break N}_(12315,13274,1230,9998);p()}_(7529,13274,1200,9998);p()}}if(y[g+23|0]){zj(e,b,x[l>>2]<<2);zj(e,x[g+32>>2],x[l>>2]<<2);zj(e,i,x[t>>2]);x[g+32>>2]=0}b=0;h=0;while(1){if((b|0)!=1024){w[(g+(b<<1)|0)+36>>1]=65535;b=b+1|0;continue}break}b=x[g+(y[g+23|0]?2092:4)>>2];b=(b|0)>=32767?32767:b;f=(b|0)>0?b:0;while(1){if((f|0)!=(h|0)){S:{if(y[x[g+8>>2]+h|0]>10){break S}T:{if(y[g+23|0]){b=Mm(x[x[g+2084>>2]+(h<<2)>>2]);break T}b=x[x[g+32>>2]+(h<<2)>>2]}while(1){if(b>>>0>1023){break S}w[(g+(b<<1)|0)+36>>1]=h;b=(1<<y[x[g+8>>2]+h|0])+b|0;continue}}h=h+1|0;continue}break}b=rc(e,4);v[g+21|0]=b;b=b&255;if(b>>>0>=3){fc(e,20);break c}if(b){M=g,O=OL(rc(e,32)),B[M+12>>2]=O;M=g,O=OL(rc(e,32)),B[M+16>>2]=O;M=g,N=rc(e,4)+1|0,v[M+20|0]=N;M=g,N=rc(e,1),v[M+22|0]=N;f=x[g>>2];h=x[t>>2];U:{if(y[g+21|0]==1){H=J(Ft(+E(E(sq(+E(h|0)))/E(f|0))));V:{if(F(H)<2147483648){b=~~H;break V}b=-2147483648}L=+(f|0);H=J(sk(+E(E(b|0)+E(1)),L));W:{if(F(H)<2147483648){f=~~H;break W}f=-2147483648}b=((f|0)<=(h|0))+b|0;I=E(b|0);if(sk(+E(I+E(1)),L)<=+(h|0)){b=-1}else{H=J(sk(+I,L));X:{if(F(H)<2147483648){f=~~H;break X}f=-2147483648}b=(f|0)>(h|0)?-1:b}if((b|0)>=0){break U}fc(e,20);break c}b=D(f,h)}x[g+24>>2]=b;if(!b){fc(e,20);break c}s=ro(e,b<<1);if(!s){break i}b=0;while(1){i=x[g+24>>2];if((i|0)>(b|0)){f=rc(e,y[g+20|0]);if((f|0)==-1){zj(e,s,x[g+24>>2]<<1);fc(e,20);break c}else{w[s+(b<<1)>>1]=f;b=b+1|0;continue}}break}Y:{Z:{if(y[g+21|0]==1){n=y[g+23|0];_:{if(n){b=x[l>>2];if(b){break _}break Y}b=x[t>>2]}b=te(e,D(x[g>>2],b)<<2);x[g+28>>2]=b;if(!b){zj(e,s,x[g+24>>2]<<1);fc(e,3);break c}h=0;b=x[(n?l:t)>>2];r=(b|0)>0?b:0;G=g+2088|0;K=E(0);while(1){if((h|0)==(r|0)){break Z}f=h;f=n?x[x[G>>2]+(f<<2)>>2]:f;i=x[g>>2];b=0;l=1;while(1){if((b|0)<(i|0)){I=E(K+E(E(E(z[s+(((f>>>0)/(l>>>0)>>>0)%A[g+24>>2]<<1)>>1])*B[g+16>>2])+B[g+12>>2]));B[(x[g+28>>2]+(D(h,i)<<2)|0)+(b<<2)>>2]=I;K=y[g+22|0]?I:K;b=b+1|0;i=x[g>>2];if((b|0)>=(i|0)){continue}u=x[g+24>>2];Sua(u,0,l,0);if(hb){zj(e,s,u<<1);fc(e,20);break c}else{l=D(l,u);continue}}break}h=h+1|0;continue}}b=te(e,i<<2);x[g+28>>2]=b;if(!b){break h}b=0;K=E(0);while(1){i=x[g+24>>2];if((i|0)<=(b|0)){break Y}I=E(K+E(E(E(z[s+(b<<1)>>1])*B[g+16>>2])+B[g+12>>2]));B[x[g+28>>2]+(b<<2)>>2]=I;K=y[g+22|0]?I:K;b=b+1|0;continue}}v[g+21|0]=2;i=x[g+24>>2]}zj(e,s,i<<1)}k=k+1|0;continue}break}fc(e,3);break c}fc(e,3);break c}zj(e,s,x[g+24>>2]<<1);fc(e,3);break c}fc(e,20);break c}fc(e,3);break c}v[j+x[g+x[e+28>>2]>>2]|0]=0;m=m+1|0;continue}}b=0}fb=q+1024|0;$:{aa:{if(!b){x[d>>2]=x[C+104>>2]?1:x[C+108>>2];fz(e);break aa}f=C+8|0;b=te(f,1512);if(b){M=c,N=x[yc(b,f,1512)+32>>2]-a|0,x[M>>2]=N;x[d>>2]=0;break $}fz(C+8|0)}b=0}fb=C+1520|0;return b}function QK(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0,u=0,w=0,z=0,B=0,C=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;s=fb-48|0;fb=s;a:{if(c>>>0<=2){c=c<<2;I=x[c+95772>>2];J=x[c+95760>>2];while(1){c=x[b+4>>2];b:{if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;c=y[c|0];break b}c=sd(b)}if(wl(c)){continue}break}w=1;c:{d:{switch(c-43|0){case 0:case 2:break d;default:break c}}w=(c|0)==45?-1:1;c=x[b+4>>2];if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;c=y[c|0];break c}c=sd(b)}e:{f:{while(1){if(v[g+4952|0]==(c|32)){g:{if(g>>>0>6){break g}c=x[b+4>>2];if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;c=y[c|0];break g}c=sd(b)}g=g+1|0;if((g|0)!=8){continue}break f}break}if((g|0)!=3){f=(g|0)==8;if(f){break f}if(!d|g>>>0<4){break e}if(f){break f}}c=x[b+116>>2];if((c|0)>=0|(c|0)>0){x[b+4>>2]=x[b+4>>2]-1}if(!d|g>>>0<4){break f}c=(c|0)<0;while(1){if(!c){x[b+4>>2]=x[b+4>>2]-1}g=g-1|0;if(g>>>0>3){continue}break}}l=fb-16|0;fb=l;k=(q(E(E(w|0)*E(Infinity))),j(2));b=k&2147483647;h:{if(b-8388608>>>0<=2130706431){c=b;b=b>>>7|0;c=c<<25;d=b+1065353216|0;break h}c=k<<25;d=k>>>7|2147418112;if(b>>>0>=2139095040){break h}c=0;d=0;if(!b){break h}c=b;b=G(b);bg(l,c,0,0,0,b+81|0);h=x[l>>2];i=x[l+4>>2];c=x[l+8>>2];d=x[l+12>>2]^65536|16265-b<<16}x[s>>2]=h;x[s+4>>2]=i;x[s+8>>2]=c;x[s+12>>2]=k&-2147483648|d;fb=l+16|0;h=x[s+8>>2];i=x[s+12>>2];k=x[s>>2];m=x[s+4>>2];break a}i:{j:{k:{if(g){break k}g=0;while(1){if(v[g+9994|0]!=(c|32)){break k}l:{if(g>>>0>1){break l}c=x[b+4>>2];if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;c=y[c|0];break l}c=sd(b)}g=g+1|0;if((g|0)!=3){continue}break}break j}m:{switch(g|0){case 0:n:{if((c|0)!=48){break n}g=x[b+4>>2];o:{if((g|0)!=x[b+104>>2]){x[b+4>>2]=g+1;g=y[g|0];break o}g=sd(b)}if((g&-33)==88){f=fb-432|0;fb=f;c=x[b+4>>2];p:{if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;g=y[c|0];break p}g=sd(b)}q:{r:{while(1){if((g|0)!=48){s:{if((g|0)!=46){break q}c=x[b+4>>2];if((c|0)==x[b+104>>2]){break s}x[b+4>>2]=c+1;g=y[c|0];break r}}else{c=x[b+4>>2];if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;g=y[c|0]}else{g=sd(b)}K=1;continue}break}g=sd(b)}r=1;if((g|0)!=48){break q}while(1){c=t;t=c-1|0;u=u-!c|0;c=x[b+4>>2];t:{if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;g=y[c|0];break t}g=sd(b)}if((g|0)==48){continue}break}K=1}m=1073676288;u:{while(1){v:{c=g|32;w:{x:{z=g-48|0;if(z>>>0<10){break x}L=(g|0)!=46;if(L&c-97>>>0>5){break u}if(L){break x}if(r){break v}r=1;t=h;u=i;break w}c=(g|0)>57?c-87|0:z;y:{if((i|0)<=0&h>>>0<=7|(i|0)<0){n=c+(n<<4)|0;break y}if(!i&h>>>0<=28){lh(f+48|0,c);Wd(f+32|0,F,H,k,m,0,0,0,1073414144);F=x[f+32>>2];H=x[f+36>>2];k=x[f+40>>2];m=x[f+44>>2];Wd(f+16|0,x[f+48>>2],x[f+52>>2],x[f+56>>2],x[f+60>>2],F,H,k,m);Sg(f,x[f+16>>2],x[f+20>>2],x[f+24>>2],x[f+28>>2],l,p,B,C);B=x[f+8>>2];C=x[f+12>>2];l=x[f>>2];p=x[f+4>>2];break y}if(!c|M){break y}Wd(f+80|0,F,H,k,m,0,0,0,1073610752);Sg(f- -64|0,x[f+80>>2],x[f+84>>2],x[f+88>>2],x[f+92>>2],l,p,B,C);B=x[f+72>>2];C=x[f+76>>2];M=1;l=x[f+64>>2];p=x[f+68>>2]}h=h+1|0;i=h?i:i+1|0;K=1}c=x[b+4>>2];if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;g=y[c|0]}else{g=sd(b)}continue}break}g=46}z:{if(!K){c=x[b+116>>2];if((c|0)>0){c=1}else{c=(c|0)>=0}A:{B:{if(c){c=x[b+4>>2];x[b+4>>2]=c-1;if(!d){break B}x[b+4>>2]=c-2;if(!r){break A}x[b+4>>2]=c-3;break A}if(d){break A}}Ii(b,0,0)}mj(f+96|0,+(w|0)*0);l=x[f+96>>2];p=x[f+100>>2];c=x[f+108>>2];b=x[f+104>>2];break z}if((i|0)<=0&h>>>0<=7|(i|0)<0){k=h;m=i;while(1){n=n<<4;k=k+1|0;m=k?m:m+1|0;if((k|0)!=8|m){continue}break}}C:{D:{E:{if((g&-33)==80){k=PK(b,d);c=hb;m=c;if(k|(c|0)!=-2147483648){break C}if(d){c=x[b+116>>2];if((c|0)>0){c=1}else{c=(c|0)>=0}if(c){break E}break D}l=0;p=0;Ii(b,0,0);c=0;b=0;break z}k=0;m=0;if(x[b+116>>2]<0){break C}}x[b+4>>2]=x[b+4>>2]-1}k=0;m=0}if(!n){mj(f+112|0,+(w|0)*0);l=x[f+112>>2];p=x[f+116>>2];c=x[f+124>>2];b=x[f+120>>2];break z}b=r?t:h;d=k+(b<<2)|0;b=m+((r?u:i)<<2|b>>>30)|0;h=d-32|0;c=0-I|0;i=(d>>>0<k>>>0?b+1|0:b)-(d>>>0<32)|0;b=i;if((b|0)>0){b=1}else{b=c>>>0<h>>>0&(b|0)>=0}if(b){x[31612]=68;lh(f+160|0,w);Wd(f+144|0,x[f+160>>2],x[f+164>>2],x[f+168>>2],x[f+172>>2],-1,-1,-1,2147418111);Wd(f+128|0,x[f+144>>2],x[f+148>>2],x[f+152>>2],x[f+156>>2],-1,-1,-1,2147418111);l=x[f+128>>2];p=x[f+132>>2];c=x[f+140>>2];b=x[f+136>>2];break z}b=I-226|0;c=b>>31;if((i|0)>=(c|0)&b>>>0<=h>>>0|(c|0)<(i|0)){if((n|0)>=0){while(1){Sg(f+416|0,l,p,B,C,0,0,0,-1073807360);b=uV(l,p,B,C,1073610752);c=(b|0)>=0;b=c;Sg(f+400|0,l,p,B,C,b?x[f+416>>2]:l,b?x[f+420>>2]:p,b?x[f+424>>2]:B,b?x[f+428>>2]:C);b=h;h=b-1|0;i=i-!b|0;B=x[f+408>>2];C=x[f+412>>2];l=x[f+400>>2];p=x[f+404>>2];n=c|n<<1;if((n|0)>=0){continue}break}}b=i-((I>>31)+(h>>>0<I>>>0)|0)|0;c=(h-I|0)+32|0;b=c>>>0<32?b+1|0:b;c=c>>>0<J>>>0&(b|0)<=0|(b|0)<0?(c|0)>0?c:0:J;F:{if((c|0)>=113){lh(f+384|0,w);t=x[f+392>>2];u=x[f+396>>2];F=x[f+384>>2];H=x[f+388>>2];k=0;b=0;break F}mj(f+352|0,pk(1,144-c|0));lh(f+336|0,w);F=x[f+336>>2];H=x[f+340>>2];t=x[f+344>>2];u=x[f+348>>2];SK(f+368|0,x[f+352>>2],x[f+356>>2],x[f+360>>2],x[f+364>>2],F,H,t,u);o=x[f+376>>2];e=x[f+380>>2];k=x[f+372>>2];b=x[f+368>>2]}d=!(n&1)&((kn(l,p,B,C,0,0,0,0)|0)!=0&(c|0)<32);Zn(f+320|0,d+n|0);Wd(f+304|0,F,H,t,u,x[f+320>>2],x[f+324>>2],x[f+328>>2],x[f+332>>2]);c=b;Sg(f+272|0,x[f+304>>2],x[f+308>>2],x[f+312>>2],x[f+316>>2],b,k,o,e);b=d;Wd(f+288|0,F,H,t,u,b?0:l,b?0:p,b?0:B,b?0:C);Sg(f+256|0,x[f+288>>2],x[f+292>>2],x[f+296>>2],x[f+300>>2],x[f+272>>2],x[f+276>>2],x[f+280>>2],x[f+284>>2]);yz(f+240|0,x[f+256>>2],x[f+260>>2],x[f+264>>2],x[f+268>>2],c,k,o,e);b=x[f+240>>2];d=x[f+244>>2];c=x[f+248>>2];k=x[f+252>>2];if(!kn(b,d,c,k,0,0,0,0)){x[31612]=68}RK(f+224|0,b,d,c,k,h);l=x[f+224>>2];p=x[f+228>>2];c=x[f+236>>2];b=x[f+232>>2];break z}x[31612]=68;lh(f+208|0,w);Wd(f+192|0,x[f+208>>2],x[f+212>>2],x[f+216>>2],x[f+220>>2],0,0,0,65536);Wd(f+176|0,x[f+192>>2],x[f+196>>2],x[f+200>>2],x[f+204>>2],0,0,0,65536);l=x[f+176>>2];p=x[f+180>>2];c=x[f+188>>2];b=x[f+184>>2]}x[s+16>>2]=l;x[s+20>>2]=p;x[s+24>>2]=b;x[s+28>>2]=c;fb=f+432|0;h=x[s+24>>2];i=x[s+28>>2];k=x[s+16>>2];m=x[s+20>>2];break a}if(x[b+116>>2]<0){break n}x[b+4>>2]=x[b+4>>2]-1}g=b;n=c;f=d;d=0;e=fb-8976|0;fb=e;M=0-I|0;L=M-J|0;G:{H:{while(1){if((n|0)!=48){I:{if((n|0)!=46){break G}b=x[g+4>>2];if((b|0)==x[g+104>>2]){break I}x[g+4>>2]=b+1;n=y[b|0];break H}}else{b=x[g+4>>2];if((b|0)!=x[g+104>>2]){x[g+4>>2]=b+1;n=y[b|0]}else{n=sd(g)}d=1;continue}break}n=sd(g)}K=1;if((n|0)!=48){break G}while(1){b=h;h=b-1|0;i=i-!b|0;b=x[g+4>>2];J:{if((b|0)!=x[g+104>>2]){x[g+4>>2]=b+1;n=y[b|0];break J}n=sd(g)}if((n|0)==48){continue}break}d=1}x[e+784>>2]=0;K:{L:{b=(n|0)==46;c=n-48|0;M:{N:{O:{if(b|c>>>0<=9){while(1){P:{if(b&1){if(!K){h=k;i=m;K=1;break P}b=!d;break O}k=k+1|0;m=k?m:m+1|0;if((r|0)<=2044){z=(n|0)==48?z:k;b=(e+784|0)+(r<<2)|0;if(o){c=(D(x[b>>2],10)+n|0)-48|0}x[b>>2]=c;d=1;c=o+1|0;b=(c|0)==9;o=b?0:c;r=b+r|0;break P}if((n|0)==48){break P}x[e+8960>>2]=x[e+8960>>2]|1;z=18396}b=x[g+4>>2];Q:{if((b|0)!=x[g+104>>2]){x[g+4>>2]=b+1;n=y[b|0];break Q}n=sd(g)}b=(n|0)==46;c=n-48|0;if(b|c>>>0<10){continue}break}}h=K?h:k;i=K?i:m;if(!(!d|(n&-33)!=69)){l=PK(g,f);b=hb;p=b;R:{if(l|(b|0)!=-2147483648){break R}if(!f){break M}l=0;p=0;if(x[g+116>>2]<0){break R}x[g+4>>2]=x[g+4>>2]-1}i=i+p|0;h=h+l|0;i=h>>>0<l>>>0?i+1|0:i;break L}b=!d;if((n|0)<0){break N}}if(x[g+116>>2]<0){break N}x[g+4>>2]=x[g+4>>2]-1}if(!b){break L}x[31612]=28}Ii(g,0,0);h=0;i=0;c=0;b=0;break K}b=x[e+784>>2];if(!b){mj(e,+(w|0)*0);h=x[e+8>>2];i=x[e+12>>2];c=x[e+4>>2];b=x[e>>2];break K}if(!((h|0)!=(k|0)|(i|0)!=(m|0)|(k>>>0>9&(m|0)>=0|(m|0)>0)|(b>>>J|0?(J|0)<=30:0))){lh(e+48|0,w);Zn(e+32|0,b);Wd(e+16|0,x[e+48>>2],x[e+52>>2],x[e+56>>2],x[e+60>>2],x[e+32>>2],x[e+36>>2],x[e+40>>2],x[e+44>>2]);h=x[e+24>>2];i=x[e+28>>2];c=x[e+20>>2];b=x[e+16>>2];break K}b=M>>>1|0;if(b>>>0<h>>>0&(i|0)>=0|(i|0)>0){x[31612]=68;lh(e+96|0,w);Wd(e+80|0,x[e+96>>2],x[e+100>>2],x[e+104>>2],x[e+108>>2],-1,-1,-1,2147418111);Wd(e- -64|0,x[e+80>>2],x[e+84>>2],x[e+88>>2],x[e+92>>2],-1,-1,-1,2147418111);h=x[e+72>>2];i=x[e+76>>2];c=x[e+68>>2];b=x[e+64>>2];break K}b=I-226|0;c=h>>>0<b>>>0;b=b>>31;if(c&(i|0)<=(b|0)|(b|0)>(i|0)){x[31612]=68;lh(e+144|0,w);Wd(e+128|0,x[e+144>>2],x[e+148>>2],x[e+152>>2],x[e+156>>2],0,0,0,65536);Wd(e+112|0,x[e+128>>2],x[e+132>>2],x[e+136>>2],x[e+140>>2],0,0,0,65536);h=x[e+120>>2];i=x[e+124>>2];c=x[e+116>>2];b=x[e+112>>2];break K}if(o){if((o|0)<=8){b=(e+784|0)+(r<<2)|0;g=x[b>>2];while(1){g=D(g,10);o=o+1|0;if((o|0)!=9){continue}break}x[b>>2]=g}r=r+1|0}o=h;S:{if((h|0)<(z|0)|(z|0)>=9|(h|0)>17){break S}if((h|0)==9){lh(e+192|0,w);Zn(e+176|0,x[e+784>>2]);Wd(e+160|0,x[e+192>>2],x[e+196>>2],x[e+200>>2],x[e+204>>2],x[e+176>>2],x[e+180>>2],x[e+184>>2],x[e+188>>2]);h=x[e+168>>2];i=x[e+172>>2];c=x[e+164>>2];b=x[e+160>>2];break K}if((o|0)<=8){lh(e+272|0,w);Zn(e+256|0,x[e+784>>2]);Wd(e+240|0,x[e+272>>2],x[e+276>>2],x[e+280>>2],x[e+284>>2],x[e+256>>2],x[e+260>>2],x[e+264>>2],x[e+268>>2]);lh(e+224|0,x[(0-o<<2)+95760>>2]);VR(e+208|0,x[e+240>>2],x[e+244>>2],x[e+248>>2],x[e+252>>2],x[e+224>>2],x[e+228>>2],x[e+232>>2],x[e+236>>2]);h=x[e+216>>2];i=x[e+220>>2];c=x[e+212>>2];b=x[e+208>>2];break K}b=(D(o,-3)+J|0)+27|0;c=x[e+784>>2];if(c>>>b|0?(b|0)<=30:0){break S}lh(e+352|0,w);Zn(e+336|0,c);Wd(e+320|0,x[e+352>>2],x[e+356>>2],x[e+360>>2],x[e+364>>2],x[e+336>>2],x[e+340>>2],x[e+344>>2],x[e+348>>2]);lh(e+304|0,x[(o<<2)+95688>>2]);Wd(e+288|0,x[e+320>>2],x[e+324>>2],x[e+328>>2],x[e+332>>2],x[e+304>>2],x[e+308>>2],x[e+312>>2],x[e+316>>2]);h=x[e+296>>2];i=x[e+300>>2];c=x[e+292>>2];b=x[e+288>>2];break K}while(1){b=r;r=b-1|0;if(!x[(e+784|0)+(r<<2)>>2]){continue}break}z=0;d=(o|0)%9|0;T:{if(!d){c=0;break T}c=0;d=(o|0)<0?d+9|0:d;U:{if(!b){b=0;break U}h=x[(0-d<<2)+95760>>2];l=1e9/(h|0)|0;n=0;g=0;while(1){k=n;i=e+784|0;m=i+(g<<2)|0;n=x[m>>2];r=(n>>>0)/(h>>>0)|0;k=k+r|0;x[m>>2]=k;k=!k&(c|0)==(g|0);c=k?c+1&2047:c;o=k?o-9|0:o;n=D(l,n-D(h,r)|0);g=g+1|0;if((g|0)!=(b|0)){continue}break}if(!n){break U}x[i+(b<<2)>>2]=n;b=b+1|0}o=(o-d|0)+9|0}while(1){g=(e+784|0)+(c<<2)|0;n=(o|0)<36;V:{while(1){W:{if(n){break W}if((o|0)!=36){break V}if(A[g>>2]<=10384592){break W}o=36;break V}r=b+2047|0;d=0;while(1){k=b;l=r&2047;r=(e+784|0)+(l<<2)|0;b=x[r>>2];m=b>>>3|0;h=d;d=b<<29;h=h+d|0;b=m;i=d>>>0>h>>>0?b+1|0:b;if(!i&h>>>0<1000000001){d=0}else{d=Uua(h,i,1e9,0);b=Sua(d,hb,-1e9,-1);h=b+h|0}x[r>>2]=h;b=(c|0)==(l|0)?k:h?k:l;h=k-1&2047;b=(h|0)!=(l|0)?k:b;r=l-1|0;if((c|0)!=(l|0)){continue}break}z=z-29|0;b=k;if(!d){continue}break}c=c-1&2047;if((c|0)==(b|0)){g=(b+2046&2047)<<2;b=e+784|0;k=g+b|0;x[k>>2]=x[k>>2]|x[b+(h<<2)>>2];b=h}o=o+9|0;x[(e+784|0)+(c<<2)>>2]=d;continue}break}X:{Y:while(1){h=b+1&2047;l=(e+784|0)+((b-1&2047)<<2)|0;while(1){k=(o|0)>45?9:1;i=(o|0)!=36;Z:{while(1){d=c;g=0;_:{while(1){$:{c=d+g&2047;if((c|0)==(b|0)){break $}c=x[(e+784|0)+(c<<2)>>2];m=x[(g<<2)+95712>>2];if(c>>>0<m>>>0){break $}if(c>>>0>m>>>0){break _}g=g+1|0;if((g|0)!=4){continue}}break}if(i){break _}g=0;h=0;i=0;k=0;m=0;while(1){c=d+g&2047;if((c|0)==(b|0)){b=b+1&2047;x[((b<<2)+e|0)+780>>2]=0}Zn(e+768|0,x[(e+784|0)+(c<<2)>>2]);Wd(e+752|0,h,i,k,m,0,0,1342177280,1075633366);Sg(e+736|0,x[e+752>>2],x[e+756>>2],x[e+760>>2],x[e+764>>2],x[e+768>>2],x[e+772>>2],x[e+776>>2],x[e+780>>2]);k=x[e+744>>2];m=x[e+748>>2];h=x[e+736>>2];i=x[e+740>>2];g=g+1|0;if((g|0)!=4){continue}break}lh(e+720|0,w);Wd(e+704|0,h,i,k,m,x[e+720>>2],x[e+724>>2],x[e+728>>2],x[e+732>>2]);k=x[e+712>>2];m=x[e+716>>2];h=0;i=0;l=x[e+704>>2];p=x[e+708>>2];r=z+113|0;g=r-I|0;n=(g|0)<(J|0);c=n?(g|0)>0?g:0:J;if((c|0)<=112){break Z}break X}z=k+z|0;c=b;if((b|0)==(d|0)){continue}break}m=1e9>>>k|0;n=-1<<k^-1;g=0;c=d;while(1){i=g;r=e+784|0;g=r+(d<<2)|0;f=x[g>>2];i=i+(f>>>k|0)|0;x[g>>2]=i;i=!i&(c|0)==(d|0);c=i?c+1&2047:c;o=i?o-9|0:o;g=D(m,f&n);d=d+1&2047;if((d|0)!=(b|0)){continue}break}if(!g){continue}if((c|0)!=(h|0)){x[r+(b<<2)>>2]=g;b=h;continue Y}x[l>>2]=x[l>>2]|1;continue}break}break}mj(e+656|0,pk(1,225-c|0));SK(e+688|0,x[e+656>>2],x[e+660>>2],x[e+664>>2],x[e+668>>2],l,p,k,m);F=x[e+696>>2];H=x[e+700>>2];B=x[e+688>>2];C=x[e+692>>2];mj(e+640|0,pk(1,113-c|0));pR(e+672|0,l,p,k,m,x[e+640>>2],x[e+644>>2],x[e+648>>2],x[e+652>>2]);h=x[e+672>>2];i=x[e+676>>2];t=x[e+680>>2];u=x[e+684>>2];yz(e+624|0,l,p,k,m,h,i,t,u);Sg(e+608|0,B,C,F,H,x[e+624>>2],x[e+628>>2],x[e+632>>2],x[e+636>>2]);k=x[e+616>>2];m=x[e+620>>2];l=x[e+608>>2];p=x[e+612>>2]}o=d+4&2047;aa:{if((o|0)==(b|0)){break aa}o=x[(e+784|0)+(o<<2)>>2];ba:{if(o>>>0<=499999999){if(!o&(d+5&2047)==(b|0)){break ba}mj(e+496|0,+(w|0)*.25);Sg(e+480|0,h,i,t,u,x[e+496>>2],x[e+500>>2],x[e+504>>2],x[e+508>>2]);t=x[e+488>>2];u=x[e+492>>2];h=x[e+480>>2];i=x[e+484>>2];break ba}if((o|0)!=5e8){mj(e+592|0,+(w|0)*.75);Sg(e+576|0,h,i,t,u,x[e+592>>2],x[e+596>>2],x[e+600>>2],x[e+604>>2]);t=x[e+584>>2];u=x[e+588>>2];h=x[e+576>>2];i=x[e+580>>2];break ba}N=+(w|0);if((d+5&2047)==(b|0)){mj(e+528|0,N*.5);Sg(e+512|0,h,i,t,u,x[e+528>>2],x[e+532>>2],x[e+536>>2],x[e+540>>2]);t=x[e+520>>2];u=x[e+524>>2];h=x[e+512>>2];i=x[e+516>>2];break ba}mj(e+560|0,N*.75);Sg(e+544|0,h,i,t,u,x[e+560>>2],x[e+564>>2],x[e+568>>2],x[e+572>>2]);t=x[e+552>>2];u=x[e+556>>2];h=x[e+544>>2];i=x[e+548>>2]}if((c|0)>111){break aa}pR(e+464|0,h,i,t,u,0,0,0,1073676288);if(kn(x[e+464>>2],x[e+468>>2],x[e+472>>2],x[e+476>>2],0,0,0,0)){break aa}Sg(e+448|0,h,i,t,u,0,0,0,1073676288);t=x[e+456>>2];u=x[e+460>>2];h=x[e+448>>2];i=x[e+452>>2]}Sg(e+432|0,l,p,k,m,h,i,t,u);yz(e+416|0,x[e+432>>2],x[e+436>>2],x[e+440>>2],x[e+444>>2],B,C,F,H);k=x[e+424>>2];m=x[e+428>>2];l=x[e+416>>2];p=x[e+420>>2];ca:{if((L-2|0)>=(r&2147483647)){break ca}x[e+408>>2]=k;x[e+412>>2]=m&2147483647;x[e+400>>2]=l;x[e+404>>2]=p;Wd(e+384|0,l,p,k,m,0,0,0,1073610752);d=uV(x[e+400>>2],x[e+404>>2],x[e+408>>2],x[e+412>>2],1081081856);b=(d|0)>=0;k=b?x[e+392>>2]:k;m=b?x[e+396>>2]:m;l=b?x[e+384>>2]:l;p=b?x[e+388>>2]:p;z=b+z|0;if(!(n&((c|0)!=(g|0)|(d|0)<0)&(kn(h,i,t,u,0,0,0,0)|0)!=0)&(z+110|0)<=(L|0)){break ca}x[31612]=68}RK(e+368|0,l,p,k,m,z);h=x[e+376>>2];i=x[e+380>>2];c=x[e+372>>2];b=x[e+368>>2]}x[s+40>>2]=h;x[s+44>>2]=i;x[s+32>>2]=b;x[s+36>>2]=c;fb=e+8976|0;h=x[s+40>>2];i=x[s+44>>2];k=x[s+32>>2];m=x[s+36>>2];break a;case 3:break j;default:break m}}c=x[b+116>>2];if((c|0)>0){c=1}else{c=(c|0)>=0}if(c){x[b+4>>2]=x[b+4>>2]-1}break i}da:{c=x[b+4>>2];ea:{if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;c=y[c|0];break ea}c=sd(b)}if((c|0)==40){g=1;break da}i=2147450880;if(x[b+116>>2]<0){break a}x[b+4>>2]=x[b+4>>2]-1;break a}while(1){c=x[b+4>>2];fa:{if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;c=y[c|0];break fa}c=sd(b)}if(!(!(c-48>>>0<10|c-65>>>0<26|(c|0)==95)&c-97>>>0>=26)){g=g+1|0;continue}break}i=2147450880;if((c|0)==41){break a}c=x[b+116>>2];if((c|0)>=0|(c|0)>0){x[b+4>>2]=x[b+4>>2]-1}ga:{if(d){if(g){break ga}break a}break i}while(1){if((c|0)>0|(c|0)>=0){x[b+4>>2]=x[b+4>>2]-1}g=g-1|0;if(g){continue}break}break a}x[31612]=28;Ii(b,0,0)}i=0}x[a>>2]=k;x[a+4>>2]=m;x[a+8>>2]=h;x[a+12>>2]=i;fb=s+48|0}function ura(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0,J=0;e=fb-416|0;fb=e;xc(b);f=e+411|0;d=zE(b,f);if(!d){hZ(f)}a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{if(!d){break j}if(!iZ(f)){break j}F=1;if((c|0)==64){break j}H=Ge(e+388|0,b);x[31737]=0;d=e+376|0;O(509,d|0,H|0);b=x[31737];x[31737]=0;k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{if((b|0)!=1){x[31737]=0;f=e+356|0;S(510,f|0,d|0,20041);b=x[31737];x[31737]=0;if((b|0)==1){break t}F=0;x[31737]=0;d=R(173,x[e+356>>2])|0;b=x[31737];x[31737]=0;if((b|0)==1){break l}if(!d){break k}x[31737]=0;d=P(511,f|0,e+265|0)|0;b=x[31737];x[31737]=0;if((b|0)==1){break l}if(!d){break k}x[31737]=0;O(247,a|0,16384);b=x[31737];x[31737]=0;if((b|0)==1){break l}x[a+480208>>2]=8;x[31737]=0;d=U(267,a+1074312|0,9,1)|0;b=x[31737];x[31737]=0;if((b|0)==1){break l}x[31737]=0;d=U(267,d|0,114,1)|0;b=x[31737];x[31737]=0;if((b|0)==1){break l}x[31737]=0;d=P(268,d|0,21)|0;b=x[31737];x[31737]=0;if((b|0)==1){break l}x[31737]=0;P(268,d|0,30)|0;b=x[31737];x[31737]=0;if((b|0)==1){break l}x[31737]=0;d=P(1,e+252|0,8280)|0;b=x[31737];x[31737]=0;if((b|0)==1){break q}Ab(a+1298344|0,d);tb(d);x[31737]=0;d=P(1,e+240|0,10767)|0;b=x[31737];x[31737]=0;if((b|0)==1){break p}Ab(a+1298356|0,d);tb(d);x[31737]=0;f=P(1,e+228|0,18160)|0;b=x[31737];x[31737]=0;if((b|0)==1){break o}d=15151;b=y[e+415|0];switch(b-16|0){case 1:break m;case 0:break s;default:break r}}h=N()|0;break a}h=N()|0;break b}d=15132;break m}if(!b){break n}d=22303;break m}h=N()|0;break c}h=N()|0;break c}h=N()|0;break c}d=13338}x[31737]=0;d=P(1,e+216|0,d|0)|0;b=x[31737];x[31737]=0;if((b|0)==1){break e}x[31737]=0;i=e+192|0;S(2,i|0,f|0,d|0);b=x[31737];x[31737]=0;if((b|0)==1){break f}Ab(a+1298368|0,i);tb(i);tb(d);tb(f);I=a+1298404|0,J=x[Fc(i,4)>>2],x[I>>2]=J;d=e+84|0;Ve(d,3,e+265|0);x[31737]=0;O(219,i|0,d|0);b=x[31737];x[31737]=0;if((b|0)==1){break g}Ab(a+1298308|0,i);tb(i);vi(d,3,e+297|0);x[31737]=0;S(370,i|0,4,d|0);b=x[31737];x[31737]=0;if((b|0)==1){break h}Ab(a+1298320|0,i);tb(i);x[a+480200>>2]=y[e+321|0]+1;I=a,J=Kd(y[e+322|0],1,255),x[I+480196>>2]=J;I=a,J=D(Kd(y[e+323|0],4,255),1e4),x[I+480204>>2]=J;d=y[a+484376|0];b=x[a+484360>>2];x[31737]=0;aa(349,Xb(b,d)|0,e+356|0,y[e+317|0]|y[e+318|0]<<8,65535,65535);b=x[31737];x[31737]=0;if((b|0)==1){break l}af(Xb(x[a+484360>>2],y[a+484376|0]),y[e+319|0]|y[e+320|0]<<8);w[a+480188>>1]=0;b=0;while(1){if((b|0)==32){x[31737]=0;g=e+192|0;f=e+376|0;S(510,g|0,f|0,17741);b=x[31737];x[31737]=0;if((b|0)!=1){i=hd(e+356|0,g);ub(g);b=x[i>>2];x[31737]=0;d=R(155,b|0)|0;b=x[31737];x[31737]=0;if((b|0)==1){break l}x[31737]=0;V(337,a+1298332|0,i|0,d|0,0);b=x[31737];x[31737]=0;if((b|0)==1){break l}x[31737]=0;S(510,g|0,f|0,21321);b=x[31737];x[31737]=0;if((b|0)!=1){k=hd(i,g);ub(g);b=x[k>>2];x[31737]=0;d=R(173,b|0)|0;b=x[31737];x[31737]=0;if((b|0)==1){break l}u:{v:{if(d){x[31737]=0;S(510,g|0,f|0,16723);b=x[31737];x[31737]=0;if((b|0)==1){break u}x[31737]=0;g=R(198,k|0)|0;b=x[31737];x[31737]=0;w:{if((b|0)!=1){i=c&2;f=0;while(1){if(g>>>0<=(f&255)>>>0){break w}x[31737]=0;j=R(198,k|0)|0;b=x[31737];x[31737]=0;if((b|0)==1){break v}if(!j){break w}d=x[k+8>>2];b=x[k>>2];x[31737]=0;d=U(151,b|0,d|0,56)|0;b=x[31737];x[31737]=0;if((b|0)==1){break v}if(!d){break w}if(j>>>0>z[a+480190>>1]){w[a+480190>>1]=j}x[31737]=0;o=D(j,104)+a|0;m=o+484380|0;O(280,m|0,0);b=x[31737];x[31737]=0;if((b|0)==1){break v}kp(m);x[31737]=0;S(318,k|0,((j<<5)+a|0)+946304|0,32);b=x[31737];x[31737]=0;if((b|0)==1){break v}x[31737]=0;O(321,k|0,o+484423|0);b=x[31737];x[31737]=0;if((b|0)==1){break v}x:{if(y[e+415|0]<=15){x[31737]=0;h=R(190,k|0)|0;b=x[31737];x[31737]=0;if((b|0)!=1){break x}break v}x[31737]=0;h=R(152,k|0)|0;b=x[31737];x[31737]=0;if((b|0)==1){break v}}x[o+484404>>2]=h<<1;x[31737]=0;d=R(152,k|0)|0;b=x[31737];x[31737]=0;if((b|0)==1){break v}x[m>>2]=d;x[31737]=0;d=R(152,k|0)|0;b=x[31737];x[31737]=0;if((b|0)==1){break v}C=o+484384|0;x[C>>2]=d;x[31737]=0;d=R(152,k|0)|0;b=x[31737];x[31737]=0;if((b|0)==1){break v}E=o+484388|0;x[E>>2]=d;if(d){b=o+484414|0;w[b>>1]=z[b>>1]|2;x[E>>2]=d+x[C>>2]}x[31737]=0;d=R(198,k|0)|0;b=x[31737];x[31737]=0;if((b|0)==1){break v}if(y[e+415|0]<=15){w[o+484410>>1]=d}x[31737]=0;j=R(198,k|0)|0;b=x[31737];x[31737]=0;if((b|0)==1){break v}b=o+484414|0;d=z[b>>1];q=8;if(j&1){d=d|1;w[b>>1]=d;x[m>>2]=x[m>>2]>>>1;x[C>>2]=x[C>>2]>>>1;x[E>>2]=x[E>>2]>>>1;q=16}w[b>>1]=d&65531|j<<1&4;b=Xc(e+84|0,q,1,0,((j&12)!=0)<<3);y:{if(!i){break y}x[31737]=0;U(216,b|0,m|0,e+192|0)|0;b=x[31737];x[31737]=0;if((b|0)!=1){break y}break v}f=f+1|0;continue}}break v}ub(e+192|0)}x[31737]=0;d=e+192|0;f=e+376|0;S(510,d|0,f|0,18761);b=x[31737];x[31737]=0;z:{if((b|0)!=1){n=hd(k,d);ub(d);b=x[n>>2];x[31737]=0;d=R(173,b|0)|0;b=x[31737];x[31737]=0;if((b|0)==1){break l}if(!d){break z}r=Nb(e+84|0);u=Nb(e+180|0);s=Nb(e+168|0);x[31737]=0;S(510,e+148|0,f|0,17750);b=x[31737];x[31737]=0;A:{if((b|0)==1){break A}b=x[e+160>>2];x[e+56>>2]=x[e+156>>2];x[e+60>>2]=b;x[e- -64>>2]=x[e+164>>2];x[31737]=0;b=x[e+152>>2];x[e+48>>2]=x[e+148>>2];x[e+52>>2]=b;O(512,e+48|0,r|0);b=x[31737];x[31737]=0;if((b|0)==1){break A}x[31737]=0;S(510,e+128|0,f|0,17744);b=x[31737];x[31737]=0;if((b|0)==1){break A}b=x[e+140>>2];x[e+32>>2]=x[e+136>>2];x[e+36>>2]=b;x[e+40>>2]=x[e+144>>2];x[31737]=0;b=x[e+132>>2];x[e+24>>2]=x[e+128>>2];x[e+28>>2]=b;O(512,e+24|0,u|0);b=x[31737];x[31737]=0;if((b|0)==1){break A}x[31737]=0;S(510,e+108|0,f|0,17734);b=x[31737];x[31737]=0;if((b|0)==1){break A}b=x[e+120>>2];x[e+8>>2]=x[e+116>>2];x[e+12>>2]=b;x[e+16>>2]=x[e+124>>2];x[31737]=0;b=x[e+112>>2];x[e>>2]=x[e+108>>2];x[e+4>>2]=b;O(512,e|0,s|0);b=x[31737];x[31737]=0;if((b|0)==1){break A}x[31737]=0;o=R(198,n|0)|0;b=x[31737];x[31737]=0;if((b|0)==1){break A}q=0;while(1){if(o>>>0<=(q&255)>>>0){bp(s);bp(u);bp(r);break z}x[31737]=0;d=e+72|0;O(199,d|0,n|0);b=x[31737];x[31737]=0;B:{if((b|0)!=1){F=Jc(d);C:{D:{if(!y[e+72|0]){break D}f=x[n+8>>2];d=x[n>>2];b=y[F|0];x[31737]=0;d=U(151,d|0,f|0,D(b,14)+32|0)|0;b=x[31737];x[31737]=0;if((b|0)==1){break A}if(!d){break D}x[31737]=0;l=U(252,a|0,y[e+72|0],0)|0;b=x[31737];x[31737]=0;if((b|0)==1){break A}if(l){break C}}b=y[F|0];x[31737]=0;P(184,n|0,D(b,14)+32|0)|0;b=x[31737];x[31737]=0;if((b|0)!=1){break B}break A}x[31737]=0;S(318,n|0,l+492|0,32);b=x[31737];x[31737]=0;if((b|0)==1){break A}m=l+88|0;C=l+68|0;E=l+48|0;j=l+236|0;b=0;f=0;while(1){if(y[F|0]<=(f&255)>>>0){break B}x[31737]=0;O(513,n|0,e+192|0);d=x[31737];x[31737]=0;if((d|0)==1){break A}d=y[e+192|0];E:{if(!d|d>>>0>z[a+480190>>1]){break E}if(y[e+193|0]>=129){v[e+193|0]=128}while(1){i=b&255;g=y[e+193|0];if(i>>>0>g>>>0){d=x[r+4>>2];b=x[r>>2];x[31737]=0;V(514,E|0,y[e+195|0],b|0,d|0);b=x[31737];x[31737]=0;if((b|0)==1){break A}d=x[u+4>>2];b=x[u>>2];x[31737]=0;V(514,C|0,y[e+197|0],b|0,d|0);b=x[31737];x[31737]=0;if((b|0)==1){break A}d=x[s+4>>2];b=x[s>>2];x[31737]=0;V(514,m|0,y[e+205|0],b|0,d|0);b=x[31737];x[31737]=0;if((b|0)==1){break A}x[l>>2]=(y[e+198|0]|y[e+199|0]<<8)+1>>>1;d=y[e+192|0];F:{if(y[e+195|0]&64){w[(D(d,104)+a|0)+484410>>1]=y[e+194|0];break F}b=(D(d,104)+a|0)+484414|0;w[b>>1]=z[b>>1]|32768}w[e+106>>1]=y[e+196|0]<<1;w[e+104>>1]=254;t=D(d,104)+a|0;I=t+484408|0,J=z[Nc(e+106|0,e+104|0)>>1],w[I>>1]=J;v[t+484418|0]=y[(y[e+203|0]&3)+25076|0];d=t+484419|0;k=y[e+202|0];v[d|0]=k;i=y[e+201|0]+3>>>2|0;v[t+484420|0]=i;v[t+484421|0]=y[e+200|0];b=g+1|0;if(k){i=yi(Bc(((i<<8|k>>>1)>>>0)/(k>>>0)|0,0))}else{i=255}v[d|0]=i;if(!(y[e+197|0]&64)){break E}d=t+484414|0;w[d>>1]=z[d>>1]|32}else{d=y[e+192|0];I=_b(j,i),J=d,w[I>>1]=J;b=b+1|0;continue}break}}f=f+1|0;continue}}break A}q=q+1|0;continue}}h=N()|0;bp(s);bp(u);bp(r);break c}h=N()|0;break c}F=1;G=Nb(e+180|0);G:{if(!(c&1)){break G}x[31737]=0;d=e+192|0;S(510,d|0,e+376|0,21076);b=x[31737];x[31737]=0;H:{I:{J:{K:{L:{M:{if((b|0)!=1){g=hd(n,d);b=x[g>>2];x[31737]=0;c=R(173,b|0)|0;b=x[31737];x[31737]=0;N:{O:{P:{if((b|0)!=1){ub(d);if(!c){break N}x[31737]=0;d=R(190,g|0)|0;c=x[31737];x[31737]=0;b=1;if((c|0)==1){break P}x[31737]=0;f=d+1|0;O(515,G|0,f|0);c=x[31737];x[31737]=0;if((c|0)==1){break P}while(1){if((b|0)==(f|0)){break N}x[31737]=0;d=R(190,g|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break O}x[31737]=0;i=e+84|0;S(186,i|0,g|0,d|0);c=x[31737];x[31737]=0;if((c|0)==1){break O}c=ic(e+192|0,i);hd(dh(x[G>>2],b),c);ub(c);b=b+1|0;ub(i);continue}}h=N()|0;ub(e+192|0);break H}h=N()|0;break H}h=N()|0;break H}x[31737]=0;d=e+192|0;S(510,d|0,e+376|0,16720);b=x[31737];x[31737]=0;if((b|0)==1){break J}B=hd(g,d);b=x[B>>2];x[31737]=0;c=R(173,b|0)|0;b=x[31737];x[31737]=0;if((b|0)==1){break K}ub(d);if(!c){break M}x[31737]=0;k=R(198,B|0)|0;b=x[31737];x[31737]=0;if((b|0)==1){break I}l=0;Q:{R:{S:while(1){T:{if(k>>>0<=(l&65535)>>>0){x[31737]=0;P(150,B|0,1)|0;b=x[31737];x[31737]=0;if((b|0)!=1){break T}break I}f=32;U:{if(y[e+415|0]<16){break U}x[31737]=0;O(516,B|0,e+192|0);b=x[31737];x[31737]=0;if((b|0)==1){break Q}f=y[e+192|0];if(f>>>0<=z[a+480188>>1]|f>>>0>32){break U}w[a+480188>>1]=f}b=0;while(1){i=b&65535;if(i>>>0>=f>>>0){l=l+1|0;continue S}x[31737]=0;d=R(190,B|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break R}if(!(!d|i>>>0>31|i>>>0<z[a+480188>>1])){w[a+480188>>1]=b+1}b=b+1|0;continue}}break}x[31737]=0;r=a+484344|0;O(224,r|0,k|0);b=x[31737];x[31737]=0;if((b|0)==1){break I}C=e+194|0;n=0;while(1){if((k|0)==(n|0)){break M}u=Fb(e+84|0);V:{if(y[e+415|0]<16){c=32;i=64;break V}x[31737]=0;O(516,B|0,e+192|0);b=x[31737];x[31737]=0;if((b|0)==1){break L}d=y[e+193|0];c=y[e+192|0];b=e+72|0;cf(b,C,16,3);x[31737]=0;f=e+168|0;O(219,f|0,b|0);b=x[31737];x[31737]=0;if((b|0)==1){break L}Ab(u,f);tb(f);i=d+1|0}x[31737]=0;d=U(197,r|0,n&65535,i|0)|0;b=x[31737];x[31737]=0;if((b|0)==1){break L}W:{if(!d){x[31737]=0;P(184,B|0,c<<1)|0;b=x[31737];x[31737]=0;if((b|0)!=1){break W}break L}b=x[r>>2];x[31737]=0;O(284,Wb(b,n)|0,u|0);b=x[31737];x[31737]=0;if((b|0)==1){break L}E=i-1|0;o=0;while(1){s=o&65535;if(s>>>0>=c>>>0){break W}x[31737]=0;d=R(190,B|0)|0;b=x[31737];x[31737]=0;X:{if((b|0)!=1){if(!d){break X}b=x[G>>2];if(Uf(b,x[G+4>>2])>>>0<=d>>>0|s>>>0>=z[a+480188>>1]){break X}A=dh(b,d);xc(A);f=0;Y:while(1){d=f;if(i>>>0<=d>>>0){break X}g=x[A+8>>2];b=x[A>>2];x[31737]=0;g=U(151,b|0,g|0,1)|0;b=x[31737];x[31737]=0;Z:{_:{$:{aa:{ba:{if((b|0)!=1){if(!g){break X}b=Wb(x[r>>2],n);b=jd(x[b>>2],x[x[b+48>>2]+12>>2],d,s);x[31737]=0;g=R(198,A|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break L}m=g<<24>>24;h=(m&252)>>>2|0;switch((m&3)-1|0){case 2:break _;case 1:break $;case 0:break aa;default:break ba}}break L}f=(d+h|0)+1|0;continue}f=0;if(!d){continue}f=Wb(x[r>>2],n);j=jd(x[f>>2],x[x[f+48>>2]+12>>2],d-1|0,s);while(1){f=y[j|0]|y[j+1|0]<<8|(y[j+2|0]<<16|y[j+3|0]<<24);v[b|0]=f;v[b+1|0]=f>>>8;v[b+2|0]=f>>>16;v[b+3|0]=f>>>24;f=y[j+4|0]|y[j+5|0]<<8;v[b+4|0]=f;v[b+5|0]=f>>>8;f=d+1|0;if((d|0)==(E|0)){continue Y}b=D(z[a+480188>>1],6)+b|0;g=h&255;d=f;h=h-1|0;if(g){continue}break}continue}if(d>>>0<=h>>>0){break Z}f=Wb(x[r>>2],n);g=jd(x[f>>2],x[x[f+48>>2]+12>>2],h,s);f=y[g|0]|y[g+1|0]<<8|(y[g+2|0]<<16|y[g+3|0]<<24);v[b|0]=f;v[b+1|0]=f>>>8;v[b+2|0]=f>>>16;v[b+3|0]=f>>>24;f=y[g+4|0]|y[g+5|0]<<8;v[b+4|0]=f;v[b+5|0]=f>>>8;break Z}if(h&1){x[31737]=0;g=R(198,A|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break L}v[b|0]=g>>>0>120?-1:g}if(h&2){x[31737]=0;g=R(198,A|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break L}v[b+1|0]=g}l=0;f=0;ca:{if(h&4){x[31737]=0;f=R(198,A|0)|0;g=x[31737];x[31737]=0;if((g|0)==1){break ca}}t=0;if(h&8){x[31737]=0;j=R(198,A|0)|0;g=x[31737];x[31737]=0;if((g|0)==1){break ca}l=j&15;t=j>>>4|0}q=0;j=0;if(h&16){x[31737]=0;j=R(198,A|0)|0;g=x[31737];x[31737]=0;if((g|0)==1){break ca}}if((m|0)<0){x[31737]=0;q=R(198,A|0)|0;g=x[31737];x[31737]=0;if((g|0)==1){break ca}}h=fb-16|0;fb=h;g=h+14|0;fZ(g,l,j);l=Jc(g);g=h+12|0;fZ(g,((t-1&255)>>>0<6?t+15|0:t)&255,q);m=Jc(g);da:{ea:{fa:{if(y[h+14|0]==10){j=y[m|0];g=y[l|0]&15;v[l|0]=g?-1:j;q=j|g<<8;g=y[h+12|0];if((g|0)!=10){break fa}g=0;v[h+12|0]=0;break fa}if(y[h+12|0]!=10){break ea}g=y[m|0]&15;v[m|0]=g?-1:0;q=g<<8;g=y[h+14|0]}if(q-256>>>0>4294967038){break ea}if(xi(g)>>>0>=xi(10)>>>0){break ea}v[b+5|0]=q;v[b+2|0]=15;v[b+3|0]=10;v[b+4|0]=q>>>8;break da}if(f){v[b+2|0]=1;v[b+4|0]=f+2>>>2}GE(h+14|0,l,h+12|0,m);j=y[h+14|0];g=y[h+12|0];if((j|0)==20|(g|0)!=(j|0)?j:0){if(!g){v[b+5|0]=y[l|0];v[b+3|0]=j;break da}if(!f){mm(h+10|0,b,j,y[l|0],g,y[m|0]);break da}if(xi(j)>>>0>xi(g)>>>0){v[b+5|0]=y[l|0];v[b+3|0]=j;break da}}v[b+5|0]=y[m|0];v[b+3|0]=g}fb=h+16|0;break Z}break L}f=d+1|0;continue}}break L}o=o+1|0;continue}}tb(u);n=n+1|0;continue}}h=N()|0;break H}h=N()|0;break H}h=N()|0;break H}x[31737]=0;d=e+192|0;S(510,d|0,e+376|0,20048);b=x[31737];x[31737]=0;ga:{ha:{if((b|0)!=1){f=hd(B,d);b=x[f>>2];x[31737]=0;c=R(173,b|0)|0;b=x[31737];x[31737]=0;if((b|0)==1){break ha}ub(d);if(!c){break G}while(1){if(!ck(x[a+484344>>2],x[a+484348>>2])){break G}c=x[f+8>>2];b=x[f>>2];x[31737]=0;c=U(151,b|0,c|0,16)|0;b=x[31737];x[31737]=0;if((b|0)==1){break ga}if(!c){break G}x[31737]=0;c=e+192|0;O(395,f|0,c|0);b=x[31737];x[31737]=0;if((b|0)!=1){b=x[a+484344>>2];x[31737]=0;O(396,Wb(b,0)|0,c|0);b=x[31737];x[31737]=0;if((b|0)!=1){continue}}break}h=N()|0;break H}h=N()|0;break H}h=N()|0;ub(e+192|0);break H}h=N()|0;break H}h=N()|0;tb(u);break H}h=N()|0;ub(e+192|0);break H}h=N()|0;break H}h=N()|0}Qc(G);break c}Qc(G);break k}h=N()|0;ub(e+192|0);break c}h=N()|0;break c}h=N()|0;break c}h=N()|0;break c}g=(b<<5)+a|0;i=g+480280|0;We(i);f=v[(b+e|0)+324|0];d=f<<1&254;w[g+480284>>1]=(d|0)==254?256:d;ia:{if((f|0)<0){x[i>>2]=x[i>>2]|1024;break ia}w[a+480188>>1]=b+1}x[31737]=0;O(517,e+356|0,g+480289|0);d=x[31737];x[31737]=0;if((d|0)==1){break i}b=b+1|0;continue}}h=N()|0;break c}ub(e+356|0);ie(e+376|0);ub(H)}fb=e+416|0;return F|0}h=N()|0;break c}h=N()|0;break c}h=N()|0;break c}h=N()|0;tb(d);break d}h=N()|0}tb(f)}ub(e+356|0)}ie(e+376|0)}ub(H);Q(h|0);p()}function xta(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0,F=0,G=0,H=0;e=fb-240|0;fb=e;xc(b);f=fb-16|0;fb=f;g=e+218|0;Zv(f+8|0,g);h=x[f+12>>2];lc(f,x[b>>2],x[b+8>>2],x[f+8>>2],x[f+12>>2]);k=x[f+4>>2];if((k|0)==(h|0)){Vb(b,x[f+12>>2])}fb=f+16|0;f=(h|0)==(k|0);if(!f){a$(g)}a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if(!f){break n}if(!b$(g)){break n}d=1;if((c|0)==64){break n}Bd(a,1024);gg(a);x[a+480208>>2]=x[a+480208>>2]|12;dg(a+1074312|0,21);d=Bb(y[e+234|0]|y[e+235|0]<<8);if(d){x[a+480204>>2]=D(d,1e4)}d=Bb(y[e+232|0]|y[e+233|0]<<8);if(d){x[a+480196>>2]=d}if(!y[e+228|0]){Xh(a,1)}wE(b,a+1298308|0,$b(y[e+222|0]|y[e+223|0]<<8|(y[e+224|0]<<16|y[e+225|0]<<24))-14|0);d=e+112|0;b=Ge(d,b);x[31737]=0;f=e+204|0;O(347,f|0,b|0);g=x[31737];x[31737]=0;o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{if((g|0)!=1){ub(b);x[31737]=0;S(348,d|0,f|0,1395544366);b=x[31737];x[31737]=0;if((b|0)==1){break s}x[31737]=0;b=R(278,x[e+112>>2])|0;f=x[31737];x[31737]=0;if((f|0)==1){break y}if(!b){break r}x[31737]=0;b=R(274,d|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break y}x[31737]=0;f=R(274,d|0)|0;g=x[31737];x[31737]=0;A:{if((g|0)==1){break A}x[31737]=0;P(184,d|0,4)|0;g=x[31737];x[31737]=0;if((g|0)==1){break A}g=y[a+484376|0];h=x[a+484360>>2];x[31737]=0;aa(349,Xb(h,g)|0,d|0,b|0,65535,65535);b=x[31737];x[31737]=0;if((b|0)!=1){break z}}break y}d=N()|0;ub(b);break a}af(Xb(x[a+484360>>2],y[a+484376|0]),f);f=e+112|0;ub(f);x[31737]=0;S(348,f|0,e+204|0,1346458708);b=x[31737];x[31737]=0;if((b|0)==1){break x}x[31737]=0;g=R(278,x[e+112>>2])|0;b=x[31737];x[31737]=0;if((b|0)==1){break w}d=0;b=0;if(!g){break t}x[31737]=0;g=R(274,f|0)|0;h=x[31737];x[31737]=0;if((h|0)==1){break w}w[a+480188>>1]=g;if((g-33&65535)>>>0<65504){break t}x[31737]=0;b=R(274,f|0)|0;m=x[31737];x[31737]=0;if((m|0)==1){break w}x[31737]=0;O(224,a+484344|0,b|0);b=x[31737];x[31737]=0;if((b|0)==1){break w}b=0;x[31737]=0;m=R(282,f|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break w}switch(m-841887796|0){case 1:break t;case 0:case 2:break u;default:break v}}d=N()|0;ub(e+112|0);break b}d=N()|0;break b}d=N()|0;ub(e+112|0);break b}if(m){break t}}b=1}f=e+112|0;ub(f);if(!b){break o}x[31737]=0;d=e+184|0;S(348,d|0,e+204|0,1398157625);b=x[31737];x[31737]=0;if((b|0)==1){break d}x[31737]=0;b=R(278,x[e+184>>2])|0;g=x[31737];x[31737]=0;if((g|0)==1){break c}if(!b){break q}x[31737]=0;P(184,d|0,2)|0;b=x[31737];x[31737]=0;if((b|0)==1){break c}x[31737]=0;b=R(282,d|0)|0;g=x[31737];x[31737]=0;if((g|0)==1){break c}G=a,H=Ze((+(b>>>0)*2.3283064365386963e-10+ +(A[a+480204>>2]/1e4>>>0))*1e4),x[G+480204>>2]=H;b=0;x[31737]=0;P(350,d|0,f|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break c}f=z[a+480188>>1];while(1){if((b|0)!=32&(b|0)!=(f|0)){G=e,H=Bb(z[(e+112|0)+(b<<1)>>1]),x[G+48>>2]=H;x[e+32>>2]=180;d=x[ud(e+48|0,e+32|0)>>2];h=d>>31<<7|d>>>25;d=d<<7;G=((b<<5)+a|0)+480284|0,H=Gc(Tua(d-11475|0,h-(d>>>0<11475)|0,90,0),hb)+128|0,w[G>>1]=H;b=b+1|0;continue}else{B:{x[31737]=0;P(184,e+184|0,16)|0;b=x[31737];x[31737]=0;if((b|0)!=1){break B}break c}}break}x[31737]=0;b=U(151,x[e+184>>2],x[e+192>>2],2)|0;d=x[31737];x[31737]=0;if((d|0)==1){break c}C:{if(b){x[31737]=0;b=R(274,e+184|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break C}w[e+48>>1]=b;w[e+32>>1]=256;G=a,H=z[Nc(e+48|0,e+32|0)>>1],x[G+480200>>2]=H}x[31737]=0;b=e+184|0;P(184,b|0,128)|0;d=x[31737];x[31737]=0;if((d|0)==1){break c}x[31737]=0;b=P(350,b|0,e+48|0)|0;d=x[31737];x[31737]=0;if((d|0)!=1){if(!b){break q}d=z[a+480188>>1];b=0;while(1)if((b|0)!=32&(b|0)!=(d|0)){G=e,H=Bb(z[(e+48|0)+(b<<1)>>1]),x[G+32>>2]=H;x[e+20>>2]=128;G=((b<<5)+a|0)+480286|0,H=x[ud(e+32|0,e+20|0)>>2]/2&255,w[G>>1]=H;b=b+1|0;continue}else{x[a+480228>>2]=x[a+480228>>2]<<1;break q}}break c}break c}d=N()|0;break b}ub(e+112|0);break p}ub(e+184|0);x[31737]=0;b=e+112|0;S(348,b|0,e+204|0,1413830740);d=x[31737];x[31737]=0;D:{E:{if((d|0)!=1){x[31737]=0;d=R(278,x[e+112>>2])|0;f=x[31737];x[31737]=0;if((f|0)==1){break e}if(!d){break D}x[31737]=0;O(351,b|0,e+48|0);d=x[31737];x[31737]=0;if((d|0)==1){break e}if((Bb(y[e+58|0]|y[e+59|0]<<8)|0)!=65535){break E}x[31737]=0;P(184,b|0,1)|0;b=x[31737];x[31737]=0;if((b|0)!=1){break E}break e}d=N()|0;break b}x[31737]=0;b=e+112|0;d=R(203,b|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break e}x[31737]=0;V(337,a+1298332|0,b|0,d|0,2);b=x[31737];x[31737]=0;if((b|0)==1){break e}}ub(e+112|0);x[31737]=0;b=e+48|0;S(348,b|0,e+204|0,1229869908);d=x[31737];x[31737]=0;if((d|0)==1){break h}x[31737]=0;d=R(278,x[e+48>>2])|0;f=x[31737];x[31737]=0;if((f|0)==1){break l}F:{if(!d){break F}x[31737]=0;b=R(274,b|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break i}G:{H:{b=b<<16>>16;f=b&32767;if(f>>>0>3999){break H}x[31737]=0;d=U(151,x[e+48>>2],x[e+56>>2],D(f,(b>>>14&2)+50|0)|0)|0;g=x[31737];x[31737]=0;if((g|0)==1){break g}if(!d){break H}w[a+480190>>1]=f;g=a+480190|0;h=e+130|0;k=(b|0)>=0;b=1;I:{J:{K:{L:{while(1){if(f>>>0<(b&65535)>>>0){x[31737]=0;b=R(274,e+48|0)|0;d=x[31737];x[31737]=0;if((d|0)!=1){break I}break g}M:{if(k){j=b}else{x[31737]=0;d=R(274,e+48|0)|0;i=x[31737];x[31737]=0;if((i|0)==1){break M}j=d+1|0}w[e+20>>1]=j;x[31737]=0;d=e+112|0;O(352,e+48|0,d|0);i=x[31737];x[31737]=0;if((i|0)==1){break L}i=z[e+20>>1];if((i-4e3&65535)>>>0>=61537){G=a,H=z[pe(g,e+20|0)>>1],w[G+480190>>1]=H;l=y[e+236|0]|y[e+237|0]<<8|(y[e+238|0]<<16|y[e+239|0]<<24);x[31737]=0;V(353,d|0,(D(i,104)+a|0)+484380|0,$b(l)|0,m|0);d=x[31737];x[31737]=0;if((d|0)==1){break K}i=e+32|0;Xk(i,2,h);x[31737]=0;d=e+184|0;O(219,d|0,i|0);i=x[31737];x[31737]=0;if((i|0)==1){break J}zc(((z[e+20>>1]<<5)+a|0)+946304|0,d);tb(d)}b=b+1|0;continue}break}d=N()|0;break f}d=N()|0;break f}d=N()|0;break f}d=N()|0;break f}if((b|0)!=4){break F}w[e+112>>1]=z[a+480190>>1];w[e+184>>1]=255;b=e+184|0;G=a,H=z[Nc(e+112|0,b)>>1],w[G+480192>>1]=H;x[31737]=0;S(348,b|0,e+204|0,1229278806);b=x[31737];x[31737]=0;if((b|0)==1){break j}N:while(1){O:{x[31737]=0;b=U(151,x[e+48>>2],x[e+56>>2],15)|0;d=x[31737];x[31737]=0;if((d|0)==1){break O}if(!b){break G}x[31737]=0;O(354,e+48|0,e+32|0);b=x[31737];x[31737]=0;if((b|0)==1){break k}b=Bb(z[e+32>>1]);if(b>>>0>=z[a+480192>>1]){continue}d=D(b,104)+a|0;v[d+484524|0]=y[e+40|0];f=y[e+39|0];v[d+484523|0]=255;v[d+484525|0]=f;x[31737]=0;b=b+1&65535;d=U(252,a|0,b|0,b|0)|0;b=x[31737];x[31737]=0;if((b|0)==1){break k}if(!d){continue}G=e,H=Bb(y[e+37|0]|y[e+38|0]<<8),w[G+112>>1]=H;w[e+20>>1]=4095;b=e+112|0;f=e+20|0;G=d,H=z[Nc(b,f)>>1],x[G>>2]=H;g=y[e+35|0];if((g|0)==255){continue}x[31737]=0;h=e+184|0;g=P(150,h|0,D(g,34)+2|0)|0;k=x[31737];x[31737]=0;if((k|0)==1){break k}if(!g){continue}x[31737]=0;O(355,h|0,b|0);b=x[31737];x[31737]=0;if((b|0)==1){break k}v[d+60|0]=y[d+60|0]|1;b=z[e+112>>1];x[e+24>>2]=16;x[e+28>>2]=240;G=e,H=Bb(b),x[G+20>>2]=H;b=sE(f);x[31737]=0;O(294,d+48|0,b|0);b=x[31737];x[31737]=0;if((b|0)==1){break k}b=0;f=x[d+48>>2];h=x[d+52>>2];g=Sd(f,h);while(1)if(b>>>0>=g>>>0){b=y[e+36|0];if((b|0)!=255){v[d- -64|0]=b;v[d+63|0]=b;v[d+60|0]=y[d+60|0]|4}if(mc(f,h)){continue N}b=g-1|0;v[d+62|0]=b;v[d+61|0]=b;v[d+60|0]=y[d+60|0]|2;continue N}else{v[e+20|0]=64;k=(e+112|0)+(b<<1)|0;v[e+16|0]=y[k+2|0];i=Qb(e+20|0,e+16|0);l=yb(f,b);v[l+2|0]=y[i|0];w[l>>1]=y[k+3|0];b=b+1|0;continue}}break}break k}ub(e+48|0);break p}ub(e+184|0)}b=e+48|0;ub(b);x[31737]=0;S(356,e+184|0,e+204|0,1145131092);d=x[31737];x[31737]=0;if((d|0)==1){break m}G=e,H=wb(x[e+184>>2]),x[G+20>>2]=H;k=a+484344|0;t=c&1;q=b|4;u=wb(x[e+188>>2]);r=(m|0)!=841887798;B=(m|0)!=841887796;while(1){P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{f=x[e+20>>2];if(!Ib(f,u)){Qc(e+184|0);x[31737]=0;S(348,e+112|0,e+204|0,1346458702);b=x[31737];x[31737]=0;if((b|0)!=1){break aa}d=N()|0;break b}x[31737]=0;P(184,f|0,4)|0;b=x[31737];x[31737]=0;if((b|0)!=1){x[31737]=0;i=R(274,f|0)|0;b=x[31737];x[31737]=0;ba:{if((b|0)!=1){x[31737]=0;l=R(274,f|0)|0;b=x[31737];x[31737]=0;if((b|0)==1){break R}l=r?l:(l>>>0)/A[a+480196>>2]|0;if(!t|i>>>0>255){break P}x[31737]=0;b=U(197,k|0,i|0,l|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break R}if(b){break ba}break P}d=N()|0;break Q}if(!r){o=0;x[31737]=0;P(184,f|0,4)|0;b=x[31737];x[31737]=0;if((b|0)==1){break R}while(1){s=o&65535;if(s>>>0>=z[a+480188>>1]){break P}x[31737]=0;b=R(274,f|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break $}x[31737]=0;d=e+48|0;S(186,d|0,f|0,b+(b&1)&65535);b=x[31737];x[31737]=0;if((b|0)==1){break S}g=ic(e+112|0,d);ub(d);x[e+48>>2]=0;x[e+52>>2]=0;d=0;ca:{while(1){b=x[g>>2];x[31737]=0;b=U(151,b|0,x[e+120>>2],6)|0;h=x[31737];x[31737]=0;if((h|0)==1){break ca}j=b;b=x[e+48>>2];if(j&b>>>0<l>>>0){h=Wb(x[k>>2],i);b=jd(x[h>>2],x[x[h+48>>2]+12>>2],b,s);x[31737]=0;h=e+32|0;O(357,h|0,g|0);j=x[31737];x[31737]=0;da:{ea:{if((j|0)!=1){j=Jc(h);C=$e(h);E=dj(h);F=ec(h);n=v[e+32|0];if((n-1&255)>>>0>95){break ea}v[b|0]=n+13;if(!x[e+52>>2]){break da}v[b+3|0]=19;x[e+16>>2]=15;G=b,H=y[ud(q,e+16|0)|0]|208,v[G+5|0]=H;break da}break T}if((n|0)>=0){break da}if(x[e+52>>2]){v[b+3|0]=19;x[e+16>>2]=15;G=b,H=y[ud(q,e+16|0)|0]|192,v[G+5|0]=H;break da}v[b|0]=254}if(y[j|0]){v[b+2|0]=1;v[e+16|0]=64;G=b,H=y[Qb(j,e+16|0)|0],v[G+4|0]=H}j=y[C|0];if(j){v[b+1|0]=j}j=y[E|0];n=y[F|0];if(j|n){Bf(b,j,n)}h=v[h+5|0];b=h&255;j=e+48|0;if((h|0)<0){x[31737]=0;h=R(198,g|0)|0;n=x[31737];x[31737]=0;if((n|0)==1){break T}b=h|b<<8&32512}d=b+d|0;dE(j,d,x[a+480196>>2]);continue}break}ub(g);o=o+1|0;continue}break}break T}b=Wb(x[k>>2],i);G=e,H=wb(x[b>>2]),x[G+48>>2]=H;l=wb(x[b+4>>2]);while(1){b=x[e+48>>2];if(!Ib(b,l)){break P}x[31737]=0;O(358,e+32|0,f|0);d=x[31737];x[31737]=0;if((d|0)!=1){v[e+15|0]=0;fa:{if(!B){d=x[e+32>>2];x[e+112>>2]=d;g=e+112|0;h=Jc(g);i=$e(g);g=dj(g);if(d<<24>>24>0){v[b|0]=(D((d&240)>>>4|0,12)+(d&15)|0)+12}d=y[h|0];if(d>>>0>=4){v[b+2|0]=1;v[b+4|0]=(d>>>2|0)-1;d=y[h|0]}v[b+1|0]=d<<4&48|y[i|0]>>>4;d=y[i|0]&15;v[e+15|0]=d;g=y[g|0];v[b+5|0]=g;break fa}d=x[e+32>>2];x[e+8>>2]=d;x[e+4>>2]=d;d=e+16|0;ip(d,e+4|0,b);g=e+112|0;VD(g,e+15|0,b+5|0);UD(g,d);d=xb(e+32|0,0);v[b+1|0]=y[b+1|0]|y[d|0]&48;g=y[b+5|0];d=y[e+15|0]}Bf(b,d&255,g);d=y[b+3|0];ga:{if(d>>>0>11){break ga}d=1<<d;ha:{if(!(d&2240)){if(!(d&12)){break ga}if(!y[b+5|0]){break ha}break ga}d=y[b+5|0];g=d&240;if(g){v[b+5|0]=g;break ga}if(d){break ga}}v[b+3|0]=0}vg(e+48|0);continue}break}d=N()|0;break Q}d=N()|0;break Q}x[31737]=0;b=R(278,x[e+112>>2])|0;d=x[31737];x[31737]=0;ia:{ja:{ka:{la:{ma:{if((d|0)!=1){if(b){f=Fb(e+48|0);b=0;na:{while(1){oa:{x[31737]=0;d=U(151,x[e+112>>2],x[e+120>>2],1)|0;g=x[31737];x[31737]=0;if((g|0)==1){break oa}if(!d){break na}if(ck(x[a+484344>>2],x[a+484348>>2])>>>0<=b>>>0){break na}x[31737]=0;S(359,e+112|0,f|0,32);d=x[31737];x[31737]=0;if((d|0)==1){break oa}d=x[k>>2];x[31737]=0;O(284,Wb(d,b)|0,f|0);d=x[31737];x[31737]=0;if((d|0)==1){break oa}b=b+1|0;continue}break}d=N()|0;tb(f);break ma}tb(f)}b=e+112|0;ub(b);x[31737]=0;S(348,b|0,e+204|0,1414679374);b=x[31737];x[31737]=0;if((b|0)==1){break la}x[31737]=0;b=R(278,x[e+112>>2])|0;d=x[31737];x[31737]=0;if((d|0)==1){break V}if(!b){break ia}f=Fb(e+48|0);b=0;while(1){x[31737]=0;d=U(151,x[e+112>>2],x[e+120>>2],1)|0;g=x[31737];x[31737]=0;if((g|0)==1){break ka}if(!(z[a+480188>>1]>b>>>0&d)){break ja}x[31737]=0;S(359,e+112|0,f|0,32);d=x[31737];x[31737]=0;if((d|0)==1){break ka}om(((b<<5)+a|0)+480289|0,f);b=b+1|0;continue}}d=N()|0}ub(e+112|0);break b}d=N()|0;break b}d=N()|0;tb(f);break U}tb(f)}b=e+112|0;ub(b);x[31737]=0;S(356,b|0,e+204|0,1145129300);b=x[31737];x[31737]=0;if((b|0)==1){break W}G=e,H=wb(x[e+112>>2]),x[G+48>>2]=H;d=c&2;f=wb(x[e+116>>2]);pa:{qa:{ra:{sa:{ta:{ua:{while(1){b=x[e+48>>2];if(!Ib(b,f)){c=e+112|0;Qc(c);b=Fb(e+48|0);if((m|0)!=841887798){break ta}x[31737]=0;c=P(1,c|0,9506)|0;d=x[31737];x[31737]=0;if((d|0)==1){break ua}Ab(b,c);tb(c);break sa}x[31737]=0;c=R(274,b|0)|0;g=x[31737];x[31737]=0;if((g|0)==1){break X}va:{if(!(!d|c>>>0>=z[a+480190>>1])){c=D(c,104)+a|0;g=z[c+484518>>1];g=Xc(e+184|0,g&1?16:8,g&64?2:1,1,0);x[31737]=0;U(216,g|0,c+484484|0,b|0)|0;b=x[31737];x[31737]=0;if((b|0)==1){break va}}Sf(e+48|0);continue}break}break X}d=N()|0;break Y}x[31737]=0;c=e+112|0;S(348,c|0,e+204|0,1447383635);d=x[31737];x[31737]=0;wa:{xa:{ya:{za:{Aa:{if((d|0)!=1){x[31737]=0;d=R(278,x[e+112>>2])|0;f=x[31737];x[31737]=0;if((f|0)==1){break ra}if(!d){break xa}x[31737]=0;c=R(282,c|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break Aa}x[31737]=0;d=e+32|0;O(269,d|0,4292);f=x[31737];x[31737]=0;if((f|0)==1){break za}x[e+20>>2]=c>>>4;x[31737]=0;x[e+16>>2]=c&15;c=e+184|0;V(360,c|0,d|0,e+20|0,e+16|0);f=x[31737];x[31737]=0;if((f|0)==1){break ya}Ab(b,c);tb(c);Eb(d);break wa}d=N()|0;break Y}d=N()|0;break Z}d=N()|0;break Z}d=N()|0;Eb(e+32|0);break Z}x[31737]=0;c=P(1,e+184|0,8509)|0;d=x[31737];x[31737]=0;if((d|0)==1){break _}Ab(b,c);tb(c)}ub(e+112|0)}x[31737]=0;c=P(1,e+32|0,8509)|0;d=x[31737];x[31737]=0;if((d|0)==1){break qa}Ab(a+1298344|0,c);tb(c);x[31737]=0;c=P(1,e+20|0,10149)|0;d=x[31737];x[31737]=0;if((d|0)==1){break pa}Ab(a+1298356|0,c);tb(c);Ab(a+1298368|0,b);G=a+1298404|0,H=x[Fc(e+16|0,28)>>2],x[G>>2]=H;tb(b);d=1;break o}d=N()|0;break Z}d=N()|0;break Y}d=N()|0;break Y}d=N()|0;break Q}d=N()|0}ub(e+112|0)}tb(b);break b}d=N()|0;Qc(e+112|0);break b}d=N()|0;break b}d=N()|0}ub(e+112|0);break b}d=N()|0;ub(g);break Q}d=N()|0;break Q}d=N()|0}Qc(e+184|0);break b}Sf(e+20|0);continue}}d=0}ie(e+204|0)}fb=e+240|0;return d|0}d=N()|0;break b}d=N()|0;break f}d=N()|0;ub(e+184|0);break f}d=N()|0;break f}d=N()|0;break f}d=N()|0;break b}d=N()|0}ub(e+48|0);break b}d=N()|0;ub(e+112|0);break b}d=N()|0;break b}d=N()|0;ub(e+184|0)}ie(e+204|0)}Q(d|0);p()}function vpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0;d=fb-336|0;fb=d;xc(b);j=d+324|0;a:{if(!lp(b,j)){break a}if(!CX(j)){break a}q=Ge(d+304|0,b);n=Nb(d+292|0);b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{if((c|0)==64){x[31737]=0;e=d+40|0;O(665,e|0,q|0);b=x[31737];x[31737]=0;if((b|0)==1){break v}break x}x[31737]=0;e=d+40|0;O(666,e|0,q|0);b=x[31737];x[31737]=0;if((b|0)==1){break w}}yv(n,e);ie(e);x[31737]=0;b=d+40|0;S(667,b|0,n|0,1413891155);e=x[31737];x[31737]=0;y:{z:{if((e|0)!=1){x[31737]=0;e=P(668,b|0,14199)|0;j=x[31737];x[31737]=0;if((j|0)==1){break z}ub(b);if((c|0)!=64&e){break y}break b}b=N()|0;break c}b=N()|0;ub(d+40|0);break c}x[31737]=0;O(247,a|0,4194304);b=x[31737];x[31737]=0;if((b|0)==1){break d}x[a+480208>>2]=12;x[31737]=0;b=d+272|0;S(667,b|0,n|0,1280592212);e=x[31737];x[31737]=0;if((e|0)==1){break e}x[31737]=0;e=R(155,x[d+272>>2])|0;j=x[31737];x[31737]=0;if((j|0)==1){break g}x[31737]=0;S(456,b|0,a+1298308|0,e|0);b=x[31737];x[31737]=0;if((b|0)==1){break g}kj(Xb(x[a+484360>>2],y[a+484376|0]));j=Nb(d+260|0);v[d+259|0]=0;v[d+258|0]=0;x[31737]=0;S(669,d+244|0,n|0,1196314451);b=x[31737];x[31737]=0;if((b|0)==1){break i}m=a+484360|0;t=d,u=wb(x[d+244>>2]),x[t+240>>2]=u;l=d+228|0;i=wb(x[d+248>>2]);A:{while(1){b=x[d+240>>2];if(!Ib(b,i)){break A}k=Ge(d+40|0,b);x[31737]=0;e=d+28|0;g=P(670,k|0,e|0)|0;b=x[31737];x[31737]=0;B:{C:{if((b|0)!=1){b=1;if(!(g&y[d+37|0]==1)){break B}t=a,u=Kd(y[d+38|0],z[a+480188>>1],127),w[t+480188>>1]=u;x[31737]=0;g=R(671,d+184|0)|0;b=x[31737];x[31737]=0;D:{E:{F:{if((b|0)!=1){h=d+172|0;cf(h,e,9,1);x[31737]=0;b=d+136|0;O(219,b|0,h|0);e=x[31737];x[31737]=0;if((e|0)==1){break F}e=d+16|0;gc(e,l,10);tm(e,b);tb(b);b=Xb(x[a+484360>>2],y[a+484376|0]);if(mc(x[b>>2],x[b+4>>2])){break D}x[31737]=0;b=R(275,m|0)|0;e=x[31737];x[31737]=0;if((e|0)==1){break m}if((b|0)!=255){break E}b=2;break C}b=N()|0;break k}b=N()|0;break l}b=Xb(x[a+484360>>2],y[a+484376|0])}x[31737]=0;e=d+160|0;O(672,e|0,l|0);h=x[31737];x[31737]=0;if((h|0)==1){break m}tp(b,e);tb(e);x[31737]=0;O(666,d+172|0,k|0);b=x[31737];x[31737]=0;if((b|0)!=1){t=d,u=wb(x[d+172>>2]),x[t+156>>2]=u;r=wb(x[d+176>>2]);while(1){G:{H:{I:{J:{K:{b=x[d+156>>2];if(Ib(b,r)){qp(d+136|0,b);wi(d+16|0,x[b>>2],x[b+4>>2]);e=x[d+16>>2];if((e|0)==1212960847){break K}b=0;if((e|0)!=1312903248){break G}while(1){e=b&65535;if(e>>>0>=z[a+480188>>1]){break G}x[31737]=0;h=U(151,x[d+136>>2],x[d+144>>2],2)|0;f=x[31737];x[31737]=0;if((f|0)==1){break I}if(!h){break G}x[31737]=0;h=d+8|0;O(199,h|0,d+136|0);f=x[31737];x[31737]=0;if((f|0)!=1){DC(g,e,y[d+8|0],y[Jc(h)|0],d+259|0,j);b=b+1|0;continue}break}break I}b=0;if(z[d+220>>1]==65535|z[d+222>>1]==65535){break J}b=y[a+484376|0];e=x[a+484360>>2];x[31737]=0;W(673,Xb(e,b)|0);b=x[31737];x[31737]=0;if((b|0)!=1){b=0;x[31737]=0;O(674,j|0,g|0);e=x[31737];x[31737]=0;if((e|0)!=1){break J}}b=N()|0;break H}if(A[d+20>>2]<9){break G}e=0;x[31737]=0;P(184,d+136|0,2)|0;b=x[31737];x[31737]=0;h=65535;L:{if((b|0)!=1){while(1){x[31737]=0;b=U(151,x[d+136>>2],x[d+144>>2],1)|0;f=x[31737];x[31737]=0;M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{if((f|0)!=1){if(!b){break G}x[31737]=0;f=R(198,d+136|0)|0;b=x[31737];x[31737]=0;if((b|0)==1){break I}b=4;switch(f|0){case 0:break G;case 14:break N;case 13:break O;case 12:break Q;case 8:break R;case 7:break S;case 2:break T;case 6:break U;case 5:break V;case 3:case 4:break W;case 1:break X;default:break P}}break I}b=Xb(x[a+484360>>2],y[a+484376|0]);if(z[d+220>>1]==65535){t=d,u=km(x[b>>2],x[b+4>>2]),w[t+220>>1]=u}b=km(x[b>>2],x[b+4>>2]);x[31737]=0;w[d+222>>1]=b;b=P(675,d+136|0,d+258|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break I}Y:{Z:{switch(b-254|0){case 1:b=65535;break Y;case 0:break Z;default:break Y}}b=65534}f=y[a+484376|0];o=x[a+484360>>2];x[31737]=0;O(538,Xb(o,f)|0,b|0);b=x[31737];x[31737]=0;if((b|0)==1){break I}h=(h&65535)==65535?e:h;break M}x[31737]=0;b=R(190,d+136|0)|0;o=x[31737];x[31737]=0;if((o|0)!=1){_:{if(b>>>0<(h&65535)>>>0){b=z[d+224>>1];break _}b=b-h|0;w[d+224>>1]=b}af(Xb(x[a+484360>>2],y[a+484376|0]),b&65535);if((f|0)!=3){break M}x[31737]=0;P(184,d+136|0,1)|0;b=x[31737];x[31737]=0;if((b|0)!=1){break M}}break I}x[31737]=0;b=d+8|0;O(199,b|0,d+136|0);f=x[31737];x[31737]=0;if((f|0)!=1){DC(g,y[d+8|0],y[Jc(b)|0],-1,d+259|0,j);break M}break I}b=1}x[31737]=0;P(184,d+136|0,b|0)|0;b=x[31737];x[31737]=0;if((b|0)!=1){break M}break I}x[31737]=0;b=R(198,d+136|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break I}v[d+227|0]=b;break M}x[31737]=0;b=R(198,d+136|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break I}v[d+226|0]=b;break M}x[31737]=0;b=P(641,d+136|0,d+8|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break I}if(y[d+8|0]|!b|(y[d+10|0]|y[d+9|0]!=255)){break P}if(y[d+11|0]|y[d+12|0]!=1){break P}if(!y[d+13|0]){break M}}ub(d+136|0);b=1;break J}x[31737]=0;b=d+8|0;O(550,b|0,d+136|0);f=x[31737];x[31737]=0;if((f|0)!=1){f=Jc(b);DC(g,y[d+8|0],y[$e(b)|0],y[f|0],d+259|0,j);break M}break I}x[31737]=0;b=d+8|0;O(199,b|0,d+136|0);f=x[31737];x[31737]=0;if((f|0)==1){break L}f=x[d+196>>2];s=Vc(f,x[d+200>>2]);o=y[d+8|0];if(s>>>0<=o>>>0){break M}b=Jc(b);t=xb(f,o),u=(y[b|0]>>>2|0)+1|0,v[t|0]=u}e=e+1|0;continue}}break I}break I}ie(d+172|0);break C}b=N()|0;ub(d+136|0)}ie(d+172|0);break l}ub(d+136|0);lm(d+156|0);continue}}b=N()|0;break l}b=N()|0;break k}er(g)}ub(k);if(!b){Sf(d+240|0);continue}break}e=0;if((b|0)!=2){break s}}e=0;ak(m,0);b=x[j>>2];if(mc(b,x[j+4>>2])){break s}if(!(c&2)){break t}x[31737]=0;S(669,d+136|0,n|0,1347244868);b=x[31737];x[31737]=0;$:{if((b|0)!=1){t=d,u=wb(x[d+136>>2]),x[t+16>>2]=u;e=a+480190|0;h=d+53|0;k=d+57|0;m=wb(x[d+140>>2]);l=y[d+258|0];while(1){b=x[d+16>>2];if(!Ib(b,m)){Qc(d+136|0);b=x[j>>2];break t}aa:{ba:{ca:{if(!l){x[31737]=0;g=d+40|0;f=P(676,b|0,g|0)|0;i=x[31737];x[31737]=0;if((i|0)==1){break aa}if(!f){break ba}f=y[d+92|0]|y[d+93|0]<<8;i=f+1|0;w[d+8>>1]=i;if(f>>>0>3998){break ca}t=a,u=z[pe(e,d+8|0)>>1],w[t+480190>>1]=u;x[31737]=0;O(677,g|0,(D(i&65535,104)+a|0)+484380|0);g=x[31737];x[31737]=0;if((g|0)==1){break aa}f=d+28|0;BX(f,h);x[31737]=0;g=d+172|0;O(219,g|0,f|0);f=x[31737];x[31737]=0;if((f|0)==1){break u}zc(((z[d+8>>1]<<5)+a|0)+946304|0,g);tb(g);break ca}x[31737]=0;g=d+40|0;f=P(678,b|0,g|0)|0;i=x[31737];x[31737]=0;if((i|0)==1){break u}if(!f){break ba}f=y[d+96|0]|y[d+97|0]<<8;i=f+1|0;w[d+8>>1]=i;if(f>>>0>3998){break ca}t=a,u=z[pe(e,d+8|0)>>1],w[t+480190>>1]=u;x[31737]=0;O(679,g|0,(D(i&65535,104)+a|0)+484380|0);g=x[31737];x[31737]=0;if((g|0)==1){break u}f=d+28|0;BX(f,k);x[31737]=0;g=d+172|0;O(219,g|0,f|0);f=x[31737];x[31737]=0;if((f|0)==1){break $}zc(((z[d+8>>1]<<5)+a|0)+946304|0,g);tb(g)}g=z[d+8>>1];if((g-1&65535)>>>0>3998){break ba}f=Xc(d+40|0,8,1,0,2);x[31737]=0;U(216,f|0,(D(g,104)+a|0)+484380|0,b|0)|0;b=x[31737];x[31737]=0;if((b|0)!=1){break ba}break u}Sf(d+16|0);continue}break}break u}b=N()|0;break j}break u}b=N()|0;break c}b=N()|0;break c}b=N()|0;Qc(d+136|0);break j}b=CC(b,0);x[a+480196>>2]=y[b+43|0];x[a+480204>>2]=D(y[b+42|0],1e4);af(Xb(x[a+484360>>2],y[a+484376|0]),z[b+40>>1]);b=0;while(1){if(z[a+480188>>1]>b>>>0){e=(b<<5)+a|0;g=e+480280|0;We(g);h=CC(x[j>>2],0);t=e+480286|0,u=y[xb(x[h+12>>2],b)|0],w[t>>1]=u;t=e+480284|0,u=y[xb(x[h>>2],b)|0],w[t>>1]=u;Kb(d+40|0,x[h+24>>2],b);t=g,u=x[g>>2]&-257|(Hb(x[x[d+40>>2]>>2],x[d+44>>2])?256:0),x[t>>2]=u;b=b+1|0;continue}break}x[31737]=0;b=P(1,d+172|0,(y[d+258|0]?17193:17050)|0)|0;e=x[31737];x[31737]=0;if((e|0)==1){break n}Ab(a+1298344|0,b);tb(b);x[31737]=0;b=P(1,d+28|0,10153)|0;e=x[31737];x[31737]=0;if((e|0)==1){break o}Ab(a+1298356|0,b);tb(b);t=a+1298404|0,u=x[Fc(d+40|0,4)>>2],x[t>>2]=u;e=1;if(!(c&1)|!z[a+480188>>1]){break s}x[31737]=0;S(669,d+16|0,n|0,1146045008);b=x[31737];x[31737]=0;if((b|0)==1){break p}b=x[d+20>>2];c=x[d+16>>2];x[31737]=0;h=a+484344|0;O(224,h|0,Uf(c,b)&65535);b=x[31737];x[31737]=0;if((b|0)==1){break r}t=d,u=wb(x[d+16>>2]),x[t+240>>2]=u;f=wb(x[d+20>>2]);while(1){g=x[d+240>>2];if(!Ib(g,f)){da:{ea:{b=x[j>>2];e=x[j+4>>2];if(xv(b,e)>>>0<2){break ea}m=y[d+259|0];c=0;while(1){if(xv(b,e)>>>0<=c>>>0){break ea}f=x[a+484344>>2];i=x[a+484348>>2];k=Tj(x[a+484360>>2],c&255);o=x[k>>2];g=CC(b,c);l=z[g+36>>1];if(He(f,i,z[_b(o,l)>>1])){x[31737]=0;e=P(369,k|0,l|0)|0;b=x[31737];x[31737]=0;if((b|0)==1){break da}fa:{if(!m){break fa}b=0;while(1){if(z[a+480188>>1]<=b>>>0){break fa}l=BC(x[g+24>>2],b);k=Wb(x[h>>2],e);ga:{if(l){ye(k,Yh(mp(Xe(Ne(d+40|0,20,145),0),b&65535)));break ga}ye(k,Yh(mp(Xe(Ne(d+40|0,9,y[xb(x[g>>2],b)|0]),0),b&65535)))}b=b+1|0;continue}}b=d+40|0;ye(Wb(x[h>>2],e),Yh(Xe(Ne(b,16,y[g+43|0]),0)));ye(Wb(x[h>>2],e),Yh(Xe(Ne(b,17,y[g+42|0]),0)));e=x[j+4>>2];b=x[j>>2]}c=c+1|0;continue}}Qc(d+16|0);e=1;break s}b=N()|0;break q}b=x[g>>2];x[31737]=0;b=R(155,b|0)|0;c=x[31737];x[31737]=0;ha:{ia:{ja:{ka:{la:{ma:{na:{if((c|0)==1){break na}x[31737]=0;c=R(152,g|0)|0;e=x[31737];x[31737]=0;if((e|0)==1){break na}if((b|0)!=(c|0)){break ha}b=x[g>>2];x[31737]=0;b=P(680,b|0,8)|0;c=x[31737];x[31737]=0;if((c|0)==1){break na}if(!b){break ha}x[31737]=0;m=P(675,g|0,d+258|0)|0;b=x[31737];x[31737]=0;if((b|0)==1){break ia}x[31737]=0;l=R(190,g|0)|0;b=x[31737];x[31737]=0;if((b|0)==1){break ja}x[31737]=0;b=U(197,h|0,m|0,l|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break ja}if(!b){break ha}k=0;while(1){if((k|0)==(l|0)){break ha}b=Wb(x[h>>2],m);bf(d+8|0,x[b>>2],x[x[b+48>>2]+12>>2],k);x[31737]=0;b=R(190,g|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break ma}oa:{if(b>>>0>=3){x[31737]=0;c=d+136|0;S(186,c|0,g|0,b-2|0);b=x[31737];x[31737]=0;if((b|0)==1){break ka}e=ic(d+40|0,c);ub(c);while(1){b=x[e>>2];x[31737]=0;b=U(151,b|0,x[d+48>>2],3)|0;c=x[31737];x[31737]=0;if((c|0)==1){break oa}if(b){x[31737]=0;b=d+136|0;O(199,b|0,e|0);c=x[31737];x[31737]=0;pa:{qa:{ra:{sa:{if((c|0)!=1){w[d+156>>1]=z[a+480188>>1]-1;t=d,u=y[Jc(b)|0],w[t+6>>1]=u;c=Wc(x[d+8>>2],z[Nc(d+156|0,d+6|0)>>1]);b=v[d+136|0];if((b|0)>=0){break pa}x[31737]=0;b=R(198,e|0)|0;i=x[31737];x[31737]=0;if((i|0)==1){break la}if(y[d+258|0]){break ra}if((b|0)!=255){break sa}b=254;break qa}break la}if(b>>>0>128){break qa}b=(D(b>>>4|0,12)+(b&15)|0)+13|0;break qa}b=b>>>0<85?b+36|0:b}v[c|0]=b;b=y[d+136|0]}if(b&64){x[31737]=0;b=R(198,e|0)|0;i=x[31737];x[31737]=0;if((i|0)==1){break la}v[c+1|0]=b+1;b=y[d+136|0]}if(b&32){x[31737]=0;b=R(198,e|0)|0;i=x[31737];x[31737]=0;if((i|0)==1){break la}v[d+156|0]=b;v[d+6|0]=127;b=y[Qb(d+156|0,d+6|0)|0];v[c+2|0]=1;v[c+4|0]=b+1>>>1;b=y[d+136|0]}if(!(b&16)){continue}x[31737]=0;b=d+156|0;O(199,b|0,e|0);i=x[31737];x[31737]=0;ta:{ua:{va:{wa:{xa:{ya:{za:{Aa:{Ba:{Ca:{Da:{Ea:{Fa:{Ga:{Ha:{Ia:{Ja:{Ka:{La:{Ma:{Na:{Oa:{Pa:{Qa:{Ra:{Sa:{Ta:{Ua:{Va:{Wa:{Xa:{Ya:{Za:{_a:{if((i|0)!=1){b=y[Jc(b)|0];v[c+5|0]=b;switch(y[d+156|0]-1|0){case 72:break ua;case 71:break va;case 70:break wa;case 61:break xa;case 60:break ya;case 53:break za;case 52:break Aa;case 51:break Ba;case 50:break Da;case 43:break Ea;case 42:break Fa;case 41:break Ga;case 40:break Ha;case 31:break Ia;case 30:break Ja;case 23:break Ka;case 22:break La;case 21:break Ma;case 20:break Na;case 18:break Oa;case 17:break Pa;case 15:break Qa;case 16:break Ra;case 14:break Sa;case 13:break Ta;case 12:break Ua;case 11:break Va;case 10:break Wa;case 3:break Xa;case 2:break Ya;case 1:break Za;case 0:break _a;default:break ta}}break la}v[c+3|0]=11;if(y[d+258|0]){v[c+5|0]=b<<4|15;continue}v[c+5|0]=b<<3|15;continue}v[c+3|0]=11;if(y[d+258|0]){v[c+5|0]=b<<4;continue}v[c+5|0]=b<<3&240;continue}v[c+3|0]=11;if(y[d+258|0]){v[c+5|0]=b|240;continue}v[c+5|0]=b>>>1|240;continue}v[c+3|0]=11;if(y[d+258|0]){v[c+5|0]=b&15;continue}if(b>>>0<=1){v[c+5|0]=b|240;continue}v[c+5|0]=b>>>1&15;continue}v[c+3|0]=2;t=c,u=wv(b,y[d+258|0])|240,v[t+5|0]=u;continue}v[c+3|0]=2;t=c,u=wv(b,y[d+258|0]),v[t+5|0]=u;continue}v[c+3|0]=3;t=c,u=wv(b,y[d+258|0])|240,v[t+5|0]=u;continue}v[c+3|0]=3;t=c,u=wv(b,y[d+258|0]),v[t+5|0]=u;continue}v[c+3|0]=4;if(y[d+258|0]){continue}v[c+5|0]=(b&252)>>>2;continue}v[c+3|0]=20;v[c+5|0]=b&1|16;continue}v[c+3|0]=6;v[c+5|0]=b&240;continue}v[c+3|0]=6;v[c+5|0]=(b&240)>>>4;continue}v[c+3|0]=20;continue}v[c+3|0]=5;continue}v[c+3|0]=20;v[c+5|0]=b&15|48;continue}v[c+3|0]=7;v[c+5|0]=b|240;continue}v[c+3|0]=7;continue}v[c+3|0]=8;continue}v[c+3|0]=20;v[c+5|0]=b&15|64;continue}v[c+3|0]=10;x[31737]=0;b=R(198,e|0)|0;i=x[31737];x[31737]=0;if((i|0)!=1){break Ca}break la}v[c+3|0]=15;continue}v[c+3|0]=20;v[c+5|0]=b&15|192;continue}v[c+3|0]=20;v[c+5|0]=b&15|208;continue}v[c+3|0]=12;b=(b&254)>>>1|0}v[c+5|0]=b;x[31737]=0;P(184,e|0,1)|0;b=x[31737];x[31737]=0;if((b|0)!=1){continue}break la}v[c+5|0]=0;v[c+3|0]=14;continue}v[c+3|0]=20;v[c+5|0]=b&15|176;continue}v[c+3|0]=20;v[c+5|0]=b&15|224;continue}v[c+3|0]=16;continue}v[c+3|0]=17;continue}v[c+3|0]=1;continue}v[c+3|0]=20;v[c+5|0]=b&15|32;continue}v[c+3|0]=20;v[c+5|0]=b&15|128;continue}v[c+3|0]=0;continue}break}ub(e)}k=k+1|0;continue}break}break la}b=N()|0;break q}b=N()|0;break q}b=N()|0;ub(e);break q}b=N()|0;break q}b=N()|0;break q}b=N()|0;break q}Sf(d+240|0);continue}}Qc(d+244|0);AX(j);ub(d+272|0);break b}b=N()|0}Qc(d+16|0);break j}b=N()|0;break j}b=N()|0;break j}b=N()|0;break j}b=N()|0}er(g)}ub(k)}Qc(d+244|0);break h}b=N()|0}AX(j);break f}b=N()|0}ub(d+272|0);break c}b=N()|0;break c}b=N()|0}ie(n);ub(q);Q(b|0);p()}ie(n);ub(q)}fb=d+336|0;return e|0}function yua(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,C=0;d=fb-416|0;fb=d;xc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{f=d+408|0;s:{if(!Bi(b,f)){break s}if(!z0(f)){break s}o=1;if((c|0)==64){break s}q=Ge(d+388|0,b);x[31737]=0;f=d+376|0;O(264,f|0,q|0);b=x[31737];x[31737]=0;t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{if((b|0)!=1){x[31737]=0;b=d+208|0;S(265,b|0,f|0,1229866575);f=x[31737];x[31737]=0;if((f|0)==1){break K}x[31737]=0;o=P(266,b|0,d+366|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break M}ub(b);if(!o){break t}x[31737]=0;O(247,a|0,524288);f=x[31737];x[31737]=0;N:{if((f|0)==1){break N}gg(a);x[a+480208>>2]=12;B=a,C=Kd(Bb(z[d+374>>1]),1,127),w[B+480188>>1]=C;B=d,C=Bb(z[d+366>>1]),w[B+208>>1]=C;w[d+320>>1]=255;f=d+320|0;B=a,C=z[Nc(b,f)>>1],w[B+480192>>1]=C;B=d,C=Bb(z[d+368>>1]),w[B+208>>1]=C;w[d+320>>1]=3999;B=a,C=z[Nc(b,f)>>1],w[B+480190>>1]=C;x[31737]=0;b=U(267,a+1074312|0,6,1)|0;f=x[31737];x[31737]=0;if((f|0)==1){break N}x[31737]=0;b=P(268,b|0,21)|0;f=x[31737];x[31737]=0;if((f|0)==1){break N}x[31737]=0;P(268,b|0,13)|0;b=x[31737];x[31737]=0;if((b|0)!=1){break L}}b=N()|0;break b}b=N()|0;break a}b=N()|0;ub(d+208|0);break b}x[31737]=0;b=P(1,d+352|0,9298)|0;f=x[31737];x[31737]=0;if((f|0)==1){break c}Ab(a+1298344|0,b);tb(b);x[31737]=0;b=P(1,d+340|0,10333)|0;f=x[31737];x[31737]=0;if((f|0)==1){break d}Ab(a+1298356|0,b);tb(b);x[31737]=0;b=d+320|0;O(269,b|0,4336);f=x[31737];x[31737]=0;if((f|0)==1){break e}x[31737]=0;f=d+300|0;O(270,f|0,d+412|0);e=x[31737];x[31737]=0;if((e|0)==1){break g}x[31737]=0;g=d+264|0;O(270,g|0,d+413|0);e=x[31737];x[31737]=0;if((e|0)==1){break i}x[31737]=0;e=d+208|0;V(90,e|0,b|0,f|0,g|0);h=x[31737];x[31737]=0;if((h|0)==1){break j}Ab(a+1298368|0,e);tb(e);tb(g);tb(f);Eb(b);B=a+1298404|0,C=x[Fc(e,28)>>2],x[B>>2]=C;x[31737]=0;e=d+376|0;S(265,b|0,e|0,1312902469);g=x[31737];x[31737]=0;if((g|0)==1){break k}x[31737]=0;g=R(155,x[d+320>>2])|0;h=x[31737];x[31737]=0;if((h|0)==1){break m}x[31737]=0;h=a+1298308|0;S(271,b|0,h|0,g|0);b=x[31737];x[31737]=0;if((b|0)==1){break m}x[31737]=0;S(265,f|0,e|0,1397706311);b=x[31737];x[31737]=0;if((b|0)==1){break n}kj(Xb(x[a+484360>>2],y[a+484376|0]));e=a+484360|0;j=Bb(z[d+370>>1]);f=0;O:{while(1){P:{if(j>>>0<=(f&65535)>>>0){break P}x[31737]=0;b=U(151,x[d+300>>2],x[d+308>>2],46)|0;g=x[31737];x[31737]=0;Q:{if((g|0)!=1){if(!b){break P}x[31737]=0;b=d+208|0;O(272,d+300|0,b|0);g=x[31737];x[31737]=0;if((g|0)!=1){if(!Ad(x[a+1298312>>2],y[a+1298319|0])){break Q}x[31737]=0;O(273,h|0,b|0);b=x[31737];x[31737]=0;if((b|0)!=1){break Q}}b=N()|0;break o}b=N()|0;break o}x[31737]=0;i=R(274,d+300|0)|0;b=x[31737];x[31737]=0;if((b|0)==1){break O}b=Xb(x[a+484360>>2],y[a+484376|0]);if(!mc(x[b>>2],x[b+4>>2])){x[31737]=0;b=R(275,e|0)|0;g=x[31737];x[31737]=0;if((g|0)==1){break O}if((b|0)==255){break P}b=Xb(x[a+484360>>2],y[a+484376|0])}x[31737]=0;g=d+288|0;O(276,g|0,d+208|0);k=x[31737];x[31737]=0;if((k|0)==1){break O}tp(b,g);tb(g);b=y[a+484376|0];g=x[a+484360>>2];x[31737]=0;S(277,Xb(g,b)|0,d+300|0,i|0);b=x[31737];x[31737]=0;if((b|0)==1){break O}f=f+1|0;continue}break}ak(e,0);x[31737]=0;S(265,d+264|0,d+376|0,1229869908);b=x[31737];x[31737]=0;if((b|0)!=1){x[31737]=0;b=R(278,x[d+264>>2])|0;f=x[31737];x[31737]=0;if((f|0)==1){break p}R:{S:{if(!b){break S}f=1;T:{while(1){b=f&65535;if(b>>>0>z[a+480192>>1]){x[31737]=0;S(265,d+188|0,d+376|0,1447382614);b=x[31737];x[31737]=0;if((b|0)!=1){break T}break p}x[31737]=0;h=d+208|0;O(279,d+264|0,h|0);e=x[31737];x[31737]=0;if((e|0)==1){break p}e=y[d+238|0]|y[d+239|0]<<8;x[31737]=0;b=U(252,a|0,b|0,Bb(e)|0)|0;e=x[31737];x[31737]=0;if((e|0)==1){break R}U:{V:{if(!b){break V}if(Bb(y[d+238|0]|y[d+239|0]<<8)>>>0>3999){break V}g=d+112|0;vE(g,2,h);x[31737]=0;e=d+132|0;O(219,e|0,g|0);j=x[31737];x[31737]=0;if((j|0)==1){break U}zc(b+492|0,e);tb(e);vE(g,2,h);x[31737]=0;O(219,e|0,g|0);h=x[31737];x[31737]=0;if((h|0)==1){break p}zc(((Bb(y[d+238|0]|y[d+239|0]<<8)<<5)+a|0)+946304|0,e);tb(e);x[b>>2]=0;B=b,C=xe((y[d+254|0]|y[d+255|0]<<8)<<16>>16)+128&65535,x[B+8>>2]=C;wc(b+8|0,256);v[b+15|0]=y[b+15|0]|1;b=y[d+238|0]|y[d+239|0]<<8;x[31737]=0;b=D(Bb(b),104)+a|0;O(280,b+484380|0,0);h=x[31737];x[31737]=0;if((h|0)==1){break p}B=d,C=Bb(y[d+240|0]|y[d+241|0]<<8),w[B+132>>1]=C;w[d+112>>1]=64;B=b+484410|0,C=z[Nc(e,g)>>1]<<2,w[B>>1]=C;g=b+484404|0;e=$b(y[d+242|0]|y[d+243|0]<<8|(y[d+244|0]<<16|y[d+245|0]<<24));h=Sua(e,e>>31,8303,0);e=hb;h=h+4181|0;e=h>>>0<4181?e+1|0:e;B=g,C=Gc(Tua(h,e,8363,0),hb),x[B>>2]=C;e=$b(y[d+250|0]|y[d+251|0]<<8|(y[d+252|0]<<16|y[d+253|0]<<24));if(!e){break V}g=Bb(y[d+256|0]|y[d+257|0]<<8);if(!(g&3)){break V}h=e;e=$b(y[d+246|0]|y[d+247|0]<<8|(y[d+248|0]<<16|y[d+249|0]<<24));x[b+484388>>2]=h+e;x[b+484384>>2]=e;b=b+484414|0;e=z[b>>1];w[b>>1]=e|2;if(!(g&2)){break V}w[b>>1]=e|6}f=f+1|0;continue}break}break p}b=x[d+200>>2];x[d+32>>2]=x[d+196>>2];x[d+36>>2]=b;x[d+40>>2]=x[d+204>>2];x[31737]=0;b=x[d+192>>2];x[d+24>>2]=x[d+188>>2];x[d+28>>2]=b;V(281,d+24|0,0,a|0,0);b=x[31737];x[31737]=0;if((b|0)==1){break p}x[31737]=0;S(265,d+168|0,d+376|0,1346719318);b=x[31737];x[31737]=0;if((b|0)==1){break p}b=x[d+180>>2];x[d+8>>2]=x[d+176>>2];x[d+12>>2]=b;x[d+16>>2]=x[d+184>>2];x[31737]=0;b=x[d+172>>2];x[d>>2]=x[d+168>>2];x[d+4>>2]=b;V(281,d|0,1,a|0,y[d+412|0]>2|0);b=x[31737];x[31737]=0;if((b|0)==1){break p}b=z[a+480192>>1]+1&65535;e=b>>>0<=1?1:b;b=1;while(1){if((b|0)==(e|0)){break S}f=x[((b<<2)+a|0)+900380>>2];if(!(!f|v[f+60|0]&1)){x[f>>2]=32767}b=b+1|0;continue}}b=d+264|0;ub(b);x[31737]=0;f=d+376|0;S(265,d+208|0,f|0,1346458708);e=x[31737];x[31737]=0;if((e|0)==1){break x}x[31737]=0;e=R(173,x[d+208>>2])|0;g=x[31737];x[31737]=0;if((g|0)==1){break y}if(!(c&1)|e^1){break J}x[31737]=0;S(265,b|0,f|0,1347305805);f=x[31737];x[31737]=0;if((f|0)==1){break z}x[31737]=0;P(184,b|0,1)|0;b=x[31737];x[31737]=0;if((b|0)==1){break B}b=z[d+372>>1];x[31737]=0;k=a+484344|0;O(224,k|0,Bb(b)|0);b=x[31737];x[31737]=0;if((b|0)==1){break B}j=Nb(d+152|0);i=0;W:{while(1){if(Bb(z[d+372>>1])>>>0<=i>>>0){md(j);ub(d+264|0);if(c&4){f=0;if(!t){break w}f=z[a+480188>>1];b=0;while(1)if((b|0)==(f|0)){f=1;break w}else{e=(b<<5)+a|0;v[e+480288|0]=1;e=e+480280|0;x[e>>2]=x[e>>2]|33554432;b=b+1|0;continue}}if(!r){break u}break v}x[31737]=0;f=d+208|0;b=R(274,f|0)|0;e=x[31737];x[31737]=0;if((e|0)==1){break D}x[31737]=0;g=R(282,f|0)|0;e=x[31737];x[31737]=0;if((e|0)==1){break E}x[31737]=0;e=d+112|0;S(186,e|0,f|0,g|0);f=x[31737];x[31737]=0;if((f|0)==1){break F}h=ic(d+132|0,e);ub(e);x[31737]=0;f=U(197,k|0,i&65535,b|0)|0;e=x[31737];x[31737]=0;if((e|0)==1){break H}X:{if(f){n=Fb(d+100|0);x[31737]=0;O(283,d+264|0,n|0);f=x[31737];x[31737]=0;if((f|0)==1){break I}f=x[k>>2];x[31737]=0;O(284,Wb(f,i)|0,n|0);f=x[31737];x[31737]=0;if((f|0)==1){break I}l=0;f=Wb(x[k>>2],i);bf(d+88|0,x[f>>2],x[x[f+48>>2]+12>>2],0);kj(j);u=(b>>>0<=1?1:b)-1|0;Y:while(1){b=x[h>>2];x[31737]=0;b=U(151,b|0,x[d+140>>2],1)|0;f=x[31737];x[31737]=0;if((f|0)==1){break X}Z:{if(!b){break Z}x[31737]=0;b=R(198,h|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break I}if(!b){B=d,C=wb(x[j>>2]),x[B+84>>2]=C;f=wb(x[j+4>>2]);while(1){b=x[d+84>>2];if(Ib(b,f)){ye(Wb(x[k>>2],i),Xe(Ne(d+112|0,y[b|0],y[b+1|0]),l));Md(d+84|0);continue}else{kj(j);if((l|0)==(u|0)){break Z}b=Wb(x[k>>2],i);l=l+1|0;bf(d+112|0,x[b>>2],x[x[b+48>>2]+12>>2],l);b=x[d+116>>2];x[d+88>>2]=x[d+112>>2];x[d+92>>2]=b;continue Y}}}w[d+116>>1]=0;x[d+112>>2]=0;g=d+112|0;if(b>>>0<=z[a+480188>>1]){g=Wc(x[d+88>>2],b-1|0)}x[31737]=0;b=R(198,h|0)|0;f=x[31737];x[31737]=0;_:{$:{if((f|0)!=1){aa:{if(!(b&1)){break aa}x[31737]=0;f=R(198,h|0)|0;e=x[31737];x[31737]=0;if((e|0)==1){break I}if((f|0)!=31){if((f-1&255)>>>0>252){break aa}e=(D(f>>>4|0,12)+(f&15)|0)+13|0}else{e=255}v[g|0]=e}if(!(b&2)){break _}x[31737]=0;f=R(198,h|0)|0;e=x[31737];x[31737]=0;if((e|0)!=1){break $}}break I}v[g+1|0]=f}if(!(b&60)){continue}f=0;m=0;if(b&4){x[31737]=0;m=R(198,h|0)|0;e=x[31737];x[31737]=0;if((e|0)==1){break I}}if(b&8){x[31737]=0;f=R(198,h|0)|0;e=x[31737];x[31737]=0;if((e|0)==1){break I}}s=0;e=0;if(b&16){x[31737]=0;e=R(198,h|0)|0;A=x[31737];x[31737]=0;if((A|0)==1){break I}}if(b&32){x[31737]=0;s=R(198,h|0)|0;b=x[31737];x[31737]=0;if((b|0)==1){break I}}b=d+84|0;w0(b,e,s);e=Jc(b);b=d+82|0;w0(b,m,f);f=Jc(b);b=y[d+82|0];ba:{if((b|0)!=13){if(b){break ba}b=0;if(y[d+84|0]==13){break ba}}tg(d+84|0,d+82|0);tg(e,f);b=y[d+82|0]}m=d+80|0;mm(m,g,y[d+84|0],y[e|0],b&255,y[f|0]);if(v0(y[d+80|0],y[d+81|0])){b=x[vb(d+76|0,wb(x[j>>2]))>>2];x[31737]=0;S(285,j|0,b|0,m|0);b=x[31737];x[31737]=0;if((b|0)==1){break W}}b=y[g+3|0];if((b|0)==43){t=1;continue}if((b|0)!=31){continue}r=1;continue}break}tb(n)}ub(h);i=i+1|0;continue}break}break I}break I}break p}b=N()|0;break o}b=N()|0;break o}b=N()|0;break b}f=0;if(c&4){break w}break u}b=N()|0;tb(n);break G}b=N()|0}ub(h);break C}b=N()|0;break C}b=N()|0;break C}b=N()|0}md(j);break A}b=N()|0}ub(d+264|0);break q}b=N()|0;break q}b=N()|0;break q}b=N()|0;break o}x[d+152>>2]=-1778364416;x[d+156>>2]=-16756736;x[31737]=0;S(265,d+264|0,d+376|0,1146310725);b=x[31737];x[31737]=0;ca:{da:{if((b|0)!=1){x[31737]=0;b=R(278,x[d+264>>2])|0;e=x[31737];x[31737]=0;if((e|0)!=1){if(!b){e=f;break ca}x[31737]=0;h=R(274,d+264|0)|0;b=x[31737];x[31737]=0;if((b|0)==1){break da}b=0;e=f;while(1){if((b|0)==(h|0)){x[31737]=0;O(286,d+264|0,d+152|0);b=x[31737];x[31737]=0;if((b|0)!=1){break ca}break da}x[31737]=0;g=R(198,d+264|0)|0;j=x[31737];x[31737]=0;ea:{fa:{if((j|0)!=1){if(z[a+480188>>1]<=b>>>0){break ea}if(!f){break fa}j=((b<<5)+a|0)+480280|0;x[j>>2]=x[j>>2]&-33554433|((g|0)!=0)<<25;break ea}break da}if(g){break ea}e=1;v[((b<<5)+a|0)+480288|0]=1}b=b+1|0;continue}}break da}b=N()|0;break q}b=N()|0;ub(d+264|0);break q}f=d+264|0;ub(f);ga:{ha:{if(e&1){b=vd(a+906300|0,0);x[31737]=0;W(287,b|0);e=x[31737];x[31737]=0;if((e|0)==1){break r}x[b+16>>2]=810369604;x[b+20>>2]=1869112133;x[b+24>>2]=655376;x[b+28>>2]=0;x[d+264>>2]=0;g=b+48|0;s0(b+32|0,g,f);x[31737]=0;e=P(36,d+132|0,9587)|0;h=x[31737];x[31737]=0;if((h|0)==1){break ha}uE(g,e);tb(e);x[31737]=0;e=P(36,d+112|0,9551)|0;g=x[31737];x[31737]=0;if((g|0)==1){break ga}nw(b+80|0,e);tb(e);x[31737]=0;O(288,b+4|0,8);e=x[31737];x[31737]=0;if((e|0)==1){break r}r0(f,y[d+153|0],y[d+155|0],y[d+157|0],y[d+159|0]);f=x[d+268>>2];b=x[b+4>>2];e=x[d+264>>2];v[b|0]=e;v[b+1|0]=e>>>8;v[b+2|0]=e>>>16;v[b+3|0]=e>>>24;v[b+4|0]=f;v[b+5|0]=f>>>8;v[b+6|0]=f>>>16;v[b+7|0]=f>>>24}if(r){break v}break u}b=N()|0;break q}b=N()|0;break q}h=a+902204|0;b=0;ia:{ja:{ka:{la:{ma:{na:{oa:{pa:{qa:{ra:{sa:{ta:{ua:{va:{wa:{while(1){if((b|0)==32){break u}x[d+88>>2]=D(b,127)>>>5;x[31737]=0;f=d+152|0;O(289,f|0,4093);e=x[31737];x[31737]=0;if((e|0)!=1){x[31737]=0;e=d+100|0;j=d+88|0;O(290,e|0,j|0);g=x[31737];x[31737]=0;if((g|0)==1){break wa}x[31737]=0;g=d+264|0;S(291,g|0,f|0,e|0);i=x[31737];x[31737]=0;if((i|0)==1){break va}ee(d+68|0,g);qf(Oe(h,b),x[d+68>>2],x[d+72>>2]);tb(g);tb(e);Eb(f);x[31737]=0;O(289,f|0,4075);i=x[31737];x[31737]=0;if((i|0)==1){break ta}x[31737]=0;O(290,e|0,j|0);i=x[31737];x[31737]=0;if((i|0)==1){break sa}x[31737]=0;S(291,g|0,f|0,e|0);i=x[31737];x[31737]=0;if((i|0)==1){break ra}ee(d+60|0,g);qf(Oe(h,b+32|0),x[d+60>>2],x[d+64>>2]);tb(g);tb(e);Eb(f);x[31737]=0;O(289,f|0,4066);i=x[31737];x[31737]=0;if((i|0)==1){break pa}x[31737]=0;O(290,e|0,j|0);i=x[31737];x[31737]=0;if((i|0)==1){break oa}x[31737]=0;S(291,g|0,f|0,e|0);i=x[31737];x[31737]=0;if((i|0)==1){break na}ee(d+52|0,g);qf(Oe(h,b- -64|0),x[d+52>>2],x[d+56>>2]);tb(g);tb(e);Eb(f);x[31737]=0;O(289,f|0,4039);i=x[31737];x[31737]=0;if((i|0)==1){break la}x[31737]=0;O(290,e|0,j|0);j=x[31737];x[31737]=0;if((j|0)==1){break ka}x[31737]=0;S(291,g|0,f|0,e|0);e=x[31737];x[31737]=0;if((e|0)==1){break ja}ee(d+44|0,g);qf(Oe(h,b+96|0),x[d+44>>2],x[d+48>>2]);b=b+1|0;tb(d+264|0);tb(d+100|0);Eb(f);continue}break}b=N()|0;break q}b=N()|0;break ua}b=N()|0;tb(d+100|0)}Eb(d+152|0);break q}b=N()|0;break q}b=N()|0;break qa}b=N()|0;tb(d+100|0)}Eb(d+152|0);break q}b=N()|0;break q}b=N()|0;break ma}b=N()|0;tb(d+100|0)}Eb(d+152|0);break q}b=N()|0;break q}b=N()|0;break ia}b=N()|0;tb(d+100|0)}Eb(d+152|0);break q}x[31737]=0;S(265,d+264|0,d+376|0,1397575756);b=x[31737];x[31737]=0;xa:{if((b|0)!=1){x[31737]=0;b=R(173,x[d+264>>2])|0;f=x[31737];x[31737]=0;if((f|0)!=1){ya:{f=1;if(!(c&2)|b^1){break xa}while(1){e=f&65535;if(e>>>0>z[a+480190>>1]){break xa}x[31737]=0;c=d+264|0;b=R(282,c|0)|0;g=x[31737];x[31737]=0;za:{if((g|0)!=1){x[31737]=0;g=R(282,c|0)|0;h=x[31737];x[31737]=0;if((h|0)==1){break ya}if(!(b&7)){break za}e=(D(e,104)+a|0)+484380|0;x[e>>2]=g;b=Xc(d+152|0,b&4?32:b&2?16:8,1,1,0);x[31737]=0;U(216,b|0,e|0,c|0)|0;b=x[31737];x[31737]=0;if((b|0)!=1){break za}break ya}break ya}f=f+1|0;continue}}}b=N()|0;ub(d+264|0);break q}b=N()|0;break q}ub(d+264|0);ub(d+208|0);ub(d+300|0);ub(d+320|0)}ie(d+376|0);ub(q)}fb=d+416|0;return o|0}b=N()|0}ub(d+208|0);break o}b=N()|0;ub(d+264|0)}ub(d+300|0);break l}b=N()|0;break l}b=N()|0}ub(d+320|0);break b}b=N()|0;break b}b=N()|0;tb(d+264|0);break h}b=N()|0}tb(d+300|0);break f}b=N()|0}Eb(d+320|0);break b}b=N()|0;break b}b=N()|0;break b}b=N()|0}ie(d+376|0)}ub(q);Q(b|0);p()}function bpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0;e=fb-320|0;fb=e;xc(b);a:{b:{c:{f=e+224|0;if(!zv(b,f)){break c}if(!jX(f)){break c}if(!Mb(x[b>>2],x[b+8>>2],Bc(iX(f),hb))){break c}d=1;if((c|0)==64){break c}Bd(a,2);x[a+480260>>2]=64;x[a+480264>>2]=32767;j=Fb(e+212|0);d=y[e+264|0]|y[e+265|0]<<8;m=(d|0)==20479?y[e+278|0]|y[e+279|0]<<8:d-16464|0;d:{e:{f:{g:{h:{i:{switch(d>>>12|0){case 0:f=0;if((d|0)!=520){break d}x[31737]=0;d=P(1,e+200|0,12393)|0;g=x[31737];x[31737]=0;if((g|0)!=1){Ab(j,d);break e}b=N()|0;break a;case 1:j:{if((d|0)!=4896){break j}d=y[e+286|0]|y[e+287|0]<<8;if(d){break j}if(!((y[e+262|0]|y[e+263|0]<<8)&65455|(y[e+276|0]|y[e+256|0]&15))){k:{if(v[e+275|0]<0){x[a+1074308>>2]=18219008;x[31737]=0;d=P(1,e+200|0,14838)|0;f=x[31737];x[31737]=0;if((f|0)!=1){break k}b=N()|0;break a}x[a+1074308>>2]=16777376;x[31737]=0;d=P(1,e+200|0,13461)|0;f=x[31737];x[31737]=0;if((f|0)==1){break h}}Ab(j,d);tb(d);x[31737]=0;f=1;U(267,a+1074312|0,81,1)|0;d=x[31737];x[31737]=0;g=1;if((d|0)!=1){break d}break b}if(y[e+276|0]|d|(y[e+277|0]|(y[e+262|0]|y[e+263|0]<<8))){break j}f=0;x[31737]=0;d=P(1,e+200|0,9492)|0;g=x[31737];x[31737]=0;if((g|0)!=1){Ab(j,d);break e}b=N()|0;break a}x[31737]=0;d=P(1,e+200|0,8494)|0;f=x[31737];x[31737]=0;i=1;if((f|0)!=1){Ab(j,d);tb(d);break f}b=N()|0;break a;case 2:x[31737]=0;d=P(1,e+200|0,6808)|0;f=x[31737];x[31737]=0;g=1;if((f|0)!=1){Ab(j,d);tb(d);break f}b=N()|0;break a;case 3:l:{m:{n:{o:{if(d>>>0<=12820){x[31737]=0;f=P(1,e+200|0,8573)|0;g=x[31737];x[31737]=0;if((g|0)!=1){Ab(j,f);tb(f);break o}b=N()|0;break a}x[31737]=0;f=e+200|0;O(446,f|0,4015);g=x[31737];x[31737]=0;if((g|0)==1){break n}x[31737]=0;x[e+188>>2]=(y[e+264|0]|y[e+265|0]<<8)-12820;g=e+48|0;S(447,g|0,f|0,e+188|0);i=x[31737];x[31737]=0;if((i|0)==1){break m}Ab(j,g);tb(g);Eb(f)}f=y[e+264|0]|y[e+265|0]<<8;if(f>>>0<12807){break g}g=y[e+280|0]|y[e+281|0]<<8|(y[e+282|0]<<16|y[e+283|0]<<24);if(g){break l}break g}b=N()|0;break a}b=N()|0;Eb(e+200|0);break a}f=HF(f,g);g=op(e+48|0);x[g+32>>2]=f;x[31737]=0;O(448,a+1298412|0,g|0);f=x[31737];x[31737]=0;if((f|0)!=1){break g}b=N()|0;break a;case 4:if((d|0)==16640){f=0;x[31737]=0;d=P(1,e+200|0,8340)|0;h=x[31737];x[31737]=0;g=1;if((h|0)!=1){Ab(j,d);tb(d);x[31737]=0;U(267,a+1074312|0,81,1)|0;d=x[31737];x[31737]=0;h=0;if((d|0)==1){break b}break d}b=N()|0;break a}x[31737]=0;f=e+48|0;S(443,f|0,d|0,y[e+278|0]|y[e+279|0]<<8);d=x[31737];x[31737]=0;p:{q:{r:{if((d|0)!=1){Ab(j,f);tb(f);x[a+480260>>2]=1;if((m|0)<4201){break r}x[31737]=0;U(267,a+1074312|0,7,1)|0;d=x[31737];x[31737]=0;if((d|0)==1){break b}break q}b=N()|0;break a}if((m|0)<2386){break p}}x[31737]=0;U(267,a+1074312|0,38,1)|0;d=x[31737];x[31737]=0;if((d|0)==1){break b}}f=0;x[31737]=0;P(268,a+1074312|0,118)|0;d=x[31737];x[31737]=0;g=1;h=1;if((d|0)==1){break b}break d;case 5:if((d|0)!=21575){d=d&4095;x[a+1074308>>2]=d<<16|(d>>>0>296?y[e+278|0]|y[e+279|0]<<8:0)&65535;x[31737]=0;d=P(1,e+200|0,18273)|0;f=x[31737];x[31737]=0;s:{t:{u:{if((f|0)!=1){f=x[a+1074308>>2];x[31737]=0;g=e+188|0;O(135,g|0,f|0);f=x[31737];x[31737]=0;if((f|0)==1){break u}f=0;x[31737]=0;h=e+48|0;S(2,h|0,d|0,g|0);i=x[31737];x[31737]=0;if((i|0)==1){break t}Ab(j,h);tb(h);tb(g);break e}b=N()|0;break a}b=N()|0;break s}b=N()|0;tb(e+188|0)}tb(d);break a}f=0;x[31737]=0;d=P(1,e+200|0,8557)|0;g=x[31737];x[31737]=0;if((g|0)!=1){Ab(j,d);break e}b=N()|0;break a;case 6:f=0;x[31737]=0;d=P(1,e+200|0,8340)|0;g=x[31737];x[31737]=0;if((g|0)!=1){Ab(j,d);tb(d);x[31737]=0;U(267,a+1074312|0,81,1)|0;d=x[31737];x[31737]=0;g=0;if((d|0)==1){break b}break d}b=N()|0;break a;case 7:f=0;x[31737]=0;d=P(1,e+200|0,8352)|0;g=x[31737];x[31737]=0;if((g|0)!=1){Ab(j,d);break e}b=N()|0;break a;default:break i}}f=0;if((d|0)!=51712){break d}x[31737]=0;d=P(1,e+200|0,9291)|0;g=x[31737];x[31737]=0;if((g|0)!=1){Ab(j,d);break e}b=N()|0;break a}b=N()|0;break a}x[31737]=0;f=U(267,a+1074312|0,7,1)|0;g=x[31737];x[31737]=0;if((g|0)==1){break b}x[31737]=0;f=U(267,f|0,23,1)|0;g=x[31737];x[31737]=0;if((g|0)==1){break b}x[31737]=0;f=U(267,f|0,38,1)|0;g=x[31737];x[31737]=0;if((g|0)==1){break b}x[31737]=0;U(267,f|0,107,1)|0;f=x[31737];x[31737]=0;if((f|0)==1){break b}g=1;x[a+480260>>2]=1;i=0;f=0;if(d>>>0>12820){break d}}x[31737]=0;d=e+188|0;W(696,d|0);f=x[31737];x[31737]=0;v:{w:{x:{if((f|0)!=1){f=y[e+264|0]|y[e+265|0]<<8;x[e+164>>2]=f>>>8&15;x[31737]=0;x[e+148>>2]=f&255;h=e+176|0;O(445,h|0,e+148|0);f=x[31737];x[31737]=0;if((f|0)==1){break x}f=0;x[31737]=0;k=e+48|0;aa(697,k|0,d|0,j|0,e+164|0,h|0);o=x[31737];x[31737]=0;if((o|0)==1){break w}Ab(j,k);tb(k);tb(h);Eb(d);h=0;break d}b=N()|0;break a}b=N()|0;break v}b=N()|0;tb(e+176|0)}Eb(e+188|0);break a}tb(d);g=0;i=0;h=0}x[31737]=0;d=P(1,e+188|0,15136)|0;k=x[31737];x[31737]=0;y:{z:{A:{B:{if((k|0)!=1){Ab(a+1298344|0,d);tb(d);x[31737]=0;d=P(1,e+176|0,10490)|0;k=x[31737];x[31737]=0;if((k|0)==1){break B}Ab(a+1298356|0,d);tb(d);k=Ab(a+1298368|0,j);A=a+1298404|0,B=x[Fc(e+48|0,x[a+1074308>>2]?22:4)>>2],x[A>>2]=B;if(g){x[31737]=0;d=P(268,a+1074312|0,77)|0;g=x[31737];x[31737]=0;if((g|0)==1){break b}x[31737]=0;d=P(268,d|0,78)|0;g=x[31737];x[31737]=0;if((g|0)==1){break b}x[31737]=0;d=P(268,d|0,79)|0;g=x[31737];x[31737]=0;if((g|0)==1){break b}x[31737]=0;d=P(268,d|0,80)|0;g=x[31737];x[31737]=0;if((g|0)==1){break b}x[31737]=0;d=P(268,d|0,82)|0;g=x[31737];x[31737]=0;if((g|0)==1){break b}x[31737]=0;d=P(268,d|0,96)|0;g=x[31737];x[31737]=0;if((g|0)==1){break b}x[31737]=0;P(268,d|0,113)|0;d=x[31737];x[31737]=0;if((d|0)==1){break b}}d=y[e+264|0]|y[e+265|0]<<8;if(d>>>0<=4865){x[31737]=0;P(268,a+1074312|0,118)|0;d=x[31737];x[31737]=0;if((d|0)==1){break b}d=y[e+264|0]|y[e+265|0]<<8}g=d&61440;if(g>>>0>=4097){f=(g|0)!=12288|(d&65535)>>>0>12819|f}x[31737]=0;d=a+901404|0;W(698,d|0);g=x[31737];x[31737]=0;if((g|0)==1){break b}if(!f){pr(d)}f=e+164|0;aj(f,1,e+224|0);x[31737]=0;d=e+48|0;O(219,d|0,f|0);f=x[31737];x[31737]=0;if((f|0)==1){break y}Ab(a+1298308|0,d);tb(d);d=y[e+262|0]|y[e+263|0]<<8;if(d&16){x[a+480208>>2]=x[a+480208>>2]|65536}if(d&1){x[a+480208>>2]=x[a+480208>>2]|131072}f=y[e+264|0]|y[e+265|0]<<8;if(!(!(d&64)&(f|0)!=4864)){x[a+480208>>2]=x[a+480208>>2]|2}d=y[e+273|0];x[a+480196>>2]=d;if(!(!i|(d|0)!=255?d:0)){x[a+480196>>2]=6}d=y[e+274|0];x[a+480204>>2]=d>>>0<33?i?125e4:32e4:D(d,1e4);v[e+48|0]=y[e+272|0];v[e+164|0]=64;d=y[Qb(e+48|0,e+164|0)|0];x[a+480200>>2]=d<<2;if(!(d|f>>>0>4895)){x[a+480200>>2]=256}g=y[e+275|0];if((y[e+266|0]|y[e+267|0]<<8)!=1|g>>>0>7){break A}x[e+48>>2]=(g<<4)+16;x[e+164>>2]=127;d=x[ud(e+48|0,e+164|0)>>2];break z}b=N()|0;break a}b=N()|0;break a}d=32;if((g|16)==18){break z}f=g&127;d=48;if(!f){break z}x[e+48>>2]=f;x[e+164>>2]=16;d=x[Ye(e+48|0,e+164|0)>>2]}f=d;x[a+480228>>2]=f;d=0;o=x[a+1074308>>2]!=0|g<<24>>24<0;if(!o){A=a,B=Bc(Uua(f<<3|5,f>>>29|0,11,0),hb),x[A+480228>>2]=B}w[a+480188>>1]=4;x[a+480232>>2]=h?(m|0)<3299?64:36:36;f=sc(e+160|0);while(1){if((d|0)==32){if(!z[a+480188>>1]){w[a+480188>>1]=1}d=y[a+484376|0];g=x[a+484360>>2];x[31737]=0;aa(349,Xb(g,d)|0,b|0,y[e+256|0]|y[e+257|0]<<8,255,254);d=x[31737];x[31737]=0;if((d|0)!=1){o=Nb(e+164|0);x[31737]=0;U(214,b|0,o|0,y[e+258|0]|y[e+259|0]<<8)|0;d=x[31737];x[31737]=0;C:{if((d|0)!=1){s=Nb(e+148|0);x[31737]=0;U(214,b|0,s|0,y[e+260|0]|y[e+261|0]<<8)|0;d=x[31737];x[31737]=0;D:{E:{F:{G:{H:{if((d|0)!=1){I:{if(y[e+277|0]!=252){break I}d=0;x[31737]=0;O(699,b|0,e+48|0);g=x[31737];x[31737]=0;if((g|0)==1){break E}g=0;J:{while(1){if((d|0)==32){K:{if(x[a+1074308>>2]!=18219008|z[a+480188>>1]>31){break I}if(!(g&1)){break J}x[31737]=0;d=P(1,e+136|0,14869)|0;f=x[31737];x[31737]=0;if((f|0)==1){break K}Ab(k,d);tb(d);break I}}else{L:{M:{h=y[(e+48|0)+d|0];if(!(h&32)){break M}if(i){Pc(e+136|0,f,d);if(Hb(x[x[e+136>>2]>>2],x[e+140>>2])){break M}}w[((d<<5)+a|0)+480284>>1]=(((h&15)<<8|8)>>>0)/15;break L}g=h>>>0<16|g}d=d+1|0;continue}break}b=N()|0;break D}x[31737]=0;d=P(1,e+136|0,8541)|0;f=x[31737];x[31737]=0;if((f|0)==1){break H}Ab(k,d);tb(d)}w[e+48>>1]=y[e+258|0]|y[e+259|0]<<8;w[e+36>>1]=3999;f=z[Nc(e+48|0,e+36|0)>>1];w[a+480190>>1]=f;t=c&2;u=e+96|0;d=0;h=0;g=0;m=0;N:{O:{P:{Q:{R:{S:{T:{while(1){if((f&65535)>>>0<=d>>>0){d=m&65535;if(!(d|!(h&i))&(y[e+264|0]|y[e+265|0]<<8)!=4864){break R}if(!i){break Q}x[31737]=0;f=U(267,a+1074312|0,79,d>>>0>1|0)|0;h=x[31737];x[31737]=0;if((h|0)==1){break O}x[31737]=0;h=f;f=d>>>0<2;h=U(267,h|0,107,f|0)|0;i=x[31737];x[31737]=0;if((i|0)==1){break O}x[31737]=0;U(267,h|0,38,f|0)|0;h=x[31737];x[31737]=0;if((h|0)==1){break O}x[31737]=0;P(128,k|0,(d>>>0>1?17237:17244)|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break O}if(f){break Q}x[a+480228>>2]=48;break Q}f=_b(x[o>>2],d);f=y[f|0]|y[f+1|0]<<8;x[31737]=0;f=P(150,b|0,f<<4)|0;l=x[31737];x[31737]=0;if((l|0)==1){break G}U:{V:{if(!f){break V}x[31737]=0;l=e+48|0;f=P(700,b|0,l|0)|0;n=x[31737];x[31737]=0;if((n|0)==1){break G}if(!f){break V}x[31737]=0;n=d+1|0;r=(D(n,104)+a|0)+484380|0;S(701,l|0,r|0,i|0);f=x[31737];x[31737]=0;if((f|0)==1){break G}q=e+24|0;aj(q,1,u);x[31737]=0;f=e+36|0;O(219,f|0,q|0);q=x[31737];x[31737]=0;if((q|0)==1){break U}zc(((n<<5)+a|0)+946304|0,f);tb(f);if(y[e+48|0]>1){break V}W:{if(!t|!(y[e+64|0]|y[e+65|0]<<8|(y[e+66|0]<<16|y[e+67|0]<<24))){break W}l=fX(l);x[31737]=0;l=P(150,b|0,l|0)|0;n=x[31737];x[31737]=0;if((n|0)==1){break T}if(!l){break W}eX(f,y[e+78|0],y[e+79|0],(y[e+266|0]|y[e+267|0]<<8)==1);x[31737]=0;U(216,f|0,r|0,b|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break S}g=y[e+39|0]==10|g;h=1}m=y[e+88|0]|y[e+89|0]<<8|m}d=d+1|0;f=z[a+480190>>1];continue}break}b=N()|0;break D}b=N()|0;break D}b=N()|0;break D}x[31737]=0;d=P(1,e+48|0,9766)|0;f=x[31737];x[31737]=0;if((f|0)==1){break P}Ab(k,d);tb(d)}if(g&1){break N}break F}b=N()|0;break D}b=N()|0;break D}x[31737]=0;d=P(1,e+36|0,17177)|0;f=x[31737];x[31737]=0;X:{if((f|0)!=1){x[31737]=0;P(75,k|0,d|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break X}tb(d);break F}b=N()|0;break D}b=N()|0;tb(d);break D}b=N()|0;break D}b=N()|0;break D}b=N()|0;break D}Y:{if(!(c&1)){break Y}c=y[e+264|0]|y[e+265|0]<<8;w[e+24>>1]=y[e+260|0]|y[e+261|0]<<8;w[e+16>>1]=255;t=z[Nc(e+24|0,e+16|0)>>1];x[31737]=0;i=a+484344|0;O(224,i|0,t|0);d=x[31737];x[31737]=0;if((d|0)!=1){u=c>>>0<4896;h=0;k=0;l=0;Z:{_:{while(1){if((h|0)==(t|0)){if(!u){break Y}a=z[a+480188>>1];if((a|0)>(k+l|0)|(a|0)<=(k-l|0)){break Y}c=fb-16|0;fb=c;a=wb(x[i>>2]);x[c+12>>2]=a;d=wb(x[i+4>>2]);while(1){if(Ib(a,d)){b=wb(x[a>>2]);f=wb(x[a+4>>2]);a=fb-16|0;fb=a;x[a+12>>2]=b;while(1){if(Ib(b,f)){if(y[b+3|0]==31){v[b+3|0]=20;v[b+5|0]=y[b+5|0]|128}b=x[vg(a+12|0)>>2];continue}break}fb=a+16|0;a=x[am(c+12|0)>>2];continue}else{fb=c+16|0}break}break Y}x[31737]=0;c=U(197,i|0,h&65535,64)|0;d=x[31737];x[31737]=0;$:{if((d|0)==1){break $}aa:{if(!c){break aa}c=_b(x[s>>2],h);c=y[c|0]|y[c+1|0]<<8;if(!c){break aa}x[31737]=0;c=P(150,b|0,c<<4)|0;d=x[31737];x[31737]=0;if((d|0)==1){break $}if(!c){break aa}x[31737]=0;P(184,b|0,2)|0;c=x[31737];x[31737]=0;if((c|0)==1){break $}d=0;c=Wb(x[i>>2],h);bf(e+24|0,x[c>>2],x[x[c+48>>2]+12>>2],0);while(1){if(d>>>0>63){break aa}f=d;x[31737]=0;c=R(198,b|0)|0;d=x[31737];x[31737]=0;ba:{if((d|0)!=1){d=c<<24>>24;if(d){break ba}d=64;if(f>>>0>62){continue}c=Wb(x[i>>2],h);d=f+1|0;bf(e+16|0,x[c>>2],x[x[c+48>>2]+12>>2],d);c=x[e+20>>2];x[e+24>>2]=x[e+16>>2];x[e+28>>2]=c;continue}b=N()|0;break D}g=bh(e+16|0);n=d&31;if(n>>>0<z[a+480188>>1]){g=Wc(x[e+24>>2],n)}r=d&255;if(r&32){x[31737]=0;c=e+14|0;O(199,c|0,b|0);q=x[31737];x[31737]=0;ca:{da:{ea:{if((q|0)!=1){q=Jc(c);c=y[e+14|0];if(c>>>0>239){break ea}c=dX((D(c>>>4|0,12)+(c&15)|0)+13|0);break da}b=N()|0;break D}fa:{switch(c-254|0){case 0:break da;case 1:break fa;default:break ca}}c=0}v[g|0]=c}v[g+1|0]=y[q|0]}if(r&64){x[31737]=0;c=R(198,b|0)|0;r=x[31737];x[31737]=0;if((r|0)==1){break _}c=c<<24>>24;v[e+14|0]=c;ga:{if((c|0)<=-64){v[g+2|0]=2;c=c^-128;break ga}v[g+2|0]=1;v[e+13|0]=64;c=y[Qb(e+14|0,e+13|0)|0]}v[g+4|0]=c}ha:{if((d|0)>=0){break ha}x[31737]=0;c=e+14|0;O(199,c|0,b|0);d=x[31737];x[31737]=0;if((d|0)==1){break Z}xD(g,y[e+14|0],y[Jc(c)|0],0);c=y[g+3|0];ia:{if((c|0)!=10){if((c|0)!=31){if((c|0)!=20){break ha}c=y[g+5|0];if((c&240)!=160|(y[e+264|0]|y[e+265|0]<<8)>>>0>4895){break ha}if((m&65535)>>>0>1){break ia}d=y[(e+n|0)+288|0]&127;if(d>>>0>=16){break ia}ja:{switch(c-160|0){case 0:case 2:v[g+5|0]=d&8?-116:-125;break ha;case 1:case 3:v[g+5|0]=d&8?-125:-116;break ha;default:break ja}}if(c>>>0>167){break ia}v[g+5|0]=136;break ha}c=y[g+5|0];if(c>>>0>15){u=0;break ha}if(c>>>0<=7){l=l+1|0;break ha}k=((c|0)!=8)+k|0;break ha}if(y[g+5|0]|(y[e+264|0]|y[e+265|0]<<8)>>>0>4865){break ha}}v[g+3|0]=37}d=f;continue}}h=h+1|0;continue}break}b=N()|0;break D}b=N()|0;break D}b=N()|0;break D}b=N()|0;break D}md(s);md(o);tb(j);d=1;break c}b=N()|0}md(s);break C}b=N()|0}md(o);break a}b=N()|0;break a}g=(d<<5)+a|0;m=g+480280|0;We(m);h=y[(d+e|0)+288|0];s=h&126;ka:{if((h|0)!=255){h=h<<24>>24;w[a+480188>>1]=d+1;if(o){w[g+480284>>1]=h&8?204:51}if((h|0)>=0){break ka}}x[m>>2]=1024}if((s-16&255)>>>0<=13){w[g+480284>>1]=128;g=e+48|0;Pc(g,f,d);fp(g)}d=d+1|0;continue}}b=N()|0;break a}fb=e+320|0;return d|0}b=N()|0}tb(j);Q(b|0);p()}function Soa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,T=0,V=0;e=fb-480|0;fb=e;xc(b);d=fb-16|0;fb=d;l=e+276|0;QW(d+8|0,l);i=x[d+12>>2];lc(d,x[b>>2],x[b+8>>2],x[d+8>>2],x[d+12>>2]);h=x[d+4>>2];if((h|0)==(i|0)){Vb(b,x[d+12>>2])}fb=d+16|0;d=(h|0)==(i|0);if(!d){OW(l)}a:{if(!d){break a}if(!RW(l)){break a}f=1;if((c|0)==64){break a}Bd(a,134217728);l=e+8|0;ig(l,3953);x[31737]=0;d=e+116|0;S(704,d|0,l|0,y[e+280|0]|y[e+281|0]<<8);i=x[31737];x[31737]=0;b:{c:{d:{if((i|0)!=1){Ab(a+1298344|0,d);tb(d);Eb(l);l=tc(d,8990);Ab(a+1298356|0,l);tb(l);T=a+1298404|0,V=x[Fc(d,28)>>2],x[T>>2]=V;x[a+480188>>2]=4;T=a,V=Bb(y[e+412|0]|y[e+413|0]<<8),x[T+480196>>2]=V;d=y[e+416|0]|y[e+417|0]<<8;x[a+480260>>2]=56;x[a+480264>>2]=13696;T=a,V=NW(Bb(d)),x[T+480204>>2]=V;kw(Xb(x[a+484360>>2],y[a+484376|0]),e+284|0,y[e+282|0]);n=a+480190|0;m=a+480188|0;o=Nb(e+264|0);t=Nb(e+252|0);e:{while(1){f:{g:{h:{i:{j:{k:{l:{if(Bb(y[e+476|0]|y[e+477|0]<<8)>>>0>(g&65535)>>>0){x[31737]=0;d=R(274,b|0)|0;l=x[31737];x[31737]=0;if((l|0)==1){break i}w[e+228>>1]=d;if((d-4e3&65535)>>>0<=61536){break c}f=Bb(y[e+478|0]|y[e+479|0]<<8);if((Bb(y[e+280|0]|y[e+281|0]<<8)|0)==2){x[31737]=0;d=R(282,b|0)|0;l=x[31737];x[31737]=0;if((l|0)==1){break j}f=d-2|0}x[31737]=0;d=e+8|0;S(186,d|0,b|0,f|0);l=x[31737];x[31737]=0;if((l|0)==1){break k}h=ic(e+116|0,d);ub(d);B=z[pe(n,e+228|0)>>1];w[a+480190>>1]=B;x[31737]=0;f=D(z[e+228>>1],104)+a|0;i=f+484380|0;O(280,i|0,1);d=x[31737];x[31737]=0;m:{n:{o:{if((d|0)==1){break o}if(Bb(y[e+280|0]|y[e+281|0]<<8)>>>0>1){break n}x[31737]=0;O(705,h|0,f+484423|0);d=x[31737];x[31737]=0;if((d|0)==1){break o}x[31737]=0;P(184,h|0,1)|0;d=x[31737];x[31737]=0;if((d|0)==1){break o}x[31737]=0;S(332,h|0,((z[e+228>>1]<<5)+a|0)+946304|0,30);d=x[31737];x[31737]=0;if((d|0)!=1){break m}}i=N()|0;break f}d=Fb(e+8|0);x[31737]=0;S(359,h|0,d|0,257);l=x[31737];x[31737]=0;p:{q:{if((l|0)==1){break q}ze(f+484423|0,d);x[31737]=0;P(184,h|0,1)|0;l=x[31737];x[31737]=0;if((l|0)==1){break q}x[31737]=0;S(359,h|0,d|0,31);l=x[31737];x[31737]=0;if((l|0)==1){break q}zc(((z[e+228>>1]<<5)+a|0)+946304|0,d);if(!(v[e+124|0]&1)){break p}x[31737]=0;P(184,h|0,1)|0;l=x[31737];x[31737]=0;if((l|0)!=1){break p}}i=N()|0;tb(d);break f}tb(d)}x[31737]=0;O(706,h|0,e+8|0);d=x[31737];x[31737]=0;r:{if((d|0)==1){break r}k=fb-16|0;fb=k;l=$b(y[e+8|0]|y[e+9|0]<<8|(y[e+10|0]<<16|y[e+11|0]<<24));x[i>>2]=l;v[k+15|0]=y[e+12|0];v[k+14|0]=64;T=i,V=y[Qb(k+15|0,k+14|0)|0]<<2,w[T+30>>1]=V;j=$b(y[e+14|0]|y[e+15|0]<<8|(y[e+16|0]<<16|y[e+17|0]<<24));x[i+4>>2]=j;d=$b(y[e+14|0]|y[e+15|0]<<8|(y[e+16|0]<<16|y[e+17|0]<<24))+$b(y[e+18|0]|y[e+19|0]<<8|(y[e+20|0]<<16|y[e+21|0]<<24))|0;x[i+8>>2]=d;if(j>>>0>=l>>>0){j=l-1|0;x[i+4>>2]=j}if(d>>>0>l>>>0){x[i+8>>2]=l;d=l}s:{if(d>>>0<j>>>0){x[i+4>>2]=0;x[i+8>>2]=0;break s}if(d>>>0<=j>>>0){break s}w[i+34>>1]=z[i+34>>1]|2;T=yb(i+68|0,0),V=j,x[T>>2]=V}fb=k+16|0;t:{switch(Bb(y[e+280|0]|y[e+281|0]<<8)|0){case 2:v[f+484417|0]=y[e+26|0]<<3;break;case 0:break g;default:break t}}x[31737]=0;O(211,t|0,B|0);d=x[31737];x[31737]=0;if((d|0)==1){break r}x[31737]=0;O(707,o|0,B|0);d=x[31737];x[31737]=0;if((d|0)==1){break r}l=Hd(x[o>>2],z[e+228>>1]-1|0);KW(l);x[31737]=0;d=R(274,b|0)|0;i=x[31737];x[31737]=0;if((i|0)==1){break l}i=x[b+8>>2];k=x[b>>2];x[31737]=0;i=U(151,k|0,i|0,d<<3)|0;k=x[31737];x[31737]=0;if((k|0)==1){break l}if(i){x[31737]=0;O(708,l|0,d|0);i=x[31737];x[31737]=0;if((i|0)==1){break l}x[e+248>>2]=0;if(!(y[f+484414|0]&2)|d){break h}d=x[f+484384>>2];x[e+240>>2]=d;i=x[f+484388>>2];x[31737]=0;x[e+244>>2]=i-d;O(709,l|0,e+240|0);d=x[31737];x[31737]=0;if((d|0)!=1){break g}i=N()|0;break f}ub(h);break c}i=N()|0;break f}u:{v:{w:{x:{if(Bb(y[e+280|0]|y[e+281|0]<<8)){u=y[e+283|0];w[e+238>>1]=4;C=128;break x}x[31737]=0;C=R(274,b|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){i=N()|0;break e}d=y[e+280|0]|y[e+281|0]<<8;u=y[e+283|0];w[e+238>>1]=4;if(!Bb(d)){break w}}l=x[b+8>>2];i=0;while(1){y:{if((i&65535)>>>0>=C>>>0){break y}x[31737]=0;d=R(274,b|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break v}if((d|0)==65535){break y}x[31737]=0;u=R(274,b|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break v}x[31737]=0;d=R(274,b|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break v}w[e+238>>1]=d;if(d>>>0>127){break c}T=m,V=z[pe(m,e+238|0)>>1],w[T>>1]=V;x[31737]=0;P(184,b|0,D(d,u)<<2)|0;d=x[31737];x[31737]=0;if((d|0)==1){break v}i=i+1|0;continue}break}x[31737]=0;P(150,b|0,l|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break u}}d=z[m>>1];x[31737]=0;E=P(710,e+240|0,d|0)|0;d=x[31737];x[31737]=0;if((d|0)!=1){J=a+484344|0;M=c&1;F=Bb(y[e+414|0]|y[e+415|0]<<8);d=0;l=0;while(1){z:{A:{B:{C:{if((d&65535)>>>0>=C>>>0){break C}D:{if(!Bb(y[e+280|0]|y[e+281|0]<<8)){f=z[e+238>>1];i=d;break D}x[31737]=0;i=R(274,b|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break z}if((i|0)==65535){break C}x[31737]=0;u=R(274,b|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break z}x[31737]=0;f=R(274,b|0)|0;h=x[31737];x[31737]=0;if((h|0)==1){break z}w[e+238>>1]=f}h=x[b+8>>2];g=x[b>>2];x[31737]=0;j=h;G=u&65535;h=G<<2;f=U(151,g|0,j|0,D(h,f&65535)|0)|0;g=x[31737];x[31737]=0;if((g|0)==1){break z}if(!f){break C}if(!M){break B}x[31737]=0;K=i&65535;i=U(197,J|0,K|0,G|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break z}if(!i){break B}r=0;E:while(1){if((r|0)==(G|0)){break A}i=Wb(x[J>>2],K);bf(e+228|0,x[i>>2],x[x[i+48>>2]+12>>2],r);i=0;s=0;F:{G:{switch((F&3)-1|0){case 0:s=!(r&3);break F;case 1:s=!(r&1);break F;case 2:break G;default:break F}}s=(r&3)!=3}H=0;while(1){if(z[e+238>>1]<=i>>>0){r=r+1|0;continue E}g=x[E>>2];h=Wc(x[e+228>>2],i);x[31737]=0;f=e+224|0;O(358,f|0,b|0);k=x[31737];x[31737]=0;if((k|0)==1){break z}k=D(i,9)+g|0;g=Jc(f);q=$e(f);v[h+1|0]=y[e+224|0];j=y[g|0];v[h|0]=j;g=y[dj(f)|0];v[h+5|0]=g;m=h+5|0;if(j){v[h|0]=j+25;v[k+8|0]=0;v[k|0]=0;v[k+1|0]=0;v[k+2|0]=0;v[k+3|0]=0;v[k+4|0]=0;v[k+5|0]=0;v[k+6|0]=0;v[k+7|0]=0;g=y[h+5|0]}j=g&255;q=y[q|0];H:{I:{if(q>>>0>=240){f=j|(q&15)<<8;if(f){v[h+3|0]=17;T=h,V=fm(+(NW(f)>>>0)/1e4),v[T+5|0]=V;j=0;break H}break I}I=j>>>4|0;L=j<<4;f=I|L;J:{switch(q|0){case 0:if(g&255){v[h+3|0]=1;j=0;break H}break I;case 1:v[h+3|0]=2;j=0;break H;case 2:v[h+3|0]=3;j=0;break H;case 3:v[e+220|0]=15;T=k,V=y[Qb(m,e+220|0)|0]|16,v[T|0]=V;v[k+7|0]=0;v[k+1|0]=0;v[k+2|0]=0;break I;case 4:v[e+220|0]=15;T=k,V=y[Qb(m,e+220|0)|0]|32,v[T|0]=V;v[k+7|0]=0;v[k+1|0]=0;v[k+2|0]=0;break I;case 5:v[k+7|0]=0;v[k+2|0]=0;v[k+1|0]=g;v[k|0]=0;break I;case 6:v[k+7|0]=0;v[k+2|0]=g;v[k|0]=0;v[k+1|0]=0;break I;case 7:v[h+3|0]=23;j=0;l=0;break H;case 8:v[h+3|0]=0;j=1;l=f;break H;case 9:v[h+3|0]=19;v[e+220|0]=15;T=h,V=y[Qb(m,e+220|0)|0]|16,v[T+5|0]=V;j=0;break H;case 10:v[h+3|0]=19;v[e+220|0]=15;T=h,V=y[Qb(m,e+220|0)|0]|32,v[T+5|0]=V;j=0;break H;case 11:v[k+3|0]=f;break I;case 12:v[h+4|0]=g;j=1;v[h+2|0]=1;v[k+3|0]=0;v[h+3|0]=0;break H;case 13:K:{L:{if((g&255)>>>0>=16){v[h+2|0]=4;g=(g&240)>>>4|0;break L}if(!(j&15)){break K}v[h+2|0]=3}v[h+4|0]=g}v[k+3|0]=0;break I;case 14:v[h+3|0]=19;v[h+5|0]=!(g&255);j=0;break H;case 15:v[h+3|0]=16;v[h+5|0]=(g&240)>>>4;F=g&15;j=0;break H;case 16:v[k+5|0]=0;v[k+4|0]=g;break I;case 17:v[k+6|0]=j&15?g:0;break I;case 18:v[h+3|0]=14;j=0;break H;case 19:v[k+8|0]=0;v[k+7|0]=g;v[k+2|0]=0;v[k|0]=0;v[k+1|0]=0;break I;case 20:v[h+3|0]=12;j=0;break H;case 22:f=y[h+1|0];M:{if(!f){break M}j=x[o>>2];if(Ud(j,x[o+4>>2])>>>0<f>>>0){break M}g=g-1|0;v[m|0]=g;x[31737]=0;R(711,e+116|0)|0;q=x[31737];x[31737]=0;if((q|0)==1){break z}x[e+220>>2]=9;f=Hd(j,f-1|0);T=e,V=Ud(x[f>>2],x[f+4>>2]),x[T+112>>2]=V;if(A[Gb(e+220|0,e+112|0)>>2]<=(g&255)>>>0){break M}v[h+2|0]=15;v[h+4|0]=y[h+5|0]}break I;case 23:f=y[h+1|0];N:{if(!f){break N}j=x[o>>2];if(Ud(j,x[o+4>>2])>>>0<f>>>0){break N}g=g-1|0;v[m|0]=g;f=Hd(j,f-1|0);j=x[f>>2];q=Ud(j,x[f+4>>2]);f=g&255;if(q>>>0<=f>>>0){break N}f=Hd(j,f);g=z[f+8>>1];O:{if(g){break O}g=0;j=z[n>>1];if(!ui(j)){break O}g=j+1|0;w[n>>1]=g;w[f+8>>1]=g}v[h+1|0]=g}break I;case 24:f=y[h+1|0];P:{if(!f){break P}j=x[o>>2];if(Ud(j,x[o+4>>2])>>>0<f>>>0){break P}g=g-1|0;v[m|0]=g;x[31737]=0;R(711,e+8|0)|0;q=x[31737];x[31737]=0;if((q|0)==1){break z}x[e+220>>2]=9;f=Hd(j,f-1|0);T=e,V=Ud(x[f>>2],x[f+4>>2]),x[T+112>>2]=V;if(A[Gb(e+220|0,e+112|0)>>2]>(g&255)>>>0){v[h+2|0]=15;v[h+4|0]=y[h+5|0]}f=_b(x[t>>2],y[h+1|0]-1|0);g=z[f>>1];Q:{if(g){break Q}g=0;j=z[n>>1];if(!ui(j)){break Q}g=j+1|0;w[n>>1]=g;w[f>>1]=g}v[h+1|0]=g}break I;case 25:f=y[h+1|0];R:{if(!f){break R}j=x[o>>2];if(Ud(j,x[o+4>>2])>>>0<f>>>0){break R}g=g-1|0;v[m|0]=g;f=Hd(j,f-1|0);j=x[f>>2];q=Ud(j,x[f+4>>2]);f=g&255;if(q>>>0<=f>>>0){break R}f=Hd(j,f);g=z[f+10>>1];S:{if(g){break S}g=0;j=z[n>>1];if(!ui(j)){break S}g=j+1|0;w[n>>1]=g;w[f+10>>1]=g}v[h+1|0]=g}break I;case 29:v[h+5|0]=f;v[h+3|0]=11;if(j&15){v[m|0]=L|15;j=0;break H}j=0;if((g&255)>>>0<16){break H}v[m|0]=I|240;break H;case 32:if((g&255)>>>0>=16){v[k+3|0]=I;break I}v[h+3|0]=19;v[h+5|0]=g|192;j=0;break H;case 33:v[h+3|0]=19;v[e+220|0]=15;T=h,V=y[Qb(m,e+220|0)|0]|208,v[T+5|0]=V;j=0;break H;case 34:v[h+3|0]=19;v[e+220|0]=15;T=h,V=y[Qb(m,e+220|0)|0]|144,v[T+5|0]=V;j=0;break H;case 73:v[h+3|0]=10;j=0;break H;case 78:if((g&112|128)==224){v[h+3|0]=19;j=0;break H}break I;case 79:if((g&255)>>>0<=31){v[h+3|0]=16;j=0;F=0;break H}v[h+3|0]=17;j=0;break H;default:break J}}}v[h+3|0]=0;j=1}f=0;g=y[k+3|0];if(!(y[h+2|0]|!g)){f=g>>>0<16;v[h+4|0]=f?g:g>>>4|0;v[h+2|0]=f?6:5;f=1}T:{if(!j){break T}g=y[k+1|0];U:{if(g){v[h+3|0]=2;break U}g=y[k+2|0];if(g){v[h+3|0]=3;break U}g=y[k|0];if(g){v[h+3|0]=19;break U}g=y[k+7|0];if(g){v[h+3|0]=4;v[k+8|0]=g;break U}g=y[k+4|0];if(g){v[h+3|0]=5;v[k+5|0]=g;break U}g=f;f=y[k+3|0];if(!(g|!f)){v[h+5|0]=f;v[h+3|0]=11;if(f&15){g=f|-16;break U}if(f>>>0<16){break T}g=f|15;break U}g=y[k+6|0];if(g){v[h+3|0]=8;break U}if(s){v[h+3|0]=20;s=0;g=97;break U}s=0;f=l&255;if(!f|H){break T}v[h+5|0]=l;v[h+3|0]=24;if(l&15){g=l|-16}else{H=1;if(f>>>0<16){break T}g=l|15}H=1}v[m|0]=g}i=i+1|0;continue}}}x[a+480228>>2]=256/z[a+480188>>1];j=1;Xh(a,1);if(Bb(y[e+280|0]|y[e+281|0]<<8)){V:{while(1){d=x[b+8>>2];l=x[b>>2];x[31737]=0;d=U(151,l|0,d|0,2)|0;l=x[31737];x[31737]=0;if((l|0)==1){break z}if(!d){break V}x[31737]=0;d=R(274,b|0)|0;l=x[31737];x[31737]=0;if((l|0)==1){break z}if((d|0)==65535){break V}x[31737]=0;P(184,b|0,2)|0;d=x[31737];x[31737]=0;if((d|0)==1){break z}x[31737]=0;d=R(282,b|0)|0;l=x[31737];x[31737]=0;if((l|0)!=1){x[31737]=0;P(184,b|0,d|0)|0;d=x[31737];x[31737]=0;if((d|0)!=1){continue}}break}break z}x[31737]=0;P(184,b|0,34)|0;d=x[31737];x[31737]=0;if((d|0)==1){break z}}W:{if(!(c&2)){break W}while(1){c=j&65535;if(c>>>0>B>>>0){break W}X:{i=(D(c,104)+a|0)+484380|0;if(!x[i>>2]){break X}d=Xc(e+228|0,8,1,0,0);x[31737]=0;U(216,d|0,i|0,b|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break z}d=x[o>>2];if(Ud(d,x[o+4>>2])>>>0<c>>>0){break X}k=c-1|0;h=Hd(d,k);c=0;d=0;m=fb-112|0;fb=m;Y:{g=x[i>>2];if(!je(g,x[i+20>>2])){break Y}r=x[h>>2];l=Ud(r,x[h+4>>2]);if(l>>>0<2){break Y}f=$o(m+8|0,i);x[f+20>>2]=0;x[f>>2]=0;Z:{while(1){if((c|0)==(l|0)){break Z}_:{n=Hd(r,c);s=x[n>>2];if(s>>>0>=g>>>0){break _}n=x[n+4>>2];if(n>>>0>g-s>>>0|268435456-n>>>0<d>>>0){break _}d=d+n|0;x[f>>2]=d;c=c+1|0;continue}break}l=c}if(!Eh(f)){break Y}n=f+68|0;d=0;c=0;while(1){if((c|0)==(l|0)){sn(i);c=$o(i,f);x[c+4>>2]=0;x[c+8>>2]=x[c>>2];w[c+34>>1]=z[c+34>>1]|2;break Y}r=x[f+20>>2]+d|0;s=x[i+20>>2];g=Hd(x[h>>2],c);yc(r,s+x[g>>2]|0,x[g+4>>2]);x[g>>2]=d;if(c-10>>>0>=4294967287){T=yb(n,c-1|0),V=d,x[T>>2]=V}c=c+1|0;d=x[g+4>>2]+d|0;continue}}fb=m+112|0;c=z[_b(x[t>>2],k)>>1];if(c){wC(i,(D(c,104)+a|0)+484380|0,0,x[i>>2],0)}c=Hd(x[o>>2],k);T=e,V=wb(x[c>>2]),x[T+228>>2]=V;d=wb(x[c+4>>2]);while(1){c=x[e+228>>2];if(!Ib(c,d)){break X}l=z[c+8>>1];if(l){wC(i,(D(l,104)+a|0)+484380|0,x[c>>2],x[c+4>>2],1)}l=z[c+10>>1];if(l){wC(i,(D(l,104)+a|0)+484380|0,x[c>>2],x[c+4>>2],0)}hl(e+228|0);continue}}j=j+1|0;continue}}MW(E);f=1;break b}x[31737]=0;P(184,b|0,D(h,z[e+238>>1])|0)|0;i=x[31737];x[31737]=0;if((i|0)!=1){break A}break z}d=d+1|0;continue}break}i=N()|0;MW(E);break e}i=N()|0;break e}i=N()|0;break e}i=N()|0;break e}i=N()|0;break f}i=N()|0;break e}i=N()|0;break e}i=N()|0;break e}f=0;while(1){if(d>>>0<=(f&65535)>>>0){break g}x[31737]=0;i=R(282,b|0)|0;k=x[31737];x[31737]=0;$:{if((k|0)==1){break $}x[31737]=0;x[e+240>>2]=i;i=R(282,b|0)|0;k=x[31737];x[31737]=0;if((k|0)==1){break $}x[31737]=0;x[e+244>>2]=i;O(709,l|0,e+240|0);i=x[31737];x[31737]=0;if((i|0)==1){break $}f=f+1|0;continue}break}i=N()|0;break f}ub(h);g=g+1|0;continue}break}ub(h)}md(t);LW(o);break d}i=N()|0;Eb(e+8|0)}Q(i|0);p()}f=0}md(t);LW(o)}fb=e+480|0;return f|0}function Yna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0;d=fb-576|0;fb=d;xc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{g=d+496|0;l:{if(!yD(b,g)){break l}if(!KV(g)){break l}if(!Mb(x[b>>2],x[b+8>>2],Bc(JV(g),hb))){break l}e=1;if((c|0)==64){break l}Bd(a,4);gg(a);v[a+1074368|0]=4;l=Fb(d+484|0);k=d+534|0;m:{if(!(kd(k,18446,20)|(y[d+556|0]|y[d+557|0]<<8|(y[d+558|0]<<16|y[d+559|0]<<24))!=276)){r=41192;e=48;if((y[d+554|0]|y[d+555|0]<<8)>>>0<260){break m}e=fu(d+513|0,0,20)?1154:34;break m}r=41192;if(!kd(k,18425,20)){break m}e=d+104|0;vi(e,3,k);x[31737]=0;g=d+192|0;S(370,g|0,4,e|0);e=x[31737];x[31737]=0;n:{if((e|0)!=1){Ab(l,g);tb(g);if((y[k|0]|y[k+1|0]<<8|(y[k+2|0]<<16|y[k+3|0]<<24))!=1852141647|(y[k+4|0]|y[k+5|0]<<8|(y[k+6|0]<<16|y[k+7|0]<<24))!=542396493){break n}e=1048;break m}b=N()|0;break a}if(!kd(k,18173,12)){e=16;if((y[d+546|0]|y[d+547|0]<<8|(y[d+548|0]<<16|y[d+549|0]<<24))==538976288&(y[d+550|0]|y[d+551|0]<<8|(y[d+552|0]<<16|y[d+553|0]<<24))==538976288){break m}v[a+1074368|0]=5;break m}if(!kd(k,11673,20)){e=48;break m}if(!kd(k,25504,15)){x[31737]=0;g=P(268,a+1074312|0,54)|0;e=x[31737];x[31737]=0;if((e|0)==1){break b}x[31737]=0;P(268,g|0,51)|0;g=x[31737];x[31737]=0;if((g|0)==1){break b}r=41184;e=16;break m}o:{if(kd(k,25520,14)){if(kd(k,25535,14)){break o}}x[31737]=0;g=P(268,a+1074312|0,57)|0;e=x[31737];x[31737]=0;if((e|0)==1){break b}x[31737]=0;P(268,g|0,51)|0;g=x[31737];x[31737]=0;e=16;if((g|0)!=1){break m}break b}e=kd(k,18261,11)?16:256}f=d+104|0;u=d+513|0;vi(f,3,u);x[31737]=0;g=d+192|0;O(219,g|0,f|0);m=x[31737];x[31737]=0;p:{q:{r:{s:{t:{if((m|0)!=1){Ab(a+1298308|0,g);tb(g);x[a+480260>>2]=1;x[a+480264>>2]=31999;af(Xb(x[a+484360>>2],y[a+484376|0]),y[d+562|0]|y[d+563|0]<<8);w[a+480188>>1]=y[d+564|0]|y[d+565|0]<<8;w[d+192>>1]=y[d+568|0]|y[d+569|0]<<8;w[d+104>>1]=255;H=a,I=z[Nc(g,f)>>1],w[H+480192>>1]=I;g=y[d+572|0]|y[d+573|0]<<8;if(g){x[a+480196>>2]=g}g=y[d+574|0]|y[d+575|0]<<8;if(g){g=D(g,1e4);g=g>>>0>=1e7?1e7:g;x[a+480204>>2]=g>>>0<=32e4?32e4:g}g=y[d+570|0]|y[d+571|0]<<8;x[a+480208>>2]=g<<4&16|g<<3&32768;f=x[a+484360>>2];m=y[a+484376|0];x[31737]=0;aa(349,Xb(f,m)|0,b|0,y[d+560|0]|y[d+561|0]<<8,65535,65535);f=x[31737];x[31737]=0;if((f|0)==1){break b}f=g>>>12&1?(e|0)==34?146:e:e;if(!(y[d+560|0]|y[d+561|0]<<8|f>>>0>1023)){g=y[a+484376|0];e=x[a+484360>>2];x[31737]=0;W(764,Xb(e,g)|0);g=x[31737];x[31737]=0;if((g|0)==1){break b}}x[31737]=0;P(150,b|0,(y[d+556|0]|y[d+557|0]<<8|(y[d+558|0]<<16|y[d+559|0]<<24))+60|0)|0;g=x[31737];x[31737]=0;if((g|0)==1){break b}if((y[d+554|0]|y[d+555|0]<<8)>>>0>=260){x[31737]=0;S(765,b|0,d+496|0,a|0);g=x[31737];x[31737]=0;if((g|0)==1){break b}}v[d+483|0]=0;B=c&2;F=d+122|0;o=d+225|0;m=Nb(d+468|0);s=1;g=-1;while(1){e=s&65535;if(e>>>0>z[a+480192>>1]){if(!(!(f&2)|t&255)){f=fu(u,0,20)?f|16:f}if((y[d+554|0]|y[d+555|0]<<8)>>>0>259){break r}if(c&3){x[31737]=0;S(765,b|0,d+496|0,a|0);c=x[31737];x[31737]=0;if((c|0)==1){break q}}if(!B){break r}e=1;while(1){c=e&65535;if(c>>>0>z[a+480190>>1]){break r}o=x[m>>2];x[31737]=0;U(216,yb(o,c-1|0)|0,(D(c,104)+a|0)+484380|0,b|0)|0;c=x[31737];x[31737]=0;if((c|0)!=1){e=e+1|0;continue}break}b=N()|0;break c}x[31737]=0;i=R(152,b|0)|0;j=x[31737];x[31737]=0;u:{v:{if((j|0)!=1){Gh(b,4);x[31737]=0;S(766,b|0,d+192|0,(i?i:263)|0);i=x[31737];x[31737]=0;if((i|0)==1){break s}w:{if((f|0)==1){i=x[d+192>>2];if((i|0)!=263){f=16;if((i|0)!=245){break w}x[a+1074308>>2]=16777381;x[31737]=0;f=P(1,d+180|0,13461)|0;i=x[31737];x[31737]=0;if((i|0)!=1){Ab(l,f);tb(f);f=17;break w}b=N()|0;break c}x[a+1074308>>2]=16777395;x[31737]=0;f=P(1,d+168|0,13352)|0;i=x[31737];x[31737]=0;if((i|0)!=1){Ab(l,f);tb(f);f=17;break w}b=N()|0;break c}if(y[d+219|0]|y[d+220|0]<<8){break w}i=x[d+192>>2];if(!(!(f&2)|(y[d+221|0]|y[d+222|0]<<8|(y[d+223|0]<<16|y[d+224|0]<<24))|(i|0)!=263)){f=f|16;break w}if(!(!(f&256)|(i|0)==29)){f=f&-257;break w}if(!(f&160)){break w}f=(i|0)==33?f:0}x[31737]=0;i=U(252,a|0,e|0,0)|0;j=x[31737];x[31737]=0;if((j|0)==1){break s}if(!i){break u}i=((e<<2)+a|0)+900380|0;e=x[i>>2];x[31737]=0;O(767,d+192|0,e|0);e=x[31737];x[31737]=0;if((e|0)==1){break s}e=y[d+218|0];x:{if((g|0)==-1){g=e;break x}if(!(f&32)|(e|0)==(g|0)){break x}f=f&-161|128}e=y[d+219|0]|y[d+220|0]<<8;if(!e){break u}x[31737]=0;j=y[d+439|0];h=y[d+435|0]|y[d+436|0]<<8;n=y[d+434|0];q=y[d+433|0];S(768,d+156|0,a|0,e|0);e=x[31737];x[31737]=0;if((e|0)==1){break t}f=j|(h|(n|q))?f&-4:f;i=x[i>>2]+236|0;e=12;j=x[d+156>>2];h=Zc(j,x[d+160>>2]);y:{while(1){z:{if((e|0)==108){if((y[d+554|0]|y[d+555|0]<<8)>>>0>259){Nf(m)}e=0;x[31737]=0;i=P(769,d+144|0,y[d+219|0]|y[d+220|0]<<8)|0;j=x[31737];x[31737]=0;if((j|0)!=1){break z}b=N()|0;break y}if(h>>>0>z[_b(i,e)>>1]){n=z[_b(j,z[_b(i,e)>>1])>>1];H=_b(i,e),I=n,w[H>>1]=I}e=e+1|0;continue}break}A:{B:{C:{D:{while(1){j=y[d+219|0]|y[d+220|0]<<8;if(e>>>0>=j>>>0){e=0;if((y[d+554|0]|y[d+555|0]<<8)>>>0<=259){break v}E:{while(1){if(e>>>0>=j>>>0){break v}n=y[yb(x[m>>2],e)+3|0];j=x[yb(x[i>>2],e)>>2];x[31737]=0;h=d+72|0;S(186,h|0,b|0,((n|0)==10?(j+1>>>1|0)+16|0:j)|0);j=x[31737];x[31737]=0;if((j|0)!=1){j=ic(d+104|0,h);ub(h);h=x[d+156>>2];if(!(!B|Zc(h,x[d+160>>2])>>>0<=e>>>0)){n=z[_b(h,e)>>1];h=yb(x[m>>2],e);h=y[h|0]|y[h+1|0]<<8|(y[h+2|0]<<16|y[h+3|0]<<24);x[31737]=0;x[d+68>>2]=h;x[d+8>>2]=h;h=ba(770,(D(n,104)+a|0)+484380|0,d+8|0,j|0,d+483|0)|0;n=x[31737];x[31737]=0;if((n|0)==1){break E}C=h^1|C}ub(j);e=e+1|0;j=y[d+219|0]|y[d+220|0]<<8;continue}break}b=N()|0;break A}b=N()|0;ub(j);break A}x[31737]=0;q=d+104|0;O(771,b|0,q|0);j=x[31737];x[31737]=0;if((j|0)==1){break B}j=d+72|0;h=y[d+118|0];F:{if(!(h&48|y[d+121|0]!=173)){Xc(j,8,1,0,10);break F}Xc(j,h&16?16:8,h&32?3:1,0,2)}x[31737]=0;O(772,m|0,j|0);h=x[31737];x[31737]=0;if((h|0)!=1){H=yb(x[i>>2],e),I=x[d+104>>2],x[H>>2]=I;G=y[d+121|0];h=x[d+156>>2];if(Zc(h,x[d+160>>2])>>>0>e>>>0){n=z[_b(h,e)>>1];x[31737]=0;h=(D(n,104)+a|0)+484380|0;O(773,q|0,h|0);q=x[31737];x[31737]=0;if((q|0)==1){break D}v[h+38|0]=y[o+202|0];v[h+39|0]=y[o+203|0];v[h+40|0]=y[o+204|0];v[h+41|0]=y[o+205|0];h=d+92|0;Xk(h,3,F);x[31737]=0;O(219,j|0,h|0);h=x[31737];x[31737]=0;if((h|0)==1){break C}zc(((n<<5)+a|0)+946304|0,j);tb(j);f=(y[d+118|0]&3)!=3?f:f&2?f|4:f}t=t|G;e=e+1|0;E=y[xf(x[m+4>>2])+3|0]==10|E;continue}break}b=N()|0;break A}b=N()|0;break A}b=N()|0;break A}b=N()|0}vc(i)}md(d+156|0);break c}b=N()|0;break c}vc(i);md(d+156|0)}s=s+1|0;continue}}b=N()|0;break a}b=N()|0;break c}b=N()|0;break c}G:{if(!(C&1)){break G}x[31737]=0;c=P(1,d+104|0,16698)|0;e=x[31737];x[31737]=0;H:{if((e|0)!=1){e=x[a+1298472>>2];x[31737]=0;S(386,e|0,2,c|0);e=x[31737];x[31737]=0;if((e|0)==1){break H}tb(c);break G}b=N()|0;break c}b=N()|0;tb(c);break c}x[31737]=0;c=P(413,b|0,5558)|0;e=x[31737];x[31737]=0;if((e|0)==1){break q}if(c){x[31737]=0;c=R(152,b|0)|0;e=x[31737];x[31737]=0;if((e|0)==1){break q}x[31737]=0;V(337,a+1298332|0,b|0,c|0,0);c=x[31737];x[31737]=0;if((c|0)==1){break q}f=f|16}x[31737]=0;o=P(413,b|0,14179)|0;c=x[31737];x[31737]=0;if((c|0)==1){break d}if(o){x[31737]=0;c=R(152,b|0)|0;e=x[31737];x[31737]=0;if((e|0)==1){break d}x[31737]=0;e=a+901404|0;S(774,b|0,e|0,c|0);c=x[31737];x[31737]=0;if((c|0)==1){break d}zD(e);f=f|16}x[31737]=0;c=P(413,b|0,13951)|0;e=x[31737];x[31737]=0;if((e|0)==1){break d}if(!c){break p}x[31737]=0;c=R(152,b|0)|0;e=x[31737];x[31737]=0;if((e|0)!=1){w[d+192>>1]=c>>>5;H=d,I=ck(x[a+484344>>2],x[a+484348>>2]),w[H+72>>1]=I;c=z[Nc(d+192|0,d+72|0)>>1];e=0;while(1){if((c|0)==(e|0)){f=f|16;break p}x[31737]=0;i=d+192|0;O(581,b|0,i|0);j=x[31737];x[31737]=0;I:{if((j|0)==1){break I}j=x[a+484344>>2];x[31737]=0;O(582,Wb(j,e)|0,i|0);i=x[31737];x[31737]=0;if((i|0)==1){break I}e=e+1|0;continue}break}b=N()|0;break c}b=N()|0;break c}b=N()|0;break c}x[31737]=0;c=P(413,b|0,13956)|0;e=x[31737];x[31737]=0;if((e|0)==1){break d}J:{if(!c){break J}x[31737]=0;c=R(152,b|0)|0;e=x[31737];x[31737]=0;if((e|0)!=1){w[d+192>>1]=(c>>>0)/20;w[d+72>>1]=z[a+480188>>1];c=z[Nc(d+192|0,d+72|0)>>1];e=0;while(1){if((c|0)==(e|0)){f=f|16;break J}x[31737]=0;S(425,b|0,((e<<5)+a|0)+480289|0,20);i=x[31737];x[31737]=0;if((i|0)!=1){e=e+1|0;continue}break}b=N()|0;break c}b=N()|0;break c}c=x[b+8>>2];e=x[b>>2];x[31737]=0;c=U(151,e|0,c|0,8)|0;e=x[31737];x[31737]=0;if((e|0)==1){break d}if(c){c=x[b+8>>2];x[31737]=0;S(426,d+192|0,a|0,b|0);e=x[31737];x[31737]=0;if((e|0)==1){break h}f=(c|0)==x[b+8>>2]?f:f|16}K:{if(!(f&16)){break K}if(f&4){x[a+1074308>>2]=17367040;x[31737]=0;c=P(1,d+192|0,14740)|0;e=x[31737];x[31737]=0;if((e|0)!=1){Ab(l,c);tb(c);break K}b=N()|0;break c}if(!(f&2)){break K}x[a+1074308>>2]=18219008;x[31737]=0;c=P(1,d+192|0,14961)|0;e=x[31737];x[31737]=0;if((e|0)==1){break g}Ab(l,c);tb(c)}L:{M:{N:{O:{P:{Q:{R:{if((y[k|0]|y[k+1|0]<<8|(y[k+2|0]<<16|y[k+3|0]<<24))==1852141647&(y[k+4|0]|y[k+5|0]<<8|(y[k+6|0]<<16|y[k+7|0]<<24))==542396493){x[31737]=0;c=U(393,d+72|0,d+542|0,12)|0;e=x[31737];x[31737]=0;if((e|0)==1){break R}x[31737]=0;e=d+156|0;S(259,e|0,1,c|0);f=x[31737];x[31737]=0;if((f|0)==1){break Q}x[31737]=0;f=R(775,e|0)|0;k=x[31737];x[31737]=0;if((k|0)==1){break P}x[a+1074308>>2]=f;tb(e);v[a+1074368|0]=A[a+1074308>>2]<19007257?4:5;tb(c);f=24}if(!(!x[a+1074308>>2]|f&8)){v[a+1074368|0]=0;Qv(a+1074312|0)}c=f&32;S:{if(!c){break S}v[a+1074368|0]=5;if(!o){pr(a+901404|0)}if((y[d+554|0]|y[d+555|0]<<8)>>>0<260){break S}x[31737]=0;U(267,a+1074312|0,4,1)|0;e=x[31737];x[31737]=0;if((e|0)==1){break d}}if(!Ad(x[l+4>>2],y[l+11|0])){break L}if(!(f&256)|t&255|g+1>>>0>1){break M}x[31737]=0;c=P(1,d+156|0,8292)|0;g=x[31737];x[31737]=0;if((g|0)==1){break N}Ab(l,c);tb(c);break L}b=N()|0;break c}b=N()|0;break O}b=N()|0;tb(d+156|0)}tb(c);break c}b=N()|0;break c}if(c){x[31737]=0;c=P(1,d+156|0,12085)|0;g=x[31737];x[31737]=0;if((g|0)!=1){Ab(l,c);tb(c);break L}b=N()|0;break c}x[31737]=0;c=P(1,d+156|0,9766)|0;g=x[31737];x[31737]=0;if((g|0)==1){break f}Ab(l,c);tb(c)}v[d+67|0]=0;if(z[a+480192>>1]){x[31737]=0;c=P(436,a|0,b|0)|0;g=x[31737];x[31737]=0;if((g|0)==1){break i}v[d+67|0]=c}x[31737]=0;ba(437,a|0,b|0,1,d+67|0)|0;b=x[31737];x[31737]=0;if((b|0)==1){break i}e=x[a+1074308>>2];T:{U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{ca:{da:{ea:{fa:{if(y[d+67|0]){if(e>>>0>18284543){break fa}x[a+1074308>>2]=18284544;break fa}if(e>>>0<18284544){break ea}}x[31737]=0;c=P(1,d+52|0,18273)|0;b=x[31737];x[31737]=0;if((b|0)==1){break da}g=x[a+1074308>>2];x[31737]=0;b=d+40|0;O(776,b|0,g|0);g=x[31737];x[31737]=0;if((g|0)==1){break ca}x[31737]=0;g=d+92|0;S(2,g|0,c|0,b|0);e=x[31737];x[31737]=0;if((e|0)==1){break ba}Ab(l,g);tb(g);tb(b);tb(c);e=x[a+1074308>>2]}ga:{if(e-1>>>0>19005952){break ga}b=x[a+484344>>2];f=x[a+484348>>2];if(!He(b,f,254)){b=y[a+484376|0];c=x[a+484360>>2];x[31737]=0;W(777,Xb(c,b)|0);b=x[31737];x[31737]=0;if((b|0)==1){break i}f=x[a+484348>>2];b=x[a+484344>>2]}if(He(b,f,255)){break ga}RC(Xb(x[a+484360>>2],y[a+484376|0]),255,65535)}x[31737]=0;c=d+40|0;O(778,c|0,4102);b=x[31737];x[31737]=0;if((b|0)==1){break $}b=y[d+554|0]|y[d+555|0]<<8;x[d+12>>2]=b>>>8;x[31737]=0;x[d+24>>2]=b&255;g=d+28|0;O(445,g|0,d+24|0);b=x[31737];x[31737]=0;if((b|0)==1){break _}x[31737]=0;b=d+92|0;V(431,b|0,c|0,d+12|0,g|0);e=x[31737];x[31737]=0;if((e|0)==1){break Z}e=Ab(a+1298344|0,b);tb(b);tb(g);Eb(c);f=Ab(a+1298368|0,l);H=a+1298404|0,I=x[Fc(b,x[(x[a+1074308>>2]?41184:r)>>2])>>2],x[H>>2]=I;if(!y[d+483|0]){break U}Ab(a+1298380|0,e);x[31737]=0;b=P(1,b|0,15388)|0;k=x[31737];x[31737]=0;if((k|0)==1){break X}Ab(e,b);tb(b);x[31737]=0;b=P(1,c|0,10117)|0;c=x[31737];x[31737]=0;if((c|0)==1){break W}Ab(a+1298356|0,b);tb(b);x[31737]=0;b=P(1,g|0,10118)|0;c=x[31737];x[31737]=0;if((c|0)==1){break V}Ab(a+1298392|0,b);break T}b=N()|0;break c}b=N()|0;break aa}b=N()|0;tb(d+40|0)}tb(c);break c}b=N()|0;break c}b=N()|0;break Y}b=N()|0;tb(d+28|0)}Eb(d+40|0);break c}b=N()|0;break c}b=N()|0;break c}b=N()|0;break c}x[31737]=0;b=P(1,d+92|0,10118)|0;c=x[31737];x[31737]=0;if((c|0)==1){break e}Ab(a+1298356|0,b)}tb(b);e=1;if(E&1){x[31737]=0;a=P(1,d+12|0,17177)|0;b=x[31737];x[31737]=0;if((b|0)==1){break k}x[31737]=0;P(75,f|0,a|0)|0;b=x[31737];x[31737]=0;if((b|0)==1){break j}tb(a)}vc(m);tb(l)}fb=d+576|0;return e|0}b=N()|0;break c}b=N()|0;tb(a);break c}b=N()|0;break c}b=N()|0;break c}b=N()|0;break c}b=N()|0;break c}b=N()|0;break c}b=N()|0}vc(m);break a}b=N()|0}tb(l);Q(b|0);p()}function uR(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;l=fb-16|0;fb=l;a:{if(z[x[x[a+48>>2]+12>>2]+480188>>1]!=z[x[x[b+48>>2]+12>>2]+480188>>1]){break a}if((a|0)!=(b|0)){g=fb-16|0;fb=g;f=x[b>>2];d=x[b+4>>2];c=Mk(f,d);b:{if(cw(a)>>>0>=c>>>0){e=d;h=x[a>>2];i=Mk(h,x[a+4>>2]);k=i>>>0>=c>>>0;if(!k){x[g+12>>2]=f;rR(g+12|0,i);e=x[g+12>>2]}f=tA(f,e,h);if(!k){uu(a,e,d,c-Mk(x[a>>2],x[a+4>>2])|0);break b}sD(a,f);break b}vR(a);NZ(a,oD(a,c));uu(a,f,d,c)}fb=g+16|0}x[a+12>>2]=x[b+12>>2];x[a+16>>2]=x[b+16>>2];x[a+20>>2]=x[b+20>>2];tR(a+24|0,b+24|0);qw(a+36|0,b+36|0);if(x[x[x[a+48>>2]+12>>2]+480180>>2]==x[x[x[b+48>>2]+12>>2]+480180>>2]){break a}c=wb(x[a>>2]);x[l+12>>2]=c;m=wb(x[a+4>>2]);while(1){if(!Ib(c,m)){break a}d=0;g=fb-112|0;fb=g;k=x[x[a+48>>2]+12>>2];f=x[k+480180>>2];h=x[x[x[b+48>>2]+12>>2]+480180>>2];c:{if((f|0)==(h|0)){break c}e=y[c+3|0];d:{e:{if((f|0)!=16){break e}i=y[c+5|0];if(!((e|0)!=19|(i|0)!=144)){v[c+3|0]=0;f=1;break d}d=5;f=1;if((e|0)!=5){break e}v[c+5|0]=i>>>1&7|i&240;break d}if(!((h|0)==67108864|(e|0)!=45)){v[c+5|0]=159;d=20;v[c+3|0]=20;break d}if((e|0)!=46){d=e;break d}d=13;v[c+3|0]=13;v[c+5|0]=y[c+5|0]+3>>>2}n=(f|0)==32|(f|0)==16777216|(f|0)==2;f:{g:{h:{i:{j:{k:{if((h|0)==2){e=9;j=1;i=LD(2);if((d&255)!=9){break k}v[c+5|0]=y[c+5|0]+1>>>1;break h}j=(h|0)==32|(h|0)==16777216;e=9;i=LD(h);if((d&255)!=9){break k}if((f|0)!=2){break h}e=y[c+5|0];if((e|0)!=164){break j}v[c+5|0]=145;d=h&16777248?20:28;v[c+3|0]=d;break g}if((d&255)!=32){e=d;break h}d=x[i+84>>2];if($i(d,32)){break i}e=31;if(!$i(d,31)){break i}v[c+3|0]=31;break h}o=c,p=yi(e<<1),v[o+5|0]=p;break g}e=32}l:{if((f|0)==16777216){d=y[c|0];m:{if(!Vg(d)){d=e;break m}j=x[i+84>>2];d=(d|0)==252?31:32;if(!$i(j,d)){d=$i(j,31)?31:0}w[g+4>>1]=999;o=g,p=Jj(e,y[c+5|0]),w[o+110>>1]=p;o=c,p=(D(z[Nc(g+4|0,g+110|0)>>1],127)>>>0)/999|0,v[o+5|0]=p;v[c+2|0]=0;v[c+3|0]=d;v[c|0]=0;v[c+1|0]=0}n:{o:{p:{e=d&255;switch(e-33|0){case 1:break g;case 2:case 3:break n;case 0:break o;default:break p}}if((e|0)!=20){break g}d=y[c+5|0];if((d&240)!=112|(d&15)>>>0<13){break l}v[c+5|0]=124;break l}d=20;v[c+3|0]=20;v[c+5|0]=y[c+5|0]>>>4|208;break g}q:{j=v[c+5|0];r:{if((j|0)>=0){v[c+3|0]=3;e=-128-j|0;d=3;break r}e=128;if((j|0)==-128){break q}v[c+3|0]=2;e=j^-128;d=2}v[c+5|0]=e;if((e&255)>>>0>30){break q}v[c+5|0]=e+1>>>1|224;break g}v[g+4|0]=(e&255)+7>>>3;v[g+110|0]=15;o=c,p=y[Qb(g+4|0,g+110|0)|0]|240,v[o+5|0]=p;break g}d=e;s:{switch(f-1|0){case 0:case 3:break s;default:break g}}if(!j){break g}t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{d=d&255;switch(d-1|0){case 2:break x;case 1:break y;case 0:break B;default:break C}}D:{switch(d-25|0){case 1:case 2:break f;case 4:break u;case 0:break v;case 3:break w;default:break D}}if((d|0)==13){break z}if((d|0)==19){break A}if((d|0)!=37){break f}v[c+3|0]=0;break f}if(y[c+5|0]){break f}v[c+3|0]=0;break f}sw(c);break f}E:{switch(y[c+2|0]){case 0:case 1:v[c+2|0]=1;v[c+3|0]=0;d=y[c+5|0];v[c+5|0]=0;v[c+4|0]=d>>>0>=64?64:d;break f;case 2:break E;default:break f}}tg(c+4|0,c+5|0);v[c+2|0]=1;if(y[c+4|0]>=65){v[c+4|0]=64}v[c+3|0]=20;v[c+5|0]=y[c+5|0]>>>2|128;break f}if(y[c+5|0]<224){break f}v[c+5|0]=223;break f}if(y[c+5|0]<224){break f}v[c+5|0]=223;break f}d=y[c+5|0];e=d-16>>>4|0;if(e>>>0>9){break f}if(!(1<<e&880)){if(!e){break t}if((e|0)!=1){break f}v[c+3|0]=3;v[c+5|0]=d&15|224;break f}v[c+3|0]=20;if(!(h&2)|(d|0)!=145){break f}v[c+5|0]=164;v[c+3|0]=9;break f}if(y[c|0]){break f}v[c+3|0]=20;v[c|0]=(h|0)==2?-2:-1;d=y[c+5|0];if(!d){v[c+1|0]=0}v[c+5|0]=d&15|208;break f}d=y[c+5|0];if(d>>>0>=16){v[g+4|0]=14;v[g+110|0]=d>>>4;o=c,p=y[Qb(g+4|0,g+110|0)|0]|240,v[o+5|0]=p;break f}v[g+4|0]=14;v[g+110|0]=d;o=c,p=y[Qb(g+4|0,g+110|0)|0]<<4|15,v[o+5|0]=p;break f}v[c+3|0]=2;v[c+5|0]=d&15|224;break f}d=20}F:{if(!n){break F}G:{switch(h-1|0){case 0:case 3:break G;default:break F}}H:{I:{switch(y[c|0]-253|0){case 1:v[c|0]=0;if(!(d&255?(h|0)==4:0)){v[c+5|0]=0;v[c+3|0]=13;break f}v[c+4|0]=0;v[c+2|0]=1;break H;case 0:break I;default:break H}}v[c|0]=255}J:{K:{L:{M:{N:{O:{P:{Q:{R:{e=d&255;switch(e-2|0){case 2:case 3:case 6:case 7:case 8:case 10:case 11:case 12:case 14:case 16:case 17:break f;case 13:break J;case 15:break L;case 1:break M;case 0:break N;case 9:break O;case 4:case 5:break P;case 18:break Q;default:break R}}if((e|0)!=29){break f}d=y[c+5|0];e=d&15;if((e|0)!=15|d>>>0<16){break K}v[c+5|0]=d>>>4;break f}S:{if(y[c+3|0]!=20){break S}v[c+3|0]=19;T:{U:{V:{W:{X:{Y:{Z:{_:{d=y[c+5|0];switch(d-16>>>4|0){case 4:case 5:case 8:case 9:break T;case 6:break U;case 10:break V;case 7:break W;case 3:break X;case 2:break Y;case 1:break Z;case 0:break _;default:break S}}v[c+5|0]=d&15|48;break S}v[c+5|0]=d&175^120;break S}v[c+5|0]=d&15|64;break S}v[c+5|0]=d&15|112;break S}v[c+3|0]=9;v[c+5|0]=D(d&15,17);break S}v[c+5|0]=d&15|96;break S}v[c+3|0]=0;break S}v[c+3|0]=28}break f}if(y[c+2|0]){break O}e=y[c+5|0];j=e&15;if(!((j|0)==15&e>>>0>=16)&(!j|(e&240)!=240)){break O}e=11;$:{switch((d&255)-6|0){case 1:e=8;case 0:v[c+2|0]=e;break;default:break $}}v[c+4|0]=0}d=y[c+5|0];e=d&15;if(!((e|0)!=15|d>>>0<16)){v[c+3|0]=19;v[c+5|0]=d>>>4|160;break f}if(!e|(d&240)!=240){break f}v[c+3|0]=19;v[c+5|0]=e|176;break f}d=y[c+5|0];if(d>>>0>=240){v[c+3|0]=19;v[c+5|0]=d&15|16;break f}if(d>>>0>=224){d=d&15;if((h|0)==4){v[c+3|0]=28;v[c+5|0]=d|16;break f}v[c+3|0]=19;v[c+5|0]=d+3>>>2|16;break f}v[c+3|0]=2;break f}d=y[c+5|0];if(d>>>0>=240){v[c+3|0]=19;v[c+5|0]=d&15|32;break f}if(d>>>0>=224){d=d&15;if((h|0)==4){v[c+3|0]=28;v[c+5|0]=d|32;break f}v[c+3|0]=19;v[c+5|0]=d+3>>>2|32;break f}v[c+3|0]=3;break f}if(y[c+5|0]>31){break f}v[c+3|0]=0;break f}if(!(!e|(d&240)!=240)){v[c+5|0]=d<<4;break f}if(e){v[c+5|0]=240;break f}if(d>>>0>=16){v[c+5|0]=15;break f}v[c+5|0]=0;break f}d=y[c+5|0];if((d-1&255)>>>0>14){break f}v[c+5|0]=d|128;break f}if((f|0)!=16777216&(f|0)!=32|(h|0)!=2){break f}aa:{switch(y[c|0]-253|0){case 0:case 2:v[c|0]=254;break;default:break aa}}ba:{switch((d&255)-20|0){case 0:d=y[c+5|0];e=d&240;if((e|0)!=144){if((e|0)!=112){break f}v[c+3|0]=0;break f}ca:{switch(d-144|0){case 1:v[c+5|0]=164;v[c+3|0]=9;break f;case 0:break ca;default:break f}}v[c+5|0]=64;v[c+3|0]=9;break f;case 3:break ba;default:break f}}v[g+4|0]=128;o=c,p=y[Qb(g+4|0,c+5|0)|0]+1>>>1|0,v[o+5|0]=p}da:{ea:{fa:{ga:{ha:{ia:{ja:{if(!((f|0)!=16777216&(f|0)!=32)){if((h|0)!=4){break ja}d=y[c+3|0];if((d|0)==23){break ia}if((d|0)!=5){break ga}d=y[c+5|0];v[c+5|0]=(d&15)+1>>>1|d&240;break ha}if((f|0)!=4){break ja}ka:{la:{switch(h-1|0){default:if((h|0)==32|(h|0)==16777216){break ka}break;case 1:case 2:break la;case 0:case 3:break ha}}d=y[c+3|0];break ea}d=y[c+3|0];if((d|0)!=23){if((d|0)!=5){break ja}d=y[c+5|0];v[g+4|0]=d<<1&30;v[g+110|0]=15;o=c,p=y[Qb(g+4|0,g+110|0)|0]|d&240,v[o+5|0]=p;break ja}v[g+4|0]=64;o=c,p=y[Qb(g+4|0,c+5|0)|0]<<1,v[o+5|0]=p}ma:{switch(h-1|0){case 0:case 3:break ha;default:break ma}}d=y[c+3|0];break fa}v[g+4|0]=128;o=c,p=y[Qb(g+4|0,c+5|0)|0]+1>>>1|0,v[o+5|0]=p}d=y[c+3|0]}na:{switch((d&255)-16|0){case 0:v[g+4|0]=31;o=c,p=y[Qb(c+5|0,g+4|0)|0],v[o+5|0]=p;d=16;break fa;case 1:break na;default:break fa}}v[g+4|0]=32;o=c,p=y[df(c+5|0,g+4|0)|0],v[o+5|0]=p;d=17}oa:{if((f|0)!=1){break oa}pa:{qa:{ra:{sa:{ta:{ua:{va:{e=d&255;switch(e-2|0){case 2:case 3:case 6:case 7:case 8:break oa;case 0:case 1:case 9:break sa;case 5:break ta;case 4:break ua;default:break va}}switch(e-19|0){case 1:break qa;case 0:break ra;default:break oa}}d=6;if(y[c+5|0]){break oa}e=4;break pa}d=7;if(y[c+5|0]){break oa}e=5;break pa}if(y[c+5|0]){break oa}e=0;break pa}d=19;j=y[c+5|0];e=(j<<4|(j<<24)+1610612736>>>28)&255;if(!(e>>>0>8|!(1<<e&387))){v[c+3|0]=0;d=0}e=0;if(j>>>0>239){break pa}break oa}d=20;e=0;if(y[c+5|0]<240){break oa}}v[c+3|0]=e;d=e}if((h|0)!=1){break ea}wa:{xa:{ya:{za:{Aa:{if(Ml(y[c|0])){v[c|0]=0;Ba:{Ca:{e=d&255;switch(e-15|0){case 1:case 2:case 3:break wa;case 0:break Aa;case 4:break Ba;default:break Ca}}if(e){break wa}v[c+5|0]=0;d=13;v[c+3|0]=13;break wa}f=y[c+5|0];if((f&240)!=208){break ya}v[c+5|0]=f&15|192;break wa}Da:{e=d&255;switch(e-15|0){case 1:case 2:case 3:break wa;case 4:break za;case 0:break Aa;default:break Da}}if(!e){break xa}break wa}d=19;v[c+3|0]=19;v[c+5|0]=y[c+5|0]&15|144;break wa}f=y[c+5|0]}if((f&255)>>>0<240){break wa}v[c+3|0]=0}d=0;Ea:{switch(y[c+2|0]-1|0){case 0:d=13;v[c+3|0]=13;v[c+5|0]=y[c+4|0];break wa;case 1:d=9;v[c+3|0]=9;e=y[c+4|0];v[c+5|0]=e>>>0>=64?-1:e<<2;break wa;case 3:d=11;v[c+3|0]=11;v[c+5|0]=y[c+4|0];break wa;case 2:d=11;v[c+3|0]=11;v[c+5|0]=y[c+4|0]<<4;break wa;case 5:d=19;v[c+3|0]=19;v[c+5|0]=y[c+4|0]|176;break wa;case 4:d=19;v[c+3|0]=19;v[c+5|0]=y[c+4|0]|160;break wa;case 12:d=3;v[c+3|0]=3;v[c+5|0]=y[c+4|0]<<2;break wa;case 11:d=2;v[c+3|0]=2;v[c+5|0]=y[c+4|0]<<2;break wa;case 10:d=4;v[c+3|0]=4;v[c+5|0]=y[c+4|0]<<2;break wa;case 7:d=5;v[c+3|0]=5;v[c+5|0]=y[c+4|0];break wa;case 6:break Ea;default:break wa}}d=5;v[c+3|0]=5;v[c+5|0]=y[c+4|0]<<4}v[c+2|0]=0;break da}if(!(d&255|(h|0)!=2)){d=0;Fa:{switch(y[c+2|0]-3|0){case 1:v[c+2|0]=0;v[c+3|0]=11;v[c+5|0]=y[c+4|0];d=11;break da;case 0:v[c+2|0]=0;v[c+3|0]=11;v[c+5|0]=y[c+4|0]<<4;d=11;break da;case 3:v[c+2|0]=0;v[c+3|0]=11;v[c+5|0]=y[c+4|0]|240;d=11;break da;case 2:v[c+2|0]=0;v[c+3|0]=11;v[c+5|0]=y[c+4|0]<<4|15;d=11;break da;case 10:v[c+2|0]=0;v[c+3|0]=3;v[c+5|0]=y[c+4|0]<<2;d=3;break da;case 9:v[c+2|0]=0;v[c+3|0]=2;d=2;v[c+5|0]=y[c+4|0]<<2;break da;case 8:v[c+2|0]=0;v[c+3|0]=4;v[c+5|0]=y[c+4|0]<<2;d=4;break da;case 5:v[c+2|0]=0;v[c+3|0]=5;v[c+5|0]=y[c+4|0];d=5;break da;case 4:v[c+2|0]=0;v[c+3|0]=5;v[c+5|0]=y[c+4|0]<<4;d=5;break da;case 6:v[c+2|0]=0;v[c+3|0]=29;v[c+5|0]=y[c+4|0]<<4;d=29;break da;case 7:break Fa;default:break da}}v[c+2|0]=0;v[c+3|0]=29;v[c+5|0]=y[c+4|0];d=29;break da}if((h|0)==4){f=y[c|0];if(!(f|(y[c+5|0]&240)!=208|(d&255)!=19)){f=0;v[c+5|0]=0;v[c+3|0]=0;d=0}Ga:{if(Ml(f)){v[c+1|0]=0;e=d&255;if(!e){break Ga}if((e|0)!=19){break da}d=19;e=y[c+5|0];if((e&240)!=208){break da}d=25;v[c+3|0]=25;v[c|0]=0;v[c+5|0]=e&15;break da}if(d&255){break da}}Ha:{switch(y[c+2|0]-11|0){case 2:v[c+2|0]=0;v[c+3|0]=3;v[c+5|0]=y[c+4|0]<<2;d=3;break da;case 1:v[c+2|0]=0;v[c+3|0]=2;d=2;v[c+5|0]=y[c+4|0]<<2;break da;case 0:break Ha;default:break da}}v[c+2|0]=0;v[c+3|0]=4;v[c+5|0]=y[(y[c+4|0]&15)+42256|0];d=4;break da}if((h|0)!=16777216&(h|0)!=32){break da}Ia:{if(d&255|((f|0)==32|(f|0)==16777216)){break Ia}d=0;Ja:{Ka:{switch(y[c+2|0]-7|0){case 2:v[c+3|0]=29;e=y[c+4|0]<<4;d=29;break Ja;case 3:v[c+3|0]=29;e=y[c+4|0];d=29;break Ja;case 0:v[c+3|0]=5;e=y[c+4|0]<<4;d=5;break Ja;case 4:break Ka;default:break Ia}}v[c+3|0]=4;e=y[c+4|0]<<4;d=4}v[c+2|0]=0;v[c+5|0]=e}e=y[c+2|0];if(e>>>0>15|!(1<<e&47480)){break da}v[g+4|0]=9;o=c,p=y[Qb(c+4|0,g+4|0)|0],v[o+4|0]=p}La:{if(y[c+2|0]!=15){break La}if(Wv(x[i+88>>2],15)){break La}e=d&255;if(!(!e|(e|0)==10)){if($i(x[i+84>>2],e)){break La}}v[c+2|0]=0;v[c+3|0]=10;Ma:{Na:{f=y[c+1|0];if(!f){break Na}d=y[c+5|0];if(z[k+480192>>1]>=f>>>0){h=y[c|0];Oa:{if(!Sc(h)){break Oa}j=x[(k+(f<<2)|0)+900380>>2];if(!j){break Oa}f=z[_b(j+236|0,h-1|0)>>1]}if(!(f&65535)){break Na}}f=f&65535;if(f>>>0>z[k+480190>>1]){break Na}h=y[c+4|0];Vv(g+4|0);if(h>>>0>9){break Na}d=(e|0)==10?d:0;e=ti(k,f);f=y[c+4|0];if(!f){e=Sua(x[e>>2],0,d&255,0);d=hb;e=e+32768|0;d=e>>>0<32768?d+1|0:d;d=yi(Bc((d&65535)<<16|e>>>16,d>>>16|0));break Ma}d=yi((x[yb(e+68|0,f-1|0)>>2]+((d&255)<<8)|0)+128>>>8|0);break Ma}d=y[c+4|0]<<3}v[c+5|0]=d;d=y[c+3|0]}Pa:{Qa:{e=d&255;switch(e-42|0){case 0:case 2:break Qa;default:break Pa}}if($i(x[i+84>>2],e)){break Pa}d=10;v[c+3|0]=10}f=y[c|0];Ra:{if(f>>>0>=y[i+8|0]){e=1;if(f>>>0<=y[i+9|0]){break Ra}}if(Ml(f)){Sa:{switch(f-253|0){case 1:e=y[i+70|0]!=0;break Ra;case 2:e=y[i+71|0]!=0;break Ra;case 0:e=y[i+72|0]!=0;break Ra;default:break Sa}}e=x[i>>2]==16777216;break Ra}e=!f}if(!e){v[c|0]=0}if(!$i(x[i+84>>2],d&255)){v[c+3|0]=0}if(Wv(x[i+88>>2],y[c+2|0])){break c}v[c+2|0]=0}fb=g+112|0;c=x[vg(l+12|0)>>2];continue}}fb=l+16|0;return a}function oka(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0,n=0,o=0,s=0,t=0,u=0,B=0,C=0,F=0,G=0,H=E(0),I=E(0),J=0,K=0;h=fb-32|0;fb=h;c=x[a+1074308>>2];if(!(c>>>0>18285125|(c|0)==18284544)){dg(a+1074312|0,0)}c=h+12|0;i=a+1074312|0;Kb(c,i,0);b=Hb(x[x[h+12>>2]>>2],x[h+16>>2]);d=x[a+480180>>2];Kb(c,i,0);n=(d&16777248)!=0&b;B=Hb(x[x[h+12>>2]>>2],x[h+16>>2]);C=x[a+480180>>2];a:{c=x[a+1074308>>2];if(c>>>0>18874367){break a}c=1;while(1){b:{b=c&65535;if(b>>>0<=z[a+480192>>1]){b=x[((b<<2)+a|0)+900380>>2];if(!b){break b}x[h+12>>2]=D(y[b+20|0],100)>>>6;x[h+24>>2]=100;J=b,K=x[Gb(h+12|0,h+24|0)>>2],v[J+20|0]=K;if(A[a+1074308>>2]>18350079&n){break b}d=v[b+26|0];v[b+26|0]=((d>>31|1)+d|0)/2;if(A[a+1074308>>2]>18285313&n){break b}AD(Zh(b,2),x[a+480180>>2]);d=x[a+1074308>>2];c:{if(d>>>0<18284544){break c}if(d>>>0>18285135){break b}if(!y[b+34|0]){break c}if(!Qj(y[b+31|0])){break c}Lb(i,2,1);if(A[a+1074308>>2]>18285135){break b}}if(!(y[b+24|0]|(y[b+23|0]|(y[b+19|0]|y[b+20|0])))){break b}Lb(i,1,1)}d:{if(!(x[a+480180>>2]&16777248)|A[a+1074308>>2]>18285313&n){break d}c=z[a+480190>>1]+1&65535;d=c>>>0<=1?1:c;b=1;while(1){if((b|0)==(d|0)){break d}c=D(b,104)+a|0;e=c+484419|0;if(!(y[e|0]|!(y[c+484421|0]|y[c+484420|0]))){v[e|0]=255}b=b+1|0;continue}}c=a+901404|0;d=c+288|0;b=zV(d);while(1){if((b|0)==(d|0)){e:{d=c+800|0;c=sC(d);while(1){if((d|0)==(c|0)){break e}yV(d);d=d+32|0;continue}}}else{yV(d);d=d+32|0;continue}break}c=x[a+1074308>>2];break a}c=c+1|0;continue}}f:{if(!(x[a+480180>>2]&16777252)|((c|0)==18874368|c>>>0>18874895)){break f}b=z[a+480192>>1]+1&65535;g=b>>>0<=1?1:b;d=0;b=1;while(1){if((b|0)==(g|0)){if(!d){break f}Lb(i,3,1);c=x[a+1074308>>2]}else{e=x[((b<<2)+a|0)+900380>>2];if(!(!e|!y[e+31|0])){v[e+33|0]=13;d=1}b=b+1|0;continue}break}}g:{if(!(x[a+480180>>2]&16777248)|((c|0)==19005440|c>>>0>19006225)){break g}Kb(h+12|0,i,0);if(!Hb(x[x[h+12>>2]>>2],x[h+16>>2])){Kb(h+24|0,i,1);if(!Hb(x[x[h+24>>2]>>2],x[h+28>>2])){break g}}c=z[a+480192>>1]+1&65535;d=c>>>0<=1?1:c;b=1;while(1){if((b|0)==(d|0)){break g}c=x[((b<<2)+a|0)+900380>>2];if(!(!c|!y[c+19|0]|!(v[c+80|0]&1))){v[c+19|0]=0}b=b+1|0;continue}}f=x[a+480180>>2];h:{i:{if(!(f&16777252)){break i}c=a+906300|0;e=Ak(c);b=c;while(1){if((b|0)==(e|0)){break i}d=b;b=b+160|0;if(!Ti(y[d+16|0]|y[d+17|0]<<8|(y[d+18|0]<<16|y[d+19|0]<<24),y[d+20|0]|y[d+21|0]<<8|(y[d+22|0]<<16|y[d+23|0]<<24))){continue}break}s=1;d=x[a+1074308>>2];if(d>>>0>19007232){break h}while(1){if((c|0)!=(e|0)){d=h+12|0;b=fb-32|0;fb=b;g=b+8|0;k=c+80|0;iS(g,k);x[31737]=0;f=b+20|0;S(124,f|0,22,g|0);m=x[31737];x[31737]=0;j:{k:{l:{if((m|0)!=1){x[31737]=0;S(245,d|0,0,f|0);m=x[31737];x[31737]=0;if((m|0)==1){break l}Ub(f);tb(g);fb=b+32|0;break j}a=N()|0;break k}a=N()|0;Ub(b+20|0)}tb(b+8|0);Q(a|0);p()}nw(k,d);c=c+160|0;tb(d);continue}break}f=x[a+480180>>2]}d=x[a+1074308>>2]}m:{n:{o:{p:{q:{if((f|0)!=4){break q}if(d>>>0<19007257){break p}if(y[a+1074368|0]!=4|d>>>0>19071235){break q}RA(a,5);d=x[a+1074308>>2]}if(d>>>0>19202054){break o}c=19202048;if((d|0)==19202048){break n}}c=z[a+480192>>1]+1&65535;g=c>>>0<=1?1:c;c=1;while(1){if((c|0)==(g|0)){break o}e=x[((c<<2)+a|0)+900380>>2];r:{if(!e|!y[e+20|0]|!y[e+31|0]){break r}b=e+236|0;f=xr(b);while(1){if((b|0)!=(f|0)){k=z[b>>1];b=b+2|0;if(!k){continue}break r}break}v[e+20|0]=0}c=c+1|0;continue}}c=d;if(c>>>0>19267583){break m}}b=z[a+480192>>1]+1&65535;e=b>>>0<=1?1:b;b=1;while(1){if((b|0)==(e|0)){break m}d=x[((b<<2)+a|0)+900380>>2];s:{if(!d){break s}c=v[d+26|0];v[d+26|0]=((c>>31|1)+c|0)/2;c=x[a+1074308>>2];if(c>>>0>18350079&n){break s}v[d+19|0]=y[d+19|0]+3>>>2}b=b+1|0;continue}}t:{if(c>>>0>19398673){break t}d=z[a+480192>>1];b=1;while(1){e=b&65535;if(e>>>0>d>>>0){break t}e=x[((e<<2)+a|0)+900380>>2];if(!e|y[e+65|0]==255){b=b+1|0;continue}else{Lb(i,94,1);c=x[a+1074308>>2]}break}}u:{if(c>>>0>19399427){break u}d=z[a+480192>>1];b=1;while(1){e=b&65535;if(e>>>0>d>>>0){break u}e=x[((e<<2)+a|0)+900380>>2];if(!e|y[e+36|0]>1){b=b+1|0;continue}else{Lb(i,101,1);c=x[a+1074308>>2]}break}}v:{if(c>>>0>19923027){break v}d=z[a+480190>>1];b=1;while(1){c=b&65535;if(c>>>0>d>>>0){break v}c=D(c,104)+a|0;if(!je(x[c+484380>>2],x[c+484400>>2])|!(y[c+484414|0]&20)){b=b+1|0;continue}else{Lb(i,116,1)}break}}c=fb-16|0;fb=c;w[h+4>>1]=0;x[h>>2]=a;Kb(c+8|0,a+1074312|0,0);J=h,K=Hb(x[x[c+8>>2]>>2],x[c+12>>2]),v[J+6|0]=K;fb=c+16|0;c=x[h>>2];u=x[h+4>>2];e=fb-32|0;fb=e;b=a+484344|0;f=wb(x[b>>2]);x[e+28>>2]=f;F=wb(x[b+4>>2]);while(1){if(Ib(f,F)){b=wb(x[f>>2]);G=wb(x[f+4>>2]);x[e+16>>2]=c;x[e+20>>2]=u;x[e>>2]=c;x[e+4>>2]=u;m=fb-16|0;fb=m;x[m+12>>2]=b;while(1){if(Ib(b,G)){t=z[e+4>>1];d=t+1|0;w[e+4>>1]=d;f=x[e>>2];w[e+4>>1]=z[f+480188>>1]>(d&65535)>>>0?d:0;w:{if(Vg(y[b|0])){break w}g=x[f+1074308>>2];x:{k=x[f+480180>>2];y:{z:{if((k|0)==2){if(g>>>0>18415615){break z}if(y[b+3|0]!=23){break y}Qf(b+5|0,64);break y}A:{if(k&16777248){B:{C:{if(g>>>0>=18285314){if(y[e+6|0]){break C}d=0;f=0;if(g>>>0>18874367){break B}}D:{switch(y[b+3|0]-20|0){case 3:Qf(b+5|0,128);break C;case 0:break D;default:break C}}d=y[b+5|0];if((d|0)!=208){if((d|0)!=192){break C}v[b|0]=254;v[b+3|0]=0;break C}v[b+3|0]=0}E:{F:{G:{if(g>>>0>=18350080){if(y[e+6|0]){break G}d=0;f=0;if(g>>>0>18874367){break B}}f=y[b+3|0];if(f>>>0>29){break F}d=1;if(!(1<<f&536873152)){break F}break E}d=0;f=0;if(g>>>0>18874367){break B}f=y[b+3|0]}d=0}f=(f|0)==24|(f|0)==22}H:{if(!(d|f)){break H}f=y[b+5|0];d=f&15;if(!d|(d|0)==15){break H}f=f&240;if(!f|(f|0)==240){break H}v[b+5|0]=y[b+3|0]==24?f:d}I:{if((g|0)==19005440|g>>>0>19005699){break I}d=z[x[e>>2]+480192>>1];if(y[e+6|0]|(!d|d>>>0>=y[b+1|0])){break I}v[b+4|0]=0;v[b+2|0]=1}if(y[b+3|0]!=18|y[b+5|0]!=17){break z}if(g>>>0>19468801){break x}if(!Ob(x[e>>2]+1074312|0,22)|y[x[e>>2]+480208|0]&4){break z}d=b+5|0;break A}if((k|0)!=4){break z}d=!y[e+6|0];J:{if((d|g>>>0<18285314)&g>>>0<=18874367){break J}if(g>>>0>19137025){break x}if(y[b+3|0]!=23|y[b+5|0]<65){break J}v[b+3|0]=0}K:{L:{M:{if(!(!(d&g>>>0<18874368)&g>>>0>=18415616)){d=y[b+3|0];f=y[b+2|0];if((d|0)!=10|(f|0)!=11){break M}d=0;v[b+3|0]=0;break K}if(g>>>0>18874639){break L}d=y[b+3|0];f=y[b+2|0]}if((f|0)!=11|(d|0)!=4){break K}f=y[b+4|0];if(!(f|y[e+6|0])){d=4;break K}d=4;o=y[b+5|0];if(!o){break K}v[b+2|0]=0;J=b,K=$v(o+(f<<4)|0),v[J+5|0]=K;break K}if(g>>>0>19007240){break x}d=y[b+3|0]}if(y[b+5|0]|(d|0)!=16){break z}d=b+3|0}v[d|0]=0}if(g>>>0>18874367){break x}}d=y[b+3|0];f=y[b+5|0]&240;N:{O:{if((d|0)!=28|(f|0)!=96){o=0}else{if(!y[e+6|0]|(k|0)!=4){break O}o=g>>>0<18350080}if(!(o|(d|0)==20&(f|0)==96)){break N}}d=D(t,-6)+b|0;while(1){if(b>>>0>d>>>0){if(!((y[d+3|0]|8)!=28|(y[d+5|0]&240)!=96)){v[d+3|0]=0}d=d+6|0;continue}break}d=y[b+3|0]}if((d|0)!=20|(f|0)!=224){break x}d=D(t,-6)+b|0;while(1){if(b>>>0<=d>>>0){break x}if(!(y[d+3|0]!=20|(y[d+5|0]&240)!=224)){v[d+3|0]=0}d=d+6|0;continue}}d=y[b+2|0];if(!((d|0)!=8|g>>>0>19333174|(g|0)==19333120)){g=y[b+4|0];d=y[b+3|0];if(!(!g|(d|0)!=7)){v[b+3|0]=11;break w}P:{Q:{switch(d-5|0){default:if((d|0)!=26){break w}break;case 1:break w;case 2:break P;case 0:break Q}}f=y[b+5|0];if(!(f&15)){v[b+2|0]=0;v[b+3|0]=5;v[b+5|0]=f|g&15;break w}R:{switch(d-5|0){case 1:break w;case 0:case 2:break P;default:break R}}if((d|0)!=26){break w}}v[b+2|0]=0;break w}S:{if(!((k|0)==16777216|(d|0)!=15)){d=y[b+3|0];if(d){break S}v[b+2|0]=0;v[b+3|0]=10;v[b+5|0]=y[b+4|0]<<3;break w}if((d|0)!=15){break w}d=y[b+3|0]}if((d&255)!=10|g>>>0>19922963){break w}if(y[b+4|0]?y[b+5|0]:1){v[b+2|0]=0;break w}v[b+3|0]=0}b=x[vg(m+12|0)>>2];continue}break}b=x[e+4>>2];x[e+8>>2]=x[e>>2];x[e+12>>2]=b;fb=m+16|0;f=x[am(e+28|0)>>2];continue}else{fb=e+32|0}break}T:{c=A[a+1074308>>2]<19267584;if(c&n){b=40352;while(1){if((b|0)==40696){break T}c=x[a+1074308>>2];d=x[b+4>>2];Lb(i,x[b>>2],c>>>0>=d>>>0|(c|0)==(d&-65536));b=b+8|0;continue}}if(!(c&((C|0)==4&B))){break T}b=40704;while(1){if((b|0)==40944){break T}Lb(i,x[b>>2],A[a+1074308>>2]>=A[b+4>>2]);b=b+8|0;continue}}U:{d=x[a+480180>>2];if(d&16777248){b=40944;while(1){if((b|0)==41016){break U}c=x[a+1074308>>2];d=x[b+4>>2];e=d&-65536;if(!(c>>>0>=e>>>0&(d>>>0<=c>>>0|c>>>0<=e>>>0))){dg(i,x[b>>2])}b=b+8|0;continue}}b=41088;c=41024;V:{switch(d-2|0){case 2:while(1){if((c|0)==41088){break U}if(A[a+1074308>>2]<A[c+4>>2]){dg(i,x[c>>2])}c=c+8|0;continue};case 0:break V;default:break U}}while(1){if((b|0)==41184){break U}if(A[a+1074308>>2]<A[b+4>>2]){dg(i,x[b>>2])}b=b+8|0;continue}}b=x[a+1074308>>2];if(!(x[a+480180>>2]!=4|b>>>0>18415615)){Lb(i,98,1);b=x[a+1074308>>2]}if(b-19333159>>>0<=33){b=0;while(1){if((b|0)!=5){c=b+77|0;Kb(h+12|0,i,c);dg(Lb(i,b+86|0,Hb(x[x[h+12>>2]>>2],x[h+16>>2])),c);b=b+1|0;continue}break}b=x[a+1074308>>2]}c=8;W:{if(b>>>0>=18284544){if(b>>>0>18874627){break W}c=6;if((b|0)==18874368){break W}}Lb(i,c,1)}c=x[a+1074308>>2];X:{if(y[a+480208|0]&16){if(c>>>0<=19136511){dg(i,7);break X}if(!(x[a+480180>>2]&16777248)|c>>>0>19267583){break X}Lb(i,7,1);break X}if((c|0)==19922944|c>>>0>19922997){break X}dg(i,7)}Kb(h+12|0,i,31);Y:{if(!Hb(x[x[h+12>>2]>>2],x[h+16>>2])){break Y}c=x[a+1074308>>2];if(c>>>0<19071234|c>>>0>19398722){break Y}d=z[a+480192>>1];b=1;while(1){c=b&65535;if(c>>>0>d>>>0){break Y}Z:{c=x[((c<<2)+a|0)+900380>>2];if(!c){break Z}e=y[c+65|0];if(!(y[c+60|0]&4)|(e|0)==255|e>>>0<=y[c- -64|0]){break Z}Lb(i,97,1);break Y}b=b+1|0;continue}}c=x[a+480180>>2];_:{if(!(c&16777218)){break _}d=z[a+480190>>1];b=1;while(1){e=b&65535;if(e>>>0>d>>>0){break _}b=b+1|0;if(!(y[(D(e,104)+a|0)+484415|0]&2)){continue}break}$:{aa:{ba:{if(!(!z[a+480192>>1]|(c|0)!=16777216)){b=x[a+1074308>>2];if(b>>>0<19398688){break aa}if(b>>>0>19464277){break ba}Lb(i,109,1)}b=x[a+1074308>>2]}if((b|0)==19922944|b>>>0>19922996){break $}}dg(i,111);b=x[a+1074308>>2]}c=x[a+480180>>2];if(!((c|0)!=2|b>>>0>19464191)){Lb(i,108,1);break _}if((c|0)==2){break _}dg(i,108)}ca:{c=x[a+1074308>>2];if(c-19333186>>>0<=589827){if(!s){break ca}b=a+906300|0;c=Ak(b);while(1){if((b|0)!=(c|0)){da:{if((y[b+16|0]|y[b+17|0]<<8|(y[b+18|0]<<16|y[b+19|0]<<24))!=1146637647|(y[b+20|0]|y[b+21|0]<<8|(y[b+22|0]<<16|y[b+23|0]<<24))!=-271958638){break da}if((Vc(x[b+4>>2],x[b+8>>2])|0)!=32){break da}d=Dc(h+12|0,16898);nw(b+80|0,d);tb(d)}b=b+160|0;continue}break}c=x[a+1074308>>2]}e=!s;ea:{if(e|c>>>0>19923027){break ea}g=z[a+480192>>1];b=1;while(1){d=b&65535;if(d>>>0>g>>>0){break ea}d=x[((d<<2)+a|0)+900380>>2];if(!d|y[d+30|0]!=1&z[d+28>>1]!=1){b=b+1|0;continue}else{Lb(i,121,1);c=x[a+1074308>>2]}break}}b=!s;if(!(e|c>>>0>19988488)){Lb(i,117,1);c=x[a+1074308>>2]}if(c-19333120>>>0>591359|b){break ca}a=a+906300|0;d=Ak(a);while(1){if((a|0)==(d|0)){break ca}fa:{if((y[a+16|0]|y[a+17|0]<<8|(y[a+18|0]<<16|y[a+19|0]<<24))!=1146637647|(y[a+20|0]|y[a+21|0]<<8|(y[a+22|0]<<16|y[a+23|0]<<24))!=-281111764){break fa}c=x[a+4>>2];if((Vc(c,x[a+8>>2])|0)!=24){break fa}H=Pd(E(E(E((l(2,y[c+12|0]|y[c+13|0]<<8|(y[c+14|0]<<16|y[c+15|0]<<24)),r())*E(2e3))+E(-1))/E(1999)),E(0));I=Pd(E(E(E((l(2,y[c+16|0]|y[c+17|0]<<8|(y[c+18|0]<<16|y[c+19|0]<<24)),r())*E(2e3))+E(-1))/E(1999)),E(0));b=(q(H),j(2));v[c+12|0]=b;v[c+13|0]=b>>>8;v[c+14|0]=b>>>16;v[c+15|0]=b>>>24;c=x[a+4>>2];b=(q(I),j(2));v[c+16|0]=b;v[c+17|0]=b>>>8;v[c+18|0]=b>>>16;v[c+19|0]=b>>>24}a=a+160|0;continue}}fb=h+32|0}function DP(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;j=fb-32|0;fb=j;a:{b:{c:{d:{e:{f:{if(Ld(b,22303)){Fb(a);break f}if(Ld(b,9909)){b=fb-96|0;fb=b;g=Fb(a);x[31737]=0;W(129,b- -64|0);a=x[31737];x[31737]=0;g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{if((a|0)!=1){x[31737]=0;x[b+40>>2]=0;a=b+52|0;c=b+40|0;O(1123,a|0,c|0);d=x[31737];x[31737]=0;if((d|0)==1){break C}x[31737]=0;d=P(842,g|0,a|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break B}tb(a);x[31737]=0;d=P(991,d|0,16817)|0;f=x[31737];x[31737]=0;if((f|0)==1){break A}x[31737]=0;x[b+40>>2]=8;O(1123,a|0,c|0);f=x[31737];x[31737]=0;if((f|0)==1){break z}x[31737]=0;d=P(842,d|0,a|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break y}tb(a);x[31737]=0;d=P(991,d|0,16817)|0;f=x[31737];x[31737]=0;if((f|0)==1){break A}x[31737]=0;x[b+40>>2]=0;O(1123,a|0,c|0);f=x[31737];x[31737]=0;if((f|0)==1){break x}x[31737]=0;d=P(842,d|0,a|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break w}tb(a);x[31737]=0;f=P(991,d|0,15125)|0;d=x[31737];x[31737]=0;if((d|0)==1){break A}d=Nb(a);a=x[b+76>>2];if(a){x[31737]=0;x[b+16>>2]=a;a=b+28|0;O(1123,a|0,b+16|0);h=x[31737];x[31737]=0;if((h|0)==1){break v}x[31737]=0;S(1017,c|0,8980,a|0);h=x[31737];x[31737]=0;if((h|0)==1){break u}x[31737]=0;O(179,d|0,c|0);h=x[31737];x[31737]=0;if((h|0)==1){break t}tb(c);tb(a)}if(!Gd(y[b+80|0])){break p}x[31737]=0;c=P(36,b+40|0,12854)|0;a=x[31737];x[31737]=0;if((a|0)==1){break r}x[31737]=0;O(179,d|0,c|0);a=x[31737];x[31737]=0;if((a|0)==1){break q}tb(c);break o}a=N()|0;break h}a=N()|0;break i}a=N()|0;tb(b+52|0);break i}a=N()|0;break i}a=N()|0;break i}a=N()|0;tb(b+52|0);break i}a=N()|0;break i}a=N()|0;tb(b+52|0);break i}a=N()|0;break j}a=N()|0;break s}a=N()|0;tb(b+40|0)}tb(b+28|0);break j}a=N()|0;break j}a=N()|0;tb(c);break j}if(!Gd(y[b+81|0])){break o}x[31737]=0;c=P(36,b+40|0,12625)|0;a=x[31737];x[31737]=0;if((a|0)==1){break n}x[31737]=0;O(179,d|0,c|0);a=x[31737];x[31737]=0;if((a|0)==1){break m}tb(c)}if(Gd(y[b+82|0])){break l}break k}a=N()|0;break j}a=N()|0;tb(c);break j}x[31737]=0;c=P(36,b+28|0,11144)|0;a=x[31737];x[31737]=0;D:{if((a|0)!=1){x[31737]=0;O(179,d|0,c|0);a=x[31737];x[31737]=0;if((a|0)==1){break D}tb(c);break k}a=N()|0;break j}a=N()|0;tb(c);break j}if(mc(x[d>>2],x[d+4>>2])){break g}x[31737]=0;f=P(991,f|0,16847)|0;a=x[31737];x[31737]=0;if((a|0)!=1){x[31737]=0;c=P(36,b+4|0,16817)|0;a=x[31737];x[31737]=0;E:{F:{G:{if((a|0)!=1){x[31737]=0;a=b+16|0;S(1124,a|0,d|0,c|0);h=x[31737];x[31737]=0;if((h|0)==1){break G}x[31737]=0;P(842,f|0,a|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break F}tb(a);tb(c);break g}a=N()|0;break j}a=N()|0;break E}a=N()|0;tb(b+16|0)}tb(c);break j}a=N()|0}Td(d)}zg(b- -64|0)}tb(g);break a}Td(d);zg(b- -64|0);fb=b+96|0;break f}if(Ld(b,8132)){x[j>>2]=0;fr(a,j);break f}if(Ld(b,8110)){x[j>>2]=8;fr(a,j);break f}if(Ld(b,10869)){x[j>>2]=0;fr(a,j);break f}if(Ld(b,10641)){Dc(a,15125);break f}if(Ld(b,11419)){Dc(a,15880);break f}if(Ld(b,7412)){b=fb-48|0;fb=b;d=b+24|0;TG(d);x[31737]=0;c=b+12|0;W(146,c|0);g=x[31737];x[31737]=0;H:{I:{J:{K:{if((g|0)!=1){x[31737]=0;g=b+36|0;S(147,g|0,d|0,c|0);f=x[31737];x[31737]=0;if((f|0)==1){break K}x[31737]=0;O(1065,a|0,g|0);a=x[31737];x[31737]=0;if((a|0)==1){break J}tb(g);tb(c);tb(d);fb=b+48|0;break f}a=N()|0;break H}a=N()|0;break I}a=N()|0;tb(b+36|0)}tb(b+12|0)}tb(b+24|0);break a}if(Ld(b,9925)){b=fb-16|0;fb=b;f=fb-16|0;fb=f;x[f+12>>2]=101;h=b+4|0;d=fb-96|0;fb=d;g=Nb(d+84|0);L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{c=x[f+12>>2];if(c&1){x[31737]=0;c=d+52|0;O(135,c|0,20054022);e=x[31737];x[31737]=0;if((e|0)==1){break _}x[31737]=0;O(102,g|0,c|0);e=x[31737];x[31737]=0;if((e|0)==1){break Z}tb(c);c=x[f+12>>2]}if(!(c&4)){break X}x[31737]=0;c=ca(136)|0;e=x[31737];x[31737]=0;if((e|0)==1){break W}if(!c){break Y}break X}c=N()|0;break M}c=N()|0;tb(d+52|0);break M}x[31737]=0;c=d+52|0;W(137,c|0);e=x[31737];x[31737]=0;$:{if((e|0)!=1){x[31737]=0;O(102,g|0,c|0);e=x[31737];x[31737]=0;if((e|0)==1){break $}tb(c);break X}c=N()|0;break M}c=N()|0;tb(d+52|0);break M}aa:{c=x[f+12>>2];if(!(c&32)){break aa}x[31737]=0;e=d+52|0;W(129,e|0);c=x[31737];x[31737]=0;ba:{ca:{da:{ea:{fa:{ga:{ha:{ia:{ja:{ka:{la:{ma:{na:{oa:{pa:{qa:{ra:{sa:{ta:{if((c|0)!=1){x[31737]=0;c=d+40|0;O(138,c|0,e|0);i=x[31737];x[31737]=0;if((i|0)==1){break ca}i=Ad(x[d+44>>2],y[d+51|0]);tb(c);if(!i){x[31737]=0;i=d+28|0;W(139,i|0);k=x[31737];x[31737]=0;if((k|0)==1){break ta}x[31737]=0;k=d+16|0;O(138,k|0,e|0);e=x[31737];x[31737]=0;if((e|0)==1){break sa}x[31737]=0;S(140,c|0,i|0,k|0);e=x[31737];x[31737]=0;if((e|0)==1){break ra}x[31737]=0;O(102,g|0,c|0);e=x[31737];x[31737]=0;if((e|0)==1){break qa}tb(c);tb(k);Eb(i)}c=Tp(d+52|0);if(!Ad(x[c+4>>2],y[c+11|0])){x[31737]=0;e=d+28|0;W(141,e|0);i=x[31737];x[31737]=0;if((i|0)==1){break na}x[31737]=0;i=d+40|0;S(142,i|0,e|0,c|0);c=x[31737];x[31737]=0;if((c|0)==1){break ma}x[31737]=0;O(102,g|0,i|0);c=x[31737];x[31737]=0;if((c|0)==1){break la}tb(i);Eb(e)}x[31737]=0;c=d+40|0;k=d+52|0;O(143,c|0,k|0);e=x[31737];x[31737]=0;if((e|0)==1){break ja}e=Ad(x[d+44>>2],y[d+51|0]);tb(c);if(!e){x[31737]=0;e=d+28|0;W(139,e|0);i=x[31737];x[31737]=0;if((i|0)==1){break ia}x[31737]=0;i=d+16|0;O(143,i|0,k|0);k=x[31737];x[31737]=0;if((k|0)==1){break ha}x[31737]=0;S(140,c|0,e|0,i|0);k=x[31737];x[31737]=0;if((k|0)==1){break ga}x[31737]=0;O(102,g|0,c|0);k=x[31737];x[31737]=0;if((k|0)==1){break fa}tb(c);tb(i);Eb(e)}zg(d+52|0);c=x[f+12>>2];break aa}c=N()|0;break M}c=N()|0;break ba}c=N()|0;break oa}c=N()|0;break pa}c=N()|0;tb(d+40|0)}tb(d+16|0)}Eb(d+28|0);break ba}c=N()|0;break ba}c=N()|0;break ka}c=N()|0;tb(d+40|0)}Eb(d+28|0);break ba}c=N()|0;break ba}c=N()|0;break ba}c=N()|0;break da}c=N()|0;break ea}c=N()|0;tb(d+40|0)}tb(d+16|0)}Eb(d+28|0);break ba}c=N()|0}zg(d+52|0);break M}ua:{if(!(c&64)){break ua}x[31737]=0;c=ca(136)|0;e=x[31737];x[31737]=0;if((e|0)==1){break W}if(c){break ua}c=d+52|0;Fb(c);x[31737]=0;O(102,g|0,c|0);e=x[31737];x[31737]=0;if((e|0)==1){break N}tb(c)}if(y[f+12|0]&128){x[31737]=0;c=d+52|0;W(144,c|0);e=x[31737];x[31737]=0;if((e|0)==1){break V}x[31737]=0;O(102,g|0,c|0);e=x[31737];x[31737]=0;if((e|0)==1){break U}tb(c)}x[31737]=0;e=P(1,d+52|0,22303)|0;c=x[31737];x[31737]=0;if((c|0)==1){break T}x[31737]=0;c=d+4|0;S(145,c|0,g|0,e|0);i=x[31737];x[31737]=0;if((i|0)==1){break S}x[31737]=0;i=d+40|0;W(146,i|0);k=x[31737];x[31737]=0;if((k|0)==1){break R}x[31737]=0;S(147,h|0,c|0,i|0);k=x[31737];x[31737]=0;if((k|0)==1){break Q}tb(i);tb(c);tb(e);Td(g);fb=d+96|0;break L}c=N()|0;break M}c=N()|0;break M}c=N()|0;tb(d+52|0);break M}c=N()|0;break M}c=N()|0;break O}c=N()|0;break P}c=N()|0;tb(d+40|0)}tb(d+4|0)}tb(e);break M}c=N()|0;tb(d+52|0)}Td(g);Q(c|0);p()}fb=f+16|0;x[31737]=0;O(1065,a|0,h|0);a=x[31737];x[31737]=0;if((a|0)!=1){tb(h);fb=b+16|0;break f}break c}if(Ld(b,10541)){b=fb-48|0;fb=b;d=b+4|0;xs(d);x[31737]=0;c=b+36|0;O(138,c|0,d|0);g=x[31737];x[31737]=0;va:{wa:{if((g|0)!=1){x[31737]=0;O(1065,a|0,c|0);a=x[31737];x[31737]=0;if((a|0)==1){break wa}tb(c);zg(d);fb=b+48|0;break f}a=N()|0;break va}a=N()|0;tb(b+36|0)}zg(b+4|0);break a}if(Ld(b,11382)){b=fb-32|0;fb=b;xs(b);x[31737]=0;O(1125,a|0,Tp(b)|0);a=x[31737];x[31737]=0;if((a|0)!=1){zg(b);fb=b+32|0;break f}a=N()|0;zg(b);break a}if(Ld(b,9938)){b=fb-48|0;fb=b;d=b+16|0;xs(d);c=x[b+28>>2];xa:{if(c){x[31737]=0;x[b+12>>2]=c;O(1123,a|0,b+12|0);a=x[31737];x[31737]=0;if((a|0)!=1){break xa}a=N()|0;zg(d);break a}Fb(a)}zg(b+16|0);fb=b+48|0;break f}if(Ld(b,12844)){xs(j);b=y[j+16|0];x[31737]=0;P(36,a|0,(Gd(b)?15577:15880)|0)|0;a=x[31737];x[31737]=0;if((a|0)==1){break e}zg(j);break f}if(Ld(b,9954)){xs(j);b=y[j+17|0];x[31737]=0;P(36,a|0,(Gd(b)?15577:15880)|0)|0;a=x[31737];x[31737]=0;if((a|0)!=1){zg(j);break f}break e}if(Ld(b,12297)){xs(j);b=y[j+18|0];x[31737]=0;P(36,a|0,(Gd(b)?15577:15880)|0)|0;a=x[31737];x[31737]=0;if((a|0)!=1){zg(j);break f}break e}if(Ld(b,12599)){b=fb-16|0;fb=b;d=fb-32|0;fb=d;g=b+4|0;c=Fb(g);x[31737]=0;W(129,d|0);f=x[31737];x[31737]=0;ya:{za:{if((f|0)!=1){x[31737]=0;O(130,c|0,Tp(d)|0);f=x[31737];x[31737]=0;if((f|0)==1){break za}zg(d);fb=d+32|0;break ya}a=N()|0;break b}a=N()|0;zg(d);break b}x[31737]=0;O(1065,a|0,g|0);a=x[31737];x[31737]=0;if((a|0)!=1){tb(g);fb=b+16|0;break f}break c}if(Ld(b,8253)){b=fb-16|0;fb=b;d=fb-48|0;fb=d;g=b+4|0;c=Fb(g);x[31737]=0;f=d+24|0;O(132,f|0,4135);h=x[31737];x[31737]=0;Aa:{Ba:{Ca:{Da:{if((h|0)!=1){x[d+20>>2]=18;x[d+16>>2]=0;x[31737]=0;x[d+12>>2]=0;h=d+36|0;aa(133,h|0,f|0,d+20|0,d+16|0,d+12|0);e=x[31737];x[31737]=0;if((e|0)==1){break Da}x[31737]=0;P(75,c|0,h|0)|0;e=x[31737];x[31737]=0;if((e|0)==1){break Ca}tb(h);Eb(f);fb=d+48|0;break Aa}a=N()|0;break b}a=N()|0;break Ba}a=N()|0;tb(d+36|0)}Eb(d+24|0);break b}x[31737]=0;O(1065,a|0,g|0);a=x[31737];x[31737]=0;if((a|0)!=1){tb(g);fb=b+16|0;break f}break c}if(Ld(b,6857)){b=fb-16|0;fb=b;c=b+4|0;d=fb-32|0;fb=d;g=d+8|0;Dc(g,20226);x[31737]=0;f=d+20|0;S(124,f|0,0,g|0);h=x[31737];x[31737]=0;Ea:{Fa:{Ga:{if((h|0)!=1){x[31737]=0;O(12,c|0,f|0);h=x[31737];x[31737]=0;if((h|0)==1){break Ga}Ub(f);tb(g);fb=d+32|0;break Ea}a=N()|0;break Fa}a=N()|0;Ub(d+20|0)}tb(d+8|0);break a}x[31737]=0;O(1065,a|0,c|0);a=x[31737];x[31737]=0;if((a|0)!=1){tb(c);fb=b+16|0;break f}break c}if(Ld(b,6455)){b=fb-48|0;fb=b;d=tc(b+24|0,18310);x[31737]=0;c=b+12|0;O(1126,c|0,2);g=x[31737];x[31737]=0;Ha:{Ia:{Ja:{Ka:{if((g|0)!=1){x[31737]=0;g=b+36|0;S(2,g|0,d|0,c|0);f=x[31737];x[31737]=0;if((f|0)==1){break Ka}x[31737]=0;O(1065,a|0,g|0);a=x[31737];x[31737]=0;if((a|0)==1){break Ja}tb(g);tb(c);tb(d);fb=b+48|0;break f}a=N()|0;break Ha}a=N()|0;break Ia}a=N()|0;tb(b+36|0)}tb(b+12|0)}tb(d);break a}if(Ld(b,11405)){b=fb-16|0;fb=b;d=fb-16|0;fb=d;Dc(d+4|0,18626);f=b+4|0;g=Fb(f);h=y[d+15|0];e=x[d+8>>2];x[31737]=0;O(94,g|0,xh(e,h)|0);h=x[31737];x[31737]=0;La:{if((h|0)!=1){Ma:{while(1){if(xh(x[d+8>>2],y[d+15|0])>>>0>c>>>0){h=y[cc(d+4|0,c)|0];x[31737]=0;O(96,g|0,h|0);h=x[31737];x[31737]=0;if((h|0)==1){break Ma}c=c+1|0;continue}break}tb(d+4|0);fb=d+16|0;break La}}a=N()|0;tb(g);tb(d+4|0);break a}x[31737]=0;O(1065,a|0,f|0);a=x[31737];x[31737]=0;if((a|0)!=1){tb(f);fb=b+16|0;break f}break c}if(Ld(b,10548)){b=fb-16|0;fb=b;d=b+4|0;ts(d,0);x[31737]=0;O(1065,a|0,d|0);a=x[31737];x[31737]=0;if((a|0)!=1){tb(d);fb=b+16|0;break f}break c}if(Ld(b,10523)){b=fb-16|0;fb=b;d=b+4|0;ts(d,2);x[31737]=0;O(1065,a|0,d|0);a=x[31737];x[31737]=0;if((a|0)!=1){tb(d);fb=b+16|0;break f}break c}if(Ld(b,10508)){b=fb-16|0;fb=b;d=b+4|0;ts(d,3);x[31737]=0;O(1065,a|0,d|0);a=x[31737];x[31737]=0;if((a|0)!=1){tb(d);fb=b+16|0;break f}break c}Fb(a)}fb=j+32|0;break d}a=N()|0;zg(j);break a}return}a=N()|0;tb(b+4|0);break a}tb(c)}Q(a|0);p()}function Ita(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,C=0;e=fb-416|0;fb=e;xc(b);f=e+399|0;g=S0(b,f);if(!g){FE(f)}a:{b:{c:{d:{e:{f:{if(!g){break f}if(!n$(f)){break f}if(!Mb(x[b>>2],x[b+8>>2],Bc(72,0))){break f}d=1;if((c|0)==64){break f}Bd(a,1);x[a+480208>>2]=x[a+480208>>2]&-25231361|16842752;k=y[e+408|0];w[a+480190>>1]=63;w[a+480188>>1]=k;d=0;g:{h:{i:{while(1){if((k&65535)>>>0<=d>>>0){j:{Rb(e+320|0,0,64);d=1;k:{l:{m:{n:{while(1){o:{f=d&65535;if(f>>>0>z[a+480190>>1]){KE(b,a+1298308|0);o$(e+312|0,b);o=Nb(e+300|0);f=y[e+409|0]|y[e+410|0]<<8;if(f){d=Nb(e+212|0);x[31737]=0;f=U(327,b|0,d|0,D(f,y[e+408|0])<<1)|0;g=x[31737];x[31737]=0;if((g|0)==1){break k}if(!f){break j}re(e+272|0,x[d>>2],x[d+4>>2]);f=Nd(e+264|0);x[31737]=0;g=x[f+4>>2];x[e+40>>2]=x[f>>2];x[e+44>>2]=g;f=jg(328,e+280|0,x[e+272>>2],x[e+276>>2],e+40|0);g=x[31737];x[31737]=0;if((g|0)==1){break o}g=x[d+4>>2];k=x[d>>2];x[31737]=0;U(214,f|0,o|0,Vc(k,g)>>>1|0)|0;g=x[31737];x[31737]=0;if((g|0)==1){break n}ub(f);dc(d)}m=Nb(e+252|0);x[31737]=0;O(329,m|0,(y[e+411|0]|y[e+412|0]<<8)<<8);d=x[31737];x[31737]=0;if((d|0)==1){break i}d=0;while(1){g=y[e+411|0]|y[e+412|0]<<8;f=d&65535;if(g>>>0<=f>>>0){break l}x[e+212>>2]=g-f;x[e+160>>2]=2e3;d=e+212|0;g=x[ud(d,e+160|0)>>2];d=Nb(d);x[31737]=0;g=U(327,b|0,d|0,g<<8)|0;k=x[31737];x[31737]=0;if((k|0)==1){break d}if(!g){break m}g=vb(e+248|0,wb(x[m+4>>2]));k=wb(x[d>>2]);h=wb(x[e+216>>2]);g=x[g>>2];x[31737]=0;V(330,m|0,g|0,k|0,h|0);g=x[31737];x[31737]=0;if((g|0)==1){break d}dc(d);d=f+2e3|0;continue}}g=(D(f,104)+a|0)+484380|0;ld(g,1);i=f+(e+320|0)|0;f=Zd(b);v[i|0]=f;if(f<<24>>24>=0){B=g,C=k$(b)<<1,x[B>>2]=C}d=d+1|0;continue}break}a=N()|0;break b}a=N()|0;ub(f);break b}dc(d);d=0;break h}re(e+232|0,x[m>>2],x[m+4>>2]);lf(e+240|0,x[e+232>>2],x[e+236>>2]);d=y[a+484376|0];f=x[a+484360>>2];x[31737]=0;O(331,Xb(f,d)|0,y[e+409|0]|y[e+410|0]<<8);d=x[31737];x[31737]=0;if((d|0)==1){break e}q=a+484344|0;s=c&1;h=0;while(1){if((y[e+409|0]|y[e+410|0]<<8)>>>0<=h>>>0){g=c&2;k=1;p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{while(1){c=k&65535;if(c>>>0>z[a+480190>>1]){break w}x[31737]=0;d=y[c+(e+320|0)|0];S(332,b|0,((c<<5)+a|0)+946304|0,d&63);f=x[31737];x[31737]=0;if((f|0)==1){break u}B:{C:{if(d<<24>>24<0){break C}x[31737]=0;d=R(333,b|0)|0;f=x[31737];x[31737]=0;D:{E:{F:{G:{H:{I:{J:{K:{if((f|0)==1){break K}c=D(c,104)+a|0;f=c+484392|0;x[f>>2]=d<<1;x[31737]=0;d=R(333,b|0)|0;h=x[31737];x[31737]=0;if((h|0)==1){break J}if(d>>>0>=2){x[c+484396>>2]=x[f>>2]+(d<<1);d=c+484414|0;w[d>>1]=z[d>>1]|8}x[31737]=0;d=R(198,b|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break t}v[e+80|0]=d;v[e+180|0]=64;B=c+484410|0,C=y[Qb(e+80|0,e+180|0)|0]<<2,w[B>>1]=C;x[31737]=0;d=R(198,b|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break K}v[c+484417|0]=d<<4;c=c+484380|0;kp(c);if(!x[c>>2]){break C}x[31737]=0;f=R(198,b|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break E}d=0;switch(f|0){case 4:case 5:break D;case 2:case 3:break G;case 1:break H;case 0:break I;default:break h}}a=N()|0;break c}a=N()|0;break c}if(g){f=Nb(e+80|0);h=x[b+8>>2];i=x[b>>2];j=x[c>>2];x[31737]=0;h=U(151,i|0,h|0,j|0)|0;i=x[31737];x[31737]=0;if((i|0)==1){break s}if(!h){break x}d=x[c>>2];x[31737]=0;S(334,b|0,f|0,d|0);d=x[31737];x[31737]=0;if((d|0)==1){break s}B=e,C=wb(x[f>>2]),x[B+180>>2]=C;h=wb(x[e+84>>2]);while(1){d=x[e+180>>2];if(Ib(d,h)){i=d;d=y[d|0];v[i|0]=d<<7|(d^-1)>>>1&127;le(e+180|0);continue}break}re(e+200|0,x[f>>2],x[e+84>>2]);d=Nd(e+192|0);x[31737]=0;h=x[d+4>>2];x[e+16>>2]=x[d>>2];x[e+20>>2]=h;d=jg(328,e+212|0,x[e+200>>2],x[e+204>>2],e+16|0);h=x[31737];x[31737]=0;L:{if((h|0)!=1){h=Xc(e+180|0,16,1,0,16);x[31737]=0;U(216,h|0,c|0,d|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break L}ub(d);dc(f);break C}a=N()|0;break p}a=N()|0;ub(d);break p}c=x[c>>2];break F}f=Nb(e+80|0);h=x[c>>2];x[31737]=0;d=e+180|0;S(335,d|0,b|0,h|0);h=x[31737];x[31737]=0;M:{N:{O:{if((h|0)!=1){i=Fn(f,d);dc(d);if(g){re(e+152|0,x[i>>2],x[e+84>>2]);h=Nd(e+144|0);x[31737]=0;j=x[h+4>>2];x[e+24>>2]=x[h>>2];x[e+28>>2]=j;h=jg(328,e+160|0,x[e+152>>2],x[e+156>>2],e+24|0);j=x[31737];x[31737]=0;if((j|0)==1){break O}d=Xc(d,8,1,0,2);x[31737]=0;U(216,d|0,c|0,h|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break N}ub(h)}dc(i);break C}a=T(28896)|0;if((gb|0)!=($(28896)|0)){break M}Y(a|0)|0;d=0;x[31737]=0;X(26);a=x[31737];x[31737]=0;if((a|0)!=1){break v}a=N()|0;break M}a=N()|0;break M}a=N()|0;ub(h)}dc(f);break c}if(g){d=Xc(e+80|0,(f|0)==2?8:16,1,0,0);x[31737]=0;U(216,d|0,c|0,b|0)|0;c=x[31737];x[31737]=0;if((c|0)!=1){break C}a=N()|0;break c}c=D(x[c>>2],f-1|0)}x[31737]=0;P(184,b|0,c|0)|0;c=x[31737];x[31737]=0;if((c|0)!=1){break C}}a=N()|0;break c}h=Nb(e+80|0);d=x[c>>2];x[31737]=0;i=e+180|0;S(336,i|0,b|0,d|0);d=x[31737];x[31737]=0;P:{Q:{if((d|0)!=1){d=Fn(h,i);dc(i);if(!g){break P}if((f|0)!=5){break Q}B=e,C=wb(x[d>>2]),x[B+180>>2]=C;j=wb(x[e+84>>2]);while(1){i=x[e+180>>2];if(!Ib(i,j)){break Q}l=i;i=y[i|0];v[l|0]=y[(i>>>7|0)+24769|0]^i;le(e+180|0);continue}}a=T(28896)|0;if((gb|0)!=($(28896)|0)){break y}Y(a|0)|0;d=0;x[31737]=0;X(26);a=x[31737];x[31737]=0;if((a|0)!=1){break B}a=N()|0;break y}re(e+112|0,x[d>>2],x[e+84>>2]);i=Nd(e+104|0);x[31737]=0;j=x[i+4>>2];x[e+32>>2]=x[i>>2];x[e+36>>2]=j;i=jg(328,e+124|0,x[e+112>>2],x[e+116>>2],e+32|0);j=x[31737];x[31737]=0;if((j|0)==1){break A}f=(f|0)==5;f=Xc(e+180|0,f?16:8,1,0,f?16:1);x[31737]=0;U(216,f|0,c|0,i|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break z}ub(i)}dc(d)}k=k+1|0;continue}break}dc(h);break h}a=N()|0;break y}a=N()|0;ub(i)}dc(h);break c}dc(f);break h}d=0;v[e+182|0]=0;w[e+180>>1]=0;w[e+80>>1]=y[e+413|0]|y[e+414|0]<<8;v[e+82|0]=y[e+415|0];while(1){if((d|0)!=3){c=y[xb(e+80|0,d)|0];B=xb(e+180|0,d),C=c,v[B|0]=C;d=d+1|0;continue}break}R:{S:{T:{U:{c=e+180|0;d=eg(c);if(d){c=Nb(c);x[31737]=0;b=U(327,b|0,c|0,d|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break r}if(!b){break S}re(e+72|0,x[c>>2],x[c+4>>2]);b=Nd(e- -64|0);x[31737]=0;f=x[b+4>>2];x[e+8>>2]=x[b>>2];x[e+12>>2]=f;b=jg(328,e+80|0,x[e+72>>2],x[e+76>>2],e+8|0);f=x[31737];x[31737]=0;if((f|0)==1){break U}x[31737]=0;V(337,a+1298332|0,b|0,d|0,1);d=x[31737];x[31737]=0;if((d|0)==1){break T}ub(b);dc(c)}x[31737]=0;W(338,e+52|0);b=x[31737];x[31737]=0;if((b|0)!=1){break R}a=N()|0;break c}a=N()|0;break q}a=N()|0;ub(b);break q}dc(c);d=0;break h}x[31737]=0;b=e+180|0;c=e+52|0;S(339,b|0,c|0,y[e+407|0]);d=x[31737];x[31737]=0;V:{W:{if((d|0)!=1){Ab(a+1298344|0,b);tb(b);Eb(c);x[31737]=0;b=P(1,b|0,10112)|0;d=x[31737];x[31737]=0;if((d|0)==1){break W}Ab(a+1298356|0,b);tb(b);x[31737]=0;b=P(1,c|0,5101)|0;c=x[31737];x[31737]=0;if((c|0)==1){break V}Ab(a+1298368|0,b);tb(b);B=a+1298404|0,C=x[Fc(e+48|0,24)>>2],x[B>>2]=C;d=1;break h}a=N()|0;Eb(e+52|0);break c}a=N()|0;break c}a=N()|0;break c}dc(f);break h}a=N()|0;break c}a=N()|0;break c}a=N()|0;break p}a=N()|0}dc(c);break c}dc(f);break c}B=_b(x[Xb(x[a+484360>>2],y[a+484376|0])>>2],h),C=h,w[B>>1]=C;X:{Y:{if(!s){break Y}x[31737]=0;r=h&65535;d=U(197,q|0,r|0,64)|0;f=x[31737];x[31737]=0;if((f|0)==1){break X}if(!d){break Y}f=z[a+480188>>1];i=0;while(1){d=f&65535;if(d>>>0<=i>>>0){break Y}d=_b(x[o>>2],D(d,h)+i|0);d=y[d|0]|y[d+1|0]<<8;Z:{if(d>>>0>=(y[e+411|0]|y[e+412|0]<<8)>>>0){break Z}k=0;t=d<<8;d=Wb(x[q>>2],h);d=jd(x[d>>2],x[x[d+48>>2]+12>>2],0,i&65535);u=D(i,-6);while(1){if((k|0)==64){break Z}Cr(e+212|0,x[e+240>>2],x[e+244>>2],(k<<2)+t|0,4);f=x[e+212>>2];g=xb(f,0);n=y[g|0]&63;v[d|0]=n?n+48|0:0;j=xb(f,1);v[d+1|0]=y[j|0]<<2&60|y[g|0]>>>6;l=y[j|0];g=xb(f,2);j=y[xb(f,3)|0];f=y[g|0];g=j<<4|f>>>4;w[e+80>>1]=g;A=l>>>6|0;l=f<<2&60;f=A|l;_:{if(!(y[xb(e+312|0,l>>>3|0)|0]>>>(f&7)&1)|!(f|g)){break _}v[d+5|0]=g;l=j>>>4|0;v[d+4|0]=l;$:{aa:{ba:{ca:{da:{ea:{fa:{ga:{ha:{ia:{ja:{ka:{switch(f|0){case 0:case 1:case 2:case 32:case 33:case 34:Bf(d,f&15,g&255);if(!y[d+4|0]){break _}v[d+2|0]=f>>>0<32?3:4;break _;case 9:v[d+3|0]=10;v[d+5|0]=g>>>1;if(g>>>0<512){break _}v[d+2|0]=15;v[d+4|0]=j>>>5;break _;case 10:case 42:if(g>>>0>254){break ja}f=f&15;break;case 50:break aa;case 48:break ba;case 43:break ca;case 47:break da;case 17:case 18:case 26:case 27:break ea;case 22:case 25:case 28:case 29:case 30:break fa;case 16:case 19:case 20:case 21:case 23:case 31:break ga;case 13:break ha;case 11:case 15:break ia;case 3:case 4:case 5:case 6:case 7:case 12:break ka;default:break $}}Bf(d,f,g&255);break _}v[d+3|0]=19;v[d+5|0]=l|(f>>>0<32?16:32);if(j&15){v[d+2|0]=3;v[d+4|0]=(g&240)>>>4;break _}v[d+2|0]=4;v[d+4|0]=g&15;break _}v[d+3|0]=(f|0)==11?12:16;B=d,C=$v(g),v[B+5|0]=C;break _}v[d+3|0]=14;if((g&255)>>>0<64){break _}v[d+5|0]=0;break _}v[d+3|0]=19;v[d+5|0]=g&15|f<<4;break _}v[d+3|0]=19;w[e+160>>1]=15;B=d,C=y[Nc(e+80|0,e+160|0)|0]|f<<4,v[B+5|0]=C;break _}v[d+3|0]=19;if(g&255){v[d+5|0]=g&15|((f|0)==17?16:(f|0)==26?16:32);if(j>>>0<16){break _}v[d+2|0]=f>>>0>25?6:5;break _}v[d+5|0]=l|(f>>>0>25?-80:-96);break _}if(!g){break $}v[d+3|0]=17;x[e+160>>2]=8;x[e+124>>2]=g+4;B=d,C=Ch(x[Ye(e+160|0,e+124|0)>>2]/8|0),v[B+5|0]=C;break _}v[d+3|0]=14;j=d+u|0;n=z[a+480188>>1];f=0;while(1){if((f|0)==(n|0)){break _}g=j+D(f,6)|0;if(!y[g+3|0]){v[g+3|0]=12;B=g,C=$v(r),v[B+5|0]=C}f=f+1|0;continue}}v[d+3|0]=9;f=g&7;if(f){v[d+5|0]=y[f+24761|0];break _}f=g>>>4|0;if((f|0)==128){break $}v[d+5|0]=f;if(g>>>0<=2047){v[d+5|0]=f^128;break _}v[d+5|0]=f^-1;break _}v[d+5|0]=0;v[d+3|0]=0;if(!n){v[d|0]=255;break _}v[d+3|0]=25;break _}v[d+3|0]=0}k=k+1|0;f=z[a+480188>>1];d=D(f,6)+d|0;continue}}i=i+1|0;continue}}h=h+1|0;continue}break}a=N()|0;break c}a=N()|0;break b}}else{ZD(a,d&65535);w[((d<<5)+a|0)+480284>>1]=(d&3)-1>>>0<2?64:192;d=d+1|0;k=z[a+480188>>1];continue}break}dc(d);d=0;break g}a=N()|0;break c}dc(m)}md(o)}fb=e+416|0;return d|0}a=N()|0;break c}a=N()|0;dc(d)}dc(m);break a}dc(d)}md(o);Q(a|0);p()}function D1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;a:{n=gk(b,13930);if(!n){break a}b:while(1){if(!Mb(x[b>>2],x[b+8>>2],6)){break a}f=Pg(b);if(!(!((f|0)==(Jn(13780)|0)|!(f&1616928864)|f&-2139062144)&(f|0)!=70791730)){Gh(b,4);break a}l=1;c=hh(b);while(1){e=l&65535;if(e>>>0>z[a+480192>>1]){continue b}e=x[((e<<2)+a|0)+900380>>2];if(e){c:{g=0;if((Jn(16801)|0)==(f|0)){Vb(b,c);break c}h=fb-48|0;fb=h;d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{switch(f-1349079874|0){default:if((f|0)==1095062094){break t}if((f|0)==1095126087){break q}if((f|0)==1129524782){break z}if((f|0)==1145263150){break W}if((f|0)==1145979182){break V}if((f|0)==1179463214){break x}if((f|0)==1851469358){break D}if((f|0)==1179931728){break l}Z:{_:{$:{aa:{ba:{ca:{da:{ea:{fa:{ga:{ha:{if((f|0)!=1196830254){if((f|0)==1229341486){break S}if((f|0)==1229345326){break R}if((f|0)==1264266798){break E}if((f|0)==1296182830){break Q}if((f|0)==1296248366){break O}if((f|0)==1297100334){break P}if((f|0)==1297110852){break o}if((f|0)==1298747438){break B}if((f|0)==1313692462){break F}if((f|0)==1313751342){break X}if((f|0)==1345203758){break ha}if((f|0)==1346711086){break j}if((f|0)==1346720334){break u}if((f|0)==1346722606){break H}if((f|0)==1346784327){break r}if((f|0)==1347175726){break ba}if((f|0)==1347179310){break ca}if((f|0)==1347437358){break M}if((f|0)==1347441454){break N}if((f|0)==1347443502){break K}if((f|0)==1347628590){break U}if((f|0)==1347633710){break aa}if((f|0)==1347634478){break $}if((f|0)==1347703884){break m}if((f|0)==1347831112){break w}if((f|0)==1347833672){break v}if((f|0)==1349076270){break i}if((f|0)==1349076315){break G}if((f|0)==1349078085){break Z}if((f|0)==1349078099){break _}if((f|0)==1349079131){break J}if((f|0)==1378758190){break n}if((f|0)==1381183022){break y}if((f|0)==1447374382){break k}if((f|0)==1447383630){break s}if((f|0)==1447385902){break I}if((f|0)==1447447623){break p}if((f|0)==1447839022){break fa}if((f|0)==1447842606){break ga}if((f|0)==1448106798){break L}if((f|0)==1448226350){break A}if((f|0)==1448291886){break T}if((f|0)==1448297006){break ea}if((f|0)==1448297774){break da}if((f|0)!=1682320942){if((f|0)==1718508334){break C}if((f|0)!=1179594286|c>>>0>4){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Mw(b,c),x[o>>2]=q;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Jd(b,c),v[o+15|0]=q;break e}if(c>>>0>4){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Mw(b,c),x[o+4>>2]=q;break e}if(c>>>0>4){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Mw(b,c),x[o+8>>2]=q;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Jd(b,c),v[o+61|0]=q;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Jd(b,c),v[o+62|0]=q;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Jd(b,c),v[o+63|0]=q;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e- -64|0,q=Jd(b,c),v[o|0]=q;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Jd(b,c),v[o+81|0]=q;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Jd(b,c),v[o+82|0]=q;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Jd(b,c),v[o+83|0]=q;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Jd(b,c),v[o+84|0]=q;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Jd(b,c),v[o+101|0]=q;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Jd(b,c),v[o+102|0]=q;break e;case 0:if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Jd(b,c),v[o+103|0]=q;break e;case 3:break Y;case 1:case 2:break d}}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Jd(b,c),v[o+104|0]=q;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Jd(b,c),v[o+16|0]=q;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Jd(b,c),v[o+17|0]=q;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Jd(b,c),v[o+18|0]=q;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Jd(b,c),v[o+19|0]=q;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Jd(b,c),v[o+20|0]=q;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Jd(b,c),v[o+21|0]=q;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Jd(b,c),v[o+22|0]=q;break e}if(c>>>0>2){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=GF(b,c),w[o+28>>1]=q;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Jd(b,c),v[o+30|0]=q;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Jd(b,c),v[o+31|0]=q;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=FF(b,c),v[o+26|0]=q;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Jd(b,c),v[o+27|0]=q;break e}d=h+8|0;fe(d,b,c);j=ic(h+28|0,d);ub(d);i=Zh(e,0);g=x[i>>2];d=0;while(1){if(Sd(g,x[i+4>>2])>>>0<=d>>>0){ub(j);break e}x[31737]=0;k=R(193,j|0)|0;g=x[31737];x[31737]=0;if((g|0)==1){break h}g=x[i>>2];o=yb(g,d),q=k,w[o>>1]=q;d=d+1|0;continue}}d=h+8|0;fe(d,b,c);j=ic(h+28|0,d);ub(d);i=Zh(e,1);g=x[i>>2];d=0;while(1){if(Sd(g,x[i+4>>2])>>>0<=d>>>0){ub(j);break e}x[31737]=0;k=R(193,j|0)|0;g=x[31737];x[31737]=0;if((g|0)!=1){g=x[i>>2];o=yb(g,d),q=k,w[o>>1]=q;d=d+1|0;continue}break}d=N()|0;break g}d=h+8|0;fe(d,b,c);j=ic(h+28|0,d);ub(d);i=Zh(e,2);g=x[i>>2];d=0;while(1){if(Sd(g,x[i+4>>2])>>>0<=d>>>0){ub(j);break e}x[31737]=0;k=R(193,j|0)|0;g=x[31737];x[31737]=0;if((g|0)!=1){g=x[i>>2];o=yb(g,d),q=k,w[o>>1]=q;d=d+1|0;continue}break}d=N()|0;break g}d=h+8|0;fe(d,b,c);j=ic(h+28|0,d);ub(d);i=Zh(e,0);g=x[i>>2];d=0;while(1){if(Sd(g,x[i+4>>2])>>>0<=d>>>0){ub(j);break e}x[31737]=0;k=R(194,j|0)|0;g=x[31737];x[31737]=0;if((g|0)!=1){g=x[i>>2];o=yb(g,d),q=k,v[o+2|0]=q;d=d+1|0;continue}break}d=N()|0;break g}d=h+8|0;fe(d,b,c);j=ic(h+28|0,d);ub(d);i=Zh(e,1);g=x[i>>2];d=0;while(1){if(Sd(g,x[i+4>>2])>>>0<=d>>>0){ub(j);break e}x[31737]=0;k=R(194,j|0)|0;g=x[31737];x[31737]=0;if((g|0)!=1){g=x[i>>2];o=yb(g,d),q=k,v[o+2|0]=q;d=d+1|0;continue}break}d=N()|0;break g}d=h+8|0;fe(d,b,c);j=ic(h+28|0,d);ub(d);i=Zh(e,2);g=x[i>>2];d=0;while(1){if(Sd(g,x[i+4>>2])>>>0<=d>>>0){ub(j);break e}x[31737]=0;k=R(194,j|0)|0;g=x[31737];x[31737]=0;if((g|0)!=1){g=x[i>>2];o=yb(g,d),q=k,v[o+2|0]=q;d=d+1|0;continue}break}d=N()|0;break g}if(c>>>0>128){break d}g=e+108|0;d=h+8|0;fe(d,b,c);j=ic(h+28|0,d);ub(d);d=0;while(1){if((d|0)==128){ub(j);break e}x[31737]=0;i=R(194,j|0)|0;k=x[31737];x[31737]=0;if((k|0)!=1){o=xb(g,d),q=i,v[o|0]=q;d=d+1|0;continue}break}d=N()|0;break g}if(c>>>0>256){break d}g=e+236|0;d=h+8|0;fe(d,b,c);j=ic(h+28|0,d);ub(d);d=0;while(1){if((d|0)==128){ub(j);break e}x[31737]=0;i=R(193,j|0)|0;k=x[31737];x[31737]=0;if((k|0)!=1){o=_b(g,d),q=i,w[o>>1]=q;d=d+1|0;continue}break}d=N()|0;break g}if(c>>>0>32){break d}i=e+492|0;d=h+8|0;fe(d,b,c);j=ic(h+28|0,d);ub(d);g=Fb(d);d=0;while(1){if((c|0)==(d|0)){break f}x[31737]=0;k=R(195,j|0)|0;m=x[31737];x[31737]=0;ia:{if((m|0)==1){break ia}x[31737]=0;P(196,g|0,k|0)|0;k=x[31737];x[31737]=0;if((k|0)==1){break ia}d=d+1|0;continue}break}d=N()|0;tb(g);break g}if(c>>>0>32){break d}i=e+524|0;d=h+8|0;fe(d,b,c);j=ic(h+28|0,d);ub(d);g=Fb(d);d=0;ja:{while(1){if((c|0)!=(d|0)){x[31737]=0;k=R(195,j|0)|0;m=x[31737];x[31737]=0;if((m|0)==1){break ja}x[31737]=0;P(196,g|0,k|0)|0;k=x[31737];x[31737]=0;if((k|0)==1){break ja}d=d+1|0;continue}break}zc(i,g);tb(g);ub(j);break e}d=N()|0;tb(g);break g}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Jd(b,c),v[o+34|0]=q;break e}if(c>>>0>2){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=GF(b,c),w[o+12>>1]=q;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Jd(b,c),v[o+23|0]=q;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Jd(b,c),v[o+24|0]=q;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Jd(b,c),v[o+25|0]=q;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Jd(b,c),v[o+35|0]=q;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Jd(b,c),v[o+36|0]=q;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Jd(b,c),v[o+105|0]=q;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Jd(b,c),v[o+85|0]=q;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Jd(b,c),v[o+65|0]=q;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Jd(b,c),v[o+100|0]=q;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Jd(b,c),v[o+80|0]=q;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=Jd(b,c),v[o+60|0]=q;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}o=e,q=FF(b,c),v[o+33|0]=q;break e}g=1;d=Ap(b,c);if(!zp(d)){break d}v[e+14|0]=d;break d}o=e,q=D(Kw(b,c),1e4)+(A[e+40>>2]%1e4|0)|0,x[o+40>>2]=q;break e}g=(Kw(b,c)>>>0)%1e4|0;d=x[e+40>>2];x[e+40>>2]=g+d-(d>>>0)%1e4;break e}x[h+28>>2]=240;o=h,q=Ap(b,c),x[o+8>>2]=q;gh(e+48|0,x[Gb(h+28|0,h+8|0)>>2]);break e}x[h+28>>2]=240;o=h,q=Ap(b,c),x[o+8>>2]=q;gh(e+68|0,x[Gb(h+28|0,h+8|0)>>2]);break e}x[h+28>>2]=240;o=h,q=Ap(b,c),x[o+8>>2]=q;gh(e+88|0,x[Gb(h+28|0,h+8|0)>>2]);break e}d=N()|0}ub(j);Q(d|0);p()}zc(i,g);tb(g);ub(j)}g=1}fb=h+48|0;if(!g){Vb(b,c);break c}if((Jn(16806)|0)==(f|0)){d=y[e+15|0];v[e+15|0]=0;v[e+100|0]=d>>>5&4|(y[e+100|0]&224|d>>>6&1);v[e+60|0]=d>>>1&2|(d<<1&4|(y[e+60|0]&240|d&1));v[e+80|0]=d>>>4&2|(d>>>2&4|(y[e+80|0]&240|d>>>3&1))}}}l=l+1|0;continue}}}return n|0}function Ed(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;l=fb-16|0;fb=l;a:{b:{c:{d:{e:{f:{g:{h:{i:{if(a>>>0<=244){g=x[31613];h=a>>>0<11?16:a+11&-8;c=h>>>3|0;b=g>>>c|0;if(b&3){c=c+((b^-1)&1)|0;a=c<<3;b=a+126492|0;d=x[a+126500>>2];a=x[d+8>>2];j:{if((b|0)==(a|0)){m=126452,n=Vua(-2,c)&g,x[m>>2]=n;break j}x[a+12>>2]=b;x[b+8>>2]=a}a=d+8|0;b=c<<3;x[d+4>>2]=b|3;b=b+d|0;x[b+4>>2]=x[b+4>>2]|1;break a}k=x[31615];if(k>>>0>=h>>>0){break i}if(b){a=2<<c;d=Rua((0-a|a)&b<<c);a=d<<3;b=a+126492|0;e=x[a+126500>>2];a=x[e+8>>2];k:{if((b|0)==(a|0)){g=Vua(-2,d)&g;x[31613]=g;break k}x[a+12>>2]=b;x[b+8>>2]=a}x[e+4>>2]=h|3;c=e+h|0;a=d<<3;d=a-h|0;x[c+4>>2]=d|1;x[a+e>>2]=d;if(k){b=(k&-8)+126492|0;f=x[31618];a=1<<(k>>>3);l:{if(!(a&g)){x[31613]=a|g;a=b;break l}a=x[b+8>>2]}x[b+8>>2]=f;x[a+12>>2]=f;x[f+12>>2]=b;x[f+8>>2]=a}a=e+8|0;x[31618]=c;x[31615]=d;break a}j=x[31614];if(!j){break i}c=x[(Rua(j)<<2)+126756>>2];e=(x[c+4>>2]&-8)-h|0;b=c;while(1){m:{a=x[b+16>>2];if(!a){a=x[b+20>>2];if(!a){break m}}b=(x[a+4>>2]&-8)-h|0;d=b>>>0<e>>>0;e=d?b:e;c=d?a:c;b=a;continue}break}i=x[c+24>>2];d=x[c+12>>2];if((d|0)!=(c|0)){a=x[c+8>>2];x[a+12>>2]=d;x[d+8>>2]=a;break b}b=c+20|0;a=x[b>>2];if(!a){a=x[c+16>>2];if(!a){break h}b=c+16|0}while(1){f=b;d=a;b=a+20|0;a=x[b>>2];if(a){continue}b=d+16|0;a=x[d+16>>2];if(a){continue}break}x[f>>2]=0;break b}h=-1;if(a>>>0>4294967231){break i}a=a+11|0;h=a&-8;j=x[31614];if(!j){break i}e=0-h|0;g=0;n:{if(h>>>0<256){break n}g=31;if(h>>>0>16777215){break n}a=G(a>>>8|0);g=((h>>>38-a&1)-(a<<1)|0)+62|0}b=x[(g<<2)+126756>>2];o:{p:{q:{if(!b){a=0;break q}a=0;c=h<<((g|0)!=31?25-(g>>>1|0)|0:0);while(1){r:{f=(x[b+4>>2]&-8)-h|0;if(f>>>0>=e>>>0){break r}d=b;e=f;if(e){break r}e=0;a=b;break p}f=x[b+20>>2];b=x[((c>>>29&4)+b|0)+16>>2];a=f?(f|0)==(b|0)?a:f:a;c=c<<1;if(b){continue}break}}if(!(a|d)){d=0;a=2<<g;a=(0-a|a)&j;if(!a){break i}a=x[(Rua(a)<<2)+126756>>2]}if(!a){break o}}while(1){b=(x[a+4>>2]&-8)-h|0;c=b>>>0<e>>>0;e=c?b:e;d=c?a:d;b=x[a+16>>2];if(b){a=b}else{a=x[a+20>>2]}if(a){continue}break}}if(!d|x[31615]-h>>>0<=e>>>0){break i}g=x[d+24>>2];c=x[d+12>>2];if((d|0)!=(c|0)){a=x[d+8>>2];x[a+12>>2]=c;x[c+8>>2]=a;break c}b=d+20|0;a=x[b>>2];if(!a){a=x[d+16>>2];if(!a){break g}b=d+16|0}while(1){f=b;c=a;b=a+20|0;a=x[b>>2];if(a){continue}b=c+16|0;a=x[c+16>>2];if(a){continue}break}x[f>>2]=0;break c}a=x[31615];if(a>>>0>=h>>>0){d=x[31618];b=a-h|0;s:{if(b>>>0>=16){c=d+h|0;x[c+4>>2]=b|1;x[a+d>>2]=b;x[d+4>>2]=h|3;break s}x[d+4>>2]=a|3;a=a+d|0;x[a+4>>2]=x[a+4>>2]|1;c=0;b=0}x[31615]=b;x[31618]=c;a=d+8|0;break a}i=x[31616];if(i>>>0>h>>>0){b=i-h|0;x[31616]=b;c=x[31619];a=c+h|0;x[31619]=a;x[a+4>>2]=b|1;x[c+4>>2]=h|3;a=c+8|0;break a}a=0;e=h+47|0;if(x[31731]){c=x[31733]}else{x[31734]=-1;x[31735]=-1;x[31732]=4096;x[31733]=4096;x[31731]=l+12&-16^1431655768;x[31736]=0;x[31724]=0;c=4096}g=e+c|0;f=0-c|0;b=g&f;if(b>>>0<=h>>>0){break a}d=x[31723];if(d){c=x[31721];j=c+b|0;if(d>>>0<j>>>0|c>>>0>=j>>>0){break a}}t:{if(!(y[126896]&4)){u:{v:{w:{x:{d=x[31619];if(d){a=126900;while(1){c=x[a>>2];if(c>>>0<=d>>>0&d>>>0<c+x[a+4>>2]>>>0){break x}a=x[a+8>>2];if(a){continue}break}}c=jp(0);if((c|0)==-1){break u}g=b;d=x[31732];a=d-1|0;if(a&c){g=(b-c|0)+(a+c&0-d)|0}if(g>>>0<=h>>>0){break u}d=x[31723];if(d){a=x[31721];f=a+g|0;if(d>>>0<f>>>0|a>>>0>=f>>>0){break u}}a=jp(g);if((c|0)!=(a|0)){break w}break t}g=f&g-i;c=jp(g);if((c|0)==(x[a>>2]+x[a+4>>2]|0)){break v}a=c}if((a|0)==-1){break u}if(h+48>>>0<=g>>>0){c=a;break t}c=x[31733];c=c+(e-g|0)&0-c;if((jp(c)|0)==-1){break u}g=c+g|0;c=a;break t}if((c|0)!=-1){break t}}x[31724]=x[31724]|4}c=jp(b);a=jp(0);if((c|0)==-1|(a|0)==-1|a>>>0<=c>>>0){break d}g=a-c|0;if(g>>>0<=h+40>>>0){break d}}a=x[31721]+g|0;x[31721]=a;if(a>>>0>A[31722]){x[31722]=a}y:{e=x[31619];if(e){a=126900;while(1){d=x[a>>2];b=x[a+4>>2];if((d+b|0)==(c|0)){break y}a=x[a+8>>2];if(a){continue}break}break f}a=x[31617];if(!(a>>>0<=c>>>0?a:0)){x[31617]=c}a=0;x[31726]=g;x[31725]=c;x[31621]=-1;x[31622]=x[31731];x[31728]=0;while(1){d=a<<3;b=d+126492|0;x[d+126500>>2]=b;x[d+126504>>2]=b;a=a+1|0;if((a|0)!=32){continue}break}d=g-40|0;a=-8-c&7;b=d-a|0;x[31616]=b;a=a+c|0;x[31619]=a;x[a+4>>2]=b|1;x[(c+d|0)+4>>2]=40;x[31620]=x[31735];break e}if(x[a+12>>2]&8|(c>>>0<=e>>>0|d>>>0>e>>>0)){break f}x[a+4>>2]=b+g;a=-8-e&7;c=a+e|0;x[31619]=c;b=x[31616]+g|0;a=b-a|0;x[31616]=a;x[c+4>>2]=a|1;x[(b+e|0)+4>>2]=40;x[31620]=x[31735];break e}d=0;break b}c=0;break c}if(A[31617]>c>>>0){x[31617]=c}b=c+g|0;a=126900;z:{A:{B:{while(1){if((b|0)!=x[a>>2]){a=x[a+8>>2];if(a){continue}break B}break}if(!(y[a+12|0]&8)){break A}}a=126900;while(1){C:{b=x[a>>2];if(b>>>0<=e>>>0){f=b+x[a+4>>2]|0;if(f>>>0>e>>>0){break C}}a=x[a+8>>2];continue}break}d=g-40|0;a=-8-c&7;b=d-a|0;x[31616]=b;a=a+c|0;x[31619]=a;x[a+4>>2]=b|1;x[(c+d|0)+4>>2]=40;x[31620]=x[31735];a=(f+(39-f&7)|0)-47|0;d=a>>>0<e+16>>>0?e:a;x[d+4>>2]=27;a=x[31728];x[d+16>>2]=x[31727];x[d+20>>2]=a;a=x[31726];x[d+8>>2]=x[31725];x[d+12>>2]=a;x[31727]=d+8;x[31726]=g;x[31725]=c;x[31728]=0;a=d+24|0;while(1){x[a+4>>2]=7;b=a+8|0;a=a+4|0;if(b>>>0<f>>>0){continue}break}if((d|0)==(e|0)){break e}x[d+4>>2]=x[d+4>>2]&-2;f=d-e|0;x[e+4>>2]=f|1;x[d>>2]=f;if(f>>>0<=255){b=(f&-8)+126492|0;c=x[31613];a=1<<(f>>>3);D:{if(!(c&a)){x[31613]=a|c;a=b;break D}a=x[b+8>>2]}x[b+8>>2]=e;x[a+12>>2]=e;x[e+12>>2]=b;x[e+8>>2]=a;break e}a=31;if(f>>>0<=16777215){a=G(f>>>8|0);a=((f>>>38-a&1)-(a<<1)|0)+62|0}x[e+28>>2]=a;x[e+16>>2]=0;x[e+20>>2]=0;b=(a<<2)+126756|0;d=x[31614];c=1<<a;E:{if(!(d&c)){x[31614]=c|d;x[b>>2]=e;break E}a=f<<((a|0)!=31?25-(a>>>1|0)|0:0);d=x[b>>2];while(1){b=d;if((f|0)==(x[b+4>>2]&-8)){break z}c=a>>>29|0;a=a<<1;c=(c&4)+b|0;d=x[c+16>>2];if(d){continue}break}x[c+16>>2]=e}x[e+24>>2]=b;x[e+12>>2]=e;x[e+8>>2]=e;break e}x[a>>2]=c;x[a+4>>2]=x[a+4>>2]+g;j=(-8-c&7)+c|0;x[j+4>>2]=h|3;e=b+(-8-b&7)|0;i=h+j|0;g=e-i|0;F:{if(x[31619]==(e|0)){x[31619]=i;a=x[31616]+g|0;x[31616]=a;x[i+4>>2]=a|1;break F}if(x[31618]==(e|0)){x[31618]=i;a=x[31615]+g|0;x[31615]=a;x[i+4>>2]=a|1;x[a+i>>2]=a;break F}c=x[e+4>>2];if((c&3)==1){f=c&-8;G:{if(c>>>0<=255){b=x[e+12>>2];a=x[e+8>>2];if((b|0)==(a|0)){m=126452,n=x[31613]&Vua(-2,c>>>3|0),x[m>>2]=n;break G}x[a+12>>2]=b;x[b+8>>2]=a;break G}h=x[e+24>>2];a=x[e+12>>2];H:{if((e|0)!=(a|0)){b=x[e+8>>2];x[b+12>>2]=a;x[a+8>>2]=b;break H}I:{b=e+20|0;c=x[b>>2];if(!c){c=x[e+16>>2];if(!c){break I}b=e+16|0}while(1){d=b;a=c;b=a+20|0;c=x[b>>2];if(c){continue}b=a+16|0;c=x[a+16>>2];if(c){continue}break}x[d>>2]=0;break H}a=0}if(!h){break G}c=x[e+28>>2];b=(c<<2)+126756|0;J:{if(x[b>>2]==(e|0)){x[b>>2]=a;if(a){break J}m=126456,n=x[31614]&Vua(-2,c),x[m>>2]=n;break G}x[h+(x[h+16>>2]==(e|0)?16:20)>>2]=a;if(!a){break G}}x[a+24>>2]=h;b=x[e+16>>2];if(b){x[a+16>>2]=b;x[b+24>>2]=a}b=x[e+20>>2];if(!b){break G}x[a+20>>2]=b;x[b+24>>2]=a}g=f+g|0;e=e+f|0;c=x[e+4>>2]}x[e+4>>2]=c&-2;x[i+4>>2]=g|1;x[g+i>>2]=g;if(g>>>0<=255){b=(g&-8)+126492|0;c=x[31613];a=1<<(g>>>3);K:{if(!(c&a)){x[31613]=a|c;a=b;break K}a=x[b+8>>2]}x[b+8>>2]=i;x[a+12>>2]=i;x[i+12>>2]=b;x[i+8>>2]=a;break F}c=31;if(g>>>0<=16777215){a=G(g>>>8|0);c=((g>>>38-a&1)-(a<<1)|0)+62|0}x[i+28>>2]=c;x[i+16>>2]=0;x[i+20>>2]=0;b=(c<<2)+126756|0;L:{d=x[31614];a=1<<c;M:{if(!(d&a)){x[31614]=a|d;x[b>>2]=i;break M}c=g<<((c|0)!=31?25-(c>>>1|0)|0:0);a=x[b>>2];while(1){b=a;if((x[a+4>>2]&-8)==(g|0)){break L}d=c>>>29|0;c=c<<1;d=(d&4)+a|0;a=x[d+16>>2];if(a){continue}break}x[d+16>>2]=i}x[i+24>>2]=b;x[i+12>>2]=i;x[i+8>>2]=i;break F}a=x[b+8>>2];x[a+12>>2]=i;x[b+8>>2]=i;x[i+24>>2]=0;x[i+12>>2]=b;x[i+8>>2]=a}a=j+8|0;break a}a=x[b+8>>2];x[a+12>>2]=e;x[b+8>>2]=e;x[e+24>>2]=0;x[e+12>>2]=b;x[e+8>>2]=a}a=x[31616];if(a>>>0<=h>>>0){break d}b=a-h|0;x[31616]=b;c=x[31619];a=c+h|0;x[31619]=a;x[a+4>>2]=b|1;x[c+4>>2]=h|3;a=c+8|0;break a}x[31612]=48;a=0;break a}N:{if(!g){break N}b=x[d+28>>2];a=(b<<2)+126756|0;O:{if(x[a>>2]==(d|0)){x[a>>2]=c;if(c){break O}j=Vua(-2,b)&j;x[31614]=j;break N}x[g+(x[g+16>>2]==(d|0)?16:20)>>2]=c;if(!c){break N}}x[c+24>>2]=g;a=x[d+16>>2];if(a){x[c+16>>2]=a;x[a+24>>2]=c}a=x[d+20>>2];if(!a){break N}x[c+20>>2]=a;x[a+24>>2]=c}P:{if(e>>>0<=15){a=e+h|0;x[d+4>>2]=a|3;a=a+d|0;x[a+4>>2]=x[a+4>>2]|1;break P}x[d+4>>2]=h|3;f=d+h|0;x[f+4>>2]=e|1;x[e+f>>2]=e;if(e>>>0<=255){b=(e&-8)+126492|0;c=x[31613];a=1<<(e>>>3);Q:{if(!(c&a)){x[31613]=a|c;a=b;break Q}a=x[b+8>>2]}x[b+8>>2]=f;x[a+12>>2]=f;x[f+12>>2]=b;x[f+8>>2]=a;break P}a=31;if(e>>>0<=16777215){a=G(e>>>8|0);a=((e>>>38-a&1)-(a<<1)|0)+62|0}x[f+28>>2]=a;x[f+16>>2]=0;x[f+20>>2]=0;b=(a<<2)+126756|0;R:{c=1<<a;S:{if(!(c&j)){x[31614]=c|j;x[b>>2]=f;break S}a=e<<((a|0)!=31?25-(a>>>1|0)|0:0);h=x[b>>2];while(1){b=h;if((x[b+4>>2]&-8)==(e|0)){break R}c=a>>>29|0;a=a<<1;c=(c&4)+b|0;h=x[c+16>>2];if(h){continue}break}x[c+16>>2]=f}x[f+24>>2]=b;x[f+12>>2]=f;x[f+8>>2]=f;break P}a=x[b+8>>2];x[a+12>>2]=f;x[b+8>>2]=f;x[f+24>>2]=0;x[f+12>>2]=b;x[f+8>>2]=a}a=d+8|0;break a}T:{if(!i){break T}b=x[c+28>>2];a=(b<<2)+126756|0;U:{if(x[a>>2]==(c|0)){x[a>>2]=d;if(d){break U}m=126456,n=Vua(-2,b)&j,x[m>>2]=n;break T}x[i+(x[i+16>>2]==(c|0)?16:20)>>2]=d;if(!d){break T}}x[d+24>>2]=i;a=x[c+16>>2];if(a){x[d+16>>2]=a;x[a+24>>2]=d}a=x[c+20>>2];if(!a){break T}x[d+20>>2]=a;x[a+24>>2]=d}V:{if(e>>>0<=15){a=e+h|0;x[c+4>>2]=a|3;a=a+c|0;x[a+4>>2]=x[a+4>>2]|1;break V}x[c+4>>2]=h|3;d=c+h|0;x[d+4>>2]=e|1;x[d+e>>2]=e;if(k){b=(k&-8)+126492|0;f=x[31618];a=1<<(k>>>3);W:{if(!(a&g)){x[31613]=a|g;a=b;break W}a=x[b+8>>2]}x[b+8>>2]=f;x[a+12>>2]=f;x[f+12>>2]=b;x[f+8>>2]=a}x[31618]=d;x[31615]=e}a=c+8|0}fb=l+16|0;return a|0}function Nua(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0;e=fb-272|0;fb=e;xc(b);a:{b:{c:{d:{if(Tr(b,18467)){n=Fb(e+260|0);x[31737]=0;g=P(231,b|0,n|0)|0;d=x[31737];x[31737]=0;e:{if((d|0)!=1){if(!g){break e}x[31737]=0;h=e+253|0;g=P(246,b|0,h|0)|0;d=x[31737];x[31737]=0;f:{if((d|0)==1){break f}if(!g){break e}if(!P0(y[e+253|0],y[e+254|0])){break e}h=Bc(O0(h),hb);g=x[b+8>>2];d=x[b>>2];x[31737]=0;g=U(151,d|0,g|0,h|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break f}if(!g){break e}f=1;if((c|0)==64){break e}x[31737]=0;O(247,a|0,4096);d=x[31737];x[31737]=0;if((d|0)==1){break f}x[31737]=0;O(248,a+1298308|0,n|0);d=x[31737];x[31737]=0;if((d|0)==1){break f}d=y[e+255|0];w[a+480188>>1]=32;w[a+480192>>1]=d;Xh(a,1);x[31737]=0;f=P(1,e+240|0,9492)|0;d=x[31737];x[31737]=0;g:{h:{i:{j:{k:{l:{m:{n:{o:{if((d|0)!=1){Ab(a+1298344|0,f);tb(f);x[31737]=0;f=P(1,e+228|0,7105)|0;d=x[31737];x[31737]=0;if((d|0)==1){break o}Ab(a+1298356|0,f);tb(f);x[31737]=0;g=e+32|0;W(249,g|0);d=x[31737];x[31737]=0;if((d|0)==1){break n}v[e+204|0]=y[e+254|0];x[31737]=0;v[e|0]=y[e+253|0];f=e+216|0;O(250,f|0,e|0);d=x[31737];x[31737]=0;if((d|0)==1){break m}x[31737]=0;h=e+80|0;V(251,h|0,g|0,e+204|0,f|0);d=x[31737];x[31737]=0;if((d|0)==1){break l}Ab(a+1298368|0,h);tb(h);tb(f);Eb(g);r=a+1298404|0,s=x[Fc(h,4)>>2],x[r>>2]=s;if(y[e+253|0]<2){break h}w[e+80>>1]=8192;x[31737]=0;f=R(190,b|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break j}w[e+32>>1]=f;r=a,s=D(z[pe(h,g)>>1],1e4)>>>8|0,x[r+480204>>2]=s;x[31737]=0;v[e+80|0]=1;f=R(198,b|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break i}v[e+32|0]=f;r=a,s=y[df(h,g)|0],x[r+480196>>2]=s;x[31737]=0;P(184,b|0,3)|0;d=x[31737];x[31737]=0;if((d|0)!=1){x[31737]=0;f=R(190,b|0)|0;d=x[31737];x[31737]=0;if((d|0)!=1){break g}}b=N()|0;break a}b=N()|0;break a}b=N()|0;break a}b=N()|0;break a}b=N()|0;break k}b=N()|0;tb(e+216|0)}Eb(e+32|0);break a}b=N()|0;break a}b=N()|0;break a}v[e+80|0]=32;x[31737]=0;f=R(198,b|0)|0;d=x[31737];x[31737]=0;p:{if((d|0)!=1){v[e+32|0]=f;r=a,s=D(y[df(e+80|0,e+32|0)|0],1e4),x[r+480204>>2]=s;x[31737]=0;v[e+80|0]=1;f=R(198,b|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break p}v[e+32|0]=f;r=a,s=y[df(e+80|0,e+32|0)|0],x[r+480196>>2]=s;x[31737]=0;f=R(198,b|0)|0;d=x[31737];x[31737]=0;if((d|0)!=1){break g}b=N()|0;break a}b=N()|0;break a}b=N()|0;break a}x[a+480208>>2]=f>>>2&16|12;l=Nb(e+216|0);j=e+80|12;m=Nb(e+204|0);o=1;while(1){q:{r:{d=o&65535;if(d>>>0>z[a+480192>>1]){break r}x[31737]=0;i=U(252,a|0,d|0,0)|0;d=x[31737];x[31737]=0;s:{if((d|0)==1){break s}if(!i){break r}x[31737]=0;f=P(241,b|0,i+492|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break s}if(!f){break r}x[31737]=0;q=R(198,b|0)|0;d=x[31737];x[31737]=0;t:{u:{v:{if((d|0)!=1){d=e+80|0;Rb(d,0,120);if(!q){break q}w:{if(y[e+253|0]){x[31737]=0;f=P(253,b|0,d|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break v}if(!f){break q}if(y[e+253|0]){break w}}d=gc(e+72|0,j,96);f=x[d>>2];d=x[d+4>>2];x[31737]=0;ao(160,e+32|0,b,f,d);d=x[31737];x[31737]=0;if((d|0)==1){break u}if(!x[e+36>>2]){break q}}h=i+236|0;f=0;break t}b=N()|0;break b}b=N()|0;break b}b=N()|0;break b}while(1){if((f|0)!=120){g=z[a+480190>>1];d=y[(e+80|0)+f|0];r=_b(h,f),s=(d+g|0)+1|0,w[r>>1]=s;f=f+1|0;continue}break}x[31737]=0;f=i+48|0;S(254,e|0,f|0,b|0);d=x[31737];x[31737]=0;if((d|0)==1){break c}x[31737]=0;k=i+68|0;S(254,e+16|0,k|0,b|0);d=x[31737];x[31737]=0;if((d|0)==1){break c}x[31737]=0;h=i+88|0;S(254,e- -64|0,h|0,b|0);d=x[31737];x[31737]=0;if((d|0)==1){break c}x[31737]=0;O(255,b|0,e+56|0);d=x[31737];x[31737]=0;if((d|0)==1){break d}x[i>>2]=(y[e+57|0]|y[e+58|0]<<8)&4095;d=y[e+57|0]|y[e+58|0]<<8;AE(y[e+59|0]|y[e+60|0]<<8,f,0);AE(y[e+59|0]|y[e+60|0]<<8,k,1);AE(y[e+59|0]|y[e+60|0]<<8,h,2);r=e,s=wb(x[f>>2]),x[r+32>>2]=s;f=d>>>12|0;d=wb(x[i+52>>2]);while(1){g=x[e+32>>2];if(Ib(g,d)){v[e+28|0]=64;v[e+54|0]=((y[g+2|0]<<6)- -64>>>0)/127;r=g,s=y[Qb(e+28|0,e+54|0)|0],v[r+2|0]=s;Je(e+32|0);continue}else{r=e,s=wb(x[k>>2]),x[r+32>>2]=s;d=wb(x[i+72>>2])}break}while(1){g=x[e+32>>2];if(Ib(g,d)){v[e+28|0]=64;v[e+54|0]=((y[g+2|0]<<6)+128>>>0)/255;r=g,s=y[Qb(e+28|0,e+54|0)|0],v[r+2|0]=s;Je(e+32|0);continue}break}r=e,s=wb(x[h>>2]),x[r+32>>2]=s;k=f&3;h=wb(x[i+92>>2]);while(1){f=x[e+32>>2];if(Ib(f,h)){g=v[f+2|0];d=g>>31^-1;g=g^-128;i=k&31;if((k&63)>>>0>=32){d=g<<i;i=0}else{d=(1<<i)-1&g>>>32-i|d<<i;i=g<<i}x:{if((d|0)>=-1&i>>>0>=4294967292|(d|0)>=0){g=i+4|0;d=(((g>>>0<4?d+1|0:d)&7)<<29|g>>>3)&536870911;g=0;break x}g=0-((i>>>0>3)+d|0)|0;d=3-i|0;g=((g&7)<<29|d>>>3)&536870911;d=0-g|0;g=0-((g|0)!=0)|0}r=f,s=Gc(d,g)^128,v[r+2|0]=s;Je(e+32|0);continue}else{d=z[a+480190>>1]+1|0;w[e+54>>1]=d;f=0;i=d&65535;d=4e3-i|0;k=d>>>0<=4e3?d:0;y:{z:{A:{while(1){if((f|0)==(q|0)){break z}if((f|0)==(k|0)){x[31737]=0;P(184,b|0,20)|0;d=x[31737];x[31737]=0;if((d|0)!=1){break z}b=N()|0;break b}x[31737]=0;h=f+i|0;P(241,b|0,((h<<5)+a|0)+946304|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break y}x[31737]=0;g=e+32|0;O(256,b|0,g|0);d=x[31737];x[31737]=0;B:{if((d|0)==1){break B}x[31737]=0;O(257,g|0,(D(h,104)+a|0)+484380|0);d=x[31737];x[31737]=0;if((d|0)==1){break B}x[31737]=0;w[e+28>>1]=y[e+56|0]|f<<8&32512|((y[e+51|0]&3)!=0)<<15;O(258,m|0,e+28|0);d=x[31737];x[31737]=0;if((d|0)==1){break A}f=f+1|0;continue}break}b=N()|0;break b}b=N()|0;break b}x[31737]=0;O(258,l|0,e+54|0);d=x[31737];x[31737]=0;if((d|0)!=1){x[e+32>>2]=3999;x[e+28>>2]=q+z[a+480190>>1];r=a,s=x[ud(e+32|0,e+28|0)>>2],w[r+480190>>1]=s;break q}b=N()|0;break b}b=N()|0;break b}}}b=N()|0;break b}g=Fb(e+80|0);x[31737]=0;f=P(231,b|0,g|0)|0;d=x[31737];x[31737]=0;C:{D:{E:{F:{G:{if((d|0)!=1){H:{if(f){x[31737]=0;f=e+32|0;S(259,f|0,21,g|0);d=x[31737];x[31737]=0;if((d|0)==1){break H}Ab(a+1298320|0,f);tb(f)}tb(g);f=0;I:{while(1){if((f|0)==32){x[31737]=0;f=P(260,b|0,e+16|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break E}if(!f){break F}g=x[e+16>>2];if(g>>>0<12){break G}f=x[b+8>>2];d=x[b>>2];x[31737]=0;f=U(151,d|0,f|0,g-11|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break E}if(f){break I}break G}d=(f<<5)+a|0;We(d+480280|0);x[31737]=0;O(232,b|0,d+480289|0);d=x[31737];x[31737]=0;if((d|0)!=1){f=f+1|0;continue}break}b=N()|0;break b}d=x[e+16>>2]-11|0;x[e+64>>2]=d;i=Nb(e+80|0);x[31737]=0;S(235,b|0,i|0,d|0);d=x[31737];x[31737]=0;J:{if((d|0)!=1){x[e+32>>2]=50529027;d=e+32|0;r=e,s=D(x[Gb(e- -64|0,d)>>2],85),x[r+56>>2]=s;j=Fb(d);x[e>>2]=x[e+20>>2];d=x[Gb(e+56|0,e)>>2];x[31737]=0;O(115,j|0,d|0);d=x[31737];x[31737]=0;K:{if((d|0)==1){break K}f=0;L:{while(1){d=x[e+64>>2];if(d>>>0<=f>>>0){break L}k=x[i>>2];g=y[xb(k,f)|0];h=d;d=f+1|0;if(!((g|0)!=255|h-d>>>0<2)){h=v[xb(k,d)|0];g=y[xb(k,f+2|0)|0];d=x[vb(e+12|0,Df(j))>>2];x[31737]=0;V(238,j|0,d|0,g|0,h|0);d=x[31737];x[31737]=0;if((d|0)!=1){f=f+3|0;continue}break K}x[31737]=0;O(116,j|0,g<<24>>24);g=x[31737];x[31737]=0;f=d;if((g|0)!=1){continue}break}break K}x[31737]=0;S(236,e|0,21,j|0);d=x[31737];x[31737]=0;if((d|0)!=1){M:{h=Ab(j,e);tb(e);g=Jb(h);f=y[h+11|0];d=x[h+4>>2];x[31737]=0;aa(237,a+1298332|0,g|0,Yc(d,f)|0,74,0);d=x[31737];x[31737]=0;if((d|0)==1){break M}tb(h);dc(i);break G}}}b=N()|0;tb(j);break J}b=N()|0}dc(i);break b}}b=N()|0;tb(g);break b}f=y[a+484376|0];d=x[a+484360>>2];x[31737]=0;S(239,Xb(d,f)|0,b|0,y[e+258|0]|y[e+259|0]<<8);d=x[31737];x[31737]=0;if((d|0)==1){break E}h=c&1;if(h){x[31737]=0;O(224,a+484344|0,y[e+256|0]|y[e+257|0]<<8);d=x[31737];x[31737]=0;if((d|0)==1){break E}}k=a+484344|0;f=0;while(1){N:{if((y[e+256|0]|y[e+257|0]<<8)>>>0>f>>>0){g=x[b+8>>2];d=x[b>>2];x[31737]=0;g=U(151,d|0,g|0,4)|0;d=x[31737];x[31737]=0;if((d|0)==1){break C}if(g){break N}}if(!(c&2)){break F}f=0;while(1){c=z[a+480190>>1];if(f>>>0>=c>>>0){f=0;while(1){if(c>>>0<=f>>>0){break F}g=z[_b(x[m>>2],f)>>1];b=g&255;O:{if(!b){break O}d=x[l>>2];b=b-1&65535;if(Zc(d,x[l+4>>2])>>>0<=b>>>0){break O}b=z[_b(d,b)>>1]+(g>>>8&127)&65535;if(b>>>0>c>>>0){break O}c=D(b,104);b=c+a|0;h=b+484380|0;g=x[h>>2];if(!je(g,x[b+484400>>2])){break O}d=a+484380|0;c=d+c|0;b=z[c+34>>1];d=d+D(f+1|0,104)|0;x[d>>2]=g;w[d+34>>1]=z[d+34>>1]&65534|b&1;if(!Eh(d)){break O}yc(x[d+20>>2],x[c+20>>2],Vk(x[h>>2],z[h+34>>1]))}f=f+1|0;c=z[a+480190>>1];continue}}c=z[_b(x[m>>2],f)>>1];if(c&255){f=f+1|0;continue}f=f+1|0;d=D(f,104)+a|0;c=Xc(e+80|0,w[d+484414>>1]&1?16:8,1,0,c<<16>>16<0?6:0);x[31737]=0;U(216,c|0,d+484380|0,b|0)|0;c=x[31737];x[31737]=0;if((c|0)!=1){continue}break}b=N()|0;break b}x[31737]=0;g=R(152,b|0)|0;d=x[31737];x[31737]=0;P:{Q:{R:{S:{if((d|0)!=1){x[31737]=0;i=e+32|0;S(186,i|0,b|0,g|0);d=x[31737];x[31737]=0;if((d|0)==1){break S}j=ic(e+80|0,i);ub(i);if(!h){break Q}x[31737]=0;g=R(198,j|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break P}x[31737]=0;P(184,j|0,1)|0;d=x[31737];x[31737]=0;if((d|0)==1){break P}x[31737]=0;g=U(197,k|0,f&65535,g+1|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break P}if(!g){break Q}x[31737]=0;g=P(233,j|0,i|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break D}if(!g){break R}d=x[k>>2];x[31737]=0;O(234,Wb(d,f)|0,i|0);d=x[31737];x[31737]=0;if((d|0)!=1){break R}break D}b=N()|0;break b}b=N()|0;break b}d=x[k>>2];x[31737]=0;S(240,Wb(d,f)|0,1,j|0);d=x[31737];x[31737]=0;if((d|0)==1){break D}}ub(j);f=f+1|0;continue}break}break D}md(m);md(l);f=1;break e}b=N()|0;break b}b=N()|0;ub(j);break b}b=N()|0;break b}o=o+1|0;continue}}b=N()|0;break a}b=N()|0;break a}tb(n)}fb=e+272|0;return f|0}b=N()|0;break b}b=N()|0}md(m);md(l)}tb(n);Q(b|0);p()}function NK(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,z=0,A=0,F=0,G=0,H=E(0),I=0;e=fb-144|0;fb=e;d=Rb(e,0,144);x[d+76>>2]=-1;x[d+44>>2]=a;x[d+32>>2]=1193;x[d+84>>2]=a;t=c;a=0;j=fb-304|0;fb=j;a:{b:{if(!x[d+4>>2]){Uy(d);if(!x[d+4>>2]){break b}}h=y[b|0];if(!h){break a}c:{d:{e:{f:{g:{while(1){h:{c=h&255;i:{if(wl(c)){while(1){h=b;b=b+1|0;if(wl(y[h+1|0])){continue}break}Ii(d,0,0);while(1){b=x[d+4>>2];j:{if((b|0)!=x[d+104>>2]){x[d+4>>2]=b+1;b=y[b|0];break j}b=sd(d)}if(wl(b)){continue}break}b=x[d+4>>2];c=x[d+116>>2];if((c|0)>0){c=1}else{c=(c|0)>=0}if(c){b=b-1|0;x[d+4>>2]=b}b=b-x[d+44>>2]|0;e=b;i=p+x[d+124>>2]|0;c=b>>31;b=m+x[d+120>>2]|0;i=c+(b>>>0<m>>>0?i+1|0:i)|0;m=b+e|0;p=m>>>0<b>>>0?i+1|0:i;break i}k:{l:{m:{if((c|0)==37){e=y[b+1|0];if((e|0)==42){break m}if((e|0)!=37){break l}}Ii(d,0,0);n:{if(y[b|0]==37){while(1){c=x[d+4>>2];o:{if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;h=y[c|0];break o}h=sd(d)}if(wl(h)){continue}break}b=b+1|0;break n}c=x[d+4>>2];if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;h=y[c|0];break n}h=sd(d)}if(y[b|0]!=(h|0)){a=x[d+116>>2];if((a|0)>0){a=1}else{a=(a|0)>=0}if(a){x[d+4>>2]=x[d+4>>2]-1}if((h|0)>=0|s){break a}break b}c=x[d+4>>2]-x[d+44>>2]|0;h=c;f=p+x[d+124>>2]|0;e=c>>31;c=m+x[d+120>>2]|0;g=e+(c>>>0<m>>>0?f+1|0:f)|0;m=c+h|0;p=m>>>0<c>>>0?g+1|0:g;h=b;break i}l=0;b=b+2|0;break k}if(!(!Oh(e)|y[b+2|0]!=36)){c=fb-16|0;x[c+12>>2]=t;f=c;c=e-48|0;c=c>>>0>1?((c<<2)+t|0)-4|0:t;x[f+8>>2]=c+4;l=x[c>>2];b=b+3|0;break k}l=x[t>>2];t=t+4|0;b=b+1|0}c=0;while(1){f=y[b|0];if(Oh(f)){b=b+1|0;c=(D(c,10)+f|0)-48|0;continue}break}r=0;if((f|0)==109){o=0;r=(l|0)!=0;f=y[b+1|0];b=b+1|0;a=0}h=b+1|0;k=3;g=r;p:{q:{switch((f&255)-65|0){case 39:e=b+2|0;b=y[b+1|0]==104;h=b?e:h;k=b?-2:-1;break p;case 43:e=b+2|0;b=y[b+1|0]==108;h=b?e:h;k=b?3:1;break p;case 51:case 57:k=1;break p;case 11:k=2;break p;case 41:break p;case 0:case 2:case 4:case 5:case 6:case 18:case 23:case 26:case 32:case 34:case 35:case 36:case 37:case 38:case 40:case 45:case 46:case 47:case 50:case 52:case 55:break q;default:break d}}k=0;h=b}e=y[h|0];b=(e&47)==3;u=b?1:k;q=b?e|32:e;r:{if((q|0)==91){break r}s:{if((q|0)!=110){if((q|0)!=99){break s}c=(c|0)<=1?1:c;break r}OK(l,u,m,p);break i}Ii(d,0,0);while(1){b=x[d+4>>2];t:{if((b|0)!=x[d+104>>2]){x[d+4>>2]=b+1;b=y[b|0];break t}b=sd(d)}if(wl(b)){continue}break}b=x[d+4>>2];e=x[d+116>>2];if((e|0)>0){e=1}else{e=(e|0)>=0}if(e){b=b-1|0;x[d+4>>2]=b}b=b-x[d+44>>2]|0;f=b;i=p+x[d+124>>2]|0;e=b>>31;b=m+x[d+120>>2]|0;p=e+(b>>>0<m>>>0?i+1|0:i)|0;m=b+f|0;p=m>>>0<b>>>0?p+1|0:p}i=c;n=c>>31;Ii(d,c,n);b=x[d+4>>2];u:{if((b|0)!=x[d+104>>2]){x[d+4>>2]=b+1;break u}if((sd(d)|0)<0){break e}}b=x[d+116>>2];if((b|0)>0){b=1}else{b=(b|0)>=0}if(b){x[d+4>>2]=x[d+4>>2]-1}b=16;v:{w:{x:{y:{z:{switch(q-88|0){default:b=q-65|0;if(b>>>0>6|!(1<<b&113)){break v}case 9:case 13:case 14:case 15:QK(j+8|0,d,u,0);c=x[d+4>>2]-x[d+44>>2]|0;if(x[d+120>>2]!=(0-c|0)|x[d+124>>2]!=(0-((c>>31)+((c|0)!=0)|0)|0)){break x}break f;case 3:case 11:case 27:if((q|16)==115){Rb(j+32|0,-1,257);v[j+32|0]=0;if((q|0)!=115){break w}v[j+65|0]=0;v[j+46|0]=0;w[j+42>>1]=0;w[j+44>>1]=0;break w}f=y[h+1|0];e=(f|0)==94;Rb(j+32|0,e,257);v[j+32|0]=0;b=e?h+2|0:h+1|0;A:{B:{C:{e=y[(e?2:1)+h|0];if((e|0)!=45){if((e|0)==93){break C}k=(f|0)!=94;break A}k=(f|0)!=94;v[j+78|0]=k;break B}k=(f|0)!=94;v[j+126|0]=k}b=b+1|0}h=b;while(1){f=y[h|0];D:{if((f|0)!=45){if(!f){break e}if((f|0)==93){break w}break D}f=45;g=y[h+1|0];if(!g|(g|0)==93){break D}e=h+1|0;b=y[h-1|0];E:{if(g>>>0<=b>>>0){f=g;break E}while(1){b=b+1|0;v[b+(j+32|0)|0]=k;f=y[e|0];if(f>>>0>b>>>0){continue}break}}h=e}v[(f+j|0)+33|0]=k;h=h+1|0;continue};case 23:b=8;break y;case 12:case 29:b=10;break y;case 1:case 2:case 4:case 5:case 6:case 7:case 8:case 10:case 16:case 18:case 19:case 20:case 21:case 22:case 25:case 26:case 28:case 30:case 31:break v;case 0:case 24:case 32:break y;case 17:break z}}b=0}e=0;i=0;f=0;g=0;A=0;z=fb-16|0;fb=z;F:{if((b|0)==1){x[31612]=28;break F}while(1){c=x[d+4>>2];G:{if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;c=y[c|0];break G}c=sd(d)}if(wl(c)){continue}break}H:{I:{switch(c-43|0){case 0:case 2:break I;default:break H}}A=(c|0)==45?-1:0;c=x[d+4>>2];if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;c=y[c|0];break H}c=sd(d)}J:{K:{L:{M:{if(!((b|0)!=0&(b|0)!=16|(c|0)!=48)){c=x[d+4>>2];N:{if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;c=y[c|0];break N}c=sd(d)}if((c&-33)==88){b=16;c=x[d+4>>2];O:{if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;c=y[c|0];break O}c=sd(d)}if(y[c+95441|0]<16){break L}b=x[d+116>>2];if((b|0)>0){b=1}else{b=(b|0)>=0}if(b){x[d+4>>2]=x[d+4>>2]-1}Ii(d,0,0);break F}if(b){break M}b=8;break L}b=b?b:10;if(b>>>0>y[c+95441|0]){break M}b=x[d+116>>2];if((b|0)>0){b=1}else{b=(b|0)>=0}if(b){x[d+4>>2]=x[d+4>>2]-1}Ii(d,0,0);x[31612]=28;break F}if((b|0)!=10){break L}f=c-48|0;if(f>>>0<=9){c=0;while(1){c=D(c,10)+f|0;g=c>>>0<429496729;e=x[d+4>>2];P:{if((e|0)!=x[d+104>>2]){x[d+4>>2]=e+1;b=y[e|0];break P}b=sd(d)}f=b-48|0;if(g&f>>>0<=9){continue}break}e=c}if(f>>>0>9){break J}b=Sua(e,0,10,0);g=hb;while(1){e=b+f|0;i=e>>>0<f>>>0?g+1|0:g;b=(i|0)==429496729&e>>>0<2576980378|i>>>0<429496729;c=x[d+4>>2];Q:{if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;c=y[c|0];break Q}c=sd(d)}k=c-48|0;if(!(b&k>>>0<=9)){b=10;if(k>>>0<=9){break K}break J}b=Sua(e,i,10,0);g=hb;f=k;if((g|0)==-1&(f^-1)>>>0>=b>>>0|(g|0)!=-1){continue}break}b=10;break K}if(b-1&b){g=y[c+95441|0];if(g>>>0<b>>>0){while(1){f=D(b,f)+g|0;e=f>>>0<119304647;c=x[d+4>>2];R:{if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;c=y[c|0];break R}c=sd(d)}g=y[c+95441|0];if(e&g>>>0<b>>>0){continue}break}e=f}if(b>>>0<=g>>>0){break K}n=b;while(1){f=Sua(e,i,n,0);k=hb;g=g&255;if((k|0)==-1&(g^-1)>>>0<f>>>0){break K}i=k;e=f+g|0;i=e>>>0<g>>>0?i+1|0:i;c=x[d+4>>2];S:{if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;c=y[c|0];break S}c=sd(d)}g=y[c+95441|0];if(b>>>0<=g>>>0){break K}Of(z,n,0,0,0,e,i,0,0);if(!(x[z+8>>2]|x[z+12>>2])){continue}break}break K}k=v[(D(b,23)>>>5&7)+95697|0];f=y[c+95441|0];if(f>>>0<b>>>0){while(1){g=g<<k|f;e=g>>>0<134217728;c=x[d+4>>2];T:{if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;c=y[c|0];break T}c=sd(d)}f=y[c+95441|0];if(e&f>>>0<b>>>0){continue}break}e=g}if(b>>>0<=f>>>0){break K}n=k&31;if((k&63)>>>0>=32){g=0;n=-1>>>n|0}else{g=-1>>>n|0;n=g|(1<<n)-1<<32-n}if(!g&e>>>0>n>>>0){break K}while(1){F=f&255;c=e;f=k&31;if((k&63)>>>0>=32){i=c<<f;c=0}else{i=(1<<f)-1&c>>>32-f|i<<f;c=c<<f}e=F|c;c=x[d+4>>2];U:{if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;c=y[c|0];break U}c=sd(d)}f=y[c+95441|0];if(b>>>0<=f>>>0){break K}if((g|0)==(i|0)&e>>>0<=n>>>0|g>>>0>i>>>0){continue}break}}if(y[c+95441|0]>=b>>>0){break J}while(1){c=x[d+4>>2];V:{if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;c=y[c|0];break V}c=sd(d)}if(y[c+95441|0]<b>>>0){continue}break}x[31612]=68;e=-1;i=-1;A=0}b=x[d+116>>2];if((b|0)>0){b=1}else{b=(b|0)>=0}if(b){x[d+4>>2]=x[d+4>>2]-1}b=A;f=b^e;e=f-b|0;c=b>>31;i=(c^i)-((b>>>0>f>>>0)+c|0)|0}fb=z+16|0;c=x[d+4>>2]-x[d+44>>2]|0;if(x[d+120>>2]==(0-c|0)&x[d+124>>2]==(0-((c>>31)+((c|0)!=0)|0)|0)){break f}if(!(!l|(q|0)!=112)){x[l>>2]=e;break v}OK(l,u,e,i);break v}if(!l){break v}c=x[j+16>>2];f=x[j+20>>2];b=x[j+8>>2];e=x[j+12>>2];W:{switch(u|0){case 0:G=l,H=UG(b,e,c,f),B[G>>2]=H;break v;case 1:G=l,I=yx(b,e,c,f),C[G>>3]=I;break v;case 2:break W;default:break v}}x[l>>2]=b;x[l+4>>2]=e;x[l+8>>2]=c;x[l+12>>2]=f;break v}k=(q|0)!=99;c=k?31:c+1|0;X:{if((u|0)==1){f=l;if(r){f=Ed(c<<2);if(!f){break g}}x[j+296>>2]=0;x[j+300>>2]=0;b=0;while(1){a=f;Y:{while(1){e=x[d+4>>2];Z:{if((e|0)!=x[d+104>>2]){x[d+4>>2]=e+1;e=y[e|0];break Z}e=sd(d)}if(!y[(e+j|0)+33|0]){break Y}v[j+27|0]=e;e=xt(j+28|0,j+27|0,1,j+296|0);if((e|0)==-2){continue}if((e|0)==-1){o=0;break e}if(a){x[(b<<2)+a>>2]=x[j+28>>2];b=b+1|0}if(!r|(b|0)!=(c|0)){continue}break}g=1;o=0;b=c;c=b<<1|1;f=Nv(a,c<<2);if(f){continue}break d}break}o=0;c=a;if(j+296|0?x[j+296>>2]:0){break e}break X}if(r){b=0;f=Ed(c);if(!f){break g}while(1){a=f;while(1){e=x[d+4>>2];_:{if((e|0)!=x[d+104>>2]){x[d+4>>2]=e+1;e=y[e|0];break _}e=sd(d)}if(!y[(e+j|0)+33|0]){c=0;o=a;break X}v[a+b|0]=e;b=b+1|0;if((c|0)!=(b|0)){continue}break}g=1;b=c;c=b<<1|1;f=Nv(a,c);if(f){continue}break}o=a;a=0;break d}b=0;if(l){while(1){a=x[d+4>>2];$:{if((a|0)!=x[d+104>>2]){x[d+4>>2]=a+1;a=y[a|0];break $}a=sd(d)}if(y[(a+j|0)+33|0]){v[b+l|0]=a;b=b+1|0;continue}else{c=0;a=l;o=a;break X}}}while(1){a=x[d+4>>2];aa:{if((a|0)!=x[d+104>>2]){x[d+4>>2]=a+1;a=y[a|0];break aa}a=sd(d)}if(y[(a+j|0)+33|0]){continue}break}a=0;o=0;c=0}f=x[d+4>>2];e=x[d+116>>2];if((e|0)>0){e=1}else{e=(e|0)>=0}if(e){f=f-1|0;x[d+4>>2]=f}e=f-x[d+44>>2]|0;f=e+x[d+120>>2]|0;g=x[d+124>>2]+(e>>31)|0;g=f>>>0<e>>>0?g+1|0:g;if(!(g|f)|!(k|(f|0)==(i|0)&(g|0)==(n|0))){break h}if(r){x[l>>2]=a}ba:{if((q|0)==99){break ba}if(c){x[(b<<2)+c>>2]=0}if(!o){o=0;break ba}v[b+o|0]=0}a=c}b=x[d+4>>2]-x[d+44>>2]|0;e=b;f=p+x[d+124>>2]|0;c=b>>31;b=m+x[d+120>>2]|0;i=c+(b>>>0<m>>>0?f+1|0:f)|0;m=b+e|0;p=m>>>0<b>>>0?i+1|0:i;s=((l|0)!=0)+s|0}b=h+1|0;h=y[h+1|0];if(h){continue}break a}break}a=c;break f}g=1;o=0;a=0;break d}g=r;break c}g=r}s=s?s:-1}if(!g){break a}Db(o);Db(a);break a}s=-1}fb=j+304|0;fb=d+144|0;return s}function Aoa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;j=fb-192|0;fb=j;if(!nv(a)){e=j+40|0;rW(e,a);f=j+168|0;cf(f,e,128,2);e=j+180|0;Cc(e,f);zc(b+492|0,e);tb(e)}w[c+34>>1]=z[c+34>>1]&65489;o=j+180|0;g=fb-32|0;fb=g;a:{b:{switch(y[a+128|0]-4|0){default:x[g+28>>2]=0;vn(o,0,g+28|0);break a;case 0:case 4:break b}}v[g+28|0]=y[a+129|0];v[g+24|0]=100;k=g+24|0;e=y[Qb(g+28|0,k)|0];v[g+24|0]=y[a+130|0];v[g+20|0]=100;l=g+20|0;m=y[Qb(k,l)|0];x[g+28>>2]=m;c:{if(y[a+140|0]&16){i=Bb(y[a+150|0]|y[a+151|0]<<8);h=Bb(y[a+152|0]|y[a+153|0]<<8);f=x[c>>2];s=+(f>>>0)/6553600;e=yr(s*+((i|e<<16)>>>0));x[g+24>>2]=f-e;t=g,u=yr(s*+((h|m<<16)>>>0)),x[t+20>>2]=u;t=g,u=x[Gb(k,l)>>2],x[t+28>>2]=u;break c}i=x[c>>2];l=x[c+20>>2];if(!je(i,l)){break c}f=i>>>7|0;e=D(f,(e<<7>>>0)/100|0);x[g+24>>2]=i-e;x[g+20>>2]=D(f,(m<<7>>>0)/100|0);f=x[Gb(g+24|0,g+20|0)>>2];h=z[c+34>>1];i=D(_d(h),i);d:{if(h&1){bc(g+12|0,l,i);l=x[g+12>>2];i=_d(z[c+34>>1]);h=l+(D(i,e+f|0)<<1)|0;m=w[l+(D(e,i)<<1)>>1];l=0-i<<1;while(1){e:{f:{if(f){i=w[h>>1]-m|0;k=i>>31;if((i^k)-k>>>0>=1536){break f}}else{f=0}break e}f=f-1|0;h=h+l|0;continue}break}break d}bc(g+4|0,l,i);l=x[g+4>>2];i=_d(z[c+34>>1]);m=0-i|0;h=l+D(i,e+f|0)|0;l=v[l+D(e,i)|0];while(1){g:{h:{if(f){i=v[h|0]-l|0;k=i>>31;if((i^k)-k>>>0>=6){break h}}else{f=0}break g}f=f-1|0;h=h+m|0;continue}break}}x[g+28>>2]=f}vn(o,e,g+28|0)}fb=g+32|0;r=ec(o);if(!(!x[r>>2]|y[a+128|0]!=4)){w[c+34>>1]=z[c+34>>1]|2;f=x[j+180>>2];x[c+4>>2]=f;x[c+8>>2]=f+x[r>>2]}f=j;e=y[a+134|0];if((e-1&255)>>>0<=198){v[f+40|0]=e;v[f+168|0]=100;e=(y[Qb(f+40|0,f+168|0)|0]<<7>>>0)/100|0}else{e=128}v[f+39|0]=e;v[j+40|0]=64;e=j+39|0;f=j+40|0;t=c,u=y[df(e,f)|0]>>>1|0,w[t+32>>1]=u;v[j+40|0]=64;t=b,u=y[Qb(e,f)|0],x[t+4>>2]=u;x[c+24>>2]=40460;gm(c,+v[a+139|0]/12+ +(0-y[a+143|0]|0)+ +v[a+138|0]/1536);v[b+34|0]=y[a+142|0]&2?2:1;if(y[a+142|0]&2){ik(b,127,1);hk(b,0,1)}i:{if(!je(x[c>>2],x[c+20>>2])){break i}b=y[a+140|0];if(b&1){b=x[c>>2];g=x[c+20>>2];j:{if(!je(b,g)|b>>>0<2){break j}k:{l:{switch(cl(z[c+34>>1])-1|0){case 3:e=b>>>1|0;b=g+(b<<2)|0;f=0;while(1){if((e|0)!=(f|0)){Tb(g+(f<<2)|0,b+((f^-1)<<2)|0);f=f+1|0;continue}break};break k;case 1:e=b>>>1|0;b=g+(b<<1)|0;f=0;while(1){if((e|0)!=(f|0)){RR(g+(f<<1)|0,b+((f^-1)<<1)|0);f=f+1|0;continue}break};break k;case 0:break l;default:break j}}e=b+g|0;b=b>>>1|0;f=0;while(1){if((b|0)!=(f|0)){tg(f+g|0,e+(f^-1)|0);f=f+1|0;continue}break}}Pj(c,d)}b=y[a+140|0]}if(b&4){m:{f=x[c>>2];g=x[c+20>>2];if(!je(f,g)){break m}b=z[c+34>>1];f=D(_d(b),f);n:{o:{switch(On(b)-1|0){case 1:e=0;while(1){if((e|0)!=(f|0)){b=g+(e<<1)|0;w[b>>1]=z[b>>1]^-1;e=e+1|0;continue}break};break n;case 0:break o;default:break m}}e=0;while(1){if((e|0)!=(f|0)){b=e+g|0;v[b|0]=y[b|0]^-1;e=e+1|0;continue}break}}Pj(c,d)}}p=y[a+170|0]!=2|y[a+171|0]>100?p:y[a+172|0]<101;b=z[c+34>>1];if(!(!(p|y[a+160|0]!=0|y[a+141|0])|b&1)){f=mv(x[c>>2],_d(b)<<1&254);if(!f){break i}b=f;h=x[c>>2];e=z[c+34>>1];g=D(_d(e),h);k=x[c+20>>2];e=Vk(h,e);i=fb-16|0;fb=i;x[i+12>>2]=g;wc(i+12|0,e);h=x[i+12>>2];while(1){if(h){w[b>>1]=v[k|0]<<8;k=k+1|0;b=b+2|0;h=h-1|0;continue}break}fb=i+16|0;w[c+34>>1]=z[c+34>>1]|1;pW(c,f,x[c>>2],d);b=z[c+34>>1]}f=x[c>>2];e=x[c+20>>2];p:{if(v[a+141|0]>=0){break p}bc(j+40|0,e,D(_d(b),f));q:while(1){if((0-v[a+141|0]|0)<=(q|0)){f=x[c>>2];e=x[c+20>>2];b=z[c+34>>1];break p}b=x[j+40>>2];f=w[b>>1];t=j,u=wb(b),x[t+168>>2]=u;b=mn(x[j+40>>2],x[j+44>>2]);while(1){e=x[j+168>>2];if(Ib(e,b)){f=qd(w[e>>1]-qd(f,1)|0,1);w[e>>1]=f;Md(j+168|0);continue}else{q=q+1|0;continue q}}}}if(p){bc(j+40|0,e,D(_d(b),f));h=x[j+44>>2];b=(h|0)/2|0;e=b;f=e>>31;b=y[a+172|0];i=y[a+171|0];g=b-i|0;k=0-(b>>>0<i>>>0)<<24|g>>>8;b=g<<24;e=b+e|0;f=f+k|0;b=Gc(Tua(e,b>>>0>e>>>0?f+1|0:f,h,h>>31),hb);t=j,u=wb(x[j+40>>2]),x[t+168>>2]=u;g=b;l=b>>31;b=i<<24;f=b>>31;i=mn(x[j+40>>2],x[j+44>>2]);while(1){e=x[j+168>>2];if(Ib(e,i)){h=w[e>>1];h=Sua(b,f,h,h>>31);k=hb;h=h+838860800|0;k=h>>>0<838860800?k+1|0:k;t=e,u=Gc(Tua(h,k,1677721600,0),hb),w[t>>1]=u;f=f+l|0;b=b+g|0;f=b>>>0<g>>>0?f+1|0:f;Md(j+168|0);continue}break}f=x[c>>2];e=x[c+20>>2];b=z[c+34>>1]}if(y[a+160|0]){bc(j+168|0,e,D(_d(b),f));m=y[a+163|0];l=y[a+162|0];f=0;k=0;if(y[a+161|0]>=2){i=x[j+172>>2];b=(i|0)/2|0;h=b;g=b>>31;b=y[a+164|0];e=0-(b>>>0<l>>>0)|0;b=b-l|0;k=e<<23|b>>>9;b=b<<23;e=b+h|0;k=g+k|0;n=Gc(Tua(e,b>>>0>e>>>0?k+1|0:k,i,i>>31),hb);i=x[j+172>>2];b=(i|0)/2|0;h=b;g=b>>31;b=y[a+165|0];e=0-(b>>>0<m>>>0)|0;b=b-m|0;k=e<<23|b>>>9;b=b<<23;e=b+h|0;g=g+k|0;k=Gc(Tua(e,b>>>0>e>>>0?g+1|0:g,i,i>>31),hb)}e=m<<23;q=l<<23;g=y[a+160|0];b=wb(x[j+168>>2]);x[j+32>>2]=b;i=(j+40|0)+((g&2)<<2)|0;h=mn(x[j+168>>2],x[j+172>>2]);p=0;while(1){if(Ib(b,h)){g=(w[b>>1]>>1)-p|0;x[j+48>>2]=g;m=g;g=(q|0)/8388608|0;f=qd(D(m,g),8)+f|0;x[j+44>>2]=f;g=qd(D(f,g),6)+p|0;p=qd(qd(D(g,(e|0)/8388608|0),6)+g|0,2);x[j+40>>2]=p;t=b,u=ed(x[i>>2]),w[t>>1]=u;e=e+k|0;q=n+q|0;b=x[Md(j+32|0)>>2];continue}else{f=x[c>>2];e=x[c+20>>2];b=z[c+34>>1]}break}}r:{if(v[a+141|0]<=0){break r}bc(j+40|0,e,D(_d(b),f));q=0;s:while(1){if(v[a+141|0]<=(q|0)){f=x[c>>2];e=x[c+20>>2];b=z[c+34>>1];break r}b=x[j+40>>2];f=w[b>>1];t=j,u=wb(b),x[t+168>>2]=u;b=mn(x[j+40>>2],x[j+44>>2]);while(1){e=x[j+168>>2];if(Ib(e,b)){f=((w[e>>1]<<1)+f|0)/3|0;w[e>>1]=f;Md(j+168|0);continue}else{q=q+1|0;continue s}}}}f=D(_d(b),f);t:{if(b&1){bc(j+24|0,e,f);m=x[j+28>>2];b=fb-16|0;fb=b;k=x[j+24>>2];e=wb(k);q=mn(k,m);p=fb-16|0;fb=p;v[p+14|0]=0;o=fb-16|0;fb=o;x[o+12>>2]=e;gc(o+4|0,p+15|0,p+14|0);l=b+8|0;f=o+12|0;h=vn(l,e,f);u:{if(mc(e,q)){break u}n=Md(f);g=x[n>>2];if(mc(g,q)){break u}e=x[h>>2];f=Yl(g,e);x[(f?0:4)+h>>2]=g;f=f?g:e;i=h+4|0;while(1){g=Md(n);e=x[g>>2];if(!Ib(e,q)){break u}g=x[Md(g)>>2];if(mc(g,q)){if(!Yl(e,f)){h=i;if(Yl(e,x[i>>2])){break u}}x[h>>2]=e;break u}v:{if(Yl(g,e)){if(Yl(g,f)){x[h>>2]=g;f=g}if(Yl(e,x[i>>2])){continue}break v}if(Yl(e,f)){x[h>>2]=e;f=e}e=g;if(Yl(e,x[i>>2])){continue}}x[i>>2]=e;continue}}fb=o+16|0;fb=p+16|0;x[b+4>>2]=0-w[x[b+8>>2]>>1];t=b,u=w[x[ec(l)>>2]>>1],x[t>>2]=u;w:{g=x[Ye(b+4|0,b)>>2];if((g|0)>32766|!g){break w}e=wb(k);x[b+4>>2]=e;f=mn(k,m);while(1){if(!Ib(e,f)){break w}w[e>>1]=(D(w[e>>1],32767)|0)/(g|0);e=x[Md(b+4|0)>>2];continue}}break t}bc(j+16|0,e,f);m=x[j+20>>2];b=fb-16|0;fb=b;k=x[j+16>>2];e=wb(k);q=Wk(k,m);p=fb-16|0;fb=p;v[p+14|0]=0;o=fb-16|0;fb=o;x[o+12>>2]=e;gc(o+4|0,p+15|0,p+14|0);l=b+8|0;f=o+12|0;h=vn(l,e,f);x:{if(mc(e,q)){break x}n=le(f);g=x[n>>2];if(mc(g,q)){break x}e=x[h>>2];f=Zl(g,e);x[(f?0:4)+h>>2]=g;f=f?g:e;i=h+4|0;while(1){g=le(n);e=x[g>>2];if(!Ib(e,q)){break x}g=x[le(g)>>2];if(mc(g,q)){if(!Zl(e,f)){h=i;if(Zl(e,x[i>>2])){break x}}x[h>>2]=e;break x}y:{if(Zl(g,e)){if(Zl(g,f)){x[h>>2]=g;f=g}if(Zl(e,x[i>>2])){continue}break y}if(Zl(e,f)){x[h>>2]=e;f=e}e=g;if(Zl(e,x[i>>2])){continue}}x[i>>2]=e;continue}}fb=o+16|0;fb=p+16|0;x[b+4>>2]=0-v[x[b+8>>2]];t=b,u=v[x[ec(l)>>2]],x[t>>2]=u;z:{g=x[Ye(b+4|0,b)>>2];if((g|0)>126|!g){break z}e=wb(k);x[b+4>>2]=e;f=Wk(k,m);while(1){if(!Ib(e,f)){break z}v[e|0]=(D(v[e|0],127)|0)/(g|0);e=x[le(b+4|0)>>2];continue}}}fb=b+16|0;A:{if((y[a+134|0]-101&255)>>>0>98){break A}b=z[c+34>>1];f=D(x[c>>2],_d(b));e=x[c+20>>2];if(b&1){x[j+8>>2]=e;x[j+12>>2]=(e+(f<<1)|0)-e>>1;g=x[j+12>>2];f=y[a+134|0];h=fb-16|0;fb=h;b=x[j+8>>2];e=wb(b);x[h+12>>2]=e;n=(3276800-(f<<14)|0)/100|0;f=0-n|0;i=32768-n|0;b=mn(b,g);while(1){if(Ib(e,b)){g=w[e>>1];B:{if((g|0)>(n|0)){m=i+((D(n,g-n|0)|0)/(i|0)|0)|0;break B}m=((D(n,g+n|0)|0)/(i|0)|0)-i|0;if((f|0)>(g|0)){break B}m=(D(g,i)|0)/(n|0)|0}t=e,u=ed(m),w[t>>1]=u;e=x[Md(h+12|0)>>2];continue}break}fb=h+16|0;break A}b=wo(j,e,e+f|0);h=x[b>>2];g=x[b+4>>2];b=y[a+134|0];i=fb-16|0;fb=i;e=wb(h);x[i+12>>2]=e;l=(3276800-(b<<14)|0)/100|0;f=0-l|0;n=32768-l|0;b=Wk(h,g);while(1){if(Ib(e,b)){g=v[e|0]<<8;C:{if((g|0)>(l|0)){h=n+((D(l,g-l|0)|0)/(n|0)|0)|0;break C}h=((D(l,g+l|0)|0)/(n|0)|0)-n|0;if((f|0)>(g|0)){break C}h=(D(g,n)|0)/(l|0)|0}t=e,u=uY((h|0)/256|0),v[t|0]=u;e=x[le(i+12|0)>>2];continue}break}fb=i+16|0}oW(c);if(y[a+128|0]!=8){break i}e=y[a+131|0];if(!e){break i}f=x[r>>2];if(!f){break i}b=x[j+180>>2];t=yb(c+68|0,0),u=b+D(f,e+1|0)|0,x[t>>2]=u;h=x[j+180>>2];x[c+12>>2]=h;x[c+16>>2]=h+x[r>>2];e=x[r>>2];g=y[a+131|0];if(e>>>0>268435456/(g>>>0)>>>0){break i}b=x[c>>2];f=D(e,g);if(b>>>0>268435456-f>>>0){break i}k=b+f|0;o=cl(z[c+34>>1]);b=mv(k,o);if(!b){break i}l=h+D(e,g+1|0)|0;x[c>>2]=k;n=x[c+20>>2];i=x[r>>2];h=x[j+180>>2];g=D(o,i+h|0);m=yc(b,n,g);e=D(i,o);f=n+D(h,o)|0;a=y[a+131|0];b=0;while(1){if((a|0)==(b|0)){yc(m+D(l,o)|0,g+n|0,D(o,k-l|0));pW(c,m,k,d)}else{b=b+1|0;yc(m+D(o,h+D(i,b)|0)|0,f,e);continue}break}}fb=j+192|0}function Qja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;d=fb-720|0;fb=d;xc(b);a:{b:{c:{d:{if(!Bi(b,d+712|0)){break d}if(!FR(x[d+712>>2],x[d+716>>2])){break d}if(!Ur(b,d+708|0)){break d}f=x[d+708>>2];if(!ER(f)){break d}if((f|0)==1179012417){f=0}else{if((f|0)!=538987841){break d}f=1}e=f?2:1;g=f?1414090313:1313423693;n=Ge(d+688|0,b);k=Nb(d+676|0);e:{f:{g:{h:{i:{j:{k:{if((c|0)==64){x[31737]=0;b=d+112|0;V(898,b|0,n|0,e|0,g|0);e=x[31737];x[31737]=0;if((e|0)!=1){break k}a=N()|0;break a}x[31737]=0;b=d+112|0;S(899,b|0,n|0,e|0);e=x[31737];x[31737]=0;if((e|0)==1){break j}}yv(k,b);ie(b);x[31737]=0;b=d+656|0;S(900,b|0,k|0,g|0);e=x[31737];x[31737]=0;if((e|0)!=1){x[31737]=0;g=R(173,x[d+656>>2])|0;e=x[31737];x[31737]=0;if((e|0)==1){break i}e=0;if(!g){break e}x[31737]=0;j=d+583|0;b=P(901,b|0,j|0)|0;g=x[31737];x[31737]=0;if((g|0)==1){break i}if(!b){break e}b=y[d+648|0];if(!b){break e}x[31737]=0;e=U(151,x[d+656>>2],x[d+664>>2],b|0)|0;b=x[31737];x[31737]=0;if((b|0)==1){break i}if(!((c|0)!=64&e)){break e}x[31737]=0;O(247,a|0,8388608);b=x[31737];x[31737]=0;if((b|0)==1){break i}x[a+480208>>2]=y[d+647|0]<<4&16^28;w[d+112>>1]=y[d+648|0];w[d+464>>1]=127;b=d+112|0;e=d+464|0;o=a,q=z[Nc(b,e)>>1],w[o+480188>>1]=q;x[a+480196>>2]=y[d+649|0];x[a+480204>>2]=D(y[d+650|0],1e4);x[a+480200>>2]=y[d+655|0]<<1;x[31737]=0;O(131,a+1298344|0,(f?16982:17016)|0);g=x[31737];x[31737]=0;if((g|0)==1){break i}x[31737]=0;g=P(1,d+568|0,13334)|0;m=x[31737];x[31737]=0;if((m|0)==1){break g}Ab(a+1298356|0,g);tb(g);o=a+1298404|0,q=x[Fc(b,4)>>2],x[o>>2]=q;HC(e,2,j);x[31737]=0;O(219,b|0,e|0);e=x[31737];x[31737]=0;if((e|0)==1){break h}Ab(a+1298308|0,b);tb(b);b=0;while(1){l:{m:{n:{if(z[a+480188>>1]<=b>>>0){b=wb(x[k>>2]);g=wb(x[k+4>>2]);e=fb-16|0;fb=e;x[e+12>>2]=b;while(1){o:{if(!Ib(b,g)){break o}if(J$(1380209231,x[b>>2],x[b+4>>2])){break o}b=x[lm(e+12|0)>>2];continue}break}fb=e+16|0;if(Ib(b,wb(x[k+4>>2]))){break n}break f}g=(b<<5)+a|0;j=g+480280|0;We(j);x[31737]=0;e=R(198,d+656|0)|0;m=x[31737];x[31737]=0;p:{q:{if((m|0)!=1){if(!f){break p}if(e>>>0<129){break q}break m}a=N()|0;break b}w[g+480284>>1]=e<<1;break l}if(e<<24>>24<0){break m}x[d+112>>2]=e<<2;x[d+464>>2]=256;o=g+480284|0,q=x[ud(d+112|0,d+464|0)>>2],w[o>>1]=q;break l}x[31737]=0;b=d+112|0;S(900,b|0,k|0,1380209231);e=x[31737];x[31737]=0;r:{if((e|0)!=1){x[31737]=0;e=R(198,b|0)|0;g=x[31737];x[31737]=0;if((g|0)==1){break r}g=y[a+484376|0];j=x[a+484360>>2];x[31737]=0;aa(349,Xb(j,g)|0,b|0,e+1&255,255,254);e=x[31737];x[31737]=0;if((e|0)==1){break r}ub(b);break f}a=N()|0;break b}a=N()|0;ub(d+112|0);break b}x[j>>2]=1024}b=b+1|0;continue}}a=N()|0;break a}a=N()|0;break a}a=N()|0;break b}a=N()|0;break b}a=N()|0;break b}s:{if(!(c&1)){break s}w[d+48>>1]=0;x[31737]=0;S(902,d+528|0,k|0,1414807888);b=x[31737];x[31737]=0;if((b|0)==1){break c}b=x[d+532>>2];e=x[d+528>>2];x[31737]=0;j=a+484344|0;O(224,j|0,Uf(e,b)&65535);b=x[31737];x[31737]=0;t:{if((b|0)!=1){o=d,q=wb(x[d+528>>2]),x[o+76>>2]=q;m=wb(x[d+532>>2]);u:{v:{w:{x:{y:{while(1){b=x[d+76>>2];if(!Ib(b,m)){b=0;break u}b=Ge(d+112|0,b);x[31737]=0;e=R(198,b|0)|0;g=x[31737];x[31737]=0;if((g|0)!=1){x[31737]=0;w[d+452>>1]=e;e=R(152,b|0)|0;g=x[31737];x[31737]=0;if((g|0)==1){break y}x[31737]=0;g=d+464|0;S(186,g|0,b|0,e|0);e=x[31737];x[31737]=0;if((e|0)==1){break x}e=ic(d+548|0,g);x[31737]=0;i=x[e+12>>2];x[d+8>>2]=x[e+8>>2];x[d+12>>2]=i;x[d+16>>2]=x[e+16>>2];i=x[e+4>>2];x[d>>2]=x[e>>2];x[d+4>>2]=i;V(903,d|0,z[d+452>>1],f|0,a|0);e=x[31737];x[31737]=0;if((e|0)==1){break w}ub(g);o=d,q=z[pe(d+48|0,d+452|0)>>1],w[o+48>>1]=q;ub(b);Sf(d+76|0);continue}break}a=N()|0;break v}a=N()|0;break v}a=N()|0;break v}a=N()|0;ub(d+464|0)}ub(b);break t}while(1){e=b&65535;if(e>>>0>=z[d+48>>1]){Qc(d+528|0);break s}z:{if(!He(x[a+484344>>2],x[a+484348>>2],e)){x[31737]=0;U(197,j|0,e|0,64)|0;e=x[31737];x[31737]=0;if((e|0)==1){break z}}b=b+1|0;continue}break}a=N()|0;break t}a=N()|0}Qc(d+528|0);break b}A:{B:{C:{if(!f){x[31737]=0;S(902,d+76|0,k|0,1414745673);b=x[31737];x[31737]=0;if((b|0)==1){break B}o=d,q=wb(x[d+76>>2]),x[o+100>>2]=q;g=c&2;j=d+472|0;m=wb(x[d+80>>2]);while(1){b=x[d+100>>2];if(!Ib(b,m)){Qc(d+76|0);break A}c=Ge(d+528|0,b);x[31737]=0;e=d+112|0;b=P(904,c|0,e|0)|0;f=x[31737];x[31737]=0;if((f|0)!=1){D:{if(!b){break D}b=y[d+113|0];if((b|0)==255){break D}x[31737]=0;f=U(252,a|0,b+1|0,0)|0;b=x[31737];x[31737]=0;if((b|0)==1){break C}if(!f){break D}i=z[a+480190>>1];b=0;x[31737]=0;S(905,e|0,f|0,i|0);f=x[31737];x[31737]=0;if((f|0)==1){break C}while(1){if(y[d+142|0]<=b>>>0){break D}E:{if(!ui(z[a+480190>>1])){break E}x[31737]=0;e=d+464|0;f=P(906,c|0,e|0)|0;i=x[31737];x[31737]=0;if((i|0)==1){break C}if(!f){break E}i=z[a+480190>>1]+1|0;w[a+480190>>1]=i;if(x[d+464>>2]!=1347240275){break E}h=d+452|0;aj(h,2,j);x[31737]=0;f=d+48|0;O(219,f|0,h|0);h=x[31737];x[31737]=0;F:{if((h|0)!=1){i=i&65535;zc(((i<<5)+a|0)+946304|0,f);tb(f);x[31737]=0;h=e;e=(D(i,104)+a|0)+484380|0;S(907,h|0,d+112|0,e|0);i=x[31737];x[31737]=0;if((i|0)==1){break C}if(!g){break F}CR(f,z[d+502>>1]);x[31737]=0;U(216,f|0,e|0,c|0)|0;f=x[31737];x[31737]=0;if((f|0)!=1){break E}break C}break C}f=z[e+34>>1];e=x[e>>2];x[31737]=0;P(184,c|0,Vk(e,f)|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break C}}b=b+1|0;continue}}ub(c);Sf(d+100|0);continue}break}break C}x[31737]=0;S(902,d+452|0,k|0,1179011410);b=x[31737];x[31737]=0;if((b|0)!=1){o=d,q=wb(x[d+452>>2]),x[o+448>>2]=q;g=c&2;j=d+468|0;m=wb(x[d+456>>2]);G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{while(1){b=x[d+448>>2];if(!Ib(b,m)){Qc(d+452|0);break A}c=Ge(d+528|0,b);x[31737]=0;b=R(152,c|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break P}Q:{R:{if((b|0)!=538986817){break R}x[31737]=0;b=P(908,c|0,d+440|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break O}if(!(x[d+440>>2]==1414745673&b)){break R}x[31737]=0;f=d+112|0;b=P(909,c|0,f|0)|0;e=x[31737];x[31737]=0;if((e|0)==1){break N}if(!b){break R}b=y[d+117|0];if((b|0)==255){break R}x[31737]=0;b=U(252,a|0,b+1|0,0)|0;e=x[31737];x[31737]=0;if((e|0)==1){break M}if(!b){break R}e=z[a+480190>>1];x[31737]=0;S(910,f|0,b|0,e|0);b=x[31737];x[31737]=0;if((b|0)==1){break M}x[31737]=0;b=d+464|0;S(899,b|0,c|0,2);f=x[31737];x[31737]=0;if((f|0)==1){break Q}x[31737]=0;S(902,d+100|0,b|0,1179011410);f=x[31737];x[31737]=0;if((f|0)==1){break L}ie(b);o=d,q=wb(x[d+100>>2]),x[o+96>>2]=q;i=wb(x[d+104>>2]);S:{T:{while(1){b=x[d+96>>2];if(!Ib(b,i)){break S}b=Ge(d+76|0,b);x[31737]=0;f=R(152,b|0)|0;e=x[31737];x[31737]=0;if((e|0)==1){break K}U:{V:{if((f|0)!=538989377){break V}f=z[a+480190>>1];if(!ui(f)){break V}e=y[d+436|0]|y[d+437|0]<<8;h=e-1|0;v[d+436|0]=h;v[d+437|0]=h>>>8;if(!e){ub(b);break S}h=f+1|0;w[a+480190>>1]=h;x[31737]=0;f=P(908,b|0,d+68|0)|0;e=x[31737];x[31737]=0;if((e|0)==1){break J}if(!(x[d+68>>2]==1347240275&f)){break T}x[31737]=0;e=d+464|0;S(186,e|0,b|0,x[d+72>>2]);f=x[31737];x[31737]=0;W:{if((f|0)!=1){f=ic(d+48|0,e);ub(e);x[31737]=0;e=P(911,f|0,e|0)|0;l=x[31737];x[31737]=0;if((l|0)==1){break U}if(e){break W}ub(f);ub(b);break S}a=N()|0;break H}l=d+24|0;Ve(l,2,j);x[31737]=0;e=d+36|0;O(219,e|0,l|0);l=x[31737];x[31737]=0;if((l|0)==1){break I}h=h&65535;zc(((h<<5)+a|0)+946304|0,e);tb(e);x[31737]=0;h=(D(h,104)+a|0)+484380|0;S(912,d+464|0,d+112|0,h|0);l=x[31737];x[31737]=0;if((l|0)==1){break U}X:{if(!g){break X}x[31737]=0;P(150,f|0,x[d+464>>2]+4|0)|0;l=x[31737];x[31737]=0;if((l|0)==1){break U}CR(e,z[d+504>>1]);x[31737]=0;U(216,e|0,h|0,f|0)|0;e=x[31737];x[31737]=0;if((e|0)!=1){break X}break I}ub(f)}ub(b);Sf(d+96|0);continue}break}break I}ub(b)}Qc(d+100|0)}ub(c);Sf(d+448|0);continue}break}a=N()|0;break G}a=N()|0;break G}a=N()|0;break G}a=N()|0;break G}a=N()|0;break G}a=N()|0;ie(d+464|0);break G}a=N()|0;break H}a=N()|0;break H}a=N()|0;ub(f)}ub(b);Qc(d+100|0)}ub(c);Qc(d+452|0);break b}a=N()|0;break b}a=N()|0;ub(c);Qc(d+76|0);break b}a=N()|0;break b}e=1}ub(d+656|0);ie(k);ub(n)}fb=d+720|0;return e|0}a=N()|0}ub(d+656|0)}ie(k);ub(n);Q(a|0);p()}function u1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0;e=fb-208|0;fb=e;xc(b);d=e+204|0;a:{if(!Ur(b,d)){break a}x[e+184>>2]=0;x[e+188>>2]=0;x[e+176>>2]=0;x[e+180>>2]=0;x[e+168>>2]=0;x[e+172>>2]=0;x[e+160>>2]=0;x[e+164>>2]=0;b:{c:{if(!dF(d)){break c}if(!Mb(x[b>>2],x[b+8>>2],32)){break c}Cw(b,e+160|0);break b}m=1;if(!cF(e+204|0)){break a}}j=e+155|0;f=bF(y[e+207|0]);d=fb-32|0;fb=d;x[d+28>>2]=f;x[d+8>>2]=5;g=x[b>>2];h=x[b+8>>2];f=x[Gb(d+28|0,d+8|0)>>2];if(!Mb(g,h,f)){f=kf(b)}l=d+8|0;ek(l,j);k=gc(d+16|0,x[d+8>>2],f);h=x[k>>2];lc(d,x[b>>2],x[b+8>>2],h,x[k+4>>2]);ek(l,j);Rb(x[d+8>>2]+f|0,0,5-f|0);Vb(b,x[d+28>>2]);fb=d+32|0;if(!f){break a}if(!aF(j,y[e+207|0])){break a}n=1;if((c|0)==64){break a}j=e+207|0;Bd(a,2048);gg(a);d:{e:{f:{g:{h:{i:{j:{k:{if(m){d=fb-16|0;fb=d;f=e+4|0;l=tc(d+4|0,3893);_c(f,l);tb(l);fb=d+16|0;x[31737]=0;d=e+72|0;S(210,d|0,f|0,j|0);j=x[31737];x[31737]=0;if((j|0)==1){break j}Ab(a+1298344|0,d);tb(d);Eb(f);f=tc(d,11160);Ab(a+1298356|0,f);break k}f=e+4|0;Ve(f,2,e+160|0);d=e+72|0;Cc(d,f);Ab(a+1298308|0,d);tb(d);l=fb-16|0;fb=l;k=tc(l+4|0,3944);_c(f,k);tb(k);fb=l+16|0;x[31737]=0;S(210,d|0,f|0,j|0);j=x[31737];x[31737]=0;if((j|0)==1){break i}Ab(a+1298344|0,d);tb(d);Eb(f);f=tc(d,11164);Ab(a+1298356|0,f)}tb(f);A=a+1298404|0,B=x[Fc(e+72|0,4)>>2],x[A>>2]=B;w[a+480188>>1]=y[e+159|0];w[a+480190>>1]=y[e+155|0];l:{f=y[e+207|0];if(f>>>0>8){break l}w[a+480188>>1]=4;d=0;while(1){if((d|0)==4){break l}w[((d<<5)+a|0)+480284>>1]=d&1?192:64;d=d+1|0;continue}}m:{if(f>>>0>=11){f=(f|0)==11?16:32;d=0;while(1){if((d|0)==(f|0)){break m}j=Lw(b);n:{if((j|0)==100){x[((d<<5)+a|0)+480280>>2]=256;break n}x[e+72>>2]=(j<<1)+128;x[e+4>>2]=0;x[e+140>>2]=256;A=((d<<5)+a|0)+480284|0,B=x[dk(e+72|0,e+4|0,e+140|0)>>2],w[A>>1]=B}d=d+1|0;continue}}if(f>>>0<9){break m}Vb(b,16);d=0;while(1){if((d|0)==16){break m}w[((d<<5)+a|0)+480284>>1]=d&1?192:64;d=d+1|0;continue}}o:{if(y[e+207|0]>=13){d=e+72|0;Iw(d,b);f=Jc(d);d=y[e+72|0];if(d>>>0<=31){v[e+72|0]=125;d=125}x[a+480204>>2]=D(d,1e4);x[a+480196>>2]=y[f|0];break o}x[a+480196>>2]=6;x[a+480204>>2]=125e4}xg(Xb(x[a+484360>>2],y[a+484376|0]),y[e+156|0]);l=Nb(e+140|0);d=x[b+8>>2];f=y[e+207|0]>13;if(!f){break h}x[31737]=0;O(211,l|0,y[e+156|0]);j=x[31737];x[31737]=0;if((j|0)!=1){break h}d=N()|0;break g}d=N()|0;Eb(e+4|0);break f}d=N()|0;Eb(e+4|0);break f}s=d+(f<<1)|0;d=0;p:{q:{while(1){if(y[e+156|0]<=d>>>0){j=0;if(y[e+207|0]!=10){break p}h=x[b+8>>2];d=1;while(1){j=z[a+480190>>1]>=(d&65535)>>>0;if(!j){break q}x[31737]=0;f=P(212,b|0,e+72|0)|0;k=x[31737];x[31737]=0;if((k|0)!=1){if(f){f=0;r:{if(y[e+155|0]<(y[e+118|0]|y[e+119|0]<<8|(y[e+120|0]<<16|y[e+121|0]<<24))>>>0|y[e+72|0]>1){break r}k=y[e+122|0]|y[e+123|0]<<8|(y[e+124|0]<<16|y[e+125|0]<<24);if(k>>>0>1048576|y[e+128|0]>64|k>>>0<(y[e+129|0]|y[e+130|0]<<8|(y[e+131|0]<<16|y[e+132|0]<<24))>>>0){break r}f=k>>>0>=(y[e+133|0]|y[e+134|0]<<8|(y[e+135|0]<<16|y[e+136|0]<<24))>>>0}if(!f){break q}}d=d+1|0;continue}break}d=N()|0;break g}A=_b(x[Xb(x[a+484360>>2],y[a+484376|0])>>2],d),B=d,w[A>>1]=B;s:{if(y[e+207|0]>=14){x[31737]=0;f=R(190,b|0)|0;j=x[31737];x[31737]=0;if((j|0)==1){break s}A=_b(x[l>>2],d),B=f,w[A>>1]=B}f=z[a+480188>>1];x[31737]=0;P(184,b|0,f<<1)|0;f=x[31737];x[31737]=0;if((f|0)==1){break s}d=d+1|0;continue}break}d=N()|0;break g}x[31737]=0;P(150,b|0,h|0)|0;d=x[31737];x[31737]=0;if((d|0)!=1){break p}d=N()|0;break g}d=z[a+480190>>1];x[31737]=0;x[e+72>>2]=0;k=U(213,e+60|0,d|0,e+72|0)|0;d=x[31737];x[31737]=0;t:{u:{v:{w:{if((d|0)!=1){n=j?59:65;h=e+73|0;d=1;x:{while(1){f=d&65535;if(f>>>0>z[a+480190>>1]){j=Nb(e+48|0);x[31737]=0;n=U(214,b|0,j|0,y[e+157|0]|y[e+158|0]<<8)|0;d=x[31737];x[31737]=0;y:{if((d|0)!=1){if(!n){break d}d=0;f=0;h=x[j>>2];if(!mc(h,x[j+4>>2])){f=wb(h);g=wb(x[j+4>>2]);h=fb-16|0;fb=h;z:{if(!Ib(f,g)){break z}x[h+12>>2]=f;while(1){i=x[Md(h+12|0)>>2];if(!Ib(i,g)){break z}f=bl(y[f|0]|y[f+1|0]<<8,y[i|0]|y[i+1|0]<<8)?i:f;continue}}fb=h+16|0;f=y[f|0]|y[f+1|0]<<8}x[31737]=0;i=P(215,e+24|0,f|0)|0;h=x[31737];x[31737]=0;if((h|0)==1){break y}A:{while(1){if((d|0)==(f|0)){if(!(c&2)){break w}r=Xc(e+4|0,8,1,0,m?2:1);d=z[a+480190>>1];g=1;B:{C:{D:while(1){o=g&65535;if(o>>>0>(d&65535)>>>0){break w}d=x[b+8>>2];h=x[b>>2];x[31737]=0;d=U(151,h|0,d|0,1)|0;h=x[31737];x[31737]=0;if((h|0)==1){break B}if(!d){break w}t=x[b+8>>2];h=0;E:while(1){d=z[a+480190>>1];if(h>>>0>=d>>>0){g=g+1|0;continue D}if((o|0)!=x[yb(x[k>>2],h)>>2]){h=h+1|0;continue}x[31737]=0;P(150,b|0,t|0)|0;d=x[31737];x[31737]=0;if((d|0)!=1){x[31737]=0;h=h+1|0;d=D(h,104)+a|0;q=d+484380|0;U(216,r|0,q|0,b|0)|0;u=x[31737];x[31737]=0;if((u|0)==1){break C}if(!m){continue}bc(e+72|0,x[d+484400>>2],x[q>>2]);A=e,B=wb(x[e+72>>2]),x[A>>2]=B;q=Wk(x[e+72>>2],x[e+76>>2]);while(1){d=x[e>>2];if(!Ib(d,q)){continue E}v[d|0]=y[d|0]^128;le(e);continue}}break}break}d=N()|0;break v}d=N()|0;break v}d=N()|0;break v}x[31737]=0;h=R(190,b|0)|0;g=x[31737];x[31737]=0;F:{if((g|0)==1){break F}x[31737]=0;P(184,b|0,1)|0;g=x[31737];x[31737]=0;if((g|0)==1){break F}if(h){x[31737]=0;g=e+4|0;S(186,g|0,b|0,D(h,3)+(y[e+207|0]==1?3:0)|0);h=x[31737];x[31737]=0;if((h|0)==1){break A}h=ic(e+72|0,g);hd(dh(x[i>>2],d),h);ub(h);ub(g)}d=d+1|0;continue}break}d=N()|0;break v}d=N()|0;break v}d=N()|0;break u}d=N()|0;break u}G:{H:{if(y[e+207|0]<=9){x[31737]=0;i=e+72|0;O(217,b|0,i|0);g=x[31737];x[31737]=0;I:{J:{if((g|0)==1){break J}x[31737]=0;O(218,i|0,(D(f,104)+a|0)+484380|0);i=x[31737];x[31737]=0;if((i|0)==1){break J}g=e+48|0;Ve(g,2,h);x[31737]=0;i=e+4|0;O(219,i|0,g|0);g=x[31737];x[31737]=0;if((g|0)==1){break I}zc(((f<<5)+a|0)+946304|0,i);tb(i);A=yb(x[k>>2],f-1|0),B=y[e+118|0]|y[e+119|0]<<8|(y[e+120|0]<<16|y[e+121|0]<<24),x[A>>2]=B;break H}d=N()|0;break t}d=N()|0;break t}if(m){x[31737]=0;i=e+72|0;O(220,b|0,i|0);g=x[31737];x[31737]=0;K:{L:{if((g|0)==1){break L}x[31737]=0;O(221,i|0,(D(f,104)+a|0)+484380|0);i=x[31737];x[31737]=0;if((i|0)==1){break L}x[31737]=0;i=P(36,e+36|0,22303)|0;g=x[31737];x[31737]=0;if((g|0)==1){break K}zc(((f<<5)+a|0)+946304|0,i);tb(i);A=yb(x[k>>2],f-1|0),B=y[e+74|0]|y[e+75|0]<<8|(y[e+76|0]<<16|y[e+77|0]<<24),x[A>>2]=B;break H}d=N()|0;break t}d=N()|0;break t}x[31737]=0;i=e+72|0;S(222,b|0,i|0,n|0);g=x[31737];x[31737]=0;if((g|0)==1){break G}x[31737]=0;S(223,i|0,(D(f,104)+a|0)+484380|0,j|0);i=x[31737];x[31737]=0;if((i|0)==1){break G}g=e+48|0;Ve(g,2,h);x[31737]=0;i=e+4|0;O(219,i|0,g|0);g=x[31737];x[31737]=0;if((g|0)==1){break x}zc(((f<<5)+a|0)+946304|0,i);tb(i);A=yb(x[k>>2],f-1|0),B=y[e+118|0]|y[e+119|0]<<8|(y[e+120|0]<<16|y[e+121|0]<<24),x[A>>2]=B}d=d+1|0;continue}break}d=N()|0;break t}d=N()|0;break t}d=N()|0;break g}if(!(c&1)){break e}x[31737]=0;m=a+484344|0;O(224,m|0,y[e+156|0]);c=x[31737];x[31737]=0;M:{if((c|0)!=1){c=0;while(1){N:{if(y[e+156|0]<=c>>>0){break e}d=64;h=x[l>>2];if(Zc(h,x[l+4>>2])>>>0>c>>>0){d=z[_b(h,c)>>1]}x[31737]=0;d=U(197,m|0,c&65535,d&65535)|0;h=x[31737];x[31737]=0;if((h|0)==1){break M}O:{if(d){d=z[a+480188>>1];x[31737]=0;P(150,b|0,D(((y[e+207|0]>13)<<1)+(d<<1)|0,c)+s|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break M}h=Nb(e+72|0);d=z[a+480188>>1];x[31737]=0;g=U(214,b|0,h|0,d|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break O}d=0;P:{if(!g){break P}while(1){if(z[a+480188>>1]<=d>>>0){break P}Q:{g=_b(x[h>>2],d);g=(y[g|0]|y[g+1|0]<<8)-1|0;if((g&65535)>>>0>=(y[e+157|0]|y[e+158|0]<<8)>>>0){break Q}g=_b(x[j>>2],g);g=(y[g|0]|y[g+1|0]<<8)-1&65535;if(g>>>0>=f>>>0){break Q}r=x[m>>2];o=x[i>>2];x[31737]=0;S(225,Wb(r,c)|0,d&65535,dh(o,g)|0);g=x[31737];x[31737]=0;if((g|0)!=1){break Q}break N}d=d+1|0;continue}}md(h)}c=c+1|0;continue}}break}d=N()|0;md(h);break v}d=N()|0;break v}d=N()|0}Qc(i)}md(j)}vc(k)}md(l)}Q(d|0);p()}Qc(i)}md(j);vc(k);md(l)}fb=e+208|0;return n|0}function E2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,w=0,B=0;e=fb-1456|0;fb=e;xc(b);Rp(a);a:{b:{c:{d=e+1432|0;if(!ss(b,d)){break c}if(!PG(d)){break c}if(!c){i=1;break c}if(!Cm(x[b>>2],y[e+1450|0]|y[e+1451|0]<<8|(y[e+1452|0]<<16|y[e+1453|0]<<24))){break c}if(!Cm(x[b>>2],(y[e+1450|0]|y[e+1451|0]<<8|(y[e+1452|0]<<16|y[e+1453|0]<<24))+((y[e+1444|0]|y[e+1445|0]<<8)<<2)|0)){break c}px(a);w=e,B=nx(),x[w+68>>2]=B;c=e+68|0;mx(lj(x[a+4>>2])+32|0,c);rs(c);m=x[lj(x[a+4>>2])+32>>2];x[e+1428>>2]=y[e+1446|0]|y[e+1447|0]<<8|(y[e+1448|0]<<16|y[e+1449|0]<<24);w=e,B=Kh(x[b>>2]),x[w+1168>>2]=B;x[e+1136>>2]=214748364;d=e+1168|0;w=e,B=D(x[Gb(d,e+1136|0)>>2],20),x[w+68>>2]=B;vo(m,x[Gb(e+1428|0,c)>>2]);Rb(d,0,256);s=Nb(e+1156|0);while(1){d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{i=(y[e+1444|0]|y[e+1445|0]<<8)>>>0<=t>>>0;if(!i){x[31737]=0;c=P(150,b|0,(y[e+1450|0]|y[e+1451|0]<<8|(y[e+1452|0]<<16|y[e+1453|0]<<24))+(t<<2)|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break r}if(!c){break h}c=x[b+8>>2];d=x[b>>2];x[31737]=0;c=U(151,d|0,c|0,4)|0;d=x[31737];x[31737]=0;if((d|0)==1){break r}if(!c){break h}x[31737]=0;c=R(152,b|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break q}x[31737]=0;d=P(150,b|0,c|0)|0;g=x[31737];x[31737]=0;if((g|0)==1){break q}if(!d){break h}x[31737]=0;d=P(153,b|0,e+1136|0)|0;g=x[31737];x[31737]=0;if((g|0)==1){break p}if(!d){break h}x[31737]=0;d=U(154,b|0,s|0,y[e+1148|0]|y[e+1149|0]<<8)|0;g=x[31737];x[31737]=0;if((g|0)==1){break p}if(!d){break h}g=x[s>>2];f=x[b>>2];x[31737]=0;d=y[e+1148|0]|y[e+1149|0]<<8;f=R(155,f|0)|0;j=x[31737];x[31737]=0;if((j|0)==1){break o}n=f;f=c+20|0;if(n>>>0<=f+(d<<3)>>>0){break h}c=d?g:0;g=y[e+1148|0]|y[e+1149|0]<<8;f=f+(g<<3)|0;d=0;j=y[e+1150|0]|y[e+1151|0]<<8;if(!(j&1)){while(1){if(d>>>0>=g>>>0){break d}if(!c){break h}g=y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24);j=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);x[31737]=0;g=ba(156,j|0,g|0,m|0,x[e+1428>>2])|0;j=x[31737];x[31737]=0;s:{if((j|0)==1){break s}if(!g){break h}x[31737]=0;g=P(150,b|0,f|0)|0;j=x[31737];x[31737]=0;if((j|0)==1){break s}if(!g){break h}g=gc(e+1128|0,xb(x[m>>2],y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24)),y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24));j=x[g>>2];g=x[g+4>>2];x[31737]=0;ao(157,e+68|0,b,j,g);g=x[31737];x[31737]=0;if((g|0)==1){break n}if(x[e+72>>2]!=(y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24))){break h}d=d+1|0;c=c+8|0;g=y[e+1148|0]|y[e+1149|0]<<8;continue}break}i=N()|0;break a}t:{if(j&4){if(!c){break h}d=y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24);g=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);x[31737]=0;d=ba(156,g|0,d|0,m|0,x[e+1428>>2])|0;g=x[31737];x[31737]=0;if((g|0)==1){break m}if(!d){break h}o=xb(x[m>>2],y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24));l=(y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24))&-2;if(!l){break h}x[31737]=0;g=y[e+1154|0]|y[e+1155|0]<<8;d=P(150,b|0,f+(y[e+1152|0]|y[e+1153|0]<<8)|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break l}if(!d){break h}d=x[b+8>>2];f=x[b>>2];x[31737]=0;d=U(151,f|0,d|0,(y[e+1140|0]|y[e+1141|0]<<8|(y[e+1142|0]<<16|y[e+1143|0]<<24))-(y[e+1152|0]|y[e+1153|0]<<8)|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break l}if(!d){break h}x[31737]=0;d=e+48|0;S(158,d|0,b|0,(y[e+1140|0]|y[e+1141|0]<<8|(y[e+1142|0]<<16|y[e+1143|0]<<24))-(y[e+1152|0]|y[e+1153|0]<<8)|0);f=x[31737];x[31737]=0;if((f|0)==1){break b}k=qs(e+68|0,d);ub(d);r=0;j=0;while(1){f=0;u:{while(1){if((j&65535)>>>0>=(y[e+1148|0]|y[e+1149|0]<<8)>>>0){break e}x[31737]=0;d=P(159,k|0,g+1|0)|0;h=x[31737];x[31737]=0;if((h|0)==1){break u}h=g&15;q=z[(h<<1)+24400>>1];v:{w:{if(q>>>0<=d>>>0){x[31737]=0;h=y[h+24448|0];n=P(159,k|0,h|0)|0;u=x[31737];x[31737]=0;if((u|0)==1){break u}d=n+(d-q<<h)|0;if((d|0)!=(g|0)){g=d&15;break v}x[31737]=0;d=P(159,k|0,4)|0;h=x[31737];x[31737]=0;if((h|0)==1){break u}if((d|0)==15){x[31737]=0;h=P(159,k|0,1)|0;d=x[31737];x[31737]=0;if((d|0)==1){break u}d=65535;if(!h){break w}break e}d=d+65520|0}if(d>>>0>65535){break v}}d=d&1?0-(d+1>>>1|0)|0:d>>>1|0;n=f+o|0;h=y[e+1150|0]|y[e+1151|0]<<8;x:{if(h&2){r=d+r|0;d=r;break x}d=h&512?d:d^32768}q=d>>>8|0;h=h&1024;v[n+1|0]=h?d:q;v[n|0]=h?q:d;f=f+2|0}if(f>>>0<l>>>0){continue}break}j=j+1|0;if(j>>>0>=(y[e+1148|0]|y[e+1149|0]<<8)>>>0){break e}d=(j<<3)+c|0;f=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);l=y[d+4|0]|y[d+5|0]<<8|(y[d+6|0]<<16|y[d+7|0]<<24);x[31737]=0;f=ba(156,f|0,l|0,m|0,x[e+1428>>2])|0;l=x[31737];x[31737]=0;if((l|0)==1){break u}if(!f){break t}l=(y[d+4|0]|y[d+5|0]<<8|(y[d+6|0]<<16|y[d+7|0]<<24))&-2;if(!l){break t}o=xb(x[m>>2],y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24));continue}break}i=T(28896)|0;if((gb|0)==($(28896)|0)){Y(i|0)|0;x[31737]=0;X(26);c=x[31737];x[31737]=0;if((c|0)!=1){break e}i=N()|0}ub(k);break a}if(!c){break h}d=y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24);g=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);x[31737]=0;d=ba(156,g|0,d|0,m|0,x[e+1428>>2])|0;g=x[31737];x[31737]=0;if((g|0)==1){break k}if(!d){break h}r=xb(x[m>>2],y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24));if((y[e+1152|0]|y[e+1153|0]<<8)>>>0>256){break h}o=y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24);g=y[e+1154|0]|y[e+1155|0]<<8;x[31737]=0;d=P(150,b|0,f|0)|0;f=x[31737];x[31737]=0;y:{z:{if((f|0)!=1){if(!d){break h}d=gc(e+40|0,e+1168|0,y[e+1152|0]|y[e+1153|0]<<8);f=x[d>>2];d=x[d+4>>2];x[31737]=0;ao(160,e+68|0,b,f,d);d=x[31737];x[31737]=0;if((d|0)==1){break z}d=y[e+1152|0]|y[e+1153|0]<<8;if(d>>>0>A[e+72>>2]){break h}f=x[b+8>>2];j=x[b>>2];x[31737]=0;d=U(151,j|0,f|0,(y[e+1140|0]|y[e+1141|0]<<8|(y[e+1142|0]<<16|y[e+1143|0]<<24))-d|0)|0;f=x[31737];x[31737]=0;if((f|0)!=1){break y}}i=N()|0;break a}i=N()|0;break a}if(!d){break h}x[31737]=0;d=e+48|0;S(158,d|0,b|0,(y[e+1140|0]|y[e+1141|0]<<8|(y[e+1142|0]<<16|y[e+1143|0]<<24))-(y[e+1152|0]|y[e+1153|0]<<8)|0);f=x[31737];x[31737]=0;if((f|0)==1){break f}k=qs(e+68|0,d);ub(d);l=0;j=0;while(1){f=0;A:{while(1){if((l&65535)>>>0>=(y[e+1148|0]|y[e+1149|0]<<8)>>>0){break g}x[31737]=0;d=P(159,k|0,g+1|0)|0;h=x[31737];x[31737]=0;if((h|0)==1){break A}h=g&7;q=y[h+24432|0];B:{C:{if(q>>>0<=d>>>0){x[31737]=0;h=y[h+24440|0];n=P(159,k|0,h|0)|0;u=x[31737];x[31737]=0;if((u|0)==1){break A}d=n+(d-q<<h)|0;if((d|0)!=(g|0)){g=d&7;break B}x[31737]=0;d=P(159,k|0,3)|0;h=x[31737];x[31737]=0;if((h|0)==1){break A}if((d|0)==7){x[31737]=0;h=P(159,k|0,1)|0;d=x[31737];x[31737]=0;if((d|0)==1){break A}d=255;if(!h){break C}break g}d=d+248|0}if(d>>>0>255){break B}}d=y[(e+1168|0)+d|0];h=d+j|0;n=d;d=(y[e+1150|0]|y[e+1151|0]<<8)&2;v[f+r|0]=d?h:n;j=d?h:j;f=f+1|0}if(f>>>0<o>>>0){continue}break}l=l+1|0;if(l>>>0>=(y[e+1148|0]|y[e+1149|0]<<8)>>>0){break g}d=(l<<3)+c|0;f=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);o=y[d+4|0]|y[d+5|0]<<8|(y[d+6|0]<<16|y[d+7|0]<<24);x[31737]=0;f=ba(156,f|0,o|0,m|0,x[e+1428>>2])|0;o=x[31737];x[31737]=0;if((o|0)==1){break A}if(!f){break j}o=y[d+4|0]|y[d+5|0]<<8|(y[d+6|0]<<16|y[d+7|0]<<24);r=xb(x[m>>2],y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24));continue}break}i=T(28896)|0;if((gb|0)==($(28896)|0)){Y(i|0)|0;x[31737]=0;X(26);c=x[31737];x[31737]=0;if((c|0)!=1){break g}i=N()|0}ub(k);break a}ub(k);break h}re(e+24|0,x[m>>2],x[m+4>>2]);lf(e+32|0,x[e+24>>2],x[e+28>>2]);b=Nd(e+16|0);x[31737]=0;c=x[b+4>>2];x[e+8>>2]=x[b>>2];x[e+12>>2]=c;b=jg(161,e+68|0,x[e+32>>2],x[e+36>>2],e+8|0);c=x[31737];x[31737]=0;if((c|0)==1){break i}hd(lj(x[a+4>>2])+12|0,b);ub(b);break h}i=N()|0;break a}i=N()|0;break a}i=N()|0;break a}i=N()|0;break a}i=N()|0;break a}i=N()|0;break a}i=N()|0;break a}i=N()|0;break a}ub(k);break h}i=N()|0;break a}Ae(s);break c}ub(k);break d}i=N()|0;break a}ub(k)}t=t+1|0;continue}}fb=e+1456|0;return i|0}i=N()|0}Ae(s);Q(i|0);p()}function lqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,O=0,R=0,T=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0;e=fb-368|0;fb=e;a:{if(!cd(b,1080)){break a}f=e+364|0;if(!nr(b,f)){break a}l=qY(e+344|0);if(!pY(f,l)){break a}d=z[l+10>>1];if(!d|d>>>0>127){break a}R=1;if((c|0)==64){break a}T=1;Bd(a,1);g=z[l+10>>1];w[a+480188>>1]=g;I=y[l+14|0];V=y[l+13|0];m=y[l+12|0];if(!ne(f,25290)){T=ne(f,25295)}if(y[l+15|0]){Lb(a+1074312|0,5,1);g=z[a+480188>>1]}d=e+364|0;q=ne(d,16791);n=1;if(!ne(d,17553)){n=ne(d,13702)}u=a+480188|0;B=(g&65535)==8&(V|0)!=0;cd(b,0);k=y[l+16|0];g=fb-16|0;fb=g;b:{f=e+324|0;d=f;if(!gx(b,d)|!k){break b}ex(g+8|0,d);while(1){if(i>>>0>=20){break b}d=x[g+8>>2];tg(xb(d,i),xb(d,i|1));i=i+2|0;continue}}fb=g+16|0;d=e+312|0;cf(d,f,20,3);f=e+180|0;Cc(f,d);Ab(a+1298308|0,f);tb(f);w[a+480190>>1]=31;m=(m|0)!=0;g=1;f=0;i=q;while(1){if((g|0)==32){R=A[l+4>>2]>=o>>>0;if(!R){break a}}else{j=y[l+16|0];r=fb-16|0;fb=r;c:{k=e+180|0;d=k;if(!gY(b,d)|!j){break c}Cv(r+8|0,d);t=0;while(1){if(t>>>0>=30){break c}d=x[r+8>>2];tg(xb(d,t),xb(d,t|1));t=t+2|0;continue}}fb=r+16|0;j=D(g,104)+a|0;d=j+484380|0;k=UC(k,d,((g<<5)+a|0)+946304|0,z[a+480188>>1]==4);r=x[d>>2];d:{if(n){v[j+484417|0]=0-(y[e+204|0]<<3);break d}m=r>>>0<65536&m}j=Bb(y[e+202|0]|y[e+203|0]<<8);e:{if(j){Y=!Bb(y[e+208|0]|y[e+209|0]<<8)|Y;break e}Z=y[e+205|0]==64|Z}d=i&1;i=0;f:{if(!d){break f}h=(j<<1)+h|0;d=y[e+204|0];i=!d;if(d|!j){break f}i=y[e+205|0]==64}o=k+o|0;f=f+r|0;g=g+1|0;continue}break}k=y[l+16|0];j=fb-16|0;fb=j;g:{d=e+180|0;if(!NC(b,d)|!k){break g}TC(j+8|0,d);g=0;while(1){if(g>>>0>=130){break g}d=x[j+8>>2];tg(xb(d,g),xb(d,g|1));g=g+2|0;continue}}fb=j+16|0;cd(b,z[l+8>>1]);k=y[e+181|0];d=128;kw(Xb(x[a+484360>>2],y[a+484376|0]),e+182|0,128);j=!k&i;i=j?h:0;k=y[e+180|0];h:{if(k>>>0>=129){o=y[a+484376|0];h=x[a+484360>>2];break h}o=y[a+484376|0];h=x[a+484360>>2];if(k){d=k;break h}k=x[Xb(h,o)>>2];g=128;while(1){d=g;if(d>>>0<2){d=1;break h}g=d-1|0;if(!z[_b(k,g)>>1]){continue}break}}r=nY(b,Xb(h,o),d&65535,f,u,i,0);J=1;i:{if(!(j&z[u>>1]==8)){J=(I|0)!=0;break i}x[l>>2]=11279}j:{if(!B){break j}f=Xb(x[a+484360>>2],y[a+484376|0]);aa=e,ba=wb(x[f>>2]),x[aa+312>>2]=ba;f=wb(x[f+4>>2]);while(1){h=x[e+312>>2];if(!Ib(h,f)){break j}w[h>>1]=z[h>>1]>>>1;Md(e+312|0);continue}}af(Xb(x[a+484360>>2],y[a+484376|0]),y[e+181|0]);I=d-1|0;d=y[e+181|0];k:{if((I&65535)>>>0>=d>>>0){g=z[u>>1];if((d|0)!=120|(g|0)!=4){break k}}af(Xb(x[a+484360>>2],y[a+484376|0]),0);g=z[a+480188>>1]}x[a+480260>>2]=56;x[a+480264>>2]=13696;x[a+480204>>2]=125e4;x[a+480196>>2]=6;x[a+480208>>2]=0;aa=a,ba=Yb(256/((g&65535)>>>0)|0,32,128),x[aa+480228>>2]=ba;Xh(a,0);v[e+179|0]=0;l:{if(m&1){E=1;k=1;break l}E=1;n=0;m=0;h=q;m:while(1){k=m&65535;if(k>>>0<r>>>0){t=0;g=0;while(1)if((g|0)==256){m=m+1|0;continue m}else{f=bh(e+312|0);mY(e+160|0,b,!k&y[l+16|0]!=0);d=x[e+160>>2];x[e+172>>2]=d;x[e+64>>2]=d;d=e+92|0;ip(d,e- -64|0,f);d=Jc(d);i=KD(y[f|0]);n:{o:{p:{q:{j=y[e+92|0];if((j-7&255)>>>0<3){h=0;break q}f=y[d|0];if(!((j|0)!=14|f>>>0<=1)){h=0;break p}if(!((j|0)!=15|(f&255)>>>0<=31)){h=0;break n}h=i?h:0;if((j|0)!=13){break q}t=t+1|0;h=(t&65535)>>>0<=1?h:0;break n}if((j|0)==8){break o}if((j|0)!=14){break n}f=y[d|0]}if((f&240)!=128){break n}v[e+80|0]=f<<4;aa=e,ba=y[df(e+179|0,e+80|0)|0],v[aa+179|0]=ba;break n}aa=e,ba=y[df(e+179|0,d)|0],v[aa+179|0]=ba;d=v[d|0];if((d|0)>=0){F=1;break n}n=(d|0)!=-92&d>>>0>4294967183|n}E=i&E;g=g+1|0;continue}}break}d=F^-1;F=0;F=(d|n)&1?F:y[e+179|0]>47;k=h&1}cd(b,z[l+8>>1]);d=z[a+480188>>1];G=a+484344|0;W=r+B&65535;Vf(G,W);t=B?4:d;H=a+1074312|0;j=c&1;n=0;m=0;r:{s:{t:{u:{while(1){if((n|0)==(W|0)){break t}v:{if(B){f=(n&65534)>>>1|0;d=n&1;if(!d){if(!Ng(G,f,64)){break t}}i=d<<2;d=Wb(x[G>>2],f);break v}if(!Ng(G,n&65535,64)){break t}i=0;d=Wb(x[G>>2],n)}h=0;i=jd(x[d>>2],x[x[d+48>>2]+12>>2],0,i);if(!j){K=0;L=0;break s}d=z[u>>1];v[e+92|0]=0;f=e+92|0;M=fw(e+312|0,d,f);d=z[u>>1];x[31737]=0;v[e+92|0]=0;O=U(601,e+160|0,d|0,f|0)|0;d=x[31737];x[31737]=0;if((d|0)!=1){X=0;w:{x:while(1){y:{if((X|0)==64){break w}g=0;f=0;r=0;while(1){if((g|0)==(t|0)){X=X+1|0;K=f&r|K;i=D(z[u>>1],6)+i|0;continue x}d=y[l+16|0];x[31737]=0;S(602,e+92|0,b|0,!n&(d|0)!=0);d=x[31737];x[31737]=0;if((d|0)!=1){d=x[e+92>>2];x[e+156>>2]=d;x[e+60>>2]=d;h=e+80|0;s=D(g,6)+i|0;ip(h,e+60|0,s);d=y[e+80|0];h=Jc(h);o=y[h|0];if(d|o){z:{if(!(!V|(d&255)!=14)){d=0;v[h|0]=0;v[e+80|0]=0;o=y[h|0];break z}if(!V|(d&255)!=15|(o&255)>>>0<32){break z}o=31;v[h|0]=31;d=y[e+80|0]}Bf(s,d&255,o&255)}d=1;A:{B:{C:{D:{E:{h=y[s+3|0];switch(h-14|0){case 2:break A;case 0:break D;case 3:break E;default:break C}}m=y[s+5|0]<100|m;r=1;break B}if(!k){break B}v[s+5|0]=0;break B}if((h|0)==9&F){d=y[s+5|0];if((d|0)==164){v[s+3|0]=20;v[s+5|0]=145;break B}aa=s,ba=Ch(d<<1),v[aa+5|0]=ba;break B}if((h|0)!=19){break B}d=y[s+5|0];if(d>>>0>15){break B}d=!(d&1);h=(d^_)&1;_=h?d:_;L=h+L|0}d=f}F:{if(!y[s|0]){h=y[s+1|0];if(!h|B){break F}f=y[xb(x[M>>2],g)|0];if(!f|(f|0)==(h|0)){break F}f=xb(x[O>>2],g);h=y[f|0]+1|0;v[f|0]=h;if((h&255)>>>0<4){break F}x[31737]=0;U(267,H|0,85,1)|0;f=x[31737];x[31737]=0;if((f|0)!=1){break F}break y}aa=xb(x[O>>2],g),ba=0,v[aa|0]=ba}f=y[s+1|0];if(f){aa=xb(x[M>>2],g),ba=f,v[aa|0]=ba}g=g+1|0;f=d;continue}break}}break}i=N()|0;dc(O);break u}dc(O);dc(M);n=n+1|0;continue}break}i=N()|0}dc(M);break r}h=m}G:{H:{I:{f=E^1;if((f|Y)&1){break I}d=e+364|0;J:{if(ne(d,16791)){break J}if(ne(d,17558)){break J}if(!ne(d,13697)){break I}}x[a+480208>>2]=x[a+480208>>2]|2162688;d=Lb(Lb(Lb(H,85,1),91,1),92,1);K:{if(y[e+179|0]>47){break K}d=Lb(d,84,1);if(y[e+181|0]==127){break K}Lb(d,83,1)}if(!((L|0)>6|J)){break H}break G}if(!(E&1)){if(!(q&(y[e+181|0]==127&(I&65535)>>>0<129))){break G}x[l>>2]=8494;break G}if((L|0)>6|J){break G}}x[a+480208>>2]=x[a+480208>>2]|8388608}if((q|J)==1){Lb(H,89,1)}if(T){Lb(H,84,1)}i=0;L:{if(!(c&2)){break L}cd(b,z[l+8>>1]+(D(t,W)<<8)|0);m=(f|q^1|Z)&1;g=1;while(1){if((g|0)==32){break L}k=D(g,104)+a|0;j=k+484380|0;d=x[j>>2];if(d){o=2;if(!T){c=lY(b,13945);o=c?10:0;i=c|i;d=x[j>>2]}f=Xc(e+312|0,8,1,0,o);c=wD(f,d)+x[b+8>>2]|0;if(!m){aa=j,ba=x[ad(j,k+484388|0)>>2],x[aa>>2]=ba}fg(f,j,b);cd(b,c)}g=g+1|0;continue}}M:{N:{if(!q){if(!((ne(e+364|0,17558)&h^-1|K)&1)){break N}break M}if((h^-1|K)&1){break M}}c=kY(e+128|0,0);b=x[c+20>>2];x[e+48>>2]=x[c+16>>2];x[e+52>>2]=b;b=x[c+12>>2];x[e+40>>2]=x[c+8>>2];x[e+44>>2]=b;b=x[c+4>>2];x[e+32>>2]=x[c>>2];x[e+36>>2]=b;d=e+312|0;Bv(d,a,0,e+32|0);$=C[x[e+312>>2]>>3];Xi(d);if(!($>=480)){break M}c=Lb(H,5,1);f=jY(e+104|0,$);b=x[f+20>>2];x[e+24>>2]=x[f+16>>2];x[e+28>>2]=b;b=x[f+12>>2];x[e+16>>2]=x[f+8>>2];x[e+20>>2]=b;b=x[f+4>>2];x[e+8>>2]=x[f>>2];x[e+12>>2]=b;Bv(d,a,0,e+8|0);b=y[x[e+312>>2]+26|0];Xi(d);if(b){dg(c,5);break M}x[l>>2]=17125}d=e+364|0;f=d;q=ec(d);b=d;while(1){if((f|0)!=(q|0)){c=y[f|0];v[b|0]=c>>>0<=32?32:c;b=b+1|0;f=f+1|0;continue}break}f=e+92|0;ig(f,16878);x[31737]=0;q=U(44,e+68|0,d|0,q|0)|0;b=x[31737];x[31737]=0;O:{P:{Q:{R:{S:{if((b|0)!=1){x[31737]=0;c=e+80|0;S(603,c|0,1,q|0);b=x[31737];x[31737]=0;if((b|0)==1){break S}x[31737]=0;d=e+312|0;S(140,d|0,f|0,c|0);b=x[31737];x[31737]=0;if((b|0)==1){break R}Ab(a+1298344|0,d);tb(d);tb(c);tb(q);Eb(f);b=tc(d,12402);Ab(a+1298356|0,b);tb(b);b=x[l>>2];if(b){bi(a+1298368|0,b)}b=e+312|0;aa=a+1298404|0,ba=x[Fc(b,28)>>2],x[aa>>2]=ba;if(!(i&1)){break a}b=tc(b,17177);x[31737]=0;P(75,a+1298368|0,b|0)|0;a=x[31737];x[31737]=0;if((a|0)==1){break O}tb(b);break a}i=N()|0;break P}i=N()|0;break Q}i=N()|0;tb(e+80|0)}tb(q)}Eb(e+92|0);break r}i=N()|0;tb(b)}Q(i|0);p()}fb=e+368|0;return R|0}function Tta(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0;e=fb+-64|0;fb=e;xc(a);a:{b:{if(b>>>0<=2){H=e,I=Zd(a),v[H+56|0]=I;Vb(a,2);b=hh(a);v[e+58|0]=b;v[e+59|0]=b>>>8;b=Pg(a);v[e+60|0]=b;v[e+61|0]=b>>>8;v[e+62|0]=b>>>16;v[e+63|0]=b>>>24;break b}np(a,e+56|0);if(b>>>0>5){break a}}v[e+57|0]=0}c:{t=d+484344|0;F=Kd(y[e+58|0]|y[e+59|0]<<8,1,1024);q=fE(t,F);if((q|0)==65535){break c}b=Wb(x[d+484344>>2],q);h=jd(x[b>>2],x[x[b+48>>2]+12>>2],0,0);f=z[d+480188>>1];w[e+12>>1]=f-1;w[e+44>>1]=y[e+56|0];G=z[Nc(e+12|0,e+44|0)>>1];g=G+1|0;b=g&65535;f=b>>>0<f>>>0?f:b;while(1)if((b|0)==(f|0)){v[c+13|0]=y[e+57|0]>>>4;b=y[c+12|0];v[e+12|0]=0;b=(b|0)!=0;B=fw(e+44|0,g,e+12|0);d:while(1){if((l|0)==(F|0)){dc(B);break c}e:{f:{g=xb(x[B>>2],0);f=y[g|0];g:{if(!f){x[31737]=0;g=R(198,a|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break e}h=g<<24>>24;if((h|0)<0){x[31737]=0;g=R(198,a|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break e}H=xb(x[B>>2],0),I=g,v[H|0]=I}v[e+12|0]=0;h:{i:{g=h&63;if(!g){break i}x[31737]=0;k=R(198,a|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break h}v[e+12|0]=k;j:{k:{switch(g-1|0){case 0:v[c+12|0]=0;v[e+40|0]=1;H=c,I=y[df(e+40|0,e+12|0)|0],v[H+14|0]=I;v[c+15|0]=0;break j;case 1:if(!k){break i}v[c+15|0]=k;v[c+12|0]=1;b=y[c+13|0];if(!b){break j}v[c+14|0]=D(D(b,k),15);break j;case 2:v[c+13|0]=k>>>4;if(k>>>0>=16){b=y[c+12|0];k=0;x[e+40>>2]=0;x[e+36>>2]=0;u=0;if(b){break g}break f}k=0;v[c+12|0]=0;x[e+40>>2]=0;x[e+36>>2]=0;u=0;if(b&1){break g}break f;case 3:u=0;x[e+40>>2]=0;x[e+36>>2]=0;if(b&1){break g}break f;case 5:if(!k){break i}b=(y[c+12|0]?15:14)+c|0;f=y[b|0];v[b|0]=f>>>0>=256-k>>>0?-1:f+k|0;break j;case 6:break k;default:break i}}if(!k){break i}b=(y[c+12|0]?15:14)+c|0;f=y[b|0];v[b|0]=f>>>0<=k+1>>>0?1:f-k|0}k=0;x[e+40>>2]=0;x[e+36>>2]=0;break g}k=0;x[e+40>>2]=0;x[e+36>>2]=0;u=0;if(b&1){break g}break f}break e}v[g|0]=f-1;k=0;x[e+40>>2]=0;x[e+36>>2]=0;u=0;if(!(b&1)){break f}}f=y[c+13|0];b=y[c+12|0];if(b){u=0;if(!f){break f}}l:{if(b){x[e+12>>2]=1;x[e+32>>2]=D(f,y[c+15|0])<<1;f=x[Ye(e+12|0,e+32|0)>>2];break l}f=D(y[c+14|0],30)+30|0}b=255;g=0;s=0;while(1){m:{if(b){h=D(b,f);s=(h|0)/48|0;if(h-1536>>>0>=10752){break m}g=b}x[e+36>>2]=s;x[e+40>>2]=g;Fe(e+36|0,32,255);u=1;x[e+12>>2]=1;H=c,I=x[Ye(e+12|0,e+40|0)>>2],v[H+16|0]=I;break f}b=b-1|0;continue}}C=l-1|0;E=1;b=Wb(x[t>>2],q);b=jd(x[b>>2],x[x[b+48>>2]+12>>2],l,1);while(1){i=E&65535;if(i>>>0>G>>>0){if(u){b=e+12|0;ye(Wb(x[t>>2],q),Yh(mp(Xe(Ne(b,17,y[e+36|0]),l),0)));ye(Wb(x[t>>2],q),Yh(Xe(Ne(b,16,y[e+40|0]),l)))}if(k>>>0>=16){ye(Wb(x[t>>2],q),T$(Xe(Ne(e+12|0,20,k>>>4|224),l)))}b=k&15;if(b){ye(Wb(x[t>>2],q),T$(Xe(Ne(e+12|0,20,Kd((D(b,y[c+16|0])>>>0)/15&255,1,15)|96),l)))}l=l+1|0;b=0;continue d}n:{o:{p:{q:{g=xb(x[B>>2],i);f=y[g|0];if(!f){x[31737]=0;g=R(198,a|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break e}h=g<<24>>24;if((h|0)<0){x[31737]=0;g=R(198,a|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break e}H=xb(x[B>>2],i),I=g,v[H|0]=I}s=1;m=h&255;if(m&64){x[31737]=0;g=R(198,a|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break e}v[b+1|0]=g;s=!g}if(!(m&32)){g=y[b|0];break q}x[31737]=0;g=R(198,a|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break e}v[b|0]=g;if((g-1&255)>>>0<=107){g=eE(g+24&255);v[b|0]=g;H=Wc(x[c>>2],i),I=g,v[H+1|0]=I;break q}if((g+127&255)>>>0<=107){f=eE((g&127)+24|0);H=Wc(x[c>>2],i),I=f,v[H|0]=I;v[b|0]=0;break p}if((g|0)!=255){break q}v[b|0]=254;break o}v[g|0]=f-1;break n}if(g&255){break o}}if(!y[b+1|0]){break o}f=y[Wc(x[c>>2],i)+1|0];v[b+1|0]=0;v[b|0]=f}if(Sc(y[b|0])){H=Wc(x[c>>2],i),I=0,v[H+5|0]=I}v[e+31|0]=0;v[e+30|0]=0;if(m&16){v[b+2|0]=1;x[31737]=0;g=R(198,a|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break e}v[b+4|0]=g+2>>>2}g=0;r=0;A=0;r:{if(!(m&8)){break r}x[31737]=0;h=R(198,a|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break e}x[31737]=0;A=R(198,a|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break e}s:{switch(h-1|0){case 0:v[b|0]=254;break r;case 1:v[b|0]=255;break r;case 2:f=Wc(x[c>>2],i);v[b|0]=y[f+1|0];v[f+5|0]=0;break r;case 3:f=ew(A,y[c+16|0]);A=f?f|-48:0;r=f?20:0;if(y[b|0]){break r}f=Wc(x[c>>2],i);v[b|0]=y[f+1|0];v[f+5|0]=0;break r;case 4:v[e+12|0]=1;H=e,I=ew(A,y[c+16|0]),v[H+32|0]=I;A=y[df(e+12|0,e+32|0)|0];H=Wc(x[c>>2],i),I=0,v[H+5|0]=I;r=15;break r;case 5:case 6:case 7:case 8:r=x[c>>2];t:{if(!l){break t}if((h|0)==y[Wc(r,i)+4|0]){break t}f=ye(Wb(x[t>>2],q),Gn(mp(Xe(Ne(e+12|0,20,(h+122|160)&255),C),i)));r=x[c>>2];if(!f){break t}H=Wc(r,i),I=h,v[H+4|0]=I}f=Wc(r,i);if(!y[b|0]){v[b|0]=y[f+1|0]}v[f+5|0]=0;r=10;break r;case 9:break s;default:break r}}f=Wc(x[c>>2],i);h=y[f+5|0];v[f+5|0]=h^1;A=h?-98:-97;r=20}u:{v:{w:{if(!(m&4)){break w}x[31737]=0;n=R(198,a|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break e}x[31737]=0;j=R(198,a|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break e}v[e+31|0]=j;h=1;g=1;x:{switch(n-1|0){case 0:dE(e+12|0,j<<24>>24<<3,128);f=y[b|0];if(Sc(f)){H=b,I=dw(f+x[e+12>>2]|0),v[H|0]=I}v[e+31|0]=y[e+16|0]^128;g=35;break w;case 1:f=ew(j,y[c+16|0]);v[e+31|0]=f;if(!f){break v}v[e+31|0]=f|208;g=20;break u;case 3:case 4:H=e,I=S$(j,y[c+16|0],1),v[H+31|0]=I;g=(n|0)==4?2:3;break u;case 5:if(!y[b|0]){H=b,I=y[Wc(x[c>>2],i)|0],v[H|0]=I}H=e,I=S$(j,y[c+16|0],0),v[H+31|0]=I;g=4;break u;case 6:H=b,I=dw(j+25|0),v[H|0]=I;v[e+31|0]=255;g=4;break u;case 7:case 8:case 9:y:{if(!l){break y}if((n|0)==y[Wc(x[c>>2],i)+2|0]){break y}if(!ye(Wb(x[t>>2],q),Gn(mp(Xe(Ne(e+12|0,20,(n-8|48)&255),C),i)))){break y}H=Wc(x[c>>2],i),I=n,v[H+2|0]=I}H=e,I=cE(j,y[c+16|0]),v[H+31|0]=I;g=5;break u;case 10:H=e,I=R$(j,y[c+16|0]),v[H+31|0]=I;g=18;break u;case 11:f=ew(j,y[c+16|0]);v[e+31|0]=f;if(f){v[e+31|0]=f|192;g=20;break u}v[b|0]=254;break v;case 2:break u;default:break x}}g=0}h=0;break u}g=0}o=0;f=1;z:{if(m&2){x[31737]=0;m=R(198,a|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break e}x[31737]=0;n=R(198,a|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break e}v[e+30|0]=n;o=9;f=0;j=0;A:{switch(m-1|0){case 0:case 1:j=1;H=e,I=Q$(n,y[c+16|0],(m|0)==1),v[H+30|0]=I;o=11;break z;case 2:H=e,I=R$(n,y[c+16|0]),v[H+30|0]=I;j=1;o=18;break z;case 3:case 4:case 5:B:{if(!l){break B}if((m|0)==y[Wc(x[c>>2],i)+3|0]){break B}if(!ye(Wb(x[t>>2],q),Gn(mp(Xe(Ne(e+12|0,20,(m-4|64)&255),C),i)))){break B}H=Wc(x[c>>2],i),I=m,v[H+3|0]=I}H=e,I=cE(n,y[c+16|0]),v[H+30|0]=I;j=1;o=8;break z;case 7:case 8:H=e,I=Q$(n,y[c+16|0],(m|0)==8),v[H+30|0]=I;j=1;o=29;break z;case 9:H=e,I=cE(n,y[c+16|0]),v[H+30|0]=I;j=1;o=27;break z;case 6:break z;default:break A}}o=0;f=1}j=0}if(h){P$(b,l,z[d+480188>>1],g,e+31|0)}if(j){P$(b,l,z[d+480188>>1],o,e+30|0)}C:{D:{E:{F:{G:{if(!s){break G}if(!Sc(y[b|0])){break G}if(!g){break F}if(!f|(g|0)==4){break G}v[e+30|0]=255;o=4}j=b+2|0;if(y[b+2|0]!=1){break C}if(g){break E}v[e+31|0]=y[b+4|0];g=13;break D}v[e+31|0]=255;j=b+2|0;g=4;if(y[b+2|0]!=1){break C}}if(o){break C}v[e+30|0]=y[b+4|0];o=13}v[j|0]=0}h=bh(e+12|0);mm(e+32|0,h,g,y[e+31|0],o,y[e+30|0]);H:{if(y[j|0]){break H}f=y[e+14|0];if(!f){break H}v[b+2|0]=f;v[b+4|0]=y[e+16|0]}s=y[e+15|0];I:{if(r){mm(e+32|0,h,s&255,y[e+17|0],r,A&255);J:{if(y[j|0]){break J}f=y[e+14|0];if(!f){break J}v[b+2|0]=f;v[b+4|0]=y[e+16|0]}s=y[e+15|0];break I}if(!(s&255)){break n}}v[b+3|0]=s;v[b+5|0]=y[e+17|0]}b=b+6|0;E=E+1|0;continue}}break}a=N()|0;dc(B);Q(a|0);p()}else{v[h+D(b,6)|0]=254;b=b+1|0;continue}}fb=e- -64|0;return q|0}function VR(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;k=fb-336|0;fb=k;m=h;n=i&65535;o=d;p=e&65535;s=(e^i)&-2147483648;y=i>>>16&32767;u=e>>>16&32767;a:{b:{if(y-32767>>>0>4294934529&u-32767>>>0>=4294934530){break b}j=e&2147483647;if(!(!d&(j|0)==2147418112?!(b|c):j>>>0<2147418112)){r=d;s=e|32768;break a}e=i&2147483647;if(!(!h&(e|0)==2147418112?!(f|g):e>>>0<2147418112)){r=h;s=i|32768;b=f;c=g;break a}if(!(b|d|(j^2147418112|c))){if(!(f|h|(e^2147418112|g))){b=0;c=0;s=2147450880;break a}s=s|2147418112;b=0;c=0;break a}if(!(f|h|(e^2147418112|g))){b=0;c=0;break a}if(!(b|d|(c|j))){b=!(f|h|(e|g));r=b?0:r;s=b?2147450880:s;b=0;c=0;break a}if(!(f|h|(e|g))){s=s|2147418112;b=0;c=0;break a}if((j|0)==65535|j>>>0<65535){d=!(o|p);i=d;j=d?b:o;d=d<<6;i=G(i?c:p);d=d+((i|0)==32?G(j)+32|0:i)|0;bg(k+320|0,b,c,o,p,d-15|0);q=16-d|0;o=x[k+328>>2];p=x[k+332>>2];c=x[k+324>>2];b=x[k+320>>2]}if(e>>>0>65535){break b}d=!(n|m);h=d;i=d?f:m;d=d<<6;h=G(h?g:n);d=d+((h|0)==32?G(i)+32|0:h)|0;bg(k+304|0,f,g,m,n,d-15|0);q=(d+q|0)-16|0;m=x[k+312>>2];n=x[k+316>>2];f=x[k+304>>2];g=x[k+308>>2]}e=n|65536;z=e;B=m;d=m;j=e<<15|d>>>17;e=d<<15|g>>>17;d=e;i=0-d|0;h=j;j=1963258675-(j+((d|0)!=0)|0)|0;Of(k+288|0,d,h,0,0,i,j,0,0);d=x[k+296>>2];Of(k+272|0,0-d|0,0-(x[k+300>>2]+((d|0)!=0)|0)|0,0,0,i,j,0,0);d=x[k+280>>2];i=d<<1|x[k+276>>2]>>>31;d=x[k+284>>2]<<1|d>>>31;Of(k+256|0,i,d,0,0,e,h,0,0);j=x[k+264>>2];Of(k+240|0,i,d,0,0,0-j|0,0-(x[k+268>>2]+((j|0)!=0)|0)|0,0,0);i=x[k+248>>2];j=i<<1|x[k+244>>2]>>>31;d=x[k+252>>2]<<1|i>>>31;Of(k+224|0,j,d,0,0,e,h,0,0);i=x[k+232>>2];Of(k+208|0,j,d,0,0,0-i|0,0-(x[k+236>>2]+((i|0)!=0)|0)|0,0,0);d=x[k+216>>2];i=d<<1|x[k+212>>2]>>>31;d=x[k+220>>2]<<1|d>>>31;Of(k+192|0,i,d,0,0,e,h,0,0);j=x[k+200>>2];Of(k+176|0,i,d,0,0,0-j|0,0-(x[k+204>>2]+((j|0)!=0)|0)|0,0,0);i=e;e=x[k+184>>2];d=h;m=e<<1|x[k+180>>2]>>>31;h=m-1|0;e=(x[k+188>>2]<<1|e>>>31)-!m|0;Of(k+160|0,i,d,0,0,h,e,0,0);d=h;Of(k+144|0,f<<15,g<<15|f>>>17,0,0,d,e,0,0);v=k+112|0;C=x[k+168>>2];h=x[k+172>>2];m=x[k+160>>2];i=x[k+152>>2];l=m+i|0;n=x[k+164>>2];j=n+x[k+156>>2]|0;j=i>>>0>l>>>0?j+1|0:j;i=j;j=(n|0)==(j|0)&l>>>0<m>>>0|j>>>0<n>>>0;n=j+C|0;j=j>>>0>n>>>0?h+1|0:h;m=!i&l>>>0>1|(i|0)!=0;h=n+m|0;j=m>>>0>h>>>0?j+1|0:j;Of(v,d,e,0,0,0-h|0,0-(((h|0)!=0)+j|0)|0,0,0);Of(k+128|0,1-l|0,0-((l>>>0>1)+i|0)|0,0,0,d,e,0,0);M=(u-y|0)+q|0;e=x[k+116>>2];u=e;d=x[k+112>>2];j=e<<1|d>>>31;i=d<<1;n=j;d=j;h=x[k+140>>2];w=h;e=x[k+136>>2];j=h<<1|e>>>31;l=e<<1|x[k+132>>2]>>>31;h=l+i|0;d=d+j|0;d=h>>>0<l>>>0?d+1|0:d;e=d;d=d-(h>>>0<13927)|0;t=d;v=d;l=0;j=p|65536;N=j;O=o;d=o;j=j<<1|d>>>31;Q=d<<1;R=j;H=j;d=Sua(t,l,j,0);j=hb;D=d;E=j;J=b<<1;d=c<<1|b>>>31;y=d;C=d;j=0;q=j;m=h-13927|0;t=(e|0)==(t|0)&m>>>0<h>>>0|e>>>0>t>>>0;e=(e|0)==(n|0)&h>>>0<i>>>0|e>>>0<n>>>0;d=x[k+120>>2];h=x[k+124>>2]<<1|d>>>31;d=d<<1|u>>>31;l=w>>>31|0;d=l+d|0;j=h;j=d>>>0<l>>>0?j+1|0:j;h=d;d=d+e|0;j=h>>>0>d>>>0?j+1|0:j;e=d;d=d+t|0;l=e>>>0>d>>>0?j+1|0:j;e=d-1|0;F=l-!d|0;w=0;i=Sua(C,q,F,w);d=i+D|0;h=hb+E|0;h=d>>>0<i>>>0?h+1|0:h;n=(E|0)==(h|0)&d>>>0<D>>>0|h>>>0<E>>>0;D=e;P=c>>>31|0;I=P|o<<1;t=0;e=Sua(e,0,I,t);o=e+d|0;j=hb+h|0;l=0;j=e>>>0>o>>>0?j+1|0:j;p=j;d=(j|0)==(h|0)&d>>>0>o>>>0|h>>>0>j>>>0;e=d;d=d+n|0;l=e>>>0>d>>>0?1:l;e=Sua(H,q,F,w);d=e+d|0;j=hb+l|0;n=d;d=d>>>0<e>>>0?j+1|0:j;e=Sua(H,q,D,t);l=hb;h=e;e=Sua(I,t,F,w);i=h+e|0;j=hb+l|0;j=e>>>0>i>>>0?j+1|0:j;e=j;j=(l|0)==(j|0)&h>>>0>i>>>0|j>>>0<l>>>0;l=n+e|0;d=d+j|0;d=l>>>0<e>>>0?d+1|0:d;n=l;l=d;e=0;d=e+o|0;j=i+p|0;j=d>>>0<e>>>0?j+1|0:j;e=j;h=(j|0)==(p|0)&d>>>0<o>>>0|j>>>0<p>>>0;j=l;i=h;h=h+n|0;j=i>>>0>h>>>0?j+1|0:j;u=h;l=j;o=d;E=m;d=Sua(m,0,I,t);i=hb;h=d;m=Sua(v,r,C,r);d=d+m|0;j=hb+i|0;j=d>>>0<m>>>0?j+1|0:j;m=(i|0)==(j|0)&d>>>0<h>>>0|i>>>0>j>>>0;h=j;K=J&-2;i=Sua(D,t,K,0);p=i+d|0;j=hb+j|0;j=i>>>0>p>>>0?j+1|0:j;i=j;d=(j|0)==(h|0)&d>>>0>p>>>0|h>>>0>j>>>0;h=0;j=d+m|0;d=(j>>>0<d>>>0?1:h)+e|0;n=j+o|0;d=n>>>0<j>>>0?d+1|0:d;j=l;m=d;d=(d|0)==(e|0)&n>>>0<o>>>0|d>>>0<e>>>0;e=d;d=d+u|0;j=e>>>0>d>>>0?j+1|0:j;S=d;u=j;d=Sua(H,q,E,r);L=hb;H=d;e=Sua(F,w,K,r);d=d+e|0;j=hb+L|0;j=d>>>0<e>>>0?j+1|0:j;o=d;l=Sua(v,r,I,t);e=d+l|0;h=j;d=j+hb|0;d=e>>>0<l>>>0?d+1|0:d;q=e;j=Sua(C,r,D,t);e=e+j|0;l=hb+d|0;l=e>>>0<j>>>0?l+1|0:l;F=(d|0)==(l|0)&e>>>0<q>>>0|d>>>0>l>>>0;j=(h|0)==(L|0)&o>>>0<H>>>0|h>>>0<L>>>0;d=(d|0)==(h|0)&o>>>0>q>>>0|d>>>0<h>>>0;d=d+j|0;d=d+F|0;h=l;q=h+n|0;j=(d|w)+m|0;j=h>>>0>q>>>0?j+1|0:j;o=j;d=(m|0)==(j|0)&n>>>0>q>>>0|j>>>0<m>>>0;j=u;h=d;d=d+S|0;j=h>>>0>d>>>0?j+1|0:j;w=d;m=j;d=Sua(v,r,K,r);v=hb;n=d;h=Sua(C,r,E,r);d=d+h|0;j=hb+v|0;j=d>>>0<h>>>0?j+1|0:j;u=0;h=(j|0)==(v|0)&d>>>0<n>>>0|j>>>0<v>>>0;n=j;d=j+p|0;j=(h|u)+i|0;j=d>>>0<n>>>0?j+1|0:j;i=(i|0)==(j|0)&d>>>0<p>>>0|i>>>0>j>>>0;h=j;j=e;p=0;e=p+d|0;l=h+j|0;j=0;l=e>>>0<p>>>0?l+1|0:l;d=(h|0)==(l|0)&d>>>0>e>>>0|h>>>0>l>>>0;e=d;d=d+i|0;j=(e>>>0>d>>>0?1:j)+o|0;l=m;e=d;d=d+q|0;j=e>>>0>d>>>0?j+1|0:j;e=j;h=(o|0)==(j|0)&d>>>0<q>>>0|j>>>0<o>>>0;i=h;h=h+w|0;l=i>>>0>h>>>0?l+1|0:l;i=l;c:{if((l|0)==131071|l>>>0<131071){O=Q|P;N=t|R;Of(k+80|0,d,j,h,l,f,g,B,z);l=x[k+84>>2];q=l;j=b<<17;o=0;p=x[k+88>>2];c=o-p|0;b=x[k+80>>2];l=(l|b)!=0;m=c-l|0;n=(j-(x[k+92>>2]+(o>>>0<p>>>0)|0)|0)-(c>>>0<l>>>0)|0;p=0-(((b|0)!=0)+q|0)|0;q=M+16382|0;o=0-b|0;break c}d=(e&1)<<31|d>>>1;e=h<<31|e>>>1;h=(i&1)<<31|h>>>1;i=i>>>1|0;Of(k+96|0,d,e,h,i,f,g,B,z);m=x[k+100>>2];y=m;n=0;q=x[k+104>>2];o=n-q|0;l=x[k+96>>2];p=(m|l)!=0;m=o-p|0;n=((b<<16)-(x[k+108>>2]+(n>>>0<q>>>0)|0)|0)-(o>>>0<p>>>0)|0;p=0-(((l|0)!=0)+y|0)|0;J=b;y=c;q=M+16383|0;o=0-l|0}if((q|0)>=32767){s=s|2147418112;b=0;c=0;break a}d:{if((q|0)>0){b=m<<1|p>>>31;c=n<<1|m>>>31;m=h;n=i&65535|q<<16;l=p<<1|o>>>31;h=o<<1;break d}if((q|0)<=-113){b=0;c=0;break a}gn(k- -64|0,d,e,h,i,1-q|0);bg(k+48|0,J,y,O,N,q+112|0);d=x[k+64>>2];e=x[k+68>>2];m=x[k+72>>2];n=x[k+76>>2];Of(k+32|0,f,g,B,z,d,e,m,n);b=x[k+40>>2];c=x[k+56>>2];i=x[k+36>>2];p=b<<1|i>>>31;l=c-p|0;p=x[k+60>>2]-((x[k+44>>2]<<1|b>>>31)+(c>>>0<p>>>0)|0)|0;c=x[k+52>>2];q=c;b=x[k+32>>2];h=i<<1|b>>>31;o=b<<1;b=o;j=x[k+48>>2];c=(c|0)==(h|0)&b>>>0>j>>>0|c>>>0<h>>>0;b=l-c|0;c=p-(c>>>0>l>>>0)|0;l=q-((j>>>0<o>>>0)+h|0)|0;h=j-o|0}Of(k+16|0,f,g,B,z,3,0,0,0);Of(k,f,g,B,z,5,0,0,0);o=d;p=d&1;i=p;d=h+i|0;j=0;h=j+l|0;h=d>>>0<i>>>0?h+1|0:h;i=d;g=(g|0)==(h|0)&d>>>0>f>>>0|g>>>0<h>>>0;l=c;d=(h|0)==(j|0)&d>>>0<p>>>0|h>>>0<j>>>0;f=b+d|0;l=d>>>0>f>>>0?l+1|0:l;j=e;b=(l|0)==(z|0);b=b&(f|0)==(B|0)?g:b&f>>>0>B>>>0|l>>>0>z>>>0;c=b;b=b+o|0;j=c>>>0>b>>>0?j+1|0:j;c=j;d=(e|0)==(j|0)&b>>>0<o>>>0|e>>>0>j>>>0;j=n;e=d;d=d+m|0;j=e>>>0>d>>>0?j+1|0:j;g=d;e=x[k+20>>2];m=(e|0)==(h|0)&A[k+16>>2]<i>>>0|e>>>0<h>>>0;e=x[k+28>>2];d=x[k+24>>2];e=j>>>0<2147418112&((d|0)==(f|0)&(e|0)==(l|0)?m:(e|0)==(l|0)&d>>>0<f>>>0|e>>>0<l>>>0);d=c;m=e;e=b+e|0;d=m>>>0>e>>>0?d+1|0:d;b=(c|0)==(d|0)&b>>>0>e>>>0|c>>>0>d>>>0;c=b;b=b+g|0;j=c>>>0>b>>>0?j+1|0:j;g=b;c=x[k+4>>2];h=(c|0)==(h|0)&A[k>>2]<i>>>0|c>>>0<h>>>0;c=x[k+12>>2];b=x[k+8>>2];b=j>>>0<2147418112&((b|0)==(f|0)&(c|0)==(l|0)?h:(c|0)==(l|0)&b>>>0<f>>>0|c>>>0<l>>>0);c=b;b=b+e|0;l=c>>>0>b>>>0?d+1|0:d;c=l;e=(d|0)==(l|0)&b>>>0<e>>>0|d>>>0>l>>>0;d=j;f=e;e=e+g|0;d=f>>>0>e>>>0?d+1|0:d;r=e|r;s=d|s}x[a>>2]=b;x[a+4>>2]=c;x[a+8>>2]=r;x[a+12>>2]=s;fb=k+336|0}function ZO(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=fb-32|0;fb=f;d=Dc(f+20|0,11616);e=qh(c,d);tb(d);a:{b:{c:{d:{e:{if(e){to(a,x[b+24>>2]+1298356|0);break e}d=Dc(f+20|0,11021);e=qh(c,d);tb(d);if(e){to(a,x[b+24>>2]+1298344|0);break e}d=Dc(f+20|0,11446);e=qh(c,d);tb(d);if(e){to(a,x[b+24>>2]+1298392|0);break e}d=Dc(f+20|0,11013);e=qh(c,d);tb(d);if(e){to(a,x[b+24>>2]+1298380|0);break e}d=f+20|0;e=Dc(d,8243);g=qh(c,e);tb(e);if(g){c=x[x[b+24>>2]+480184>>2];b=31104;f:{g:{while(1){if((b|0)==31152){break g}if((c|0)!=x[b>>2]){b=b+12|0;continue}break}c=fb-32|0;fb=c;e=c+8|0;Sw(e,x[b+8>>2]);x[31737]=0;b=c+20|0;S(124,b|0,0,e|0);g=x[31737];x[31737]=0;h:{i:{j:{if((g|0)!=1){x[31737]=0;O(12,d|0,b|0);g=x[31737];x[31737]=0;if((g|0)==1){break j}Ub(b);tb(e);fb=c+32|0;break h}a=N()|0;break i}a=N()|0;Ub(c+20|0)}tb(c+8|0);Q(a|0);p()}break f}Fb(d)}x[31737]=0;O(1065,a|0,d|0);a=x[31737];x[31737]=0;if((a|0)==1){break d}tb(d);break e}g=f+20|0;d=Dc(g,10998);e=qh(c,d);tb(d);if(e){l=x[x[b+24>>2]+480184>>2];c=fb-48|0;fb=c;b=31104;h=qg(c+36|0);d=Fb(g);while(1){if((b|0)!=31152){if(x[b>>2]==(l|0)){x[31737]=0;e=P(1,c+24|0,x[b+4>>2])|0;i=x[31737];x[31737]=0;k:{l:{m:{n:{o:{p:{if((i|0)!=1){x[31737]=0;S(892,c+16|0,h|0,e|0);i=x[31737];x[31737]=0;if((i|0)==1){break n}if(!y[c+20|0]){break k}if(!Ad(x[d+4>>2],y[d+11|0])){x[31737]=0;i=P(1,c+4|0,18421)|0;k=x[31737];x[31737]=0;if((k|0)==1){break p}x[31737]=0;P(75,d|0,i|0)|0;k=x[31737];x[31737]=0;if((k|0)==1){break o}tb(i)}x[31737]=0;P(75,d|0,e|0)|0;i=x[31737];x[31737]=0;if((i|0)!=1){break k}b=N()|0;break m}b=N()|0;break l}b=N()|0;break m}b=N()|0;tb(i);break m}b=N()|0}tb(e)}tb(d);NR(h);Q(b|0);p()}tb(e)}b=b+12|0;continue}break}NR(h);fb=c+48|0;x[31737]=0;O(1065,a|0,g|0);a=x[31737];x[31737]=0;if((a|0)!=1){tb(g);break e}c=N()|0;tb(f+20|0);break a}d=Dc(f+20|0,8309);e=qh(c,d);tb(d);if(e){to(a,x[b+24>>2]+1298368|0);break e}d=Dc(f+20|0,5620);e=qh(c,d);tb(d);if(e){to(a,x[b+24>>2]+1298320|0);break e}d=f+20|0;e=Dc(d,12020);g=qh(c,e);tb(e);if(g){lg(d,x[b+24>>2]+1298308|0);b=x[b+24>>2];x[31737]=0;S(1059,a|0,b|0,d|0);a=x[31737];x[31737]=0;if((a|0)!=1){tb(d);break e}c=N()|0;tb(f+20|0);break a}d=Dc(f+20|0,11389);e=qh(c,d);tb(d);if(e){d=kM(x[b+24>>2]);c=x[d+4>>2];q:{if(!mc(x[d>>2],c)){e=bw(c);d=fb-32|0;fb=d;x[d+8>>2]=0;x[d+12>>2]=0;x[d+16>>2]=0;x[d>>2]=0;x[d+4>>2]=0;x[d+24>>2]=0;x[d+28>>2]=0;c=fb-48|0;fb=c;IF(c+24|0,e,e+4|0,e+8|0,e+12|0,e+16|0,e+24|0);IF(c,d,d+4|0,d+8|0,d+12|0,d+16|0,d+24|0);e=x[c+28>>2];g=x[c+4>>2];fb=c+48|0;fb=d+32|0;if(x[e>>2]==x[g>>2]&x[x[c+24>>2]>>2]==x[x[c>>2]>>2]&x[x[c+32>>2]>>2]==x[x[c+8>>2]>>2]&x[x[c+36>>2]>>2]==x[x[c+12>>2]>>2]&x[x[c+40>>2]>>2]==x[x[c+16>>2]>>2]){e=x[c+44>>2];g=x[c+20>>2];c=x[e>>2]==x[g>>2]&x[e+4>>2]==x[g+4>>2]}else{c=0}if(!c){break q}}Fb(a);break e}g=f+20|0;b=x[b+24>>2];e=bw(x[kM(b)+4>>2]);h=x[b+1298408>>2];d=fb-512|0;fb=d;i=x[e+32>>2];r:{if(i){b=-1;j=Ee(+(i>>>0)/18.2);c=2147483647;s:{if(j>=0x8000000000000000){break s}b=0;c=-2147483648;if(j<=-0x8000000000000000){break s}if(F(j)<0x8000000000000000){b=~~j>>>0;if(F(j)>=1){c=~~(j>0?H(J(j*2.3283064365386963e-10),4294967295):K((j-+(~~j>>>0>>>0))*2.3283064365386963e-10))>>>0}else{c=0}break s}c=-2147483648}if((h|0)==1){h=x[e+28>>2];x[d+184>>2]=x[e+24>>2];x[d+188>>2]=h;h=x[e+20>>2];x[d+176>>2]=x[e+16>>2];x[d+180>>2]=h;h=x[e+12>>2];x[d+168>>2]=x[e+8>>2];x[d+172>>2]=h;h=x[e+4>>2];x[d+160>>2]=x[e>>2];x[d+164>>2]=h;Eu(d+480|0,d+160|0);e=x[d+508>>2];x[d+152>>2]=x[d+504>>2];x[d+156>>2]=e;e=x[d+500>>2];x[d+144>>2]=x[d+496>>2];x[d+148>>2]=e;e=x[d+492>>2];x[d+136>>2]=x[d+488>>2];x[d+140>>2]=e;e=x[d+484>>2];x[d+128>>2]=x[d+480>>2];x[d+132>>2]=e;e=d+448|0;h=_A(LS(d+128|0),hb);c=c+hb|0;i=b;b=b+h|0;c=i>>>0>b>>>0?c+1|0:c;JS(e,KS(b,c),hb);b=x[d+476>>2];x[d+120>>2]=x[d+472>>2];x[d+124>>2]=b;b=x[d+468>>2];x[d+112>>2]=x[d+464>>2];x[d+116>>2]=b;b=x[d+460>>2];x[d+104>>2]=x[d+456>>2];x[d+108>>2]=b;b=x[d+452>>2];x[d+96>>2]=x[d+448>>2];x[d+100>>2]=b;MN(g,d+96|0);break r}h=x[e+28>>2];x[d+312>>2]=x[e+24>>2];x[d+316>>2]=h;h=x[e+20>>2];x[d+304>>2]=x[e+16>>2];x[d+308>>2]=h;h=x[e+12>>2];x[d+296>>2]=x[e+8>>2];x[d+300>>2]=h;h=x[e+4>>2];x[d+288>>2]=x[e>>2];x[d+292>>2]=h;Eu(d+416|0,d+288|0);e=x[d+444>>2];x[d+280>>2]=x[d+440>>2];x[d+284>>2]=e;e=x[d+436>>2];x[d+272>>2]=x[d+432>>2];x[d+276>>2]=e;e=x[d+428>>2];x[d+264>>2]=x[d+424>>2];x[d+268>>2]=e;e=x[d+420>>2];x[d+256>>2]=x[d+416>>2];x[d+260>>2]=e;e=d+352|0;h=_A(LS(d+256|0),hb);c=c+hb|0;i=b;b=b+h|0;c=i>>>0>b>>>0?c+1|0:c;JS(e,KS(b,c),hb);b=x[d+380>>2];x[d+248>>2]=x[d+376>>2];x[d+252>>2]=b;b=x[d+372>>2];x[d+240>>2]=x[d+368>>2];x[d+244>>2]=b;b=x[d+364>>2];x[d+232>>2]=x[d+360>>2];x[d+236>>2]=b;b=x[d+356>>2];x[d+224>>2]=x[d+352>>2];x[d+228>>2]=b;Eu(d+384|0,d+224|0);b=x[d+412>>2];x[d+216>>2]=x[d+408>>2];x[d+220>>2]=b;b=x[d+404>>2];x[d+208>>2]=x[d+400>>2];x[d+212>>2]=b;b=x[d+396>>2];x[d+200>>2]=x[d+392>>2];x[d+204>>2]=b;b=x[d+388>>2];x[d+192>>2]=x[d+384>>2];x[d+196>>2]=b;NO(g,d+192|0);break r}if((h|0)==1){b=x[e+28>>2];x[d+56>>2]=x[e+24>>2];x[d+60>>2]=b;b=x[e+20>>2];x[d+48>>2]=x[e+16>>2];x[d+52>>2]=b;b=x[e+12>>2];x[d+40>>2]=x[e+8>>2];x[d+44>>2]=b;b=x[e+4>>2];x[d+32>>2]=x[e>>2];x[d+36>>2]=b;Eu(d+320|0,d+32|0);b=x[d+348>>2];x[d+24>>2]=x[d+344>>2];x[d+28>>2]=b;b=x[d+340>>2];x[d+16>>2]=x[d+336>>2];x[d+20>>2]=b;b=x[d+332>>2];x[d+8>>2]=x[d+328>>2];x[d+12>>2]=b;b=x[d+324>>2];x[d>>2]=x[d+320>>2];x[d+4>>2]=b;MN(g,d);break r}b=x[e+28>>2];x[d+88>>2]=x[e+24>>2];x[d+92>>2]=b;b=x[e+20>>2];x[d+80>>2]=x[e+16>>2];x[d+84>>2]=b;b=x[e+12>>2];x[d+72>>2]=x[e+8>>2];x[d+76>>2]=b;b=x[e+4>>2];x[d+64>>2]=x[e>>2];x[d+68>>2]=b;NO(g,d- -64|0)}fb=d+512|0;x[31737]=0;O(1065,a|0,g|0);a=x[31737];x[31737]=0;if((a|0)!=1){tb(g);break e}c=N()|0;tb(f+20|0);break a}d=f+20|0;e=Dc(d,12289);g=qh(c,e);tb(e);if(g){wV(d,x[b+24>>2]+1298332|0);t:{if(!Ad(x[f+24>>2],y[f+31|0])){break t}c=x[x[b+24>>2]+480180>>2];u:{v:{if((c|0)==33554432){break v}d=1;if((c|0)==32){break u}if((c|0)==16384){break v}if((c|0)==16777216){break u}}d=2}w:{switch(d-1|0){case 0:x[31737]=0;c=f+8|0;O(1066,c|0,b|0);d=x[31737];x[31737]=0;if((d|0)!=1){Ab(f+20|0,c);tb(c);break t}break b;case 1:break w;default:break t}}x[31737]=0;c=f+8|0;O(1067,c|0,b|0);d=x[31737];x[31737]=0;if((d|0)==1){break b}d=Ab(f+20|0,c);tb(c);if(!Ad(x[f+24>>2],y[f+31|0])){break t}x[31737]=0;O(1066,c|0,b|0);e=x[31737];x[31737]=0;if((e|0)==1){break b}Ab(d,c);tb(c)}b=x[b+24>>2];x[31737]=0;c=a;a=f+20|0;S(1059,c|0,b|0,a|0);b=x[31737];x[31737]=0;if((b|0)!=1){tb(a);break e}break b}d=f+20|0;e=Dc(d,5472);g=qh(c,e);tb(e);if(g){wV(d,x[b+24>>2]+1298332|0);b=x[b+24>>2];x[31737]=0;S(1059,a|0,b|0,d|0);a=x[31737];x[31737]=0;if((a|0)!=1){tb(d);break e}c=N()|0;tb(f+20|0);break a}i=c;c=Dc(f+20|0,7335);d=qh(i,c);tb(c);if(d){a=Fb(a);c=wb(x[b+68>>2]);x[f+20>>2]=c;d=wb(x[b+72>>2]);b=1;while(1){if(!Ib(c,d)){break e}if(!(b&1)){x[31737]=0;P(991,a|0,22278)|0;b=x[31737];x[31737]=0;if((b|0)==1){break c}}x[31737]=0;P(842,a|0,c|0)|0;b=x[31737];x[31737]=0;if((b|0)==1){break c}c=x[hl(f+20|0)>>2];b=0;continue}}Dc(a,22303)}fb=f+32|0;return}c=N()|0;tb(f+20|0);break a}c=N()|0;tb(a);break a}c=N()|0;tb(f+20|0)}Q(c|0);p()}function Mpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,C=0,E=0,F=0;d=fb-1328|0;fb=d;xc(b);e=fb-16|0;fb=e;h=d+220|0;PX(e+8|0,h);i=x[e+12>>2];lc(e,x[b>>2],x[b+8>>2],x[e+8>>2],x[e+12>>2]);f=x[e+4>>2];if((f|0)==(i|0)){Vb(b,x[e+12>>2])}fb=e+16|0;a:{if((f|0)!=(i|0)){break a}if(!RX(h)){break a}if(!Mb(x[b>>2],x[b+8>>2],Bc(QX(y[d+1324|0]|y[d+1325|0]<<8|(y[d+1326|0]<<16|y[d+1327|0]<<24)),hb))){break a}n=1;if((c|0)==64){break a}xc(b);b=Ge(d+220|0,b);x[31737]=0;e=d+208|0;O(643,e|0,b|0);i=x[31737];x[31737]=0;b:{c:{d:{e:{f:{g:{h:{i:{if((i|0)!=1){ub(b);x[31737]=0;S(644,d+196|0,e|0,1196314451);b=x[31737];x[31737]=0;if((b|0)==1){break i}n=0;x[31737]=0;S(644,d+184|0,e|0,1280331091);b=x[31737];x[31737]=0;if((b|0)==1){break h}if(mc(x[d+196>>2],x[d+200>>2])){break b}if(!mc(x[d+184>>2],x[d+188>>2])){break g}break b}c=N()|0;ub(b);break d}c=N()|0;break e}c=N()|0;break f}x[31737]=0;O(247,a|0,1);b=x[31737];x[31737]=0;j:{if((b|0)!=1){gg(a);x[a+480188>>2]=4;x[a+480208>>2]=25231360;E=d,F=wb(x[d+184>>2]),x[E+52>>2]=F;f=c&2;m=wb(x[d+188>>2]);k:{l:{while(1){e=x[d+52>>2];if(!Ib(e,m)){break l}b=z[a+480190>>1];if(!ui(b)){break l}b=b+1|0;w[a+480190>>1]=b;x[31737]=0;b=D(b&65535,104)+a|0;i=b+484380|0;O(280,i|0,1);h=x[31737];x[31737]=0;m:{n:{if((h|0)!=1){x[31737]=0;h=d+220|0;l=P(645,e|0,h|0)|0;n=x[31737];x[31737]=0;if((n|0)==1){break n}if(!l){break c}if(Av(h)){break m}break c}c=N()|0;break j}c=N()|0;break j}x[31737]=0;h=P(36,d+172|0,d+220|0)|0;l=x[31737];x[31737]=0;if((l|0)==1){break k}zc(((z[a+480190>>1]<<5)+a|0)+946304|0,h);tb(h);h=y[d+256|0]|y[d+257|0]<<8|(y[d+258|0]<<16|y[d+259|0]<<24);x[i>>2]=h;x[b+484388>>2]=h;x[b+484384>>2]=y[d+252|0]|y[d+253|0]<<8|(y[d+254|0]<<16|y[d+255|0]<<24);h=b+484414|0;w[h>>1]=z[h>>1]|2;w[b+484410>>1]=255;o:{if(f){b=Xc(d+24|0,8,1,0,0);x[31737]=0;U(216,b|0,i|0,e|0)|0;b=x[31737];x[31737]=0;if((b|0)==1){break o}}Sf(d+52|0);continue}break}c=N()|0;break j}E=d,F=wb(x[d+196>>2]),x[E+168>>2]=F;o=a+484344|0;q=c&1;r=a+484360|0;B=wb(x[d+200>>2]);s=a+484380|0;t=a+946304|0;c=1;n=1;while(1){p:{q:{r:{s:{t:{u:{v:{b=x[d+168>>2];if(!Ib(b,B)){break v}if(!(c&1)){x[31737]=0;c=R(275,r|0)|0;e=x[31737];x[31737]=0;if((e|0)==1){break u}if(!c){break v}}kj(Xb(x[a+484360>>2],y[a+484376|0]));x[31737]=0;e=d+220|0;c=P(646,b|0,e|0)|0;i=x[31737];x[31737]=0;if((i|0)==1){break t}if(!(!(y[d+1306|0]|y[d+1307|0]<<8)&c)|(y[d+1308|0]|y[d+1309|0]<<8|(y[d+1310|0]<<16|y[d+1311|0]<<24))-5>>>0<4294967292){break c}i=y[a+484376|0];h=x[a+484360>>2];x[31737]=0;c=d+156|0;O(647,c|0,e|0);e=x[31737];x[31737]=0;if((e|0)==1){break t}tp(Xb(h,i),c);tb(c);w:{if(q){x[31737]=0;S(186,d+52|0,b|0,y[d+1316|0]|y[d+1317|0]<<8|(y[d+1318|0]<<16|y[d+1319|0]<<24));b=x[31737];x[31737]=0;if((b|0)!=1){break w}c=N()|0;break j}x[31737]=0;b=R(169,d+116|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break s}yG(d+52|0,b)}b=d+52|0;m=ic(d+136|0,b);ub(b);if(!q){ub(d+116|0)}Rb(d+52|0,0,64);l=1;x:{y:{z:{while(1){if((l|0)==32){break z}b=(D(l,34)+d|0)+186|0;c=b+32|0;Kn(d+8|0,c);A:{B:{if(Sj(y[x[d+8>>2]])){break B}e=y[b- -64|0];if(e>>>0>15){break y}b=y[b+65|0];if(b>>>0>64){break y}if(!Av(c)){break y}i=b<<2;h=e<<4;c=0;b=1;while(1){f=b&65535;e=z[a+480190>>1];if(f>>>0<=e>>>0){x[31737]=0;k=d+24|0;S(648,k|0,x[d+8>>2],x[d+12>>2]);e=x[31737];x[31737]=0;if((e|0)==1){break A}e=fb-32|0;fb=e;ee(e+24|0,k);MX(e+16|0,((f<<5)+a|0)+946304|0);g=x[e+20>>2];x[e+8>>2]=x[e+16>>2];x[e+12>>2]=g;g=Ic(x[e+24>>2],x[e+28>>2],e+8|0);fb=e+32|0;tb(k);C:{if(g^1){break C}E=_b(d+52|0,l),F=b,w[E>>1]=F;e=D(f,104)+a|0;f=e+484410|0;k=z[f>>1];if((k|0)!=255){c=b;if(y[e+484417|0]!=(h&255)|(i|0)!=(k|0)){break C}}v[e+484417|0]=h;w[f>>1]=i;break B}b=b+1|0;continue}break}c=c&65535;if(!c){break B}if(!ui(e)){break B}b=e+1|0;w[a+480190>>1]=b;E=_b(d+52|0,l),F=b,w[E>>1]=F;b=D(z[a+480190>>1],104)+s|0;sn(b);e=D(c,104)+s|0;f=$o(b,e);w[b+30>>1]=i;v[b+37|0]=h;EY(f,e);c=(c<<5)+t|0;e=x[c+4>>2];b=(z[a+480190>>1]<<5)+t|0;x[b>>2]=x[c>>2];x[b+4>>2]=e;e=x[c+28>>2];x[b+24>>2]=x[c+24>>2];x[b+28>>2]=e;e=x[c+20>>2];x[b+16>>2]=x[c+16>>2];x[b+20>>2]=e;e=x[c+12>>2];x[b+8>>2]=x[c+8>>2];x[b+12>>2]=e}l=l+1|0;continue}break}break r}h=0;x[d+48>>2]=0;x[d+40>>2]=0;x[d+44>>2]=0;x[d+32>>2]=0;x[d+36>>2]=0;x[d+24>>2]=0;x[d+28>>2]=0;e=64;i=65535;C=y[d+1308|0]|y[d+1309|0]<<8;k=0;D:while(1){E:{if(k){break E}b=x[m>>2];x[31737]=0;b=U(151,b|0,x[d+144>>2],1)|0;c=x[31737];x[31737]=0;if((c|0)==1){break x}if(b){break E}c=i;b=e;break q}b=e+1|0;F:{if(e>>>0<63){e=b;break F}x[31737]=0;i=P(368,o|0,64)|0;c=x[31737];x[31737]=0;if((c|0)==1){break x}c=65535;if((i|0)==65535){break q}b=y[a+484376|0];c=x[a+484360>>2];e=0;x[31737]=0;O(538,Xb(c,b)|0,i|0);b=x[31737];x[31737]=0;if((b|0)==1){break x}}b=0;c=Wb(x[o>>2],i&65535);c=jd(x[c>>2],x[x[c+48>>2]+12>>2],e,0);while(1){if((b|0)==(C|0)){continue D}f=(d+24|0)+D(b,7)|0;g=y[f+6|0];G:{if(g){v[f+6|0]=g-1;g=y[f+4|0]|y[f+5|0]<<8;v[c+4|0]=g;v[c+5|0]=g>>>8;f=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);v[c|0]=f;v[c+1|0]=f>>>8;v[c+2|0]=f>>>16;v[c+3|0]=f>>>24;k=k-1|0;break G}g=x[m>>2];x[31737]=0;g=U(151,g|0,x[d+144>>2],1)|0;j=x[31737];x[31737]=0;if((j|0)==1){break r}if(!g){break G}if(x[d+144>>2]==(y[d+1312|0]|y[d+1313|0]<<8|(y[d+1314|0]<<16|y[d+1315|0]<<24))){h=Xb(x[a+484360>>2],y[a+484376|0]);af(h,iE(x[h>>2],x[h+4>>2]));h=e}x[31737]=0;g=R(198,m|0)|0;j=x[31737];x[31737]=0;H:{if((j|0)!=1){g=g<<24>>24;if((g|0)>=0){break H}g=g&127;v[f+6|0]=g;j=y[f+4|0]|y[f+5|0]<<8;v[c+4|0]=j;v[c+5|0]=j>>>8;f=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);v[c|0]=f;v[c+1|0]=f>>>8;v[c+2|0]=f>>>16;v[c+3|0]=f>>>24;k=g+k|0;break G}break r}if((g-1&255)>>>0<=35){v[c|0]=g+48}x[31737]=0;g=R(198,m|0)|0;j=x[31737];x[31737]=0;I:{J:{if((j|0)!=1){g=g<<24>>24;E=c,F=y[_b(d+52|0,g&31)|0],v[E+1|0]=F;if((g|0)>=0){break J}v[c+3|0]=y[f+3|0];v[c+5|0]=y[f+5|0];break I}break r}x[31737]=0;j=d+8|0;O(199,j|0,m|0);g=x[31737];x[31737]=0;K:{if((g|0)!=1){g=y[d+8|0];if(g>>>0>19){break I}u=g<<1;A=y[u+25360|0];v[c+3|0]=A;j=y[Jc(j)|0];v[c+5|0]=j;if((A|0)!=16|j>>>0<32){break K}v[c+3|0]=17;break I}break r}if(819137>>>g&1){break I}v[c+5|0]=y[u+25361|0]|j&15}g=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);v[f|0]=g;v[f+1|0]=g>>>8;v[f+2|0]=g>>>16;v[f+3|0]=g>>>24;g=y[c+4|0]|y[c+5|0]<<8;v[f+4|0]=g;v[f+5|0]=g>>>8}c=c+6|0;b=b+1|0;continue}}}n=0;break p}break r}ak(r,0);x[31737]=0;b=P(1,d+220|0,6467)|0;c=x[31737];x[31737]=0;L:{if((c|0)!=1){Ab(a+1298344|0,b);tb(b);x[31737]=0;b=P(1,d+52|0,6804)|0;c=x[31737];x[31737]=0;if((c|0)==1){break L}Ab(a+1298356|0,b);tb(b);E=a+1298404|0,F=x[Fc(d+24|0,4)>>2],x[E>>2]=F;n=1;break b}c=N()|0;break j}c=N()|0;break j}c=N()|0;break j}c=N()|0;break j}c=N()|0;break j}c=N()|0;ub(m);break j}c=c&65535;if(!((h|0)!=0|b>>>0<63)|(c|0)==65535){break p}ye(Wb(x[o>>2],c),Yh(Xe(Ne(d+8|0,14,h&255),b)))}ub(m);if((l|0)!=32){break b}Sf(d+168|0);c=0;continue}}c=N()|0;break j}c=N()|0}Qc(d+184|0)}Qc(d+196|0)}ie(d+208|0)}Q(c|0);p()}n=0}Qc(d+184|0);Qc(d+196|0);ie(d+208|0)}fb=d+1328|0;return n|0}function toa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0;h=fb-256|0;fb=h;e=fb-112|0;fb=e;f=Ge(h+76|0,c);x[31737]=0;o=R(169,f+20|0)|0;c=x[31737];x[31737]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{if((c|0)!=1){x[31737]=0;r=R(169,f+40|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break B}x[31737]=0;s=R(169,f+60|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break A}x[31737]=0;i=R(169,f+80|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break z}x[31737]=0;q=R(169,f+100|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break y}x[31737]=0;m=R(169,f+120|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break x}j=Nb(f+140|0);xc(f);x[f+172>>2]=1873739776;w[f+176>>1]=0;x[31737]=0;d=P(810,f|0,e+100|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break w}if(!d){break n}d=x[e+100>>2];if((d|0)!=1414744396&(d|0)!=1179011410){break n}c=x[e+108>>2];if((c|0)!=1163280727&(c|0)!=1702257015){break n}v[f+176|0]=(d|0)==1414744396;x[31737]=0;g=e+88|0;S(811,g|0,f|0,2);c=x[31737];x[31737]=0;if((c|0)==1){break v}k=x[e+88>>2];C:{if(Nr(k,x[e+92>>2])>>>0<4){break C}l=e+36|0;c=wA(k,1);d=x[c>>2];c=x[c+4>>2];wi(l,d,c);if(x[e+36>>2]!=1635017060){break C}wi(e+60|0,d,c);if(!(v[e+64|0]&1)){break C}c=wA(k,2);wi(e+16|0,x[c>>2],x[c+4>>2]);if(y[e+20|0]|y[e+21|0]<<8|(y[e+22|0]<<16|y[e+23|0]<<24)){break C}c=wA(k,3);wi(e+80|0,x[c>>2],x[c+4>>2]);if(x[e+80>>2]){break C}x[31737]=0;P(150,f|0,12)|0;c=x[31737];x[31737]=0;if((c|0)==1){break u}x[31737]=0;S(811,l|0,f|0,1);c=x[31737];x[31737]=0;if((c|0)==1){break t}yv(g,l);ie(l)}x[31737]=0;g=e+60|0;S(812,g|0,e+88|0,544501094);c=x[31737];x[31737]=0;if((c|0)==1){break s}x[31737]=0;d=P(813,g|0,f+156|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break k}if(!d){break o}d=z[f+156>>1];if((d|0)!=1){break q}x[31737]=0;d=R(203,g|0)|0;c=x[31737];x[31737]=0;if((c|0)!=1){break r}break k}d=N()|0;break b}d=N()|0;break c}d=N()|0;break d}d=N()|0;break e}d=N()|0;break f}d=N()|0;break g}d=N()|0;break h}d=N()|0;break h}d=N()|0;break i}d=N()|0;break i}d=N()|0;break i}if((d|0)==4){x[31737]=0;g=R(193,e+60|0)|0;c=x[31737];x[31737]=0;D:{if((c|0)!=1){x[31737]=0;d=R(193,e+60|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break D}if((g|0)!=2|(d|0)!=1){break p}v[f+177|0]=1;break p}d=N()|0;break j}d=N()|0;break j}d=z[f+156>>1]}if((d&65535)!=65534){break p}x[31737]=0;d=P(814,e+60|0,e+36|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break l}if(!d){break o}c=y[e+56|0]|y[e+57|0]<<8|(y[e+58|0]<<16|y[e+59|0]<<24);x[e+8>>2]=y[e+52|0]|y[e+53|0]<<8|(y[e+54|0]<<16|y[e+55|0]<<24);x[e+12>>2]=c;c=y[e+48|0]|y[e+49|0]<<8|(y[e+50|0]<<16|y[e+51|0]<<24);x[e>>2]=y[e+44|0]|y[e+45|0]<<8|(y[e+46|0]<<16|y[e+47|0]<<24);x[e+4>>2]=c;c=e+16|0;x[c>>2]=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);w[c+4>>1]=y[e+4|0]|y[e+5|0]<<8;w[c+6>>1]=y[e+6|0]|y[e+7|0]<<8;t=c,u=vA(y[e+8|0]|y[e+9|0]<<8|(y[e+10|0]<<16|y[e+11|0]<<24),y[e+12|0]|y[e+13|0]<<8|(y[e+14|0]<<16|y[e+15|0]<<24)),x[t+8>>2]=u;x[c+12>>2]=hb;w[f+172>>1]=x[c>>2]}x[31737]=0;k=e+36|0;g=e+88|0;S(812,k|0,g|0,1635017060);c=x[31737];x[31737]=0;E:{F:{G:{H:{I:{J:{if((c|0)!=1){l=hd(o,k);ub(k);c=x[l>>2];x[31737]=0;d=R(173,c|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break k}if(!d){x[31737]=0;S(812,k|0,g|0,544039792);c=x[31737];x[31737]=0;if((c|0)==1){break J}hd(l,k);ub(k)}x[31737]=0;g=e+36|0;S(812,g|0,e+88|0,1952670054);c=x[31737];x[31737]=0;if((c|0)==1){break I}x[31737]=0;d=R(152,g|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break H}x[f+152>>2]=d;ub(g);if(x[f+152>>2]?z[f+156>>1]==17:0){break E}g=z[f+158>>1];d=IR(g,z[f+170>>1]);if(!d){break E}c=z[f+168>>1];if(c){if((c>>>0)/(g>>>0)>>>0<d<<1>>>0){break G}}c=x[l>>2];x[31737]=0;d=R(155,c|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break k}c=IR(z[f+158>>1],z[f+170>>1]);break F}d=N()|0;break j}d=N()|0;break j}d=N()|0;break j}d=N()|0;ub(e+36|0);break j}c=x[l>>2];x[31737]=0;d=R(155,c|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break k}c=z[f+168>>1]}x[f+152>>2]=(d>>>0)/((c&65535)>>>0)}x[31737]=0;g=e+88|0;d=P(815,f|0,g|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break k}w[f+174>>1]=d;x[31737]=0;O(816,f|0,g|0);c=x[31737];x[31737]=0;if((c|0)==1){break k}x[31737]=0;d=e+36|0;S(812,d|0,g|0,1886221175);c=x[31737];x[31737]=0;if((c|0)==1){break m}hd(q,d);ub(d)}ub(e+60|0);ie(e+88|0)}fb=e+112|0;break a}d=N()|0;break j}d=N()|0;break j}d=N()|0}ub(e+60|0)}ie(e+88|0)}ie(j);ub(m)}ub(q)}ub(i)}ub(s)}ub(r)}ub(o)}ub(f);Q(d|0);p()}c=x[f+20>>2];x[31737]=0;d=R(746,c|0)|0;c=x[31737];x[31737]=0;K:{L:{if((c|0)!=1){M:{if(!d|(z[f+158>>1]-3&65535)>>>0<65534){break M}N:{O:{c=z[f+170>>1];P:{if(!c){if((Hk(f)|0)==85){break P}break M}if(c>>>0>31){break O}}if((Hk(f)|0)!=3){break N}break M}if(c>>>0>64){break M}}d=Hk(f);c=28656;while(1){Q:{R:{if((c|0)!=28680){if((d|0)!=x[c>>2]){break R}}else{c=28680}break Q}c=c+4|0;continue}break}if((c|0)==28680){break M}Uu(a,b);x[31737]=0;g=P(36,h- -64|0,22303)|0;c=x[31737];x[31737]=0;S:{T:{U:{V:{W:{if((c|0)!=1){d=zc(((b<<5)+a|0)+946304|0,g);tb(g);x[31737]=0;g=D(b,104)+a|0;i=g+484380|0;O(280,i|0,0);c=x[31737];x[31737]=0;if((c|0)==1){break W}x[i>>2]=x[f+152>>2];x[g+484404>>2]=x[f+160>>2];c=x[a+1298404>>2];x[31737]=0;V(747,f|0,i|0,c|0,d|0);c=x[31737];x[31737]=0;if((c|0)==1){break W}Ge(h+44|0,f+20|0);d=z[f+158>>1];j=Xc(h+40|0,8,d>>>0>1?2:1,0,0);c=Hk(f);if((c|0)!=17|d>>>0>2){break U}wc(i,268435456);b=g+484414|0;w[b>>1]=z[b>>1]&65470|((d|0)==2)<<6|1;if(Eh(i)){break V}break S}n=N()|0;break K}n=N()|0;break K}j=x[g+484400>>2];g=x[i>>2];m=Ge(h+20|0,h+44|0);d=z[f+158>>1];c=z[f+168>>1];x[31737]=0;b=x[m+12>>2];x[h+8>>2]=x[m+8>>2];x[h+12>>2]=b;x[h+16>>2]=x[m+16>>2];b=x[m+4>>2];x[h>>2]=x[m>>2];x[h+4>>2]=b;aa(748,j|0,g|0,h|0,c|0,d|0);b=x[31737];x[31737]=0;if((b|0)==1){break L}Pj(i,a);break T}if((c|0)==85){x[31737]=0;c=U(575,a|0,b|0,h+44|0)|0;b=x[31737];x[31737]=0;if((b|0)==1){break L}if(c){break T}break S}X:{Y:{Z:{if(NV(z[f+156>>1])){break Z}_:{if(!Gd(y[f+177|0])){break _}if((Hk(f)|0)!=1|z[f+170>>1]!=32|z[f+168>>1]!=d<<2){break _}fd(j,32);b=12;break Y}if((Hk(f)|0)!=1|z[f+170>>1]!=24|z[f+168>>1]!=d<<2){break Z}fd(j,32);b=13;break Y}if((Hk(f)&65534)!=6){break X}fd(j,16);b=(Hk(f)|0)==6?17:16}yg(j,b);x[31737]=0;U(216,j|0,i|0,h+44|0)|0;b=x[31737];x[31737]=0;if((b|0)!=1){break T}break L}d=z[f+170>>1];c=d-1|0;b=c&-8;g=b&31;if((b&63)>>>0>=32){b=1074268168>>>g|0}else{b=((1<<g)-1&1074268168)<<32-g|538447880>>>g}fd(j,(c>>>0>=64?8:b)&120);if(d>>>0<9){yg(j,1)}if((Hk(f)|0)==3){yg(j,3)}x[31737]=0;U(216,j|0,i|0,h+44|0)|0;b=x[31737];x[31737]=0;if((b|0)==1){break L}}bC(i,x[a+480180>>2]);Pj(i,a);n=1}ub(h+44|0)}MV(f);fb=h+256|0;return n|0}n=N()|0;break K}n=N()|0;ub(h+44|0)}MV(f);Q(n|0);p()}function Hga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=E(0),f=E(0),g=E(0),h=E(0),i=0,j=E(0),k=E(0),l=0,m=0,n=0,o=E(0),p=0,q=0,r=0,s=0,t=0,u=E(0),w=E(0),z=0,A=0,C=E(0),D=0,F=0,G=E(0),H=0,I=0,J=E(0);a:{if(!y[a+5046|0]){break a}g=B[a+4268>>2];$P(a);if(B[a+4268>>2]==g){break a}Sz(a)}b:{if(!y[a+5045|0]){break b}if(!zi(a+44|0)){break b}i=x[a+44>>2];p=Hc(i,0);q=Hc(i,1);i=x[a+56>>2];l=Hc(i,0);m=Hc(i,1);c:{if(!(!y[a+5044|0]|(!d|y[a+4264|0]&2))){B[l>>2]=B[a+5036>>2];B[m>>2]=B[a+5040>>2];v[a+5044|0]=0;q=q+4|0;p=p+4|0;m=m+4|0;l=l+4|0;n=d-1|0;break c}n=d}r=n;s=a+4888|0;t=a+4864|0;D=a+4504|0;F=a+4960|0;d:{while(1){if(!r){break d}g=B[p>>2];g=E(E(E(B[a+5008>>2]-g)*B[a+4276>>2])+g);B[a+5008>>2]=g;I=Oc(x[a+4864>>2],x[a+4868>>2],x[a+4880>>2]),J=g,B[I>>2]=J;g=B[q>>2];g=E(E(E(B[a+5012>>2]-g)*B[a+4276>>2])+g);B[a+5012>>2]=g;I=Oc(x[a+4888>>2],x[a+4892>>2],x[a+4904>>2]),J=g,B[I>>2]=J;g=E(E(E(E(E(oi(t,x[a+4356>>2])*E(.6800000071525574))+E(oi(t,x[a+4360>>2])*E(-.5)))-E(oi(t,x[a+4364>>2])*E(.6200000047683716)))+E(oi(t,x[a+4368>>2])*E(-.5)))-E(oi(t,x[a+4372>>2])*E(.6200000047683716)));if(v[a+4264|0]&1){e=g;g=E(B[Oc(x[a+4816>>2],x[a+4820>>2],x[a+4836>>2])>>2]+E(e*E(.6180340051651001)));I=Oc(x[a+4816>>2],x[a+4820>>2],x[a+4832>>2]),J=E(e-E(g*E(.6180340051651001))),B[I>>2]=J}u=B[a+4280>>2];I=a,J=E(oi(t,x[a+4352>>2])+B[a+5020>>2]),B[I+5020>>2]=J;e=E(oi(s,x[a+4376>>2])+B[a+5024>>2]);B[a+5024>>2]=e;f=B[a+5020>>2];h=E(E(E(B[a+4980>>2]-B[Oc(x[a+4624>>2],x[a+4628>>2],x[a+4644>>2])>>2])*B[a+4444>>2])+B[Oc(x[a+4624>>2],x[a+4628>>2],x[a+4644>>2])>>2]);B[a+4980>>2]=h;C=E(h*B[a+4440>>2]);k=E(e*E(.7070000171661377));j=E(f*E(-.7070000171661377));f=E(k+j);h=B[a+4272>>2];e=E(C+E(f*h));I=Oc(x[a+4624>>2],x[a+4628>>2],x[a+4640>>2]),J=E(f-E(h*e)),B[I>>2]=J;f=E(E(E(B[a+4976>>2]-B[Oc(x[a+4600>>2],x[a+4604>>2],x[a+4620>>2])>>2])*B[a+4436>>2])+B[Oc(x[a+4600>>2],x[a+4604>>2],x[a+4620>>2])>>2]);B[a+4976>>2]=f;h=B[a+4272>>2];f=E(E(f*B[a+4432>>2])+E(e*h));I=Oc(x[a+4600>>2],x[a+4604>>2],x[a+4616>>2]),J=E(e-E(h*f)),B[I>>2]=J;w=E(E(e*E(-.15000000596046448))+E(f*E(-.20000000298023224)));if(v[a+4264|0]&1){e=E(E(E(B[a+4972>>2]-B[Oc(x[a+4576>>2],x[a+4580>>2],x[a+4596>>2])>>2])*B[a+4428>>2])+B[Oc(x[a+4576>>2],x[a+4580>>2],x[a+4596>>2])>>2]);B[a+4972>>2]=e;h=B[a+4272>>2];e=E(E(e*B[a+4424>>2])+E(f*h));I=Oc(x[a+4576>>2],x[a+4580>>2],x[a+4592>>2]),J=E(f-E(h*e)),B[I>>2]=J;f=E(E(E(B[a+4968>>2]-B[Oc(x[a+4552>>2],x[a+4556>>2],x[a+4572>>2])>>2])*B[a+4420>>2])+B[Oc(x[a+4552>>2],x[a+4556>>2],x[a+4572>>2])>>2]);B[a+4968>>2]=f;h=B[a+4272>>2];f=E(E(f*B[a+4416>>2])+E(e*h));I=Oc(x[a+4552>>2],x[a+4556>>2],x[a+4568>>2]),J=E(e-E(h*f)),B[I>>2]=J;w=E(E(E(e*E(.3499999940395355))+w)+E(f*E(-.3799999952316284)))}I=Oc(x[a+4912>>2],x[a+4916>>2],x[a+4928>>2]),J=f,B[I>>2]=J;e=E(B[Oc(x[a+4912>>2],x[a+4916>>2],x[a+4932>>2])>>2]*B[a+4496>>2]);B[a+5028>>2]=E(E(B[a+5028>>2]-e)*B[a+4500>>2])+e;e=E(E(E(B[a+4964>>2]-B[Oc(x[a+4528>>2],x[a+4532>>2],x[a+4548>>2])>>2])*B[a+4412>>2])+B[Oc(x[a+4528>>2],x[a+4532>>2],x[a+4548>>2])>>2]);B[a+4964>>2]=e;f=B[a+5028>>2];o=B[a+4272>>2];h=E(E(f*o)+E(e*B[a+4408>>2]));I=Oc(x[a+4528>>2],x[a+4532>>2],x[a+4544>>2]),J=E(f-E(o*h)),B[I>>2]=J;e=E(E(E(B[a+4960>>2]-B[Oc(x[a+4504>>2],x[a+4508>>2],x[a+4524>>2])>>2])*B[a+4404>>2])+B[Oc(x[a+4504>>2],x[a+4508>>2],x[a+4524>>2])>>2]);B[a+4960>>2]=e;f=E(e*B[a+4400>>2]);e=B[a+4272>>2];o=E(f+E(h*e));I=Oc(x[a+4504>>2],x[a+4508>>2],x[a+4520>>2]),J=E(h-E(e*o)),B[I>>2]=J;B[a+5020>>2]=o;e=E(E(E(E(E(oi(s,x[a+4380>>2])*E(.7070000171661377))+E(oi(s,x[a+4384>>2])*E(-.6000000238418579)))-E(oi(s,x[a+4388>>2])*E(.5)))+E(oi(s,x[a+4392>>2])*E(-.6000000238418579)))-E(oi(s,x[a+4396>>2])*E(.5)));if(v[a+4264|0]&1){f=e;e=E(B[Oc(x[a+4840>>2],x[a+4844>>2],x[a+4860>>2])>>2]+E(e*E(.6180340051651001)));I=Oc(x[a+4840>>2],x[a+4844>>2],x[a+4856>>2]),J=E(f-E(e*E(.6180340051651001))),B[I>>2]=J}G=B[a+4280>>2];f=E(E(E(B[a+5004>>2]-B[Oc(x[a+4768>>2],x[a+4772>>2],x[a+4788>>2])>>2])*B[a+4492>>2])+B[Oc(x[a+4768>>2],x[a+4772>>2],x[a+4788>>2])>>2]);B[a+5004>>2]=f;C=E(f*B[a+4488>>2]);f=E(j-k);j=B[a+4272>>2];k=E(C+E(f*j));I=Oc(x[a+4768>>2],x[a+4772>>2],x[a+4784>>2]),J=E(f-E(j*k)),B[I>>2]=J;f=E(E(E(B[a+5e3>>2]-B[Oc(x[a+4744>>2],x[a+4748>>2],x[a+4764>>2])>>2])*B[a+4484>>2])+B[Oc(x[a+4744>>2],x[a+4748>>2],x[a+4764>>2])>>2]);B[a+5e3>>2]=f;j=B[a+4272>>2];f=E(E(f*B[a+4480>>2])+E(k*j));I=Oc(x[a+4744>>2],x[a+4748>>2],x[a+4760>>2]),J=E(k-E(j*f)),B[I>>2]=J;k=E(E(E(h*E(.3799999952316284))+E(k*E(-.15000000596046448)))+E(f*E(-.20000000298023224)));if(v[a+4264|0]&1){h=E(E(E(B[a+4996>>2]-B[Oc(x[a+4720>>2],x[a+4724>>2],x[a+4740>>2])>>2])*B[a+4476>>2])+B[Oc(x[a+4720>>2],x[a+4724>>2],x[a+4740>>2])>>2]);B[a+4996>>2]=h;j=B[a+4272>>2];h=E(E(h*B[a+4472>>2])+E(f*j));I=Oc(x[a+4720>>2],x[a+4724>>2],x[a+4736>>2]),J=E(f-E(j*h)),B[I>>2]=J;f=E(E(E(B[a+4992>>2]-B[Oc(x[a+4696>>2],x[a+4700>>2],x[a+4716>>2])>>2])*B[a+4468>>2])+B[Oc(x[a+4696>>2],x[a+4700>>2],x[a+4716>>2])>>2]);B[a+4992>>2]=f;j=B[a+4272>>2];f=E(E(f*B[a+4464>>2])+E(h*j));I=Oc(x[a+4696>>2],x[a+4700>>2],x[a+4712>>2]),J=E(h-E(j*f)),B[I>>2]=J;k=E(E(E(h*E(.3499999940395355))+k)+E(f*E(-.3799999952316284)))}H=q+4|0;n=p+4|0;h=E(g*u);w=E(w-E(o*E(.3799999952316284)));o=E(e*G);I=Oc(x[a+4936>>2],x[a+4940>>2],x[a+4952>>2]),J=f,B[I>>2]=J;g=E(B[Oc(x[a+4936>>2],x[a+4940>>2],x[a+4956>>2])>>2]*B[a+4496>>2]);B[a+5032>>2]=E(E(B[a+5032>>2]-g)*B[a+4500>>2])+g;g=E(E(E(B[a+4988>>2]-B[Oc(x[a+4672>>2],x[a+4676>>2],x[a+4692>>2])>>2])*B[a+4460>>2])+B[Oc(x[a+4672>>2],x[a+4676>>2],x[a+4692>>2])>>2]);B[a+4988>>2]=g;e=B[a+5032>>2];f=B[a+4272>>2];g=E(E(e*f)+E(g*B[a+4456>>2]));I=Oc(x[a+4672>>2],x[a+4676>>2],x[a+4688>>2]),J=E(e-E(f*g)),B[I>>2]=J;f=B[a+4284>>2];e=E(E(E(B[a+4984>>2]-B[Oc(x[a+4648>>2],x[a+4652>>2],x[a+4668>>2])>>2])*B[a+4452>>2])+B[Oc(x[a+4648>>2],x[a+4652>>2],x[a+4668>>2])>>2]);B[a+4984>>2]=e;u=B[a+4272>>2];e=E(E(e*B[a+4448>>2])+E(g*u));I=Oc(x[a+4648>>2],x[a+4652>>2],x[a+4664>>2]),J=E(g-E(u*e)),B[I>>2]=J;B[a+5024>>2]=e;e=E(-e);u=B[a+4288>>2];i=D;e:{f:{while(1){if((i|0)==(F|0)){g:{e=E(o+E(E(E(e*E(.3799999952316284))+k)*u));g=E(h+E(E(E(g*E(.3799999952316284))+w)*f));if(!(y[a+4264|0]&2)){break g}p=n;n=H;break f}}else{z=x[i+16>>2];A=z-1|0;x[i+16>>2]=A;if((z|0)<=0){x[i+16>>2]=A+x[i+12>>2]}z=x[i+20>>2];A=z-1|0;x[i+20>>2]=A;if((z|0)<=0){x[i+20>>2]=A+x[i+12>>2]}i=i+24|0;continue}break}B[l>>2]=E(g+B[a+5036>>2])*E(.5);B[m>>2]=E(e+B[a+5040>>2])*E(.5);B[a+5040>>2]=e;B[a+5036>>2]=g;if((r|0)==1){break e}r=r-1|0;p=p+8|0;m=m+4|0;l=l+4|0;n=q+8|0}q=n;B[l>>2]=g;B[m>>2]=e;r=r-1|0;m=m+4|0;l=l+4|0;continue}break}v[a+5044|0]=1}n=a;a=x[a+56>>2];Pi(n,b,c,Hc(a,0),Hc(a,1),d)}}function Xta(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;e=fb-272|0;fb=e;xc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{h=e+206|0;m:{if(!V$(b,h)){break m}if(!W$(h)){break m}d=1;if((c|0)==64){break m}Bd(a,131072);d=fb-16|0;fb=d;h=e+120|0;f=tc(d+4|0,3910);_c(h,f);tb(f);fb=d+16|0;x[31737]=0;d=e+160|0;S(210,d|0,h|0,e+210|0);f=x[31737];x[31737]=0;n:{o:{p:{if((f|0)!=1){Ab(a+1298344|0,d);tb(d);Eb(h);f=tc(d,11160);Ab(a+1298356|0,f);tb(f);o=a+1298404|0,q=x[Fc(d,4)>>2],x[o>>2]=q;vE(h,3,e+219|0);Cc(d,h);Ab(a+1298308|0,d);tb(d);vi(h,3,e+249|0);Kr(d,4,h);Ab(a+1298320|0,d);tb(d);d=op(d);o=d,q=Kd(y[e+269|0],1,31),x[o+8>>2]=q;o=d,q=Kd(y[e+270|0],1,12),x[o+4>>2]=q;x[d>>2]=y[e+271|0]+1900;h=a+1298412|0;gw(h);jE(h,d);g=e+128|0;h=Nb(e+148|0);q:{r:{s:{while(1){d=x[b+8>>2];f=x[b>>2];x[31737]=0;d=U(151,f|0,d|0,8)|0;f=x[31737];x[31737]=0;t:{u:{v:{w:{x:{if((f|0)!=1){if(!d){break q}x[31737]=0;O(311,b|0,e- -64|0);d=x[31737];x[31737]=0;if((d|0)==1){break x}d=x[e+68>>2];y:{k=y[e+210|0];switch(k-3|0){case 1:break w;case 0:break y;default:break v}}f=2;if(x[e+64>>2]!=1431389523){break u}break t}b=N()|0;break b}b=N()|0;break b}f=4;if(x[e+64>>2]!=1431389523){break u}break t}f=0;if(k>>>0>7){break t}}d=x[e+64>>2]==1146113363?-1:d;f=0}k=x[e+68>>2];x[e+120>>2]=x[e+64>>2];x[e+124>>2]=k;x[31737]=0;k=e+100|0;S(186,k|0,b|0,d|0);d=x[31737];x[31737]=0;if((d|0)==1){break s}ic(g,k);x[31737]=0;d=e+120|0;O(312,h|0,d|0);i=x[31737];x[31737]=0;if((i|0)==1){break r}Fd(d);ub(k);x[31737]=0;P(184,b|0,f|0)|0;d=x[31737];x[31737]=0;if((d|0)!=1){continue}break}b=N()|0;break b}b=N()|0;break b}b=N()|0;Fd(e+120|0);ub(e+100|0);break b}x[31737]=0;k=R(169,e+120|0)|0;b=x[31737];x[31737]=0;z:{A:{B:{if((b|0)!=1){x[31737]=0;d=e+100|0;S(313,d|0,h|0,1431389523);b=x[31737];x[31737]=0;if((b|0)==1){break B}b=hd(k,d);ub(d);w[e+98>>1]=0;w[e+96>>1]=65534;if(y[e+210|0]<3){break z}x[31737]=0;d=R(190,b|0)|0;f=x[31737];x[31737]=0;if((f|0)!=1){break A}break d}b=N()|0;break b}b=N()|0;break c}w[e+98>>1]=d;if(y[e+210|0]<4){break z}x[31737]=0;d=R(190,b|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break d}w[e+96>>1]=y[e+210|0]==4?d?d:-2:d}d=y[a+484376|0];f=x[a+484360>>2];x[31737]=0;g=R(203,b|0)|0;i=x[31737];x[31737]=0;if((i|0)==1){break d}x[31737]=0;S(239,Xb(f,d)|0,b|0,g>>>1|0);d=x[31737];x[31737]=0;if((d|0)==1){break d}d=Xb(x[a+484360>>2],y[a+484376|0]);d=iE(x[d>>2],x[d+4>>2]);Gf(e+98|0,d);Gf(e+96|0,d);x[31737]=0;d=e+100|0;S(313,d|0,h|0,1414807888);f=x[31737];x[31737]=0;if((f|0)==1){break e}b=hd(b,d);ub(d);d=x[b>>2];x[31737]=0;d=R(173,d|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break d}if(!(c&1)|d^1){break n}x[31737]=0;O(314,b|0,e+8|0);d=x[31737];x[31737]=0;if((d|0)==1){break f}o=a,q=Kd(y[e+10|0],1,32)+1|0,w[o+480188>>1]=q;x[31737]=0;d=P(215,e+84|0,z[e+8>>1])|0;f=x[31737];x[31737]=0;if((f|0)==1){break g}o=e,q=wb(x[d>>2]),x[o+44>>2]=q;i=wb(x[d+4>>2]);C:{D:{E:{while(1){j=x[e+44>>2];if(!Ib(j,i)){f=z[a+480188>>1];x[31737]=0;f=P(315,e+100|0,f|0)|0;g=x[31737];x[31737]=0;if((g|0)!=1){break C}b=N()|0;break o}x[31737]=0;f=y[e+210|0]<3?9:8;P(184,b|0,f-4|0)|0;g=x[31737];x[31737]=0;if((g|0)!=1){x[31737]=0;l=R(152,b|0)|0;g=x[31737];x[31737]=0;if((g|0)==1){break E}Gh(b,f);x[31737]=0;g=e- -64|0;S(186,g|0,b|0,f+l|0);f=x[31737];x[31737]=0;if((f|0)==1){break D}f=ic(e+100|0,g);hd(j,f);ub(f);ub(g);Sf(e+44|0);continue}break}b=N()|0;break o}b=N()|0;break o}b=N()|0;break o}g=Xb(x[a+484360>>2],y[a+484376|0]);g=km(x[g>>2],x[g+4>>2]);x[31737]=0;l=a+484344|0;O(224,l|0,g|0);g=x[31737];x[31737]=0;if((g|0)!=1){g=Xb(x[a+484360>>2],y[a+484376|0]);o=e,q=wb(x[g>>2]),x[o+64>>2]=q;i=wb(x[g+4>>2]);while(1){g=x[e+64>>2];if(!Ib(g,i)){g=Xb(x[a+484360>>2],y[a+484376|0]);i=z[e+96>>1];F:{if(!bj(g,i)){break F}j=x[g>>2];m=z[e+98>>1];if(!m){if(iE(j,x[g+4>>2])>>>0<=i>>>0){break F}}g=Wb(x[l>>2],z[_b(j,i)>>1]);ye(g,Gn(Xe(Ne(e- -64|0,12,m&255),x[g+12>>2]-1|0)))}Qk(f);Qc(d);break n}j=x[d>>2];n=Uf(j,x[d+4>>2]);m=z[g>>1];if(n>>>0>m>>>0){x[31737]=0;j=ba(316,dh(j,m)|0,y[e+210|0],f|0,a|0)|0;m=x[31737];x[31737]=0;if((m|0)==1){break p}w[g>>1]=j}Md(e- -64|0);continue}}break p}b=N()|0;Eb(e+120|0);break a}b=N()|0;Qk(f)}Qc(d);break c}x[31737]=0;d=e- -64|0;S(313,d|0,h|0,1196641603);f=x[31737];x[31737]=0;if((f|0)==1){break k}b=hd(b,d);ub(d);d=x[b>>2];x[31737]=0;d=R(173,d|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break d}if(d){x[31737]=0;P(184,b|0,1)|0;d=x[31737];x[31737]=0;if((d|0)==1){break d}x[31737]=0;d=R(203,b|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break d}x[31737]=0;aa(317,a+1298332|0,b|0,d|0,40,0);d=x[31737];x[31737]=0;if((d|0)==1){break d}}x[31737]=0;S(313,e- -64|0,h|0,1146113363);d=x[31737];x[31737]=0;if((d|0)==1){break h}x[31737]=0;d=e+44|0;S(313,d|0,h|0,1229999443);f=x[31737];x[31737]=0;if((f|0)==1){break l}b=hd(b,d);ub(d);x[31737]=0;d=R(198,b|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break j}w[a+480190>>1]=d;i=!(c&2);f=1;G:{while(1){H:{c=f&65535;if(c>>>0>(d&65535)>>>0){break G}d=30;I:{J:{K:{if(y[e+210|0]>=2){x[31737]=0;d=R(198,b|0)|0;g=x[31737];x[31737]=0;if((g|0)==1){break K}}x[31737]=0;S(318,b|0,((c<<5)+a|0)+946304|0,d|0);d=x[31737];x[31737]=0;if((d|0)==1){break K}x[31737]=0;d=e+28|0;O(319,b|0,d|0);g=x[31737];x[31737]=0;if((g|0)==1){break J}x[31737]=0;g=D(c,104)+a|0;j=g+484380|0;O(320,d|0,j|0);c=x[31737];x[31737]=0;if((c|0)==1){break J}d=y[e+210|0];if(d>>>0>=8){x[31737]=0;O(321,b|0,g+484423|0);c=x[31737];x[31737]=0;if((c|0)==1){break J}d=y[e+210|0]}x[31737]=0;P(184,b|0,((d&255)>>>0>1?6:2)|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break J}x[31737]=0;c=e- -64|0;d=R(152,c|0)|0;l=x[31737];x[31737]=0;if((l|0)!=1){x[31737]=0;S(186,e+8|0,c|0,d|0);c=x[31737];x[31737]=0;if((c|0)!=1){break I}}b=N()|0;break i}b=N()|0;break i}b=N()|0;break i}d=e+8|0;c=ic(e+44|0,d);ub(d);l=x[c>>2];x[31737]=0;l=R(173,l|0)|0;m=x[31737];x[31737]=0;if((m|0)!=1){L:{if(i|l^1){break L}d=Xc(d,w[g+484414>>1]&1?16:8,1,0,(y[e+43|0]&12)==4?7:0);x[31737]=0;U(216,d|0,j|0,c|0)|0;d=x[31737];x[31737]=0;if((d|0)!=1){break L}break H}ub(c);f=f+1|0;d=z[a+480190>>1];continue}}break}b=N()|0;ub(c);break i}gg(a);x[a+480204>>2]=12e5;x[a+480208>>2]=24;x[a+480196>>2]=6;x[a+480200>>2]=256;x[a+480228>>2]=48;x[a+480232>>2]=48;x[31737]=0;d=1;U(267,a+1074312|0,114,1)|0;a=x[31737];x[31737]=0;if((a|0)==1){break j}ub(e- -64|0);ub(b);ie(h)}fb=e+272|0;return d|0}b=N()|0;break i}b=N()|0;break c}b=N()|0}ub(e- -64|0);break c}b=N()|0;break c}b=N()|0;break c}b=N()|0;break c}b=N()|0;break c}b=N()|0}ub(k)}ie(h)}Q(b|0);p()}function Apa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,C=0,E=0,F=0;d=fb-288|0;fb=d;xc(b);a:{b:{c:{f=d+192|0;d:{if(!zv(b,f)){break d}if(!GX(f)){break d}if(!Mb(x[b>>2],x[b+8>>2],Bc(FX(f),hb))){break d}j=1;if((c|0)==64){break d}j=0;if(!cd(b,y[d+196|0])){break d}Bd(a,268435456);gg(a);x[a+480208>>2]=4;Lb(a+1074312|0,114,1);f=d+84|0;i=tc(f,15422);Ab(a+1298344|0,i);tb(i);i=tc(f,10298);Ab(a+1298356|0,i);tb(i);E=a+1298404|0,F=x[Fc(f,4)>>2],x[E>>2]=F;i=d+16|0;cf(i,d+198|0,48,3);Cc(f,i);Ab(a+1298308|0,f);tb(f);f=y[d+246|0];w[a+480188>>1]=f+1;x[a+480228>>2]=y[d+249|0];x[a+480204>>2]=D(y[d+250|0],1e4);x[a+480196>>2]=y[d+251|0];while(1){if((e|0)==(f|0)){e:{w[a+480190>>1]=y[d+284|0];e=y[d+286|0]|y[d+287|0]<<8;i=fb-16|0;fb=i;f=d+180|0;x[f>>2]=0;x[f+4>>2]=0;sc(f+8|0);Rd(i+8|0,x[vb(i+4|0,f)>>2]);f:{g:{if(e){x[31737]=0;O(663,f|0,e|0);g=x[31737];x[31737]=0;if((g|0)==1){break g}jD(f,e)}e=i+8|0;Qd(e);ch(e);fb=i+16|0;break f}a=N()|0;ch(i+8|0);Q(a|0);p()}x[31737]=0;i=f;S(658,b|0,f|0,y[d+286|0]|y[d+287|0]<<8);f=x[31737];x[31737]=0;if((f|0)==1){break b}u=Nb(d+168|0);r=Nb(d+156|0);x[31737]=0;U(421,b|0,u|0,y[d+285|0])|0;f=x[31737];x[31737]=0;if((f|0)==1){break c}x[31737]=0;U(421,b|0,r|0,y[d+284|0])|0;f=x[31737];x[31737]=0;if((f|0)==1){break c}s=c&2;t=d+122|0;q=d+90|0;f=0;h:{while(1){e=f;if(e>>>0>=y[d+284|0]){j=1;if(!(c&1)){break e}x[d+68>>2]=0;kj(Xb(x[a+484360>>2],y[a+484376|0]));E=d,F=wb(x[i>>2]),x[E+64>>2]=F;s=a+484344|0;A=wb(x[i+4>>2]);break h}x[31737]=0;f=e+1|0;g=D(f,104)+a|0;k=g+484380|0;O(280,k|0,0);h=x[31737];x[31737]=0;i:{if((h|0)!=1){h=yb(x[r>>2],e);h=y[h|0]|y[h+1|0]<<8|(y[h+2|0]<<16|y[h+3|0]<<24);if(!h){continue}x[31737]=0;h=P(150,b|0,h|0)|0;j=x[31737];x[31737]=0;j:{if((j|0)==1){break j}if(!h){continue}x[31737]=0;h=P(659,b|0,d+84|0)|0;j=x[31737];x[31737]=0;if((j|0)==1){break j}if(!h){continue}j=d+72|0;Ve(j,2,q);x[31737]=0;h=d+16|0;O(219,h|0,j|0);n=x[31737];x[31737]=0;if((n|0)==1){break c}zc(((f<<5)+a|0)+946304|0,h);tb(h);Pk(j,2,t);x[31737]=0;O(219,h|0,j|0);j=x[31737];x[31737]=0;if((j|0)==1){break c}ze(g+484423|0,h);tb(h);h=y[d+134|0];if(h>>>0<=15){w[g+484408>>1]=D(h,17);h=g+484414|0;w[h>>1]=z[h>>1]|32}v[d+16|0]=y[d+135|0];v[d+72|0]=64;E=g+484412|0,F=y[Qb(d+16|0,d+72|0)|0],w[E>>1]=F;x[g+484404>>2]=y[d+137|0]|y[d+138|0]<<8;n=g+484384|0;h=y[d+143|0]|y[d+144|0]<<8|(y[d+145|0]<<16|y[d+146|0]<<24);x[n>>2]=h;o=g+484388|0;j=y[d+147|0]|y[d+148|0]<<8|(y[d+149|0]<<16|y[d+150|0]<<24);x[o>>2]=j;l=y[d+151|0]|y[d+152|0]<<8|(y[d+153|0]<<16|y[d+154|0]<<24);x[k>>2]=l;m=y[d+136|0];if(m&1){h=h>>>1|0;x[n>>2]=h;j=j>>>1|0;x[o>>2]=j;x[k>>2]=l>>>1}k:{if(h>>>0>=j>>>0){break k}g=g+484414|0;h=z[g>>1];w[g>>1]=h|2;if(!(m&2)){break k}w[g>>1]=h|6}_k(k);if(!s){continue}e=yb(x[r>>2],e);e=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);x[31737]=0;P(150,b|0,e+y[d+88|0]|0)|0;e=x[31737];x[31737]=0;if((e|0)!=1){break i}}break c}break c}e=Xc(d+16|0,v[d+136|0]&1?16:8,1,0,1);x[31737]=0;U(216,e|0,k|0,b|0)|0;e=x[31737];x[31737]=0;if((e|0)!=1){continue}break}break c}while(1){k=x[d+64>>2];if(!Ib(k,A)){e=y[a+484376|0];f=x[a+484360>>2];l:{b=x[d+68>>2];c=b&63;m:{if(!c){break m}g=Xb(f,e);b=b>>>6&65535;if(!bj(g,b)){break m}b=z[_b(x[g>>2],b)>>1];f=x[s>>2];x[31737]=0;O(660,Wb(f,b)|0,c|0);b=x[31737];x[31737]=0;if((b|0)==1){break l}e=y[a+484376|0];f=x[a+484360>>2]}a=Xb(f,e);e=wb(x[a>>2]);x[d+84>>2]=e;a=wb(x[a+4>>2]);g=65535;while(1){if(!Ib(e,a)){break e}if(z[e>>1]==65535){n:{if((g&65535)!=65535){break n}x[31737]=0;g=P(368,s|0,64)|0;b=x[31737];x[31737]=0;if((b|0)!=1){break n}break c}w[e>>1]=g}e=x[Md(d+84|0)>>2];continue}}break c}o:{c=y[k+3|0];if(y[k+2|0]>y[d+246|0]|c>>>0>=y[d+285|0]){break o}c=yb(x[u>>2],c);c=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);x[31737]=0;c=P(150,b|0,c|0)|0;f=x[31737];x[31737]=0;p:{if((f|0)!=1){if(!c){break o}x[31737]=0;O(661,b|0,d+84|0);c=x[31737];x[31737]=0;if((c|0)==1){break c}e=y[d+88|0];if(!e){break o}c=y[k|0]|y[k+1|0]<<8;v[d+16|0]=y[d+89|0];v[d+72|0]=y[d+246|0]-y[k+2|0];t=y[Qb(d+16|0,d+72|0)|0];x[d+60>>2]=c+e;E=d,F=x[ad(d+68|0,d+60|0)>>2],x[E+68>>2]=F;x[d+40>>2]=0;x[d+44>>2]=0;x[d+32>>2]=0;x[d+36>>2]=0;x[d+24>>2]=0;x[d+28>>2]=0;x[d+16>>2]=0;x[d+20>>2]=0;g=c&63;q=c>>>6|0;n=0;while(1){if((e&255)>>>0<=n>>>0){break o}e=Xb(x[a+484360>>2],y[a+484376|0]);h=g>>>0>63;q=h+q|0;c=q&65535;if(Zc(x[e>>2],x[e+4>>2])>>>0<=c>>>0){x[31737]=0;O(331,e|0,q+1&65535);f=x[31737];x[31737]=0;if((f|0)==1){break p}x[31737]=0;f=P(368,s|0,64)|0;e=x[31737];x[31737]=0;if((e|0)==1){break p}e=Xb(x[a+484360>>2],y[a+484376|0]);E=_b(x[e>>2],c),F=f,w[E>>1]=F}l=x[a+484344>>2];f=x[a+484348>>2];o=z[_b(x[e>>2],c)>>1];if(!He(l,f,o)){break o}f=0;c=Wb(l,o);l=h?0:g;e=jd(x[c>>2],x[x[c+48>>2]+12>>2],l,y[k+2|0]);q:{while(1){if((f|0)==(t|0)){c=y[d+89|0];if(c>>>0<=t>>>0){break q}x[31737]=0;P(184,b|0,D(c-t|0,5)|0)|0;c=x[31737];x[31737]=0;if((c|0)!=1){break q}break c}x[31737]=0;c=d+72|0;O(662,c|0,b|0);g=x[31737];x[31737]=0;if((g|0)!=1){h=Jc(c);B=$e(c);m=dj(c);C=ec(c);g=0;c=y[d+72|0];if((c-1&255)>>>0<=142){g=(D((c&240)>>>4|0,12)+(c&15)|0)+13|0;v[(d+16|0)+f|0]=g}v[e|0]=g;c=y[h|0];v[e+2|0]=1;v[e+1|0]=c;c=y[B|0];r:{if((c|0)!=255){v[e+4|0]=c;break r}v[e+2|0]=0}c=y[m|0];s:{if(c>>>0>22){break s}v[e+3|0]=y[c+25408|0];h=y[C|0];v[e+5|0]=h;c=e+5|0;t:{switch(y[m|0]-4|0){case 3:v[c|0]=h&3|64;break s;case 4:v[c|0]=h&3|48;break s;case 7:g=x[i>>2];if(oc(g,x[i+4>>2])>>>0<=h>>>0){break s}m=c;c=yb(g,h);c=y[c|0]|y[c+1|0]<<8;v[m|0]=c>>>6;g=Wb(x[a+484344>>2],o);g=jd(x[g>>2],x[x[g+48>>2]+12>>2],l,z[a+480188>>1]-1&65535);v[g+5|0]=c&63;v[g+3|0]=14;break s;case 8:m=c;c=x[d+60>>2];v[m|0]=c>>>6;g=Wb(x[a+484344>>2],o);g=jd(x[g>>2],x[x[g+48>>2]+12>>2],l,z[a+480188>>1]-1&65535);v[g+5|0]=c&63;v[g+3|0]=14;break s;case 10:v[c|0]=h&15|128;break s;case 12:v[d+15|0]=15;E=c,F=y[Qb(c,d+15|0)|0]|208,v[E|0]=F;break s;case 13:v[d+15|0]=15;E=c,F=y[Qb(c,d+15|0)|0]|192,v[E|0]=F;break s;case 14:v[d+15|0]=15;E=c,F=y[Qb(c,d+15|0)|0]|224,v[E|0]=F;break s;case 0:case 16:case 17:if(!(h&15)){break s}g=h&240;if(!g|(g|0)==240){break s}v[c|0]=h|15;break s;case 9:case 18:break t;default:break s}}if(g&255){break s}v[e|0]=y[(d+16|0)+f|0]}e=e+6|0;f=f+1|0;continue}break}break c}g=l+1|0;n=n+1|0;e=y[d+88|0];continue}}break c}break c}Je(d- -64|0);continue}}}else{w[((e<<5)+a|0)+480284>>1]=D(y[(d+e|0)+252|0],17);e=e+1|0;continue}break}vc(r);vc(u);vc(i)}fb=d+288|0;return j|0}a=N()|0;vc(r);vc(u);break a}a=N()|0}vc(i);Q(a|0);p()}function iM(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;i=fb-208|0;fb=i;a:{b:{if(g){rf(i+196|0,f,32);x[31737]=0;U(543,i+184|0,f|0,32)|0;h=x[31737];x[31737]=0;if((h|0)!=1){break b}f=N()|0;break a}Fb(i+196|0);Fb(i+184|0)}c:{d:{e:{f:{g:{h:{i:{j:{if(St(c)){h=x[b+24>>2];j=x[h+484344>>2];if(He(j,x[h+484348>>2],c&65535)){break j}}x[31737]=0;S(1169,a|0,i+196|0,i+184|0);a=x[31737];x[31737]=0;if((a|0)!=1){break i}f=N()|0;break c}c=Wb(j,c);if(!(!((e|0)<0|x[c+12>>2]<=(d|0)|(d|0)<0)&z[h+480188>>1]>e>>>0)){x[31737]=0;S(1169,a|0,i+196|0,i+184|0);a=x[31737];x[31737]=0;if((a|0)!=1){break i}f=N()|0;break c}c=jd(x[c>>2],x[x[c+48>>2]+12>>2],d,e&65535);sf(i+196|0);sf(i+184|0);k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{d=y[c|0];if(!Sc(d)){if(!Ml(d)){break A}}e=y[c+1|0];h=x[b+24>>2];x[31737]=0;j=i+160|0;V(1170,j|0,h|0,d|0,e|0);d=x[31737];x[31737]=0;e=1;if((d|0)==1){break y}x[31737]=0;O(1065,i+172|0,j|0);d=x[31737];x[31737]=0;if((d|0)!=1){break z}f=N()|0;break v}e=0;x[31737]=0;P(36,i+172|0,16811)|0;d=x[31737];x[31737]=0;if((d|0)==1){break x}}x[31737]=0;h=i+172|0;d=P(842,i+196|0,h|0)|0;j=x[31737];x[31737]=0;if((j|0)==1){break w}tb(h);if(e){tb(i+160|0)}e=9984;h=y[c|0];if(!Sc(h)){e=Ml(h)?10294:16811}x[31737]=0;h=P(36,i+172|0,e|0)|0;e=x[31737];x[31737]=0;if((e|0)==1){break u}x[31737]=0;e=P(842,i+184|0,h|0)|0;j=x[31737];x[31737]=0;if((j|0)==1){break t}tb(h);if(f-6>>>0>4294967290){break l}x[31737]=0;h=P(36,i+148|0,18465)|0;j=x[31737];x[31737]=0;if((j|0)==1){break s}x[31737]=0;j=P(842,d|0,h|0)|0;m=x[31737];x[31737]=0;if((m|0)==1){break r}tb(h);x[31737]=0;h=P(36,i+136|0,18465)|0;m=x[31737];x[31737]=0;if((m|0)==1){break q}x[31737]=0;m=P(842,e|0,h|0)|0;k=x[31737];x[31737]=0;if((k|0)==1){break p}tb(h);h=c+1|0;B:{if(y[c+1|0]){x[31737]=0;O(560,i+124|0,h|0);k=x[31737];x[31737]=0;if((k|0)!=1){break B}break d}x[31737]=0;P(36,i+124|0,16816)|0;k=x[31737];x[31737]=0;if((k|0)==1){break d}}x[31737]=0;k=j;j=i+124|0;k=P(842,k|0,j|0)|0;l=x[31737];x[31737]=0;if((l|0)==1){break o}tb(j);h=y[h|0];x[31737]=0;h=P(36,j|0,(h?10817:16816)|0)|0;j=x[31737];x[31737]=0;if((j|0)==1){break n}x[31737]=0;m=P(842,m|0,h|0)|0;j=x[31737];x[31737]=0;if((j|0)!=1){break m}f=N()|0;tb(h);break c}f=N()|0;break c}f=N()|0;break c}f=N()|0;tb(i+172|0);if(!e){break c}}tb(i+160|0);break c}f=N()|0;break c}f=N()|0;tb(h);break c}f=N()|0;break c}f=N()|0;tb(h);break c}f=N()|0;break c}f=N()|0;tb(h);break c}f=N()|0;tb(i+124|0);break c}f=N()|0;break c}tb(h);if(f-9>>>0>4294967287){break l}C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{j=Vg(y[c|0]);O:{if(j){x[31737]=0;l=P(36,i+100|0,18465)|0;h=x[31737];x[31737]=0;if((h|0)==1){break N}h=y[c+4|0];n=y[c+2|0];x[31737]=0;o=i,q=Jj(n,h)&255,x[o+76>>2]=q;n=i+88|0;O(559,n|0,i+76|0);h=x[31737];x[31737]=0;if((h|0)==1){break M}h=0;x[31737]=0;S(1021,i+112|0,l|0,n|0);l=x[31737];x[31737]=0;if((l|0)!=1){break O}f=N()|0;break G}h=y[c+2|0];if(h){h=yR(x[x[x[b+24>>2]+8>>2]+88>>2],h);x[31737]=0;h=U(543,i+100|0,1,h|0)|0;l=x[31737];x[31737]=0;if((l|0)==1){break E}x[31737]=0;l=i+88|0;O(560,l|0,c+4|0);n=x[31737];x[31737]=0;if((n|0)==1){break L}x[31737]=0;S(1021,i+112|0,h|0,l|0);l=x[31737];x[31737]=0;h=1;if((l|0)!=1){break O}f=N()|0;break J}h=0;x[31737]=0;P(36,i+112|0,16815)|0;l=x[31737];x[31737]=0;if((l|0)==1){break e}}x[31737]=0;l=k;k=i+112|0;l=P(842,l|0,k|0)|0;n=x[31737];x[31737]=0;if((n|0)==1){break K}tb(k);if(h){tb(i+88|0);tb(i+100|0)}if(j){tb(i+88|0);tb(i+100|0)}h=5488;if(!Vg(y[c|0])){h=y[c+2|0]?5484:16815}x[31737]=0;h=P(36,i+112|0,h|0)|0;j=x[31737];x[31737]=0;if((j|0)==1){break D}x[31737]=0;j=P(842,m|0,h|0)|0;m=x[31737];x[31737]=0;if((m|0)!=1){break C}f=N()|0;tb(h);break c}f=N()|0;break c}f=N()|0;break F}f=N()|0;break I}f=N()|0;tb(i+112|0);if(!h){break H}}tb(i+88|0)}tb(i+100|0)}if(!j){break c}}tb(i+88|0)}tb(i+100|0);break c}f=N()|0;break c}f=N()|0;break c}tb(h);if(f-13>>>0>4294967283){break l}x[31737]=0;h=P(36,i+76|0,18465)|0;m=x[31737];x[31737]=0;P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{if((m|0)!=1){x[31737]=0;m=P(842,l|0,h|0)|0;k=x[31737];x[31737]=0;if((k|0)==1){break Z}tb(h);x[31737]=0;h=P(36,i- -64|0,18465)|0;k=x[31737];x[31737]=0;if((k|0)==1){break Y}x[31737]=0;j=P(842,j|0,h|0)|0;k=x[31737];x[31737]=0;if((k|0)==1){break X}tb(h);_:{if(Vg(y[c|0])){h=y[c+5|0];k=y[c+3|0];b=0;x[31737]=0;o=i,q=Jj(k,h)&4095,x[o+16>>2]=q;O(1171,i+52|0,i+16|0);h=x[31737];x[31737]=0;if((h|0)!=1){break _}f=N()|0;break c}h=y[c+3|0];if(h){b=xR(x[x[x[b+24>>2]+8>>2]+84>>2],h);x[31737]=0;b=U(543,i+40|0,1,b|0)|0;h=x[31737];x[31737]=0;if((h|0)==1){break W}x[31737]=0;h=i+28|0;O(560,h|0,c+5|0);k=x[31737];x[31737]=0;if((k|0)==1){break V}x[31737]=0;S(1021,i+52|0,b|0,h|0);h=x[31737];x[31737]=0;b=1;if((h|0)!=1){break _}f=N()|0;break S}b=0;x[31737]=0;P(36,i+52|0,16811)|0;h=x[31737];x[31737]=0;if((h|0)==1){break U}}x[31737]=0;h=i+52|0;P(842,m|0,h|0)|0;m=x[31737];x[31737]=0;if((m|0)==1){break T}tb(h);if(b){tb(i+28|0);tb(i+40|0)}b=11177;if(!Vg(y[c|0])){b=y[c+3|0]?11177:16811}x[31737]=0;b=P(36,i+52|0,b|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break Q}x[31737]=0;P(842,j|0,b|0)|0;c=x[31737];x[31737]=0;if((c|0)!=1){break P}f=N()|0;tb(b);break c}f=N()|0;break c}f=N()|0;tb(h);break c}f=N()|0;break c}f=N()|0;tb(h);break c}f=N()|0;break c}f=N()|0;break R}f=N()|0;break c}f=N()|0;tb(i+52|0);if(!b){break c}}tb(i+28|0)}tb(i+40|0);break c}f=N()|0;break c}tb(b);if(!f){break k}}$:{aa:{ba:{ca:{b=Yc(x[d+4>>2],y[d+11|0]);da:{if(b>>>0>f>>>0){x[31737]=0;b=i+16|0;V(122,b|0,d|0,0,f|0);c=x[31737];x[31737]=0;if((c|0)!=1){Ab(d,b);tb(b);break da}f=N()|0;break c}if(!g){break da}x[31737]=0;b=U(543,i+16|0,f-b|0,32)|0;c=x[31737];x[31737]=0;if((c|0)==1){break ca}x[31737]=0;P(842,d|0,b|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break ba}tb(b)}b=Yc(x[e+4>>2],y[e+11|0]);if(b>>>0<=f>>>0){break $}x[31737]=0;b=i+4|0;V(122,b|0,e|0,0,f|0);c=x[31737];x[31737]=0;if((c|0)==1){break aa}Ab(e,b);tb(b);break k}f=N()|0;break c}f=N()|0;tb(b);break c}f=N()|0;break c}if(!g){break k}x[31737]=0;b=U(543,i+4|0,f-b|0,32)|0;c=x[31737];x[31737]=0;if((c|0)==1){break h}x[31737]=0;P(842,e|0,b|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break g}tb(b)}x[31737]=0;S(1169,a|0,d|0,e|0);a=x[31737];x[31737]=0;if((a|0)==1){break f}}tb(i+184|0);tb(i+196|0);fb=i+208|0;return}f=N()|0;break c}f=N()|0;tb(b);break c}f=N()|0;break c}f=N()|0;break c}f=N()|0}tb(i+184|0)}tb(i+196|0);Q(f|0);p()}function eta(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0;d=fb-256|0;fb=d;xc(b);f=fb-16|0;fb=f;i=d+99|0;H_(f+8|0,i);h=x[f+12>>2];lc(f,x[b>>2],x[b+8>>2],x[f+8>>2],x[f+12>>2]);j=x[f+4>>2];if((j|0)==(h|0)){Vb(b,x[f+12>>2])}fb=f+16|0;f=(h|0)==(j|0);if(!f){G_(i)}a:{if(!f){break a}if(!I_(i)){break a}e=1;if((c|0)==64){break a}Bd(a,x[((y[d+215|0]|y[d+216|0]<<8)<<2)+24800>>2]);x[a+480208>>2]=x[a+480208>>2]|16777216;e=d+36|0;f=tc(e,13187);Ab(a+1298344|0,f);tb(f);f=tc(e,10329);Ab(a+1298356|0,f);tb(f);i=fb-16|0;fb=i;f=d+4|0;h=tc(i+4|0,4389);_c(f,h);tb(h);fb=i+16|0;x[31737]=0;V(230,e|0,f|0,y[d+178|0],d+175|0);i=x[31737];x[31737]=0;b:{if((i|0)!=1){Ab(a+1298368|0,e);tb(e);Eb(f);bi(a+1298392|0,((y[d+215|0]|y[d+216|0]<<8)<<2)+24848|0);bi(a+1298380|0,x[((y[d+215|0]|y[d+216|0]<<8)<<2)+24896>>2]);t=a+1298404|0,u=x[Fc(e,4)>>2],x[t>>2]=u;Ve(f,2,d+103|0);Cc(e,f);Ab(a+1298308|0,e);tb(e);Ve(f,2,d+135|0);Cc(e,f);c:{if(!Ld(e,9766)){x[31737]=0;S(259,f|0,4,e|0);e=x[31737];x[31737]=0;if((e|0)==1){break c}Ab(a+1298320|0,f);tb(f)}tb(d+36|0);w[a+480188>>1]=32;d:{while(1){if((g|0)!=32){f=(g<<5)+a|0;i=f+480280|0;We(i);e=y[(d+g|0)+180|0];e:{if(e>>>0<=15){x[d+36>>2]=e<<4|8;x[d+4>>2]=256;t=f+480284|0,u=x[ud(d+36|0,d+4|0)>>2],w[t>>1]=u;break e}if((e|0)!=16){if((e|0)!=255){break e}w[a+480188>>1]=g;break d}w[f+480284>>1]=128;x[i>>2]=256}g=g+1|0;continue}break}g=z[a+480188>>1]}e=0;if(!(g&65535)){break a}x[d+36>>2]=y[d+212|0]<<2;x[d+4>>2]=256;t=a,u=x[Gb(d+36|0,d+4|0)>>2],x[t+480200>>2]=u;x[a+480196>>2]=y[d+213|0];x[a+480204>>2]=D(y[d+214|0],1e4);if(cd(b,y[d+217|0]|y[d+218|0]<<8|(y[d+219|0]<<16|y[d+220|0]<<24))){fk(Xb(x[a+484360>>2],y[a+484376|0]),b,y[d+221|0]+1|0,255,254)}if(!cd(b,y[d+227|0]|y[d+228|0]<<8|(y[d+229|0]<<16|y[d+230|0]<<24))){break a}g=y[d+235|0]+1|0;w[a+480190>>1]=g;l=d+68|0;i=1;while(1){f:{g:{j=i&65535;if(j>>>0>(g&65535)>>>0){break g}e=fb-16|0;fb=e;f=d+36|0;bc(e+8|0,f,62);g=x[e+12>>2];lc(e,x[b>>2],x[b+8>>2],x[e+8>>2],x[e+12>>2]);h=x[e+4>>2];if((h|0)==(g|0)){Vb(b,x[e+12>>2])}fb=e+16|0;e=(g|0)==(h|0);if(!e){Rb(f,0,62)}if(!e){break g}g=0;e=D(j,104)+a|0;k=e+484380|0;ld(k,0);h=d+24|0;Ve(h,2,f);f=d+4|0;Cc(f,h);zc(((j<<5)+a|0)+946304|0,f);tb(f);Pk(h,2,l);Cc(f,h);ze(e+484423|0,f);tb(f);f=y[d+94|0]|y[d+95|0]<<8;x[e+484404>>2]=f;if(!En(x[a+480180>>2])){break f}while(1){if((g|0)==16){break f}if((f|0)==z[(g<<1)+24944>>1]){v[e+484417|0]=g<<4;break f}else{g=g+1|0;continue}}}h:{if(!(c&2)){break h}if(!cd(b,y[d+231|0]|y[d+232|0]<<8|(y[d+233|0]<<16|y[d+234|0]<<24))){break h}g=1;while(1){e=g&65535;if(e>>>0>z[a+480190>>1]){break h}e=D(e,104)+a|0;fg(Xc(d+36|0,w[e+484414>>1]&1?16:8,1,0,1),e+484380|0,b);g=g+1|0;continue}}n=a+484344|0;Vf(n,y[d+226|0]+1|0);j=LD(wr(a));cd(b,y[d+222|0]|y[d+223|0]<<8|(y[d+224|0]<<16|y[d+225|0]<<24));s=c&1;h=0;l=1;i:{j:{k:{while(1){if(y[d+226|0]<h>>>0){if(!(z[a+480188>>1]==4&l)|x[a+480180>>2]!=1){break k}c=x[a+480208>>2]|8454144;break j}l:{e=hh(b);if(e>>>0>=3){c=d+4|0;fe(c,b,e-2|0);i=ic(d+36|0,c);ub(c);m:{if(!s){break m}c=x[i>>2];x[31737]=0;c=R(173,c|0)|0;e=x[31737];x[31737]=0;if((e|0)==1){break l}if(!c){break m}x[31737]=0;c=U(197,n|0,h&65535,64)|0;e=x[31737];x[31737]=0;if((e|0)==1){break l}k=0;if(!c){break m}while(1){if((k|0)==64){break m}c=Wb(x[n>>2],h);bf(d+4|0,x[c>>2],x[x[c+48>>2]+12>>2],k);n:{o:while(1){x[31737]=0;c=R(198,i|0)|0;e=x[31737];x[31737]=0;if((e|0)==1){break i}if(!c){break n}e=c&31;if(e>>>0>=z[a+480188>>1]){break n}g=Wc(x[d+4>>2],e);if(c&32){x[31737]=0;e=d+24|0;O(199,e|0,i|0);f=x[31737];x[31737]=0;if((f|0)==1){break i}f=Jc(e);e=y[d+24|0];if(e){e=(e&127)-1|0;v[d+24|0]=e;e=(D((e&240)>>>4|0,12)+(e&15)|0)+13|0;v[g|0]=e;l=KD(e)&l}v[g+1|0]=y[f|0]}if(!(c&64)){continue}v[g+2|0]=0;v[g+3|0]=0;o=g+5|0;while(1){c=x[i>>2];x[31737]=0;c=U(151,c|0,x[d+44>>2],2)|0;e=x[31737];x[31737]=0;if((e|0)==1){break i}if(!c){continue o}q=y[g+5|0];c=y[g+3|0];x[31737]=0;e=d+24|0;O(199,e|0,i|0);f=x[31737];x[31737]=0;if((f|0)!=1){f=y[Jc(e)|0];v[g+5|0]=f;r=y[d+24|0];e=y[(r&31)+24976|0];v[g+3|0]=e;p:{q:{r:{s:{t:{switch(e-2|0){case 0:case 1:if(f>>>0<224){break p}m=223;if(x[a+480180>>2]!=1){break s}break p;case 11:v[d+3|0]=64;e=y[Qb(o,d+3|0)|0];v[o|0]=e;if(!Wv(x[j+88>>2],1)){break p}v[g+4|0]=e;v[g+2|0]=1;v[g+5|0]=q;v[g+3|0]=c;e=c;break r;case 17:u:{switch(((f&240)>>>4|0)-8|0){case 0:v[g+3|0]=2;v[g+5|0]=f&15|224;break p;case 1:v[g+3|0]=3;v[g+5|0]=f&15|224;break p;default:break u}}if($i(x[j+84>>2],19)){break p}sw(g);e=y[g+3|0];break r;case 13:c=x[j+84>>2];if($i(c,15)){break p}if(!$i(c,19)){break p}v[g+3|0]=19;v[g+5|0]=f&15|144;break p;case 18:m=145;if((f|0)==1){break s}if((f&240)==128){if($i(x[j+84>>2],20)){break q}v[g+3|0]=19;break p}v[g+3|0]=0;break p;case 4:case 5:break t;default:break r}}m=f&240;if(!m){break p}}v[o|0]=m}if((e&255)!=20){break p}}e=y[g+5|0];if(y[g+2|0]|(e&240)!=128){break p}v[g+2|0]=2;v[g+5|0]=q;v[g+3|0]=c;v[g+4|0]=((e<<6&960|8)>>>0)/15}if(!(r&32)){continue o}continue}break}break}break i}k=k+1|0;continue}}ub(i)}h=h+1|0;continue}break}break i}c=x[a+480208>>2]&-8454145}x[a+480208>>2]=c;e=1;if(!(y[d+240|0]|y[d+241|0]<<8|(y[d+242|0]<<16|y[d+243|0]<<24))){break a}if(!cd(b,y[d+236|0]|y[d+237|0]<<8|(y[d+238|0]<<16|y[d+239|0]<<24))){break a}_D(a+1298332|0,b,y[d+240|0]|y[d+241|0]<<8|(y[d+242|0]<<16|y[d+243|0]<<24),4);break a}g=N()|0;ub(i);break b}w[e+484412>>1]=64;f=y[d+81|0]|y[d+82|0]<<8|(y[d+83|0]<<16|y[d+84|0]<<24);x[k>>2]=f;g=y[d+93|0];if(g&2){h=e+484414|0;w[h>>1]=z[h>>1]|1;x[k>>2]=f>>>1}x[e+484384>>2]=y[d+85|0]|y[d+86|0]<<8|(y[d+87|0]<<16|y[d+88|0]<<24);x[e+484388>>2]=(y[d+89|0]|y[d+90|0]<<8|(y[d+91|0]<<16|y[d+92|0]<<24))-1;if(g&1){f=e+484414|0;w[f>>1]=z[f>>1]|2}v:{w:{if(!(g&4)){break w}f=y[d+96|0];if((f|0)==255){break w}v[d+4|0]=f;v[d+24|0]=64;t=e+484410|0,u=y[Qb(d+4|0,d+24|0)|0]<<2,w[t>>1]=u;break v}f=e+484414|0;w[f>>1]=z[f>>1]|32768}x:{if(g&8){g=e+484414|0;f=z[g>>1]|32;w[g>>1]=f;j=e+484408|0;e=y[d+97|0];if(e>>>0<=15){x[d+24>>2]=256;x[d+4>>2]=e<<4|8;h=x[ud(d+4|0,d+24|0)>>2]}else{h=128}w[j>>1]=h;w[g>>1]=f&65279|((e|0)==16)<<8;break x}w[e+484408>>1]=128}i=i+1|0;g=z[a+480190>>1];continue}}g=N()|0;tb(d+36|0);break b}g=N()|0;Eb(d+4|0)}Q(g|0);p()}fb=d+256|0;return e|0}function B7(a,b,c,d,e,f,g,h,i,j,k){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,w=0,z=0,A=0,B=0,C=0,D=0;l=fb-528|0;fb=l;x[l+520>>2]=k;x[l+524>>2]=b;a:{b:{if(li(a,l+524|0)){x[f>>2]=x[f>>2]|4;a=0;break b}x[l+72>>2]=1232;b=l+72|0;t=Be(l+104|0,l+112|0,b);m=x[t>>2];x[l+100>>2]=m;x[l+96>>2]=m+400;u=Fb(b);q=Fb(l+60|0);n=Fb(l+48|0);o=Fb(l+36|0);s=Fb(l+24|0);b=x[d>>2];x[31737]=0;ka(1242,c|0,b|0,l+92|0,l+88|0,l+84|0,u|0,q|0,n|0,o|0,l+20|0);b=x[31737];x[31737]=0;if((b|0)!=1){x[j>>2]=x[i>>2];A=e&512;w=x[l+20>>2];e=0;while(1){c:{d:{e:{f:{g:{if((e|0)==4){break g}x[31737]=0;b=P(1216,a|0,l+524|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break a}if(b){break g}h:{i:{j:{k:{l:{switch(v[(l+92|0)+e|0]){case 1:if((e|0)==3){break c}b=x[a>>2];x[31737]=0;b=R(1217,b|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break a}x[31737]=0;b=U(1243,h|0,1,b|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break a}if(b){x[31737]=0;O(1244,l+12|0,a|0);b=x[31737];x[31737]=0;if((b|0)!=1){x[31737]=0;O(35,s|0,x[l+12>>2]);b=x[31737];x[31737]=0;if((b|0)!=1){break k}}break a}x[f>>2]=x[f>>2]|4;a=0;break d;case 4:break h;case 2:break i;case 3:break j;case 0:break l;default:break c}}if((e|0)==3){break c}}while(1){x[31737]=0;b=P(1216,a|0,l+524|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break a}if(b){break c}b=x[a>>2];x[31737]=0;b=R(1217,b|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break a}x[31737]=0;b=U(1243,h|0,1,b|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break a}if(!b){break c}x[31737]=0;O(1244,l+12|0,a|0);b=x[31737];x[31737]=0;if((b|0)!=1){x[31737]=0;O(35,s|0,x[l+12>>2]);b=x[31737];x[31737]=0;if((b|0)!=1){continue}}break}break a}m:{if(!Cb(x[n+4>>2],y[n+11|0])){break m}b=x[a>>2];x[31737]=0;b=R(1217,b|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break a}if(x[Vd(n,0)>>2]!=(b|0)){break m}x[31737]=0;R(1219,a|0)|0;b=x[31737];x[31737]=0;if((b|0)==1){break a}v[g|0]=0;r=Cb(x[n+4>>2],y[n+11|0])>>>0>1?n:r;break c}n:{o:{k=x[o+4>>2];b=y[o+11|0];if(Cb(k,b)){b=x[a>>2];x[31737]=0;b=R(1217,b|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break a}if(x[Vd(o,0)>>2]==(b|0)){break o}k=x[o+4>>2];b=y[o+11|0]}c=Cb(x[n+4>>2],y[n+11|0]);if(!c){break n}if(!Cb(k,b)){break n}x[f>>2]=x[f>>2]|4;a=0;break d}x[31737]=0;R(1219,a|0)|0;b=x[31737];x[31737]=0;if((b|0)==1){break a}v[g|0]=1;r=Cb(x[o+4>>2],y[o+11|0])>>>0>1?o:r;break c}b=Cb(k,b);if(!(b|c)){break c}v[g|0]=!b;break c}if(!((e|0)==2&y[l+95|0]!=0|(e>>>0<2|r|A))){r=0;break c}c=vb(l+12|0,zd(q));p:{if(!e|y[(e+l|0)+91|0]>1){break p}q:{while(1){b=sl(q);d=x[c>>2];if(!Ib(d,b)){break q}b=x[d>>2];x[31737]=0;b=U(1243,h|0,1,b|0)|0;d=x[31737];x[31737]=0;if((d|0)!=1){if(!b){break q}Je(c);continue}break}break a}b=zd(q);b=Gv(x[c>>2],b);if(Cb(x[s+4>>2],y[s+11|0])>>>0>=b>>>0){d=Jk(sl(s),0-b|0);k=sl(s);z=zd(q);b=fb-16|0;fb=b;x[b+8>>2]=z;x[b+12>>2]=d;while(1){r:{z=Ib(d,k);if(!z){break r}if(!mc(x[d>>2],x[x[b+8>>2]>>2])){break r}d=Je(b+12|0);Je(b+8|0);d=x[d>>2];continue}break}fb=b+16|0;if(z^1){break p}}C=c,D=x[vb(l+8|0,zd(q))>>2],x[C>>2]=D}x[l+8>>2]=x[c>>2];s:{while(1){b=sl(q);if(!Ib(x[l+8>>2],b)){break s}x[31737]=0;b=P(1216,a|0,l+524|0)|0;c=x[31737];x[31737]=0;t:{if((c|0)==1){break t}if(b){break s}b=x[a>>2];x[31737]=0;b=R(1217,b|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break t}if(x[x[l+8>>2]>>2]!=(b|0)){break s}x[31737]=0;R(1219,a|0)|0;b=x[31737];x[31737]=0;if((b|0)==1){break a}Je(l+8|0);continue}break}break a}if(!A){break c}b=sl(q);if(!Ib(x[l+8>>2],b)){break c}x[f>>2]=x[f>>2]|4;a=0;break d}b=0;z=x[l+84>>2];c=m;u:{while(1){v:{x[31737]=0;d=P(1216,a|0,l+524|0)|0;k=x[31737];x[31737]=0;if((k|0)==1){break v}if(d){break u}d=x[a>>2];x[31737]=0;k=R(1217,d|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break a}x[31737]=0;d=U(1243,h|0,64,k|0)|0;B=x[31737];x[31737]=0;if((B|0)==1){break a}w:{if(d){d=x[j>>2];if((d|0)==x[l+520>>2]){x[31737]=0;S(1245,i|0,j|0,l+520|0);d=x[31737];x[31737]=0;if((d|0)==1){break a}d=x[j>>2]}x[j>>2]=d+4;x[d>>2]=k;b=b+1|0;break w}if(!Cb(x[u+4>>2],y[u+11|0])|!b|(k|0)!=(z|0)){break u}if(x[l+96>>2]==(m|0)){x[31737]=0;S(1238,t|0,l+100|0,l+96|0);c=x[31737];x[31737]=0;if((c|0)==1){break a}m=x[l+100>>2]}c=m+4|0;x[l+100>>2]=c;x[m>>2]=b;m=c;b=0}x[31737]=0;R(1219,a|0)|0;d=x[31737];x[31737]=0;if((d|0)!=1){continue}}break}break a}if(!b|x[t>>2]==(c|0)){break f}if(x[l+96>>2]==(c|0)){x[31737]=0;S(1238,t|0,l+100|0,l+96|0);c=x[31737];x[31737]=0;if((c|0)==1){break a}c=x[l+100>>2]}m=c+4|0;x[l+100>>2]=m;x[c>>2]=b;break e}x[l+20>>2]=w;x:{if(!r){break x}k=1;while(1){if(Cb(x[r+4>>2],y[r+11|0])>>>0<=k>>>0){break x}x[31737]=0;b=P(1216,a|0,l+524|0)|0;c=x[31737];x[31737]=0;y:{if((c|0)==1){break y}z:{if(!b){b=x[a>>2];x[31737]=0;b=R(1217,b|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break y}if(x[Vd(r,k)>>2]==(b|0)){break z}}x[f>>2]=x[f>>2]|4;a=0;break d}x[31737]=0;R(1219,a|0)|0;b=x[31737];x[31737]=0;k=k+1|0;if((b|0)!=1){continue}}break}break a}a=1;b=x[t>>2];if((b|0)==(m|0)){break d}a=0;x[l+12>>2]=0;Xf(u,b,m,l+12|0);if(x[l+12>>2]){x[f>>2]=x[f>>2]|4;break d}a=1;break d}m=c}A:{if((w|0)<=0){break A}x[31737]=0;b=P(1216,a|0,l+524|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break a}B:{if(!b){b=x[a>>2];x[31737]=0;b=R(1217,b|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break a}if(x[l+88>>2]==(b|0)){break B}}x[f>>2]=x[f>>2]|4;a=0;break d}x[31737]=0;b=R(1219,a|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break a}while(1){if((w|0)<=0){w=0;break A}x[31737]=0;c=P(1216,b|0,l+524|0)|0;d=x[31737];x[31737]=0;C:{if((d|0)==1){break C}D:{if(!c){c=x[b>>2];x[31737]=0;c=R(1217,c|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break C}x[31737]=0;c=U(1243,h|0,64,c|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break C}if(c){break D}}x[f>>2]=x[f>>2]|4;a=0;break d}if(x[j>>2]==x[l+520>>2]){x[31737]=0;S(1245,i|0,j|0,l+520|0);c=x[31737];x[31737]=0;if((c|0)==1){break C}}c=x[b>>2];x[31737]=0;c=R(1217,c|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break C}d=x[j>>2];x[j>>2]=d+4;x[d>>2]=c;x[31737]=0;R(1219,b|0)|0;c=x[31737];x[31737]=0;w=w-1|0;if((c|0)!=1){continue}}break}break a}if(x[j>>2]!=x[i>>2]){break c}x[f>>2]=x[f>>2]|4;a=0}Ub(s);Ub(o);Ub(n);Ub(q);tb(u);Lc(t);break b}e=e+1|0;continue}}break a}fb=l+528|0;return a|0}a=N()|0;Ub(s);Ub(o);Ub(n);Ub(q);tb(u);Lc(t);Q(a|0);p()}function tT(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=E(0),s=0,t=0,u=0,C=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=E(0),R=E(0),S=0,T=0,U=E(0),V=0;j=fb-48|0;fb=j;Nk(b+223848|0,Vj(e,Li(e,Wo(e),0))+1|0);re(j+40|0,x[b+223848>>2],x[b+223852>>2]);gc(j+32|0,e,Vj(e,Li(e,Wo(e),0)));F=x[j+32>>2];G=x[j+36>>2];g=fb-16|0;fb=g;H=a+906300|0;p=a+1074312|0;o=D(c,872)+b|0;I=o+1415|0;J=o+1304|0;K=o+1392|0;u=o+1368|0;s=o+1364|0;L=o+1336|0;M=o+1308|0;N=o+1300|0;O=o+1280|0;P=o+1402|0;m=o+1466|0;Q=E(y[m|0]);R=E(f>>>0);C=o+616|0;k=x[o+1272>>2];q=1;l=255;while(1){if((n|0)!=(G|0)&A[j+44>>2]>i>>>0){h=y[xb(F,n)|0];e=h-48|0;a:{b:{if((e&255)>>>0<=9){break b}if((h-65&255)>>>0<=5){e=h-55|0;break b}c:{d:{e:{switch(h-97|0){case 2:f:{e=vm(a,b,c,3,0)-1|0;if((e&255)>>>0>249){break f}e=x[vd(H,e)>>2];if(!e){break f}e=gB(e,46008,43064);if(!e){break f}e=ib[x[x[e>>2]+192>>2]](e,C,c)|0;h=(e|0)!=255;e=h?e:0;if(h|!k){break b}break c}if(k){break c}e=0;break b;case 21:g:{if(!Ob(p,28)){e=0;if(!Ob(p,1)){break g}}e=w[K>>1]}h=D(x[u>>2],x[s>>2]);e=D(x[a+1074456>>2],e+x[J>>2]|0);e=Yb((Gc(Tua(Sua(h,h>>31,e,e>>31),hb,1048576,0),hb)|0)/2|0,1,127);break d;case 20:e=D(x[u>>2],x[s>>2]);h=e;t=e>>31;e=D(x[a+1074456>>2],x[L>>2]);e=Yb((Gc(Tua(Sua(h,t,e,e>>31),hb,67108864,0),hb)|0)/2|0,1,127);break d;case 23:x[g>>2]=x[M>>2]/2;x[g+12>>2]=127;e=x[ud(g,g+12|0)>>2];break d;case 24:x[g>>2]=x[N>>2]/2;x[g+12>>2]=127;e=x[ud(g,g+12|0)>>2];break d;case 0:e=0;if(!k){break d}h=z[k+28>>1];if(!h){break d}e=h-1>>>7&127;break d;case 1:e=0;if(!k){break d}h=z[k+28>>1];if(!h){break d}e=h-1&127;break d;case 14:e=x[O>>2]>>>8|0;break d;case 7:e=(z[a+480188>>1]<=c>>>0?y[P|0]-1|0:c)&127;break d;case 12:e=y[o+704|0]>>>7|0;break d;case 15:e=0;if(!k){break d}h=y[k+30|0];if(!h){break d}e=h-1&127;break d;case 25:h:{if(!d|v[m|0]<0){break h}i:{if(i>>>0<3){break i}e=x[j+40>>2];if(y[xb(e,i-3|0)|0]!=240){break i}if(y[xb(e,i-2|0)|0]>239){break h}}r=Jq(b,Q,R);j:{if(r<E(4294967296)&r>=E(0)){e=~~r>>>0;break j}e=0}v[m|0]=e;l=128;break d}l=(l&255)==255?f:l;e=f;break d;case 18:k:{if(!i){e=0;break k}h=x[j+40>>2];e=i;while(1){e=e-1|0;t=xb(h,e);if(!e){break k}if(y[t|0]!=240){continue}break}}if(i-e>>>0<5){break a}t=x[j+40>>2];if(y[xb(t,e)|0]!=240){break a}e=e+5|0;h=0;while(1){if((e|0)!=(i|0)){h=y[xb(t,e)|0]+h|0;e=e+1|0;continue}break};e=0-h&127;break d;case 13:break e;default:break a}}e=y[I|0];e=Sc(e)?e-1|0:0}h=q^-1;q=1;i=(h&1)+i|0;S=xb(x[j+40>>2],i),T=e,v[S|0]=T;i=i+1|0;break a}e=z[C+786>>1];h=y[k+31|0];e=(e?e-1|0:c)&15;l:{if((h|0)==17){break l}e=Qj(h)?h-1&15:0}}h=xb(x[j+40>>2],i);v[h|0]=(q&1?0:y[h|0]<<4)|e;q=q^1;i=(q&1)+i|0}n=n+1|0;continue}else{if(l<<24>>24>=0){v[m|0]=l}bc(g,x[j+40>>2],((q^-1)&1)+i|0);e=x[g+4>>2];x[j+40>>2]=x[g>>2];x[j+44>>2]=e;fb=g+16|0}break}o=x[j+44>>2];i=0;m:while(1){q=0;while(1){k=q&255;e=i;n:{o:{p:{q:{while(1){if(A[j+44>>2]<=e>>>0){break n}f=x[j+40>>2];m=xb(f,e);g=v[m|0];if((g|0)==-16){if(o-e>>>0>=4){i=4;if((y[xb(f,e+1|0)|0]&254)==240){break o}}i=e;r:{while(1){i=i+1|0;if(o>>>0<=i>>>0){break r}if(y[xb(f,i)|0]!=247){continue}break}i=(i-e|0)+1|0;if(i){break o}}S=xb(f,o),T=247,v[S|0]=T;o=o+1|0;i=o-e|0;break p}if((g|0)<0){break q}if(k){e=e-1|0;S=xb(f,e),T=q,v[S|0]=T;continue}break}i=i+1|0;continue m}S=j,T=CV(g&255),x[S+20>>2]=T;x[j+28>>2]=o-e;i=x[Gb(j+20|0,j+28|0)>>2]}if(!i){break n}f=x[j+40>>2];m=xb(f,e)}u=y[m|0];Cr(j+20|0,f,x[j+44>>2],e,i);f=gc(j+12|0,x[j+20>>2],x[j+24>>2]);m=x[f+4>>2];x[j>>2]=x[f>>2];x[j+4>>2]=m;m=fb-32|0;fb=m;n=x[j+4>>2];s:{if(!n){break s}k=Gd(y[b+223884|0]);t:{g=x[j>>2];h=xb(g,0);f=y[h|0]-250|0;if(f>>>0>5|!(1<<f&37)){break t}l=z[a+480188>>1];f=0;while(1){if((f|0)==(l|0)){break t}p=(D(f,872)+b|0)+1453|0;v[p|0]=127;v[p+1|0]=0;f=f+1|0;continue}}u:{if((n|0)!=4|y[h|0]!=240){break u}l=y[xb(g,1)|0];if((l&254)!=240){break u}n=D(c,872)+b|0;h=n+616|0;p=xb(g,2);s=y[xb(g,3)|0];f=s<<24>>24;C=(l|0)!=241&(f|0)>=0;p=y[p|0];if(!(!C|p)){g=n+1453|0;if(d){f=zh(Jq(b,E(y[g|0]),E((f&255)>>>0)))}v[g|0]=f;v[n+1412|0]=0;f=Nq(a,h,!(x[n+704>>2]&32768),256);if((f|0)<0|!(y[n+705|0]&2)){break s}g=x[a+1298300>>2];if(k|Dd(g)^1){break s}Tq(g,c,f>>>2&255,1);break s}g=p<<24>>24;if(C&(g|0)==1){g=D(c,872)+b|0;k=g+1454|0;if(d){f=zh(Jq(b,E(y[k|0]),E((f&255)>>>0)))}v[k|0]=f;v[g+1411|0]=0;Nq(a,h,!(x[g+704>>2]&32768),256);break s}if(!((l|0)==241|(g|0)!=2)){if(f>>>0>31){break s}g=D(c,872)+b|0;v[g+1461|0]=(f&240)>>>4;Nq(a,h,!(x[g+704>>2]&32768),256);break s}if(!((l|0)==241|(g|0)!=3)){h=(f|0)<0;f=vm(a,b,c,3,0)-1|0;if(h|(f&255)>>>0>249){break s}v[m+24|0]=f;g=a+906300|0;l=f&255;f=x[vd(g,l)>>2];if(!f){break s}r=E(E(127-s|0)/E(127));if(k){l=0;g=fb-16|0;fb=g;S=g,T=Xj(m+24|0),x[S+4>>2]=T;f=fb-16|0;fb=f;k=b+223860|0;h=fB(k,f+12|0,y[m+24|0]);n=x[h>>2];if(!n){l=fb-16|0;fb=l;n=ec(k);p=Bh(f,Ec(24),Mg(l+8|0,n));n=x[p>>2];s=y[x[g+4>>2]];x[n+20>>2]=0;v[n+16|0]=s;S=ec(p),T=1,v[S+4|0]=T;fb=l+16|0;$g(k,x[f+12>>2],h,x[f>>2]);n=me(f);dm(f);l=1}_g(g+8|0,x[vb(f,n)>>2],l);fb=f+16|0;f=td(x[g+8>>2]);fb=g+16|0;B[f+4>>2]=r;break s}if(!d){Hu(x[f+20>>2],r);break s}g=vd(g,l);Hu(x[f+20>>2],Jq(b,B[g+144>>2],r));break s}l=(l|0)!=241;if(l&(g|0)>=0){break s}n=vm(a,b,c,3,0)-1|0;if((f|0)<0|(n&255)>>>0>249){break s}g=x[vd(a+906300|0,n&255)>>2];if(!g){break s}l=l?p&127:p+128|0;r=E(E((f&255)>>>0)/E(127));if(k){S=JT(b+223872|0,_S(m+24|0,n,l)),U=r,B[S>>2]=U;break s}f=x[g>>2];if(!d){ib[x[f+44>>2]](g,l,r);break s}T=g,V=l,U=Jq(b,E(ib[x[f+48>>2]](g,l)),r),S=x[x[g>>2]+44>>2],ib[S](T|0,V|0,E(U));break s}if(k){break s}k=z[a+480188>>1];v:{if(k>>>0>c>>>0){f=c+1|0;break v}f=z[(D(c,872)+b|0)+1402>>1];if(!f){break s}}if(y[(D(c,872)+b|0)+707|0]&2|k>>>0<(f&65535)>>>0){break s}f=vm(a,b,c,3,0)-1|0;if(f>>>0>249){break s}f=x[vd(a+906300|0,f)>>2];if(!f){break s}k=y[h|0];if((k|0)==240){lf(m+16|0,x[j>>2],x[j+4>>2]);g=x[x[f>>2]+72>>2];k=x[m+20>>2];x[m>>2]=x[m+16>>2];x[m+4>>2]=k;ib[g|0](f,m)|0;break s}S=m,V=CV(k),x[S+24>>2]=V;x[m+12>>2]=n;k=m+24|0;l=x[Gb(k,m+12|0)>>2];x[m+24>>2]=0;yc(k,g,l);ib[x[x[f>>2]+68>>2]](f,x[m+24>>2])|0}fb=m+32|0;q=u>>>0<240?u:q;i=e+i|0;continue}break}break}fb=j+48|0}function I7(a,b,c,d,e,f,g,h,i,j,k){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,w=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;l=fb-528|0;fb=l;x[l+520>>2]=k;x[l+524>>2]=b;a:{b:{if(sh(a,l+524|0)){x[f>>2]=x[f>>2]|4;a=0;break b}x[l+76>>2]=1232;b=l+76|0;t=Be(l+104|0,l+112|0,b);m=x[t>>2];x[l+100>>2]=m;x[l+96>>2]=m+400;u=Fb(b);q=Fb(l- -64|0);n=Fb(l+52|0);o=Fb(l+40|0);s=Fb(l+28|0);b=x[d>>2];x[31737]=0;ka(1235,c|0,b|0,l+92|0,l+91|0,l+90|0,u|0,q|0,n|0,o|0,l+24|0);b=x[31737];x[31737]=0;if((b|0)!=1){x[j>>2]=x[i>>2];A=e&512;w=x[l+24>>2];B=y[l+95|0];C=y[l+91|0];D=y[l+90|0];d=m;e=0;while(1){c:{d:{e:{f:{if((e|0)==4){break f}x[31737]=0;b=P(1201,a|0,l+524|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break a}if(b){break f}b=0;g:{h:{i:{j:{k:{switch(v[(l+92|0)+e|0]){case 1:if((e|0)==3){break c}b=x[a>>2];x[31737]=0;b=R(1202,b|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break a}if(Jf(x[h+8>>2],1,b)){x[31737]=0;O(1236,l+16|0,a|0);b=x[31737];x[31737]=0;if((b|0)!=1){x[31737]=0;O(116,s|0,v[l+16|0]);b=x[31737];x[31737]=0;if((b|0)!=1){break j}}break a}x[f>>2]=x[f>>2]|4;a=0;break d;case 4:break g;case 2:break h;case 3:break i;case 0:break k;default:break c}}if((e|0)==3){break c}}while(1){x[31737]=0;b=P(1201,a|0,l+524|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break a}if(b){break c}b=x[a>>2];x[31737]=0;b=R(1202,b|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break a}if(!Jf(x[h+8>>2],1,b)){break c}x[31737]=0;O(1236,l+16|0,a|0);b=x[31737];x[31737]=0;if((b|0)!=1){x[31737]=0;O(116,s|0,v[l+16|0]);b=x[31737];x[31737]=0;if((b|0)!=1){continue}}break}break a}l:{if(!Cb(x[n+4>>2],y[n+11|0])){break l}b=x[a>>2];x[31737]=0;b=R(1202,b|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break a}if(y[cc(n,0)|0]!=(b&255)){break l}x[31737]=0;R(1204,a|0)|0;b=x[31737];x[31737]=0;if((b|0)==1){break a}v[g|0]=0;r=Cb(x[n+4>>2],y[n+11|0])>>>0>1?n:r;break c}m:{n:{k=x[o+4>>2];b=y[o+11|0];if(Cb(k,b)){b=x[a>>2];x[31737]=0;b=R(1202,b|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break a}if(y[cc(o,0)|0]==(b&255)){break n}k=x[o+4>>2];b=y[o+11|0]}c=Cb(x[n+4>>2],y[n+11|0]);if(!c){break m}if(!Cb(k,b)){break m}x[f>>2]=x[f>>2]|4;a=0;break d}x[31737]=0;R(1204,a|0)|0;b=x[31737];x[31737]=0;if((b|0)==1){break a}v[g|0]=1;r=Cb(x[o+4>>2],y[o+11|0])>>>0>1?o:r;break c}b=Cb(k,b);if(!(b|c)){break c}v[g|0]=!b;break c}if(!(e>>>0<2|r|((e|0)==2&(B|0)!=0|A))){r=0;break c}c=vb(l+16|0,zd(q));o:{if(!e|y[(e+l|0)+91|0]>1){break o}while(1){p:{b=Df(q);k=x[c>>2];if(!Ib(k,b)){break p}if(!Jf(x[h+8>>2],1,v[k|0])){break p}le(c);continue}break}b=zd(q);b=Fk(x[c>>2],b);if(Cb(x[s+4>>2],y[s+11|0])>>>0>=b>>>0){k=YC(Df(s),b);E=Df(s);z=zd(q);b=fb-16|0;fb=b;x[b+8>>2]=z;x[b+12>>2]=k;while(1){q:{z=Ib(k,E);if(!z){break q}if(!F0(y[k|0],y[x[b+8>>2]])){break q}k=le(b+12|0);le(b+8|0);k=x[k>>2];continue}break}fb=b+16|0;if(z^1){break o}}F=c,G=x[vb(l+12|0,zd(q))>>2],x[F>>2]=G}x[l+12>>2]=x[c>>2];r:{while(1){b=Df(q);if(!Ib(x[l+12>>2],b)){break r}x[31737]=0;b=P(1201,a|0,l+524|0)|0;c=x[31737];x[31737]=0;s:{if((c|0)==1){break s}if(b){break r}b=x[a>>2];x[31737]=0;b=R(1202,b|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break s}if(y[x[l+12>>2]]!=(b&255)){break r}x[31737]=0;R(1204,a|0)|0;b=x[31737];x[31737]=0;if((b|0)==1){break a}le(l+12|0);continue}break}break a}if(!A){break c}b=Df(q);if(!Ib(x[l+12>>2],b)){break c}x[f>>2]=x[f>>2]|4;a=0;break d}t:{while(1){u:{x[31737]=0;c=P(1201,a|0,l+524|0)|0;k=x[31737];x[31737]=0;if((k|0)==1){break u}if(c){break t}c=x[a>>2];x[31737]=0;k=R(1202,c|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break a}v:{if(Jf(x[h+8>>2],64,k)){c=x[j>>2];if((c|0)==x[l+520>>2]){x[31737]=0;S(1237,i|0,j|0,l+520|0);c=x[31737];x[31737]=0;if((c|0)==1){break a}c=x[j>>2]}x[j>>2]=c+1;v[c|0]=k;b=b+1|0;break v}if(!Cb(x[u+4>>2],y[u+11|0])|!b|(k&255)!=(D|0)){break t}if(x[l+96>>2]==(d|0)){x[31737]=0;S(1238,t|0,l+100|0,l+96|0);c=x[31737];x[31737]=0;if((c|0)==1){break a}d=x[l+100>>2]}m=d+4|0;x[l+100>>2]=m;x[d>>2]=b;d=m;b=0}x[31737]=0;R(1204,a|0)|0;c=x[31737];x[31737]=0;if((c|0)!=1){continue}}break}break a}if(!(!b|x[t>>2]==(m|0))){if(x[l+96>>2]==(m|0)){x[31737]=0;S(1238,t|0,l+100|0,l+96|0);c=x[31737];x[31737]=0;if((c|0)==1){break a}m=x[l+100>>2]}c=m+4|0;x[l+100>>2]=c;x[m>>2]=b;m=c}if((w|0)<=0){break e}x[31737]=0;b=P(1201,a|0,l+524|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break a}w:{if(!b){b=x[a>>2];x[31737]=0;b=R(1202,b|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break a}if((b&255)==(C|0)){break w}}x[f>>2]=x[f>>2]|4;a=0;break d}x[31737]=0;b=R(1204,a|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break a}while(1){if((w|0)<=0){w=0;break e}x[31737]=0;c=P(1201,b|0,l+524|0)|0;d=x[31737];x[31737]=0;x:{if((d|0)==1){break x}y:{if(!c){c=x[b>>2];x[31737]=0;c=R(1202,c|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break x}if(Jf(x[h+8>>2],64,c)){break y}}x[f>>2]=x[f>>2]|4;a=0;break d}if(x[j>>2]==x[l+520>>2]){x[31737]=0;S(1237,i|0,j|0,l+520|0);c=x[31737];x[31737]=0;if((c|0)==1){break x}}c=x[b>>2];x[31737]=0;c=R(1202,c|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break x}d=x[j>>2];x[j>>2]=d+1;v[d|0]=c;x[31737]=0;R(1204,b|0)|0;c=x[31737];x[31737]=0;w=w-1|0;if((c|0)!=1){continue}}break}break a}x[l+24>>2]=w;z:{if(!r){break z}k=1;while(1){if(Cb(x[r+4>>2],y[r+11|0])>>>0<=k>>>0){break z}x[31737]=0;b=P(1201,a|0,l+524|0)|0;c=x[31737];x[31737]=0;A:{if((c|0)==1){break A}B:{if(!b){b=x[a>>2];x[31737]=0;b=R(1202,b|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break A}if(y[cc(r,k)|0]==(b&255)){break B}}x[f>>2]=x[f>>2]|4;a=0;break d}x[31737]=0;R(1204,a|0)|0;b=x[31737];x[31737]=0;k=k+1|0;if((b|0)!=1){continue}}break}break a}a=1;b=x[t>>2];if((b|0)==(m|0)){break d}a=0;x[l+16>>2]=0;Xf(u,b,m,l+16|0);if(x[l+16>>2]){x[f>>2]=x[f>>2]|4;break d}a=1;break d}d=m;if(x[j>>2]!=x[i>>2]){break c}x[f>>2]=x[f>>2]|4;a=0}tb(s);tb(o);tb(n);tb(q);tb(u);Lc(t);break b}e=e+1|0;continue}}break a}fb=l+528|0;return a|0}a=N()|0;tb(s);tb(o);tb(n);tb(q);tb(u);Lc(t);Q(a|0);p()}function ipa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=fb-272|0;fb=e;xc(b);d=fb-16|0;fb=d;f=e+126|0;pX(d+8|0,f);g=x[d+12>>2];lc(d,x[b>>2],x[b+8>>2],x[d+8>>2],x[d+12>>2]);h=x[d+4>>2];if((h|0)==(g|0)){Vb(b,x[d+12>>2])}fb=d+16|0;d=(g|0)==(h|0);if(!d){oX(f)}a:{b:{c:{d:{if(!d){break d}if(!qX(f)){break d}k=1;if((c|0)==64){break d}Bd(a,4194304);d=e+40|0;f=tc(d,17084);Ab(a+1298344|0,f);tb(f);f=tc(d,10153);Ab(a+1298356|0,f);tb(f);n=a+1298404|0,o=x[Fc(d,4)>>2],x[n>>2]=o;n=a,o=Kd(y[e+204|0]|y[e+205|0]<<8,y[e+206|0]|y[e+207|0]<<8,127),w[n+480188>>1]=o;f=y[e+195|0];x[a+480228>>2]=(f|0)==255?48:f;x[a+480196>>2]=y[e+193|0];x[a+480204>>2]=D(y[e+194|0],1e4);f=e+104|0;cf(f,e+130|0,59,3);Cc(d,f);Ab(a+1298308|0,d);tb(d);d=y[e+208|0]|y[e+209|0]<<8|(y[e+210|0]<<16|y[e+211|0]<<24);e:{if(d>>>0<5){break e}if(!cd(b,d-4|0)){break e}if(!gk(b,14294)){break e}fk(Xb(x[a+484360>>2],y[a+484376|0]),b,y[e+198|0]|y[e+199|0]<<8,65535,65535)}f:{d=y[e+212|0]|y[e+213|0]<<8|(y[e+214|0]<<16|y[e+215|0]<<24);if(d>>>0<5){break f}if(!cd(b,d-4|0)){break f}if(!gk(b,13904)){break f}d=0;while(1){if((d|0)==32){break f}f=(d<<5)+a|0;We(f+480280|0);n=f+480284|0,o=((((Zd(b)^-1)&15)<<8|8)>>>0)/15|0,w[n>>1]=o;d=d+1|0;continue}}d=y[e+220|0]|y[e+221|0]<<8|(y[e+222|0]<<16|y[e+223|0]<<24);g:{if(d>>>0<5){break g}if(!cd(b,d-4|0)){break g}if(!gk(b,14189)){break g}d=e+40|0;fe(d,b,(y[e+202|0]|y[e+203|0]<<8)<<6);i=c&2;k=a+480190|0;f=ic(e+104|0,d);ub(d);m=e+53|0;d=0;h:{while(1){if((d&65535)>>>0>=(y[e+202|0]|y[e+203|0]<<8)>>>0){break h}x[31737]=0;h=e+40|0;g=P(691,f|0,h|0)|0;j=x[31737];x[31737]=0;if((j|0)==1){break b}if(!g){break h}g=y[e+85|0]|y[e+86|0]<<8;w[e+38>>1]=g;i:{j:{if((g-1&65535)>>>0>3998){break j}g=D(g,104)+a|0;j=g+484380|0;if(je(x[j>>2],x[g+484400>>2])){break j}n=k,o=z[pe(k,e+38|0)>>1],w[n>>1]=o;x[31737]=0;O(692,h|0,j|0);g=x[31737];x[31737]=0;if((g|0)==1){break i}h=e+12|0;t_(h,1,m);x[31737]=0;g=e+24|0;O(219,g|0,h|0);h=x[31737];x[31737]=0;if((h|0)==1){break b}zc(((z[e+38>>1]<<5)+a|0)+946304|0,g);tb(g);if(!i){break j}x[31737]=0;P(150,b|0,y[e+77|0]|y[e+78|0]<<8|(y[e+79|0]<<16|y[e+80|0]<<24))|0;h=x[31737];x[31737]=0;if((h|0)==1){break i}j=1;h=y[e+87|0];l=Xc(g,h&4?16:8,1,0,0);k:{l:{if(h&8){break l}j=2;if(h&16){break l}if(h&127){break k}}yg(l,j)}x[31737]=0;U(216,g|0,(D(z[e+38>>1],104)+a|0)+484380|0,b|0)|0;g=x[31737];x[31737]=0;if((g|0)!=1){break j}break b}d=d+1|0;continue}break}break b}ub(f)}k=1;if(!(c&1)){break d}m:{c=y[e+216|0]|y[e+217|0]<<8|(y[e+218|0]<<16|y[e+219|0]<<24);if(c>>>0<5){break m}if(!cd(b,c-4|0)){break m}if(!gk(b,13775)){break m}j=a+484344|0;Vf(j,y[e+200|0]|y[e+201|0]<<8);g=0;while(1){if((y[e+200|0]|y[e+201|0]<<8)>>>0<=g>>>0){break m}if(!Ur(b,e+24|0)){break m}n:{d=z[e+24>>1];if(d>>>0>3){c=e+104|0;fe(c,b,(d+15&131056)-4|0);f=ic(e+40|0,c);ub(c);x[31737]=0;c=U(197,j|0,g&65535,y[e+26|0])|0;d=x[31737];x[31737]=0;if((d|0)==1){break n}h=0;o:{if(!c){break o}p:while(1){m=h&255;while(1){q:{c=x[f>>2];x[31737]=0;d=U(151,c|0,x[e+48>>2],1)|0;c=x[31737];x[31737]=0;r:{if((c|0)!=1){c=y[e+26|0];if(!(d&c>>>0>m>>>0)){break q}x[31737]=0;c=R(198,f|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break c}d=c<<24>>24;if(d){break r}h=h+1|0;continue p}break c}c=x[a+484344>>2];w[e+104>>1]=d&31;w[e+12>>1]=z[a+480188>>1]-1;c=Wb(c,g);i=e+104|0;c=jd(x[c>>2],x[x[c+48>>2]+12>>2],h,z[Nc(i,e+12|0)>>1]);if((d|0)<0){x[31737]=0;O(199,i|0,f|0);l=x[31737];x[31737]=0;if((l|0)==1){break c}v[c|0]=y[e+104|0]+36;n=c,o=y[Jc(i)|0],v[n+1|0]=o}d=d&255;if(d&64){v[c+2|0]=1;x[31737]=0;i=R(198,f|0)|0;l=x[31737];x[31737]=0;if((l|0)==1){break c}v[e+104|0]=i;v[e+12|0]=64;n=c,o=y[Qb(e+104|0,e+12|0)|0],v[n+4|0]=o}if(!(d&32)){continue}x[31737]=0;d=e+104|0;O(199,d|0,f|0);i=x[31737];x[31737]=0;s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{if((i|0)!=1){d=y[Jc(d)|0];v[c+5|0]=d;X:{switch(y[e+104|0]-1|0){case 71:break t;case 70:break u;case 69:break v;case 60:break w;case 59:break x;case 52:break y;case 51:break z;case 50:break A;case 49:break B;case 42:break C;case 41:break D;case 40:break E;case 39:break F;case 30:break G;case 29:break H;case 22:break I;case 21:break J;case 20:break K;case 19:break L;case 16:break M;case 15:break N;case 14:break O;case 13:break P;case 12:break Q;case 11:break R;case 10:break S;case 9:break T;case 3:break U;case 2:break V;case 1:break W;case 0:break X;default:break s}}v[c+3|0]=11;v[c+5|0]=d<<4|15;continue}break c}v[c+3|0]=11;v[c+5|0]=d<<4;continue}v[c+3|0]=11;v[c+5|0]=d|240;continue}v[c+3|0]=11;v[c+5|0]=d&15;continue}v[c+3|0]=2;v[c+5|0]=d|240;continue}v[c+3|0]=2;continue}v[c+3|0]=3;v[c+5|0]=d|240;continue}v[c+3|0]=3;continue}v[c+3|0]=4;continue}v[c+3|0]=20;v[c+5|0]=d|16;continue}v[c+3|0]=6;v[c+5|0]=d<<4;continue}v[c+3|0]=6;v[c+5|0]=d&15;continue}v[c+3|0]=5;continue}v[c+3|0]=20;v[c+5|0]=d|48;continue}v[c+3|0]=7;v[c+5|0]=d<<4;continue}v[c+3|0]=7;v[c+5|0]=d&15;continue}v[c+3|0]=8;continue}v[c+3|0]=20;v[c+5|0]=d|64;continue}v[c+3|0]=10;x[31737]=0;d=R(198,f|0)|0;i=x[31737];x[31737]=0;if((i|0)!=1){v[c+5|0]=d;x[31737]=0;P(184,f|0,1)|0;c=x[31737];x[31737]=0;if((c|0)!=1){continue}}break c}v[c+3|0]=15;v[c+5|0]=d&15;continue}v[c+3|0]=20;v[c+5|0]=d|192;continue}v[c+3|0]=20;v[c+5|0]=d|208;continue}v[c+3|0]=12;continue}v[c+3|0]=14;continue}v[c+3|0]=20;v[c+5|0]=d|176;continue}v[c+3|0]=20;v[c+5|0]=d|224;continue}v[c+3|0]=16;continue}v[c+3|0]=17;continue}v[c+3|0]=1;continue}v[c+3|0]=20;v[c+5|0]=d&15|32;continue}v[c+3|0]=20;v[c+5|0]=d&15|128;continue}v[c+3|0]=0;continue}break}break}if((c|0)==64){break o}ye(Wb(x[j>>2],g),Yh(Xe(Ne(e+104|0,14,0),c-1|0)))}ub(f)}g=g+1|0;continue}break}break c}c=y[e+224|0]|y[e+225|0]<<8|(y[e+226|0]<<16|y[e+227|0]<<24);if(!c){break d}cd(b,c);_D(a+1298332|0,b,hh(b),4)}fb=e+272|0;return k|0}a=N()|0;break a}a=N()|0}ub(f);Q(a|0);p()}function rka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;j=fb-48|0;fb=j;d=x[b>>2];x[31737]=0;f=R(173,d|0)|0;d=x[31737];x[31737]=0;a:{b:{c:{d:{if((d|0)==1){break d}e:{f:{if(f){d=0;i=Nb(j+36|0);g:{h:{i:{if(c&16){break i}x[31737]=0;e=(c|0)!=64;g=U(866,i|0,b|0,e|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break e}f=2;j:{if(g){break j}x[31737]=0;g=U(867,i|0,b|0,e|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break e}f=3;if(g){break j}x[31737]=0;g=U(868,i|0,b|0,e|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break e}f=4;if(g){break j}g=0;x[31737]=0;h=U(869,i|0,b|0,e|0)|0;e=x[31737];x[31737]=0;f=1;if((e|0)==1){break e}if(!h){break i}}if((c|0)==64){f=1;break h}g=x[i>>2];if(!mc(g,x[i+4>>2])){Xw(b,g+12|0)}g=f}f=0;if(c&32){break h}d=29968;k:{while(1){f=d;if((d|0)!=30544){e=x[d+8>>2];h=(e>>1)+a|0;d=x[d+4>>2];d=e&1?x[x[h>>2]+d>>2]:d;x[31737]=0;e=U(d|0,h|0,b|0,c|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break c}d=f+12|0;if(!e){continue}break k}break}x[a+480180>>2]=0;x[a+480184>>2]=0}if((c|0)==64){f=(f|0)!=30544;d=0;break h}if(!(x[a+480184>>2]|!g)){x[a+480184>>2]=g}x[31737]=0;d=1;O(805,a+1298264|0,1);g=x[31737];x[31737]=0;f=1;if((g|0)==1){break g}}nS(i);if(d){break f}break a}break c}x[31737]=0;O(247,a|0,0);d=x[31737];x[31737]=0;if((d|0)==1){break d}x[31737]=0;O(805,a+1298264|0,1);d=x[31737];x[31737]=0;if((d|0)==1){break d}x[a+1074304>>2]=20054022;x[a+1298408>>2]=0}f=0;while(1){if((f|0)==127){d=1;while(1){f=d&65535;if(f>>>0>z[a+480190>>1]){d=0;f=0;l:{while(1){g=f&65535;if(g>>>0>z[a+480192>>1]){m:{w[a+480192>>1]=d;d=a+480204|0;if(A[a+480204>>2]>=1e4){break m}x[d>>2]=125e4;break l}}else{e=x[((g<<2)+a|0)+900380>>2];if(e){g=x[a+480180>>2];wc(e,65536);wc(e+4|0,64);wc(e+8|0,256);Gf(e+28|0,16384);Qf(e+30|0,128);Qf(e+31|0,17);if(y[e+16|0]>=4){v[e+16|0]=0}if(y[e+17|0]>=5){v[e+17|0]=0}if(y[e+18|0]>=3){v[e+18|0]=0}Qf(e+19|0,64);Qf(e+20|0,100);i=224;d=v[e+26|0];n:{if((d|0)>=-32){i=32;if((d|0)<33){break n}}v[e+26|0]=i}Qf(e+23|0,64);Qf(e+24|0,64);dC(e+48|0,64);dC(e+68|0,64);dC(e+88|0,(g|0)==4096?255:64);d=e+108|0;g=0;while(1){if((g|0)==128){if(!zp(y[e+14|0])){v[e+14|0]=5}if(y[e+34|0]>=251){v[e+34|0]=0}}else{o:{if(y[xb(d,g)|0]){if(y[xb(d,g)|0]<121){break o}}l=xb(d,g),m=g+1|0,v[l|0]=m}g=g+1|0;continue}break}d=f}f=f+1|0;continue}break}wc(d,65535e4)}if(!x[a+480196>>2]){x[a+480196>>2]=6}g=a+480216|0;f=a+480220|0;d=x[a+480216>>2];if(!(d|y[a+480224|0]!=2)){x[g>>2]=1;d=1}if(A[a+480220>>2]<d>>>0){x[f>>2]=d}wc(g,65536);wc(f,65536);wc(a+480200|0,256);p:{if(!mc(x[a+480248>>2],x[a+480252>>2])){d=x[g>>2];x[31737]=0;O(870,a+480248|0,d|0);d=x[31737];x[31737]=0;if((d|0)==1){break p}}x[a+1074416>>2]=x[a+480196>>2];x[a+1074420>>2]=x[a+480204>>2];d=x[a+480220>>2];f=a+1074408|0;x[f>>2]=x[a+480216>>2];x[f+4>>2]=d;x[a+1074456>>2]=x[a+480200>>2];sB(a+1074376|0);d=a+1074446|0;w[d>>1]=0;w[d+2>>1]=0;w[d+4>>1]=0;w[d+6>>1]=65535;x[a+1074392>>2]=-2;d=a+1074384|0;x[d>>2]=0;x[d+4>>2]=0;x[a+1074380>>2]=0;d=a+1074424|0;x[d>>2]=0;x[d+4>>2]=0;x[a+1074432>>2]=0;d=a+1074396|0;x[d>>2]=0;x[d+4>>2]=0;if(En(x[a+480180>>2])){x[31737]=0;P(268,a+1074312|0,7)|0;d=x[31737];x[31737]=0;if((d|0)==1){break p}}w[a+480276>>1]=0;Gq(a);l=j,m=wb(x[a+484360>>2]),x[l+36>>2]=m;f=wb(x[a+484364>>2]);q:{while(1){r:{g=x[j+36>>2];if(!Ib(g,f)){if(x[a+480180>>2]){break r}f=0;break a}x[31737]=0;W(871,g|0);d=x[31737];x[31737]=0;if((d|0)==1){break q}if(Zc(x[g>>2],x[g+4>>2])>>>0<=z[g+28>>1]){af(g,0)}br(j+36|0);continue}break}Au(a+8|0,wr(a));if(x[a+1074308>>2]){x[31737]=0;W(872,a|0);d=x[31737];x[31737]=0;if((d|0)==1){break p}}h=Nb(j+36|0);s:{t:{if((c&12)!=12){break t}g=a+906300|0;f=0;u:{v:{w:{x:{y:{z:{while(1){if((f|0)==250){break t}A:{k=vd(g,f);B:{if(!Ti(x[k+16>>2],x[k+20>>2])){break B}x[31737]=0;O(873,k|0,a|0);c=x[31737];x[31737]=0;C:{if((c|0)!=1){e=x[k>>2];if(!e){break C}d=x[k+148>>2];c=x[x[e>>2]+56>>2];x[31737]=0;O(c|0,e|0,d|0);c=x[31737];x[31737]=0;if((c|0)!=1){break B}}a=N()|0;break s}i=wb(x[h>>2]);c=wb(x[h+4>>2]);e=fb-16|0;fb=e;x[e+12>>2]=i;while(1){D:{if(!Ib(i,c)){break D}d=x[i>>2];if((y[d+4|0]|y[d+5|0]<<8|(y[d+6|0]<<16|y[d+7|0]<<24))==(y[k+20|0]|y[k+21|0]<<8|(y[k+22|0]<<16|y[k+23|0]<<24))){d=(y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24))==(y[k+16|0]|y[k+17|0]<<8|(y[k+18|0]<<16|y[k+19|0]<<24))}else{d=0}if(d){break D}i=x[Je(e+12|0)>>2];continue}break}fb=e+16|0;if(Ib(i,wb(x[h+4>>2]))){break B}x[31737]=0;x[j+24>>2]=k+16;e=j+24|0;O(874,h|0,e|0);c=x[31737];x[31737]=0;if((c|0)==1){break A}x[31737]=0;d=P(1,j+12|0,18350)|0;c=x[31737];x[31737]=0;if((c|0)==1){break z}x[31737]=0;O(875,j|0,k|0);c=x[31737];x[31737]=0;if((c|0)==1){break y}x[31737]=0;S(2,e|0,d|0,j|0);c=x[31737];x[31737]=0;if((c|0)==1){break x}c=x[a+1298472>>2];x[31737]=0;S(386,c|0,2,e|0);c=x[31737];x[31737]=0;if((c|0)==1){break w}tb(e);tb(j);tb(d)}f=f+1|0;continue}break}a=N()|0;break s}a=N()|0;break s}a=N()|0;break u}a=N()|0;break v}a=N()|0;tb(j+24|0)}tb(j)}tb(d);break s}c=y[a+1074368|0];x[31737]=0;O(876,a|0,c|0);a=x[31737];x[31737]=0;f=1;if((a|0)!=1){vc(h);break a}a=N()|0}vc(h);break b}a=N()|0;break b}a=N()|0;break b}e=D(f,104)+a|0;h=e+484380|0;E:{if(je(x[h>>2],x[e+484400>>2])){Pj(h,a);break E}g=e+484414|0;f=z[g>>1];if(f&16384){break E}x[h>>2]=0;x[h+4>>2]=0;x[h+16>>2]=0;x[h+8>>2]=0;x[h+12>>2]=0;w[g>>1]=f&65505}f=e+484412|0;if(z[f>>1]>=65){w[f>>1]=64}F:{G:{if(!(y[e+484415|0]&2)){break G}if(!Mj(x[a+1298300>>2])){break G}x[31737]=0;W(877,a|0);f=x[31737];x[31737]=0;if((f|0)==1){break F}}d=d+1|0;continue}break}a=N()|0;break b}g=(f<<5)+a|0;Gf(g+480286|0,64);d=g+480284|0;if(z[d>>1]>=257){w[d>>1]=128}d=g+480288|0;if(y[d|0]>=251){v[d|0]=0}Uo((D(f,872)+a|0)+1074992|0,a,f&65535,67108864);f=f+1|0;continue}}break c}a=N()|0;break b}a=N()|0;nS(i)}ub(b);Q(a|0);p()}ub(b);fb=j+48|0;return f|0}function Qu(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;n=fb-16|0;fb=n;x[n+12>>2]=c;a:{if((c|0)<=0){break a}i=x[b+104>>2];b:{c:{d:{e:{f:{g:{h:{i:{j:{j=x[b+656>>2];k:{if(!(!j|x[a+480180>>2]!=16777216)){l=x[j+44>>2]!=0;break k}if(!j){break j}}if((c|0)>128){break i}m=c-1|0;h=z[_b(j+236|0,m)>>1];l:{if((h-1&65535)>>>0<=3998){i=(D(h,104)+a|0)+484380|0;break l}if(!Ob(a+1074312|0,43)){break l}if(!Ij(x[b+656>>2])){break a}}m=y[xb(j+108|0,m)|0];x[n+12>>2]=m;if(m>>>0<=120){break h}c=m;break i}m=c;h=0;if(c>>>0<121){break g}}m:{if(!(x[a+480180>>2]&16777248?(c|0)!=255:0)){Jo(a,b);if(d){break m}if(!Ob(a+1074312|0,100)|!(y[a+480208|0]&4)|!y[b+789|0]){break m}x[b+88>>2]=x[b+88>>2]&-6145;break m}if(!z[a+480192>>1]){break m}x[b+88>>2]=x[b+88>>2]|4096}n:{if((c|0)!=254){break n}c=x[b+88>>2];if(!(!(c&512)|x[a+480180>>2]!=2)){x[b+88>>2]=c|2048;break n}x[b+88>>2]=c|2101248;o:{if(x[a+480180>>2]&16777248){if(!z[a+480192>>1]){break o}if(Ob(a+1074312|0,50)){break o}}x[b+688>>2]=0}if(Ob(a+1074312|0,50)){x[b+8>>2]=0;x[b+12>>2]=0}x[b+696>>2]=0}if(!Ob(a+1074312|0,20)){break a}v[b+797|0]=0;v[b+802|0]=0;break a}h=0;if(!l){break g}if(d){h=y[b+797|0];if(h){break f}}x[b+708>>2]=0;h=1}if(d){break e}if(!(!(x[a+480180>>2]&1048588)|!i)){w[b+770>>1]=v[i+36|0];w[b+772>>1]=v[i+37|0];break d}if(i){break d}i=0;p=1;break c}h=D((x[x[j+44>>2]+36>>2]<<16>>16)+1|0,(m<<16>>16)-(h<<16>>16)|0)-x[b+852>>2]|0;x[b+708>>2]=h;x[b+852>>2]=0-h;h=1}p=!i;l=1;if(Ti(x[b+8>>2],x[b+12>>2])){break b}p:{l=a+1074312|0;if(!Ob(l,54)){break p}if(Ij(x[b+656>>2])){if(!Ob(l,117)){break p}}x[b+700>>2]=0;break a}l=(Ob(l,39)^-1)&d;break b}if(!Ob(a+1074312|0,24)){break c}x[b+704>>2]=x[i+24>>2]}l=0}q:{if(En(x[a+480180>>2])){x[n+12>>2]=w[b+770>>1]+m;Fe(n+12|0,12,131);break q}UX(n+12|0)}k=a+1074312|0;r:{if(Ob(k,34)){d=eE(c);break r}d=x[n+12>>2]}v[b+797|0]=d;v[b+851|0]=y[b+851|0]&183|64;if(!(x[a+480180>>2]&16777250?0:l)){v[b+803|0]=0}o=wh(a,x[n+12>>2],w[b+772>>1],x[b+704>>2]);v[b+831|0]=0;if(Ob(k,48)){nT(a,b,j,i)}s:{if(!Ob(k,115)|!j){break s}d=y[j+26|0];if(!d){break s}if(!z[b+784>>1]){w[b+784>>1]=z[b+692>>1]+1}mT(b+692|0,c,d,y[j+27|0])}t:{if(l|e^1){break t}x[b+776>>2]=0;x[b+780>>2]=0;if(!j){break t}if(Ob(k,29)){v[b+798|0]=y[j+16|0]}if(!(y[j+60|0]&8)){Hj(b+724|0)}if(!(y[j+80|0]&8)){Hj(b+732|0)}if(!(y[j+100|0]&8)){Hj(b+740|0)}if(y[j+20|0]){c=((D(Ou(Io(a)),y[j+20|0])<<16>>16)/64|0)+1<<16>>16;u:{if(Ob(k,28)){d=x[b+752>>2];break u}d=(x[b+688>>2]+1|0)/2|0}w[b+776>>1]=(D(d,c)|0)/199}v:{if(!y[j+19|0]){break v}r=b,s=(D(Ou(Io(a)),y[j+19|0])<<16>>16)/32|0,w[r+778>>1]=s;if(Ob(k,28)|z[b+784>>1]){break v}w[b+784>>1]=z[b+692>>1]+1}m=y[j+23|0];if(m){d=Ou(Io(a));c=y[b+837|0];v[b+796|0]=c+1;w[b+780>>1]=(D((D(m,d+1|0)<<16>>16)/128<<16>>16,c)+1|0)/128}m=y[j+24|0];if(!m){break t}d=Ou(Io(a));c=y[b+838|0];v[b+795|0]=c+1;w[b+782>>1]=(D(c,(D(m,d+1|0)<<16>>16)/128<<16>>16)+1|0)/128}if(p){break a}w:{x:{if(!o){d=0;break x}if(!(l&x[b+700>>2]!=0)){x[b+700>>2]=o}y:{z:{if(!h){if(!l){if(Ob(k,69)){break z}if(Ob(k,46)|x[a+480180>>2]==1){break z}}x[b+708>>2]=o;v[b+851|0]=y[b+851|0]&239}if(!l){break z}if(x[b+76>>2]|y[a+480180|0]&2){break y}}x[b+104>>2]=i;c=x[i>>2];x[b+84>>2]=c;x[b+76>>2]=c;x[b+80>>2]=0;x[b>>2]=0;x[b+4>>2]=0;A:{B:{C:{if(!(y[a+480210|0]&32)){if(!Ob(k,96)|y[b+789|0]){break B}q=x[b>>2];c=x[b+76>>2];break C}if(y[b+789|0]){break B}}x[n+8>>2]=c-1;c=x[Gb(b+660|0,n+8|0)>>2];x[b>>2]=q;x[b+4>>2]=c;break A}x[b+660>>2]=0}c=z[i+34>>1];h=c&1023;d=h|x[b+88>>2]&-525056;x[b+88>>2]=d;D:{E:{if(c&8){x[b+80>>2]=x[i+12>>2];c=x[i+16>>2];x[b+88>>2]=(h&16?d|4:d&-524295)|2;x[b+84>>2]=c;if(A[b+76>>2]>c>>>0){break E}break D}if(!(h&2)){break D}x[b+80>>2]=x[i+4>>2];c=x[i+8>>2];x[b+84>>2]=c;if(A[b+76>>2]<=c>>>0){break D}}x[b+76>>2]=c}F:{if(!(r=0,s=Ob(k,83),t=x[b+80>>2],t?r:s)){c=x[b+76>>2];break F}c=x[i>>2];x[b+84>>2]=c;x[b+76>>2]=c}d=x[b+88>>2];if(!(!(d&128)|!c)){x[b+4>>2]=c-1;x[b+88>>2]=d|128}G:{if(y[b+822|0]>3){break G}c=Ob(k,21);h=x[a+480180>>2];H:{I:{if(!(c|!(h&16777248))){d=16;if(y[a+480208|0]&4){break I}break H}d=32;if((h|0)==16){break H}}if(h&67633152){break G}d=0}v[b+819|0]=d}if(Ob(k,21)|y[b+825|0]>3){break y}v[b+820|0]=0}d=x[b>>2];if(A[b+76>>2]<=A[b+4>>2]){c=x[b+80>>2];x[b>>2]=d;x[b+4>>2]=c}d=0;if(!l){break x}d=1;if(!(x[a+480180>>2]&17301536)|(x[b+696>>2]?0:y[b+89|0]&16)){break x}c=1;if(!(y[a+480208|0]&8)){break w}c=1;if(!y[b+789|0]){break w}}if(!(x[b+696>>2]|(!(x[a+480180>>2]&17301536)|!(y[b+89|0]&16)))){cn(b);if(!Ob(k,21)){v[b+818|0]=0;x[b+756>>2]=0}x[b+696>>2]=65536;x[b+88>>2]=x[b+88>>2]&-4097}J:{if(!d){i=y[b+789|0];break J}i=y[b+789|0];if(!(y[a+480208|0]&8)){break J}c=1;if(!(i&255)){break w}}if(!(i&255?0:x[a+480180>>2]&1048580)){x[b+696>>2]=65536;x[b+88>>2]=x[b+88>>2]&-4097}c=d}K:{if(!(!c|!Ob(k,40)|(y[b+789|0]?y[a+480208|0]&8:0))){d=x[b+88>>2]&-4194305;break K}d=x[b+88>>2]&-4196353}x[b+88>>2]=d;L:{if(c){break L}w[b+842>>1]=65535;v[b+851|0]=y[b+851|0]|2;x[b+88>>2]=d&-6324225|2097152;M:{if(Ob(k,23)){break M}if(Ob(k,22)){break M}if(Ob(k,52)){break M}if(Ob(k,71)){break M}v[b+839|0]=0;v[b+808|0]=0}if(e){v[b+818|0]=0;x[b+756>>2]=0}x[b+20>>2]=0;x[b+24>>2]=0;if(!(y[b+89|0]&2)){break L}if(!Dd(x[a+1298300>>2])|(g|0)==65535){break L}if(Ob(k,111)){Dk(x[a+1298300>>2],g);break L}if(!Ob(k,110)){break L}SB(x[a+1298300>>2],g,0,1,0)}d=x[b+88>>2];N:{O:{P:{if(f){x[b+88>>2]=d&-1025;break P}if(!(d&1024)){break P}if(y[a+24618|0]&16){break O}}a=x[b+104>>2];if(!(!a|!(y[a+35|0]&4)|f)){break O}a=x[b+656>>2];if(!a|(!(y[a+15|0]&2)|f)){break N}}x[b+700>>2]=0}if(c){break a}w[b+136>>1]=0;x[b+132>>2]=4194304;x[b+112>>2]=0;x[b+116>>2]=0}fb=n+16|0}function N5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=xd(a,c);x[e>>2]=112024;f=BJ(e+8|0);x[31737]=0;b=P(71,e+152|0,b|0)|0;a=x[31737];x[31737]=0;a:{b:{c:{d:{e:{if((a|0)!=1){x[31737]=0;a=ca(105)|0;c=x[31737];x[31737]=0;if((c|0)==1){break e}a=x[a>>2];c=0;x[31737]=0;a=P(1287,f|0,a+8|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break e}while(1){f:{d=x[a>>2];if(oc(d,x[e+12>>2])>>>0<=c>>>0){x[31737]=0;c=R(856,12)|0;a=x[31737];x[31737]=0;if((a|0)!=1){break f}break e}d=x[yb(d,c)>>2];if(d){fl(d)}c=c+1|0;continue}break}x[31737]=0;a=U(1288,c|0,b|0,0)|0;d=x[31737];x[31737]=0;g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{if((d|0)!=1){x[31737]=0;O(1289,e|0,a|0);a=x[31737];x[31737]=0;if((a|0)==1){break e}x[31737]=0;c=R(856,12)|0;a=x[31737];x[31737]=0;if((a|0)==1){break e}x[31737]=0;a=U(1290,c|0,b|0,0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break t}x[31737]=0;O(1291,e|0,a|0);a=x[31737];x[31737]=0;if((a|0)==1){break e}x[31737]=0;c=R(856,20)|0;a=x[31737];x[31737]=0;if((a|0)==1){break e}x[31737]=0;a=U(1292,c|0,b|0,0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break s}x[31737]=0;O(1293,e|0,a|0);a=x[31737];x[31737]=0;if((a|0)==1){break e}x[31737]=0;c=R(856,12)|0;a=x[31737];x[31737]=0;if((a|0)==1){break e}x[31737]=0;a=U(1294,c|0,b|0,0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break r}x[31737]=0;O(1295,e|0,a|0);a=x[31737];x[31737]=0;if((a|0)==1){break e}x[31737]=0;a=R(856,8)|0;c=x[31737];x[31737]=0;if((c|0)==1){break e}a=xd(a,0);x[a>>2]=113972;x[a>>2]=119584;x[31737]=0;O(1296,e|0,a|0);a=x[31737];x[31737]=0;if((a|0)==1){break e}x[31737]=0;c=R(856,12)|0;a=x[31737];x[31737]=0;if((a|0)==1){break e}x[31737]=0;a=P(1297,c|0,b|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break q}x[31737]=0;O(1298,e|0,a|0);a=x[31737];x[31737]=0;if((a|0)==1){break e}x[31737]=0;a=R(856,8)|0;c=x[31737];x[31737]=0;if((c|0)==1){break e}a=xd(a,0);x[a>>2]=114120;x[a>>2]=119792;x[31737]=0;O(1299,e|0,a|0);a=x[31737];x[31737]=0;if((a|0)==1){break e}x[31737]=0;a=R(856,8)|0;c=x[31737];x[31737]=0;if((c|0)==1){break e}a=xd(a,0);x[a>>2]=114352;x[a>>2]=119896;x[31737]=0;O(1300,e|0,a|0);a=x[31737];x[31737]=0;if((a|0)==1){break e}x[31737]=0;a=R(856,8)|0;c=x[31737];x[31737]=0;if((c|0)==1){break e}a=xd(a,0);x[a>>2]=114236;x[a>>2]=12e4;x[31737]=0;O(1301,e|0,a|0);a=x[31737];x[31737]=0;if((a|0)==1){break e}x[31737]=0;a=R(856,8)|0;c=x[31737];x[31737]=0;if((c|0)==1){break e}a=xd(a,0);x[a>>2]=114468;x[a>>2]=120104;x[31737]=0;O(1302,e|0,a|0);a=x[31737];x[31737]=0;if((a|0)==1){break e}x[31737]=0;c=R(856,24)|0;a=x[31737];x[31737]=0;if((a|0)==1){break e}x[31737]=0;a=U(1303,c|0,b|0,0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break p}x[31737]=0;O(1304,e|0,a|0);a=x[31737];x[31737]=0;if((a|0)==1){break e}x[31737]=0;c=R(856,28)|0;a=x[31737];x[31737]=0;if((a|0)==1){break e}x[31737]=0;a=U(1305,c|0,b|0,0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break o}x[31737]=0;O(1306,e|0,a|0);a=x[31737];x[31737]=0;if((a|0)==1){break e}x[31737]=0;c=R(856,72)|0;a=x[31737];x[31737]=0;if((a|0)==1){break e}x[31737]=0;a=P(1307,c|0,b|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break n}x[31737]=0;O(1308,e|0,a|0);a=x[31737];x[31737]=0;if((a|0)==1){break e}x[31737]=0;c=R(856,72)|0;a=x[31737];x[31737]=0;if((a|0)==1){break e}x[31737]=0;a=P(1309,c|0,b|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break m}x[31737]=0;O(1310,e|0,a|0);a=x[31737];x[31737]=0;if((a|0)==1){break e}x[31737]=0;c=R(856,76)|0;a=x[31737];x[31737]=0;if((a|0)==1){break e}x[31737]=0;a=P(1311,c|0,b|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break l}x[31737]=0;O(1312,e|0,a|0);a=x[31737];x[31737]=0;if((a|0)==1){break e}x[31737]=0;c=R(856,76)|0;a=x[31737];x[31737]=0;if((a|0)==1){break e}x[31737]=0;a=P(1313,c|0,b|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break k}x[31737]=0;O(1314,e|0,a|0);a=x[31737];x[31737]=0;if((a|0)==1){break e}x[31737]=0;c=R(856,544)|0;a=x[31737];x[31737]=0;if((a|0)==1){break e}x[31737]=0;a=P(1315,c|0,b|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break j}x[31737]=0;O(1316,e|0,a|0);a=x[31737];x[31737]=0;if((a|0)==1){break e}x[31737]=0;c=R(856,544)|0;a=x[31737];x[31737]=0;if((a|0)==1){break e}x[31737]=0;a=P(1317,c|0,b|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break i}x[31737]=0;O(1318,e|0,a|0);a=x[31737];x[31737]=0;if((a|0)==1){break e}x[31737]=0;c=R(856,12)|0;a=x[31737];x[31737]=0;if((a|0)==1){break e}x[31737]=0;a=P(1319,c|0,b|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break h}x[31737]=0;O(1320,e|0,a|0);a=x[31737];x[31737]=0;if((a|0)==1){break e}x[31737]=0;c=R(856,12)|0;a=x[31737];x[31737]=0;if((a|0)==1){break e}x[31737]=0;a=P(1321,c|0,b|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break g}x[31737]=0;O(1322,e|0,a|0);a=x[31737];x[31737]=0;if((a|0)==1){break e}x[31737]=0;a=R(856,8)|0;c=x[31737];x[31737]=0;if((c|0)==1){break e}a=mJ(a,0);x[a>>2]=119432;x[31737]=0;O(1323,e|0,a|0);a=x[31737];x[31737]=0;if((a|0)==1){break e}x[31737]=0;a=R(856,8)|0;c=x[31737];x[31737]=0;if((c|0)==1){break e}a=lJ(a,0);x[a>>2]=119508;x[31737]=0;O(1324,e|0,a|0);a=x[31737];x[31737]=0;if((a|0)==1){break e}return e|0}a=T(0)|0;Db(c);break d}a=T(0)|0;Db(c);break d}a=T(0)|0;Db(c);break d}a=T(0)|0;Db(c);break d}a=T(0)|0;Db(c);break d}a=T(0)|0;Db(c);break d}a=T(0)|0;Db(c);break d}a=T(0)|0;Db(c);break d}a=T(0)|0;Db(c);break d}a=T(0)|0;Db(c);break d}a=T(0)|0;Db(c);break d}a=T(0)|0;Db(c);break d}a=T(0)|0;Db(c);break d}a=T(0)|0;Db(c);break d}a=T(0)|0;Db(c);break d}a=N()|0;break c}a=T(0)|0}Y(a|0)|0;c=0;while(1){a=x[f>>2];if(oc(a,x[e+12>>2])>>>0<=c>>>0){x[31737]=0;X(85);a=x[31737];x[31737]=0;if((a|0)!=1){break a}a=N()|0;x[31737]=0;X(26);c=x[31737];x[31737]=0;if((c|0)==1){break b}tb(b);break c}a=x[yb(a,c)>>2];if(a){Am(a)}c=c+1|0;continue}}dy(f);Q(a|0);p()}T(0)|0;Sb()}p()}function P9(a,b,c,d,e,f){a=a|0;b=+b;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,z=0,A=0,B=0,C=0,E=0;p=fb-560|0;fb=p;x[p+44>>2]=0;o(+b);g=j(1)|0;j(0)|0;a:{if((g|0)<0){w=1;B=5296;b=-b;o(+b);g=j(1)|0;j(0)|0;break a}if(e&2048){w=1;B=5299;break a}w=e&1;B=w?5302:5297;E=!w}b:{if((g&2146435072)==2146435072){g=w+3|0;Yf(a,32,c,g,e&-65537);Kf(a,B,w);d=f&32;Kf(a,b!=b?d?9994:13909:d?11148:14227,3);Yf(a,32,c,g,e^8192);n=(c|0)<(g|0)?g:c;break b}z=p+16|0;c:{d:{e:{b=EL(b,p+44|0);b=b+b;if(b!=0){g=x[p+44>>2];x[p+44>>2]=g-1;A=f|32;if((A|0)!=97){break e}break c}A=f|32;if((A|0)==97){break c}k=x[p+44>>2];m=(d|0)<0?6:d;break d}k=g-29|0;x[p+44>>2]=k;b=b*268435456;m=(d|0)<0?6:d}s=(p+48|0)+((k|0)>=0?288:0)|0;h=s;while(1){if(b<4294967296&b>=0){d=~~b>>>0}else{d=0}x[h>>2]=d;h=h+4|0;b=(b-+(d>>>0))*1e9;if(b!=0){continue}break}f:{if((k|0)<=0){d=k;g=h;i=s;break f}i=s;d=k;while(1){l=(d|0)>=29?29:d;g=h-4|0;g:{if(i>>>0>g>>>0){break g}q=0;while(1){d=x[g>>2];n=l&31;C=q;if((l&63)>>>0>=32){q=d<<n;d=0}else{q=(1<<n)-1&d>>>32-n;d=d<<n}n=C+d|0;q=q+r|0;q=Uua(n,d>>>0>n>>>0?q+1|0:q,1e9,0);d=Sua(q,hb,-1e9,0)+n|0;x[g>>2]=d;g=g-4|0;if(i>>>0<=g>>>0){continue}break}if(!q){break g}i=i-4|0;x[i>>2]=q}while(1){g=h;if(i>>>0<g>>>0){h=g-4|0;if(!x[h>>2]){continue}}break}d=x[p+44>>2]-l|0;x[p+44>>2]=d;h=g;if((d|0)>0){continue}break}}if((d|0)<0){u=((m+25>>>0)/9|0)+1|0;r=(A|0)==102;while(1){d=0-d|0;n=(d|0)>=9?9:d;h:{if(g>>>0<=i>>>0){h=x[i>>2];break h}q=1e9>>>n|0;l=-1<<n^-1;d=0;h=i;while(1){C=d;d=x[h>>2];x[h>>2]=C+(d>>>n|0);d=D(q,d&l);h=h+4|0;if(h>>>0<g>>>0){continue}break}h=x[i>>2];if(!d){break h}x[g>>2]=d;g=g+4|0}d=n+x[p+44>>2]|0;x[p+44>>2]=d;i=(!h<<2)+i|0;h=r?s:i;g=g-h>>2>(u|0)?h+(u<<2)|0:g;if((d|0)<0){continue}break}}d=0;i:{if(g>>>0<=i>>>0){break i}d=D(s-i>>2,9);h=10;l=x[i>>2];if(l>>>0<10){break i}while(1){d=d+1|0;h=D(h,10);if(l>>>0>=h>>>0){continue}break}}h=(m-((A|0)!=102?d:0)|0)-((A|0)==103&(m|0)!=0)|0;if((h|0)<(D(g-s>>2,9)-9|0)){q=h+9216|0;l=(q|0)/9|0;u=((p+48|0)+((k|0)<0?4:292)|0)+(l<<2)|0;k=u-4096|0;h=10;n=q+D(l,-9)|0;if((n|0)<=7){while(1){h=D(h,10);n=n+1|0;if((n|0)!=8){continue}break}}r=x[k>>2];q=(r>>>0)/(h>>>0)|0;n=D(q,h);l=u-4092|0;j:{if((n|0)==(r|0)&(l|0)==(g|0)){break j}r=r-n|0;k:{if(!(q&1)){b=9007199254740992;if(!(v[u-4100|0]&1)|((h|0)!=1e9|i>>>0>=k>>>0)){break k}}b=9007199254740994}t=(g|0)==(l|0)?1:1.5;l=h>>>1|0;t=l>>>0>r>>>0?.5:(l|0)==(r|0)?t:1.5;if(!(y[B|0]!=45|E)){t=-t;b=-b}x[k>>2]=n;if(b+t==b){break j}d=h+n|0;x[k>>2]=d;if(d>>>0>=1e9){while(1){x[k>>2]=0;k=k-4|0;if(k>>>0<i>>>0){i=i-4|0;x[i>>2]=0}d=x[k>>2]+1|0;x[k>>2]=d;if(d>>>0>999999999){continue}break}}d=D(s-i>>2,9);h=10;l=x[i>>2];if(l>>>0<10){break j}while(1){d=d+1|0;h=D(h,10);if(l>>>0>=h>>>0){continue}break}}h=k+4|0;g=g>>>0>h>>>0?h:g}while(1){l=g;q=g>>>0<=i>>>0;if(!q){g=g-4|0;if(!x[g>>2]){continue}}break}l:{if((A|0)!=103){k=e&8;break l}h=m?m:1;g=(h|0)>(d|0)&(d|0)>-5;m=(g?d^-1:-1)+h|0;f=(g?-1:-2)+f|0;k=e&8;if(k){break l}g=-9;m:{if(q){break m}k=x[l-4>>2];if(!k){break m}n=10;g=0;if((k>>>0)%10|0){break m}while(1){h=g;g=g+1|0;n=D(n,10);if(!((k>>>0)%(n>>>0)|0)){continue}break}g=h^-1}h=D(l-s>>2,9);if((f&-33)==70){k=0;g=(g+h|0)-9|0;g=(g|0)>0?g:0;m=(g|0)>(m|0)?m:g;break l}k=0;g=((d+h|0)+g|0)-9|0;g=(g|0)>0?g:0;m=(g|0)>(m|0)?m:g}n=-1;q=k|m;if(((q?2147483645:2147483646)|0)<(m|0)){break b}r=(((q|0)!=0)+m|0)+1|0;h=f&-33;n:{if((h|0)==70){if((r^2147483647)<(d|0)){break b}g=(d|0)>0?d:0;break n}g=d>>31;g=oo((g^d)-g|0,0,z);if((z-g|0)<=1){while(1){g=g-1|0;v[g|0]=48;if((z-g|0)<2){continue}break}}u=g-2|0;v[u|0]=f;v[g-1|0]=(d|0)<0?45:43;g=z-u|0;if((g|0)>(r^2147483647)){break b}}d=g+r|0;if((d|0)>(w^2147483647)){break b}r=d+w|0;Yf(a,32,c,r,e);Kf(a,B,w);Yf(a,48,c,r,e^65536);o:{p:{q:{if((h|0)==70){f=p+16|0;d=f|8;k=f|9;h=i>>>0>s>>>0?s:i;i=h;while(1){g=oo(x[i>>2],0,k);r:{if((h|0)!=(i|0)){if(p+16>>>0>=g>>>0){break r}while(1){g=g-1|0;v[g|0]=48;if(p+16>>>0<g>>>0){continue}break}break r}if((g|0)!=(k|0)){break r}v[p+24|0]=48;g=d}Kf(a,g,k-g|0);i=i+4|0;if(s>>>0>=i>>>0){continue}break}if(q){Kf(a,16817,1)}if((m|0)<=0|i>>>0>=l>>>0){break q}while(1){g=oo(x[i>>2],0,k);if(g>>>0>p+16>>>0){while(1){g=g-1|0;v[g|0]=48;if(p+16>>>0<g>>>0){continue}break}}Kf(a,g,(m|0)>=9?9:m);g=m-9|0;i=i+4|0;if(l>>>0<=i>>>0){break p}d=(m|0)>9;m=g;if(d){continue}break}break p}s:{if((m|0)<0){break s}s=i>>>0<l>>>0?l:i+4|0;f=p+16|0;d=f|8;l=f|9;h=i;while(1){g=oo(x[h>>2],0,l);if((l|0)==(g|0)){v[p+24|0]=48;g=d}t:{if((h|0)!=(i|0)){if(p+16>>>0>=g>>>0){break t}while(1){g=g-1|0;v[g|0]=48;if(p+16>>>0<g>>>0){continue}break}break t}Kf(a,g,1);g=g+1|0;if(!(k|m)){break t}Kf(a,16817,1)}f=l-g|0;Kf(a,g,(f|0)<(m|0)?f:m);m=m-f|0;h=h+4|0;if(s>>>0<=h>>>0){break s}if((m|0)>=0){continue}break}}Yf(a,48,m+18|0,18,0);Kf(a,u,z-u|0);break o}g=m}Yf(a,48,g+9|0,9,0)}Yf(a,32,c,r,e^8192);n=(c|0)<(r|0)?r:c;break b}k=(f<<26>>31&9)+B|0;u:{if(d>>>0>11){break u}g=12-d|0;t=16;while(1){t=t*16;g=g-1|0;if(g){continue}break}if(y[k|0]==45){b=-(t+(-b-t));break u}b=b+t-t}s=w|2;i=f&32;h=x[p+44>>2];g=h>>31;g=oo((g^h)-g|0,0,z);if((z|0)==(g|0)){v[p+15|0]=48;g=p+15|0}m=g-2|0;v[m|0]=f+15;v[g-1|0]=(h|0)<0?45:43;g=e&8;h=p+16|0;while(1){f=h;if(F(b)<2147483648){l=~~b}else{l=-2147483648}v[h|0]=i|y[l+93536|0];b=(b-+(l|0))*16;h=f+1|0;if(!(!(g|(d|0)>0)&b==0|(h-(p+16|0)|0)!=1)){v[f+1|0]=46;h=f+2|0}if(b!=0){continue}break}n=-1;g=z-m|0;f=g+s|0;if((2147483645-f|0)<(d|0)){break b}l=f;f=p+16|0;i=h-f|0;d=d?(i-2|0)<(d|0)?d+2|0:i:i;h=l+d|0;Yf(a,32,c,h,e);Kf(a,k,s);Yf(a,48,c,h,e^65536);Kf(a,f,i);Yf(a,48,d-i|0,0,0);Kf(a,m,g);Yf(a,32,c,h,e^8192);n=(c|0)<(h|0)?h:c}fb=p+560|0;return n|0}function Zsa(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;j=fb-128|0;fb=j;v[j+127|0]=d;a:{if(!c|(e|0)<0&c>>>0>=176){break a}v[b+5|0]=d;v[j+8|0]=15;l=j+127|0;p=j+8|0;k=p;o=y[Qb(l,k)|0];v[j+8|0]=14;l=y[Qb(l,k)|0];x[j+8>>2]=d+31>>>5;x[j+120>>2]=14;r=j+120|0;n=x[ud(k,r)>>2];x[j+8>>2]=d+127>>>7;x[j+120>>2]=14;q=c&15;k=q<<8|d;p=ud(p,r);b:{switch((c>>>4|0)-2|0){case 0:v[b+2|0]=1;x[j+8>>2]=k>>>2;x[j+120>>2]=64;s=b,t=x[ud(j+8|0,j+120|0)>>2],v[s+4|0]=t;break a;case 1:v[b+2|0]=1;if(!k){v[b+4|0]=0;break a}s=j,t=ID(k)>>>2|0,x[s+8>>2]=t;x[j+120>>2]=64;s=b,t=x[ud(j+8|0,j+120|0)>>2],v[s+4|0]=t;break a;case 2:v[b+3|0]=9;v[b+5|0]=k>>>4;break a;case 3:v[b+3|0]=23;v[b+5|0]=k+1>>>5;break a;case 4:v[b+3|0]=23;if(k){a=Ch(ID(k)>>>5|0)}else{a=0}v[b+5|0]=a;break a;case 5:v[b+5|0]=q;v[b+3|0]=15;break a;case 6:v[b+3|0]=15;if((e|0)>=0){if(y[b+2|0]){break a}v[b+2|0]=2;s=b,t=Gc(((q<<6|7)>>>0)/15|0,0),v[s+4|0]=t;break a}v[b+2|0]=1;v[b+5|0]=q;v[b+4|0]=d+3>>>2;break a;case 7:v[b+3|0]=10;c:{if((e|0)>5){break c}if(!k){v[b+5|0]=1;break a}c=ur(a,f,g);if(!c){break c}a=ti(a,c);c=z[a+34>>1];if(c&1){k=k>>>1|0;x[j+120>>2]=k}if(!(c&2)){break c}c=x[a>>2];if(c>>>0>=k<<8>>>0){break c}x[j+120>>2]=x[a+4>>2]+8>>>8;wc(j+120|0,c-1>>>8|0);k=x[j+120>>2]}v[b+5|0]=k;if(y[b+2|0]|k>>>0<256){break a}v[b+2|0]=15;x[j+116>>2]=k>>>8;Vv(j+8|0);x[j+112>>2]=9;s=b,t=x[Gb(j+116|0,j+112|0)>>2],v[s+4|0]=t;break a;default:break b}}k=x[p>>2];d:{switch(c-160|0){default:e:{switch(c-1|0){case 0:case 1:case 2:case 3:case 6:case 10:case 14:Bf(b,c,d);f:{switch(y[b+3|0]-16|0){case 1:x[h>>2]=D(y[b+5|0],1e4);break a;case 0:break f;default:break a}}a=y[b+5|0];if(!a){break a}x[i>>2]=a;break a;case 4:v[b+3|0]=4;if(y[b+2|0]){break a}v[b+4|0]=0;v[b+2|0]=8;break a;case 5:v[b+3|0]=5;if(y[b+2|0]){break a}v[b+4|0]=0;v[b+2|0]=11;break a;case 7:if(!Sc(y[b|0])|!d){break a}v[b+3|0]=35;v[b+5|0]=(d>>>1&120|128)-(d<<3&120);if(z[a+480192>>1]){break a}w[j+8>>1]=255;c=z[Nc(a+480190|0,j+8|0)>>1];w[a+480192>>1]=c;b=1;while(1){d=b&65535;if(d>>>0>(c&65535)>>>0){break a}c=BE(a,d,d);if(c){v[c+33|0]=2;d=(d<<5)+a|0;e=d+946304|0;f=x[e+4>>2];x[c+492>>2]=x[e>>2];x[c+496>>2]=f;e=d+946312|0;f=x[e+4>>2];x[c+500>>2]=x[e>>2];x[c+504>>2]=f;e=d+946320|0;f=x[e+4>>2];x[c+508>>2]=x[e>>2];x[c+512>>2]=f;d=d+946328|0;e=x[d+4>>2];x[c+516>>2]=x[d>>2];x[c+520>>2]=e;ik(c,127,1);hk(c,0,1)}b=b+1|0;c=z[a+480192>>1];continue};case 8:v[b+3|0]=19;v[b+5|0]=o|208;break a;case 9:v[b+3|0]=25;break a;case 11:if(d>>>0>2){break a}v[b+3|0]=19;v[b+5|0]=d|64;break a;case 12:v[b+3|0]=14;break a;case 13:if(d>>>0>2){break a}v[b+3|0]=19;v[b+5|0]=d|112;break a;case 15:v[b+3|0]=1;break a;case 16:case 17:v[b+3|0]=19;v[b+5|0]=l|c<<4;break a;case 18:v[b+3|0]=15;break a;case 19:v[b+3|0]=11;v[b+5|0]=l<<4;break a;case 20:v[b+5|0]=l;v[b+3|0]=11;break a;case 23:v[b+3|0]=6;v[b+5|0]=l<<4;break a;case 24:v[b+5|0]=l;v[b+3|0]=6;break a;case 27:v[b+3|0]=7;v[b+5|0]=l<<4;break a;case 28:break e;default:break a}}v[b+5|0]=l;v[b+3|0]=7;break a;case 0:if(!d){break a}v[b+3|0]=24;v[b+5|0]=n<<4;break a;case 1:if(!d){break a}v[b+5|0]=n;v[b+3|0]=24;break a;case 4:v[b+3|0]=11;v[b+5|0]=l<<4|15;break a;case 5:v[b+3|0]=11;v[b+5|0]=l|240;break a;case 6:if(!d){break a}v[b+3|0]=24;v[b+5|0]=n<<4|15;break a;case 7:if(!d){break a}v[b+3|0]=24;v[b+5|0]=n|240;break a;case 8:if(!d){break a}v[b+3|0]=16;x[i>>2]=d;break a;case 9:if((e|0)>5){break a}a=x[h>>2];if(a>>>0<1e4){break a}v[b+3|0]=17;m=122925/(+(a>>>0)/1e4)+ +((d<<1)-256|0);s=b,t=fm(245850/(m+m)),v[s+5|0]=t;break a;case 10:v[b+3|0]=19;v[b+5|0]=o|224;break a;case 12:v[b+3|0]=28;v[b+5|0]=o|16;break a;case 13:v[b+3|0]=28;v[b+5|0]=o|32;break a;case 14:v[b+3|0]=29;v[b+5|0]=l<<3&240;break a;case 15:v[b+3|0]=29;v[b+5|0]=(l&254)>>>1;break a;case 16:v[b+3|0]=18;break a;case 17:v[b+3|0]=19;v[b+5|0]=o|176;break a;case 18:case 19:v[b+3|0]=20;v[b+5|0]=d?120:119;break a;case 20:v[b+3|0]=20;v[b+5|0]=d?125:123;break a;case 21:v[b+3|0]=20;v[b+5|0]=d?122:121;break a;case 22:v[b+3|0]=20;v[b+5|0]=d?126:123;break a;case 26:v[b+3|0]=10;v[b+5|0]=d+15>>>4;break a;case 27:v[b+5|0]=1;v[b+3|0]=10;break a;case 30:case 31:if(!d|(!g|!f)){break a}o=x[h>>2];if(o>>>0<1e4){break a}l=x[i>>2];if(!l){break a}i=ur(a,f,g);if(!i){break a}k=ti(a,i);n=z[k+34>>1];g:{if(!(n&2)){i=x[k>>2];break g}i=x[k+8>>2]-((e|0)<6?x[k+4>>2]:0)|0;if(!(n&4)){break g}i=i<<((e|0)>5)}if(!i|(e|0)<6&i>>>0<1024){break a}n=x[k+24>>2];if(!n){break a}h:{if(z[a+480192>>1]<g>>>0){break h}a=x[((g<<2)+a|0)+900380>>2];if(!a){break h}m=+(y[xb(a+108|0,f-1|0)|0]-f|0)}a=(c|0)==190;m=Di(m/12+(a?(e|0)<6?+v[k+37|0]/-1536:-0:-0))*+(n>>>0);if(a){v[b+3|0]=17;a=fm(m*.5*(+(D(d,l)>>>0)*2.5)/+(i>>>0));v[b+5|0]=a;x[h>>2]=D(a,1e4);break a}m=Uv(ZL(+(i>>>0)/m/(+(D(d,l)>>>0)*2.5/(+(o>>>0)/1e4)))*12+61,1,120);i:{if(m<4294967296&m>=0){a=~~m>>>0;break i}a=0}c=Sc(y[b|0]);v[b|0]=a;m=(m-J(m))*64+128;j:{if(m<4294967296&m>=0){a=~~m>>>0;break j}a=0}v[b+5|0]=a;if((a|0)!=128){v[b+3|0]=35}if(c){break a}if(!y[b+2|0]){v[b+4|0]=9;v[b+2|0]=11;break a}v[b+5|0]=255;v[b+3|0]=4;break a;case 32:a=d>>>4|0;if(a-1>>>0>1){break a}v[b+3|0]=20;v[b+5|0]=a-99;break a;case 34:v[b+3|0]=21;v[b+5|0]=d<<2;break a;case 35:v[b+3|0]=21;s=b,t=Ch(ID(d<<4)>>>6|0),v[s+5|0]=t;break a;case 36:case 38:v[b+3|0]=22;v[b+5|0]=k<<4;break a;case 37:case 39:v[b+5|0]=k;v[b+3|0]=22;break a;case 40:v[b+3|0]=22;v[b+5|0]=l<<4|15;break a;case 2:case 3:case 11:case 23:case 24:case 25:case 28:case 29:case 33:break a;case 41:break d}}v[b+3|0]=22;v[b+5|0]=l|240}fb=j+128|0}function soa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;d=fb-176|0;fb=d;xc(c);a:{if(!lp(c,d+164|0)|(y[d+164|0]|y[d+165|0]<<8|(y[d+166|0]<<16|y[d+167|0]<<24))!=1297239878){break a}f=y[d+172|0]|y[d+173|0]<<8|(y[d+174|0]<<16|y[d+175|0]<<24);if((f|0)!=1179011393&(f|0)!=1128679745){break a}e=fb-32|0;fb=e;i=d+152|0;f=Nb(i);b:{c:{d:{e:{f:{while(1){g=x[c+8>>2];h=x[c>>2];x[31737]=0;g=U(151,h|0,g|0,8)|0;h=x[31737];x[31737]=0;if((h|0)==1){break d}if(!g){break e}x[31737]=0;g=e+4|0;O(829,g|0,c|0);h=x[31737];x[31737]=0;if((h|0)!=1){x[31737]=0;O(830,f|0,g|0);h=x[31737];x[31737]=0;if((h|0)==1){break f}Fd(g);continue}break}a=N()|0;break c}a=N()|0;Fd(e+4|0);break c}fb=e+32|0;break b}a=N()|0}ie(f);Q(a|0);p()}x[31737]=0;e=d+132|0;S(749,e|0,i|0,1129270605);c=x[31737];x[31737]=0;g:{h:{i:{j:{k:{l:{m:{if((c|0)!=1){x[31737]=0;c=P(750,e|0,d+114|0)|0;f=x[31737];x[31737]=0;n:{o:{if((f|0)!=1){if(!c){break g}if(!$b(z[d+116>>1]|z[d+118>>1]<<16)){break g}if((Bb(z[d+114>>1])-3&65535)>>>0<65534){break g}if((Bb(z[d+120>>1])-65&65535)>>>0<65472){break g}x[d+108>>2]=1162760014;c=1;if((y[d+172|0]|y[d+173|0]<<8|(y[d+174|0]<<16|y[d+175|0]<<24))==1128679745){x[31737]=0;c=P(629,e|0,d+108|0)|0;e=x[31737];x[31737]=0;if((e|0)==1){break o}if(!c){break g}c=x[d+108>>2]!=1936684916}x[31737]=0;e=d+88|0;S(749,e|0,d+152|0,1397968452);f=x[31737];x[31737]=0;p:{q:{if((f|0)!=1){x[31737]=0;l=P(751,e|0,d+80|0)|0;e=x[31737];x[31737]=0;if((e|0)==1){break p}if(l){break q}break h}c=N()|0;break j}f=(Bb(z[d+120>>1])-1|0)/8|0;g=f<<3;e=g&31;h=d+76|0;if((g&63)>>>0>=32){e=1074268168>>>e|0}else{e=((1<<e)-1&1074268168)<<32-e|538447880>>>e}g=Xc(h,(f>>>0>=8?8:e)&120,(Bb(z[d+114>>1])|0)==2?2:1,c,0);c=x[d+108>>2];r:{if((c|0)!=544694642){s:{t:{if(!((c|0)==842222662|(c|0)==842230886|(c|0)==875973702)){if((c|0)==2002873461){break s}if((c|0)==1463897153){break t}if((c|0)==1463897173){break s}if((c|0)==2002873441){break t}if((c|0)!=875981926){break r}}yg(g,3);break r}yg(g,17);fd(g,16);break r}yg(g,16);fd(g,16);break r}yg(g,1)}c=x[d+80>>2];x[31737]=0;c=U(151,x[d+88>>2],x[d+96>>2],$b(c)|0)|0;e=x[31737];x[31737]=0;if((e|0)==1){break l}if(c){c=x[d+80>>2];x[31737]=0;P(184,d+88|0,$b(c)|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break l}}Uu(a,b);x[31737]=0;c=D(b,104)+a|0;i=c+484380|0;O(280,i|0,0);e=x[31737];x[31737]=0;u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{if((e|0)==1){break D}s=i,t=$b(z[d+116>>1]|z[d+118>>1]<<16),x[s>>2]=t;j=c+484404|0;c=y[d+124|0]|y[d+125|0]<<8|(y[d+126|0]<<16|y[d+127|0]<<24);f=c<<24|(c&65280)<<8|(c>>>8&65280|c>>>24);h=30-y[d+123|0]|0;e=0;while(1){c=f;if(h&255){f=c>>>1|0;h=h-1|0;e=c;continue}break}x[j>>2]=c+(e&1);x[31737]=0;U(216,g|0,i|0,d+88|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break D}x[31737]=0;e=d+56|0;f=d+152|0;S(749,e|0,f|0,1296126539);c=x[31737];x[31737]=0;if((c|0)==1){break C}x[31737]=0;c=R(173,x[d+56>>2])|0;g=x[31737];x[31737]=0;if((g|0)==1){break B}if(!c){break u}x[31737]=0;c=d+16|0;S(749,c|0,f|0,1229869908);f=x[31737];x[31737]=0;if((f|0)==1){break A}x[31737]=0;f=P(752,c|0,d+36|0)|0;g=x[31737];x[31737]=0;if((g|0)==1){break z}ub(c);if(!f){break u}x[31737]=0;f=R(274,e|0)|0;e=x[31737];x[31737]=0;if((e|0)==1){break y}e=Nb(c);x[31737]=0;O(753,e|0,f|0);c=x[31737];x[31737]=0;if((c|0)==1){break w}c=0;while(1){if((c|0)==(f|0)){break x}x[31737]=0;g=d+56|0;h=d+4|0;j=P(754,g|0,h|0)|0;k=x[31737];x[31737]=0;if((k|0)==1){break w}if(!j){break x}x[31737]=0;O(755,e|0,h|0);h=x[31737];x[31737]=0;if((h|0)==1){break w}x[31737]=0;P(184,g|0,y[d+10|0]|1)|0;g=x[31737];x[31737]=0;if((g|0)==1){break w}c=c+1|0;continue}}c=N()|0;break k}c=N()|0;break k}c=N()|0;break m}c=N()|0;break m}c=N()|0;ub(d+16|0);break m}c=N()|0;break m}c=Bb(y[d+44|0]|y[d+45|0]<<8);if(c){f=(D(b,104)+a|0)+484414|0;w[f>>1]=z[f>>1]&65511|((c|0)==2)<<4|8}c=Bb(y[d+50|0]|y[d+51|0]<<8);if(c){f=(D(b,104)+a|0)+484414|0;w[f>>1]=z[f>>1]&65529|((c|0)==2?4:2)|2}s=d,t=wb(x[e>>2]),x[s+4>>2]=t;c=D(b,104)+a|0;g=c+484388|0;h=c+484384|0;j=c+484396|0;k=c+484392|0;m=wb(x[e+4>>2]);n=y[d+46|0]|y[d+47|0]<<8;o=y[d+48|0]|y[d+49|0]<<8;q=y[d+52|0]|y[d+53|0]<<8;r=y[d+54|0]|y[d+55|0]<<8;while(1){c=x[d+4>>2];if(!Ib(c,m)){break v}f=Bb(y[c|0]|y[c+1|0]<<8);if((f|0)==(Bb(n)|0)){s=k,t=$b(y[c+2|0]|y[c+3|0]<<8|(y[c+4|0]<<16|y[c+5|0]<<24)),x[s>>2]=t;f=Bb(y[c|0]|y[c+1|0]<<8)}if((Bb(o)|0)==(f|0)){s=j,t=$b(y[c+2|0]|y[c+3|0]<<8|(y[c+4|0]<<16|y[c+5|0]<<24)),x[s>>2]=t;f=Bb(y[c|0]|y[c+1|0]<<8)}if((Bb(q)|0)==(f|0)){s=h,t=$b(y[c+2|0]|y[c+3|0]<<8|(y[c+4|0]<<16|y[c+5|0]<<24)),x[s>>2]=t;f=Bb(y[c|0]|y[c+1|0]<<8)}if((f|0)==(Bb(r)|0)){s=g,t=$b(y[c+2|0]|y[c+3|0]<<8|(y[c+4|0]<<16|y[c+5|0]<<24)),x[s>>2]=t}x[d+4>>2]=x[d+4>>2]+7;continue}}c=N()|0;XT(e);break m}_k(i);XT(e)}x[31737]=0;c=d+16|0;S(749,c|0,d+152|0,1312902469);e=x[31737];x[31737]=0;if((e|0)==1){break n}x[31737]=0;e=R(173,x[d+16>>2])|0;f=x[31737];x[31737]=0;E:{if((f|0)==1){break E}F:{if(e){x[31737]=0;e=R(155,x[d+16>>2])|0;f=x[31737];x[31737]=0;if((f|0)==1){break E}x[31737]=0;S(318,c|0,((b<<5)+a|0)+946304|0,e|0);b=x[31737];x[31737]=0;if((b|0)!=1){break F}break E}x[31737]=0;c=P(36,d+4|0,22303)|0;e=x[31737];x[31737]=0;if((e|0)==1){break E}zc(((b<<5)+a|0)+946304|0,c);tb(c)}bC(i,x[a+480180>>2]);Pj(i,a);ub(d+16|0);ub(d+56|0);break h}c=N()|0;ub(d+16|0);break m}c=N()|0;break k}c=N()|0;break j}c=N()|0;break j}c=N()|0;break m}c=N()|0;break i}ub(d+56|0);break k}c=N()|0}ub(d+88|0)}ub(d+132|0)}ie(d+152|0);Q(c|0);p()}ub(d+88|0)}ub(d+132|0);ie(d+152|0)}fb=d+176|0;return l|0}function Po(a,b,c,d,e,f){var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0;h=z[a+480192>>1]>=c>>>0?x[((c<<2)+a|0)+900380>>2]:h;r=x[b+752>>2];a:{j=y[b+802|0];b:{if(!j){if(Ob(a+1074312|0,11)){break b}}c:{d:{if(!h){break d}if(!Sc(j)){break d}e:{g=h+236|0;j=j-1|0;if(z[_b(g,j)>>1]){break e}if(!Ob(a+1074312|0,43)){break e}if(Qj(y[h+31|0])){break e}x[b+656>>2]=h;return}if(y[xb(h+108|0,j)|0]>120){break b}j=z[_b(g,j)>>1];k=(j-1&65535)>>>0<3999?(D(j,104)+a|0)+484380|0:0;break c}if(!z[a+480192>>1]){k=(D(c,104)+a|0)+484380|0;break c}if(j>>>0>250){break b}if(!Ob(a+1074312|0,43)){break c}if(h){if(Qj(y[h+31|0])){break c}}v[b+803|0]=0;x[b+656>>2]=0;return}j=x[b+104>>2];m=(j|0)!=0&(j|0)!=(k|0);i=x[b+656>>2];p=!h|x[a+480180>>2]!=16777216?p:x[h+44>>2]!=0;n=d^1;g=(h|0)!=(i|0);if((n|g|m)==1){w[b+774>>1]=0}l=!m;if(!(l|(!(d&p)|g))){break b}f:{if(l|n){break f}q=a+1074312|0;if(!(!Ob(q,32)|!(y[a+480208|0]&8))){k=x[b+8>>2]|x[b+12>>2]?x[b+104>>2]:k}j=x[a+480180>>2];g:{h:{i:{j:{if(!g){if((h|0)!=0&(j&1048580)!=0|(j|0)==268435456){break h}if((j|0)!=1){break i}break j}if((j|0)==1){break j}if((j|0)==268435456){break h}break i}if(Ti(x[b+8>>2],x[b+12>>2])){break h}}if(!Ob(q,79)){break g}if(!Ti(x[b+8>>2],x[b+12>>2])){break g}}o=1}if(!Ob(q,119)|z[a+480192>>1]){break f}v[b+851|0]=y[b+851|0]|2}k:{if(!x[b+16>>2]|(l|(!z[a+480192>>1]|g))){break k}if(!Ob(a+1074312|0,87)){break k}o=Sc(y[b+788|0])^1|o}l=(h|0)!=(i|0);l:{if(Ti(x[b+8>>2],x[b+12>>2])|!(x[a+480180>>2]&16777248)){break l}if(h){if(Qj(y[h+31|0])){break l}}l=1}m:{n:{if(!(m|l)|!d){break n}if(!Ob(a+1074312|0,61)){break n}g=x[b+104>>2];i=x[b+656>>2];j=0;if(g|i){break m}}x[b+656>>2]=h;g=k;i=h;j=l}o:{p:{q:{if(!e){break q}r:{if(y[a+480180|0]&3){if(g){if(je(x[g>>2],x[g+20>>2])){break r}}if(!Ij(i)){break q}}if(!g){break p}}if(w[g+34>>1]<0){break q}x[b+688>>2]=z[g+30>>1]}h=(g|0)!=0;if(!(m&o)|!g){break o}if(Ob(a+1074312|0,85)){w[b+772>>1]=v[g+37|0]}h=1;if(x[a+480180>>2]!=2){break o}if(!je(x[g>>2],x[g+20>>2])){break o}x[b+704>>2]=x[g+24>>2];break o}if(!(!i|!y[i+34|0])){h=x[b+688>>2];if(i){h=x[i+4>>2]<<2}x[b+688>>2]=h;h=0;break o}h=0;x[b+688>>2]=0}if(o){break b}v[b+803|0]=0;s:{if(!i){break s}if(s=(B=Ob(a+1074312|0,29),C=1,E=g,E?B:C),t=0,u=!y[i+34|0]&(j^-1),u?s:t){break s}v[b+798|0]=y[i+16|0]}k=64;x[b+752>>2]=64;if(g){k=z[g+32>>1];x[b+752>>2]=k}if(i){x[b+752>>2]=D(x[i+4>>2],k)>>>6}t:{if(!(x[a+480180>>2]&1048580?e:1)){break t}if(Ob(a+1074312|0,48)){break t}nT(a,b,i,g)}u:{v:{w:{if(!f){break w}x:{y:{z:{A:{B:{C:{D:{E:{f=a+1074312|0;if(Ob(f,19)){if(!x[b+76>>2]){e=1;break D}if(!(!c|n)){e=(y[a+480208|0]&8)>>>3|0;if(e){break D}break E}e=0;if(c){break E}break D}F:{c=x[a+480180>>2]&17301536;e=1;G:{if(!d|!c){break G}c=1;e=1;if(y[a+480208|0]&8){break G}e=1;if(!x[b+76>>2]){break G}if(!(y[b+89|0]&16)){break F}e=!x[b+696>>2]}if(j|(!i|!c)){break B}if(!e){break x}c=x[b+88>>2];x[b+88>>2]=c|2097152;if(c&6144){break A}break C}if((j|!i)!=1){break x}break y}if(d){break D}if(!(y[b+89|0]&24)){e=0;break D}e=(y[a+480208|0]&4)>>>2|0}if(j|!x[b+696>>2]){break B}if(!e){break y}c=x[b+88>>2];x[b+88>>2]=c|2097152;if(!i){break z}if(c&2048){break A}}if(!(y[i+60|0]&8)){Hj(b+724|0)}if(!(y[i+80|0]&8)){Hj(b+732|0)}if(y[i+100|0]&8){break z}Hj(b+740|0);break z}if(!e){break y}x[b+88>>2]=x[b+88>>2]|2097152;if(!i){break z}}cn(b)}if(Ob(f,21)){break w}v[b+818|0]=0;x[b+756>>2]=0;break w}if(!i){break v}}if(v[i+60|0]&1){break w}if(Ob(f,32)){Hj(b+724|0);break w}cn(b)}c=0;if(g){break u}if(!i){break a}c=1;if(Qj(y[i+31|0])){break u}break a}c=0;if(!g){break a}}H:{if(!(!d|(h^1|x[b+104>>2]!=(g|0)))){e=x[a+480180>>2];if(x[b+76>>2]?e&16777250:0){break b}I:{J:{if((e|0)!=4){break J}if(!Ob(a+1074312|0,40)|y[b+789|0]){break J}e=x[b+88>>2];break I}e=x[b+88>>2]&-6145}x[b+88>>2]=e&-640;break H}x[b+88>>2]=x[b+88>>2]&-6145;e=a+1074312|0;K:{L:{if(!Ob(e,18)){h=-640;if(j|(x[a+480180>>2]&16777248|x[b+104>>2]!=(g|0))){break L}break K}h=-640;if((j^-1)&x[b+104>>2]==(g|0)){break K}}h=-768}x[b+88>>2]=x[b+88>>2]&h;if(!i){break H}v[b+730|0]=y[i+60|0];v[b+738|0]=y[i+80|0];f=y[i+100|0];v[b+746|0]=f;M:{if((f&17)!=17){break M}if(Ob(e,36)|y[b+837|0]){break M}v[b+837|0]=127}e=y[i+21|0];if(Cd(e)){s=b,t=Fh(e),v[s+837|0]=t}e=y[i+22|0];if(!Cd(e)){break H}s=b,t=Fh(e),v[s+838|0]=t}if(c){x[b+76>>2]=0;x[b+104>>2]=0;return}N:{if(x[b+76>>2]|!d){break N}c=a+1074312|0;if(!Ob(c,54)){if(!Ob(c,39)){break N}}x[b+8>>2]=0;x[b+12>>2]=0}O:{if(y[b+788|0]!=255){break O}if(!Ob(a+1074312|0,100)|!(y[a+480208|0]>>>2&m)){break O}c=x[b+104>>2];if(c){x[b+88>>2]=x[b+88>>2]|z[c+34>>1]&1023}x[b+752>>2]=r;x[b+688>>2]=z[g+30>>1];if(!(y[g+34|0]&32)){break b}Vq(b,z[g+28>>1],a);return}x[b+104>>2]=g;x[b+76>>2]=x[g>>2];x[b+80>>2]=x[g+4>>2];x[b+84>>2]=x[g+8>>2];c=a+1074312|0;if(!(!Ob(c,83)|x[b+80>>2])){x[b+84>>2]=x[g>>2]}x[b+88>>2]=x[b+88>>2]|z[g+34>>1]&1023;if(Ob(c,21)){v[b+818|0]=0;x[b+756>>2]=0}P:{Q:{if(p){x[b+704>>2]=x[g+24>>2];v[b+851|0]=y[b+851|0]|64;d=0;break Q}if(!(m|n)){d=x[a+480180>>2];if(d&5){break P}}x[b+704>>2]=x[g+24>>2];d=v[g+37|0]}w[b+772>>1]=d;d=x[a+480180>>2]}if(En(d)){d=v[g+36|0]}else{d=0}w[b+770>>1]=d;if(!(Ob(c,69)|x[a+480180>>2]==1)){x[b+708>>2]=0}x[b+852>>2]=0;h=x[b+88>>2];if(h&8){x[b+80>>2]=x[g+12>>2];x[b+84>>2]=x[g+16>>2];h=h>>>2&4|h|2;x[b+88>>2]=h}c=x[b+76>>2];R:{if(!(h&2)){break R}d=x[b+84>>2];if(d>>>0>=c>>>0){break R}x[b+76>>2]=d;c=d}if(!(x[a+480180>>2]&16777248)|A[b+4>>2]<c>>>0){break b}x[b>>2]=0;x[b+4>>2]=0}return}x[b+752>>2]=0;x[b+104>>2]=0}
function Uoa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;d=fb-224|0;fb=d;xc(b);f=d+160|0;a:{if(!Er(b,f)){break a}if(!TW(f)){break a}if(!Mb(x[b>>2],x[b+8>>2],Bc(SW(f),hb))){break a}e=1;if((c|0)==64){break a}Bd(a,256);i=d+148|0;vi(i,2,f);e=d+56|0;Cc(e,i);Ab(a+1298308|0,e);tb(e);f=y[d+210|0]|y[d+211|0]<<8;x[a+480260>>2]=64;x[a+480264>>2]=32767;w[a+480188>>1]=4;w[a+480190>>1]=f;Lb(a+1074312|0,107,1);f=y[d+203|0];f=f?f:96;i=xC(f);x[a+480196>>2]=f>>>4;x[a+480204>>2]=i;v[d+56|0]=64;q=a,r=y[Qb(d+202|0,e)|0]<<2,x[q+480200>>2]=r;e=0;b:{c:{d:{e:{f:{g:{while(1){if((e|0)==4){h:{i=Nb(d+148|0);m=Nb(d+136|0);x[31737]=0;P(150,b|0,(y[d+192|0]|y[d+193|0]<<8)<<4)|0;e=x[31737];x[31737]=0;i:{if((e|0)==1){break i}x[31737]=0;U(214,b|0,i|0,y[d+208|0]|y[d+209|0]<<8)|0;e=x[31737];x[31737]=0;if((e|0)==1){break i}x[31737]=0;P(150,b|0,(y[d+194|0]|y[d+195|0]<<8)<<4)|0;e=x[31737];x[31737]=0;if((e|0)==1){break i}x[31737]=0;U(214,b|0,m|0,y[d+210|0]|y[d+211|0]<<8)|0;e=x[31737];x[31737]=0;if((e|0)==1){break i}x[31737]=0;P(150,b|0,((y[d+196|0]|y[d+197|0]<<8)<<4)+32|0)|0;e=x[31737];x[31737]=0;if((e|0)==1){break i}e=y[a+484376|0];f=x[a+484360>>2];x[31737]=0;O(331,Xb(f,e)|0,y[d+212|0]|y[d+213|0]<<8);e=x[31737];x[31737]=0;if((e|0)==1){break i}e=Xb(x[a+484360>>2],y[a+484376|0]);q=d,r=wb(x[e>>2]),x[q+56>>2]=r;e=wb(x[e+4>>2]);j:{while(1){f=x[d+56>>2];if(!Ib(f,e)){e=0;if(!VW(Xb(x[a+484360>>2],y[a+484376|0]))){break b}k=c&2;n=d+57|0;e=1;break j}x[31737]=0;g=R(198,b|0)|0;h=x[31737];x[31737]=0;k:{if((h|0)==1){break k}w[f>>1]=g;x[31737]=0;P(184,b|0,4)|0;f=x[31737];x[31737]=0;if((f|0)==1){break k}Md(d+56|0);continue}break}b=N()|0;break c}l:{m:{n:{o:{while(1){g=e&65535;if(g>>>0>(y[d+210|0]|y[d+211|0]<<8)>>>0){break l}f=_b(x[m>>2],g-1|0);f=y[f|0]|y[f+1|0]<<8;x[31737]=0;f=P(150,b|0,f<<4)|0;h=x[31737];x[31737]=0;p:{if((h|0)!=1){if(f){break p}e=0;break b}b=N()|0;break c}x[31737]=0;h=d+56|0;P(700,b|0,h|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break o}x[31737]=0;l=(D(g,104)+a|0)+484380|0;S(701,h|0,l|0,0);f=x[31737];x[31737]=0;if((f|0)==1){break o}j=d+28|0;Pk(j,2,n);x[31737]=0;f=d+40|0;O(219,f|0,j|0);j=x[31737];x[31737]=0;if((j|0)==1){break n}zc(((g<<5)+a|0)+946304|0,f);tb(f);q:{r:{if(!k|!(y[d+72|0]|y[d+73|0]<<8|(y[d+74|0]<<16|y[d+75|0]<<24))){break r}g=fX(h);x[31737]=0;g=P(150,b|0,g|0)|0;h=x[31737];x[31737]=0;if((h|0)==1){break m}if(!g){break r}eX(f,y[d+86|0],y[d+87|0],1);x[31737]=0;U(216,f|0,l|0,b|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break q}}e=e+1|0;continue}break}b=N()|0;break c}b=N()|0;break c}b=N()|0;break c}b=N()|0;break c}v[d+27|0]=1;n=0;e=x[i>>2];s:{if(mc(e,x[i+4>>2])|(y[d+188|0]|y[d+189|0]<<8)==26){break s}f=y[e|0]|y[e+1|0]<<8;e=0;x[31737]=0;f=P(150,b|0,f<<4)|0;g=x[31737];x[31737]=0;if((g|0)==1){break h}if(!f){break b}x[31737]=0;e=R(190,b|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break h}if((y[d+188|0]|y[d+189|0]<<8)!=(e|0)){break s}v[d+27|0]=0;n=1}l=c&1;if(l){x[31737]=0;O(224,a+484344|0,y[d+208|0]|y[d+209|0]<<8);c=x[31737];x[31737]=0;if((c|0)==1){break h}}h=a+484344|0;f=0;while(1){t:{if(!l|(y[d+208|0]|y[d+209|0]<<8)>>>0<=f>>>0){break t}x[31737]=0;c=U(197,h|0,f&65535,64)|0;e=x[31737];x[31737]=0;if((e|0)==1){break g}if(!c){break t}c=_b(x[i>>2],f);c=y[c|0]|y[c+1|0]<<8;x[31737]=0;c=P(150,b|0,c<<4)|0;e=x[31737];x[31737]=0;if((e|0)==1){break g}e=0;if(!c){break b}if(n){x[31737]=0;c=R(190,b|0)|0;g=x[31737];x[31737]=0;if((g|0)==1){break g}if(c>>>0>2112){break b}}w[d+12>>1]=65535;x[d+28>>2]=63;c=Wb(x[h>>2],f);bf(d+40|0,x[c>>2],x[x[c+48>>2]+12>>2],0);u:while(1){c=e;while(1){if(c>>>0<=63){x[31737]=0;e=R(198,b|0)|0;g=x[31737];x[31737]=0;if((g|0)==1){break f}k=e<<24>>24;if(!k){e=64;if(c>>>0>62){continue u}e=Wb(x[h>>2],f);g=x[e>>2];j=x[x[e+48>>2]+12>>2];e=c+1|0;bf(d+56|0,g,j,e);c=x[d+60>>2];x[d+40>>2]=x[d+56>>2];x[d+44>>2]=c;continue u}e=bh(d+56|0);g=k&31;if(g>>>0<z[a+480188>>1]){e=Wc(x[d+40>>2],g)}j=k&255;if(j&32){x[31737]=0;g=d+25|0;O(199,g|0,b|0);o=x[31737];x[31737]=0;v:{w:{x:{if((o|0)!=1){o=Jc(g);g=y[d+25|0];if(g>>>0>239){break x}g=dX((D(g>>>4|0,12)+(g&15)|0)+37|0);break w}b=N()|0;break c}y:{switch(g-254|0){case 0:break w;case 1:break y;default:break v}}g=0}v[e|0]=g}v[e+1|0]=y[o|0]}if(j&64){x[31737]=0;g=R(198,b|0)|0;j=x[31737];x[31737]=0;if((j|0)==1){break e}v[d+25|0]=g;v[e+2|0]=1;v[d+24|0]=64;q=e,r=y[Qb(d+25|0,d+24|0)|0],v[q+4|0]=r}if((k|0)>=0){continue}x[31737]=0;g=d+25|0;O(199,g|0,b|0);k=x[31737];x[31737]=0;if((k|0)==1){break d}q=e,r=y[Jc(g)|0],v[q+5|0]=r;UW(e,y[d+25|0],c,255,d+12|0,d+28|0);continue}break}break}c=z[d+12>>1];if((c|0)!=65535){ye(Wb(x[h>>2],f),Gn(Xe(Ne(d+56|0,12,c&255),x[d+28>>2])))}f=f+1|0;continue}break}x[31737]=0;b=P(1,d+56|0,6088)|0;c=x[31737];x[31737]=0;z:{A:{B:{if((c|0)!=1){Ab(a+1298344|0,b);tb(b);x[31737]=0;b=P(1,d+40|0,5274)|0;c=x[31737];x[31737]=0;if((c|0)==1){break B}Ab(a+1298356|0,b);tb(b);b=d+28|0;q=a+1298404|0,r=x[Fc(b,4)>>2],x[q>>2]=r;x[31737]=0;c=d+12|0;O(703,c|0,4405);e=x[31737];x[31737]=0;if((e|0)==1){break A}x[31737]=0;S(210,b|0,c|0,d+27|0);e=x[31737];x[31737]=0;if((e|0)==1){break z}Ab(a+1298368|0,b);tb(b);Eb(c);e=1;break b}b=N()|0;break c}b=N()|0;break c}b=N()|0;break c}b=N()|0;Eb(d+12|0);break c}b=N()|0;break c}}else{f=(e<<5)+a|0;We(f+480280|0);w[f+480284>>1]=e&1?64:192;e=e+1|0;continue}break}b=N()|0;break c}b=N()|0;break c}b=N()|0;break c}b=N()|0;break c}b=N()|0}md(m);md(i);Q(b|0);p()}md(m);md(i)}fb=d+224|0;return e|0}function zsa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0;e=fb-1344|0;fb=e;xc(b);f=fb-16|0;fb=f;d=e+768|0;a_(f+8|0,d);g=x[f+12>>2];lc(f,x[b>>2],x[b+8>>2],x[f+8>>2],x[f+12>>2]);i=x[f+4>>2];if((i|0)==(g|0)){Vb(b,x[f+12>>2])}fb=f+16|0;f=(g|0)==(i|0);if(!f){$Z(d)}a:{b:{c:{if(!f){break c}if(!c_(d)){break c}if(!Mb(x[b>>2],x[b+8>>2],Bc(b_(y[e+802|0]|y[e+803|0]<<8,y[e+804|0]|y[e+805|0]<<8),hb))){break c}s=1;if((c|0)==64){break c}n=sc(e+764|0);f=0;while(1){s=(j|0)==32;if(!s){d=(j<<5)+a|0;g=d+480280|0;We(g);i=(e+768|0)+(j<<4)|0;w[d+480284>>1]=((y[i+78|0]<<8&65280)>>>0)/255;l=e+496|0;Pk(l,1,i- -64|0);h=e+108|0;Cc(h,l);om(d+480289|0,h);tb(h);d:{e:{switch(y[i+79|0]){case 0:k=f+1|0;break d;case 1:x[g>>2]=1024;k=j+1|0;break d;case 2:break e;default:break c}}x[g>>2]=1024;d=e+108|0;Pc(d,n,j);fp(d)}f=f+1|0;j=j+1|0;continue}break}Bd(a,33554432);w[a+480188>>1]=k&255;f=e+108|0;d=tc(f,6808);Ab(a+1298344|0,d);tb(d);d=tc(f,11156);Ab(a+1298356|0,d);tb(d);B=a+1298404|0,C=x[Fc(f,4)>>2],x[B>>2]=C;f:{if(y[e+847|0]){break f}j=1;f=1;while(1){if((j|0)==16){while(1){if((f|0)==16){break f}d=((f<<5)+a|0)+480280|0;x[d>>2]=x[d>>2]&-1025;f=f+1|0;continue}}d=j<<4;j=j+1|0;if(y[(e+d|0)+847|0]==1){continue}break}}f=e+496|0;Ve(f,1,e+768|0);d=e+108|0;Cc(d,f);Ab(a+1298308|0,d);tb(d);x[a+480208>>2]=x[a+480208>>2]&-17|(y[e+806|0]|y[e+807|0]<<8)<<4&16;x[a+480196>>2]=y[e+816|0];x[a+480204>>2]=D(y[e+817|0],1e4);x[a+480200>>2]=y[e+818|0]<<2;x[a+480228>>2]=y[e+819|0];d=y[e+804|0]|y[e+805|0]<<8;w[a+480190>>1]=0;w[a+480192>>1]=d;Dw(b,f);Vr(Xb(x[a+484360>>2],y[a+484376|0]),f,y[e+800|0]|y[e+801|0]<<8,65535,255);t=c&1;if(t){Vf(a+484344|0,y[e+802|0]|y[e+803|0]<<8)}m=a+484344|0;j=0;g:{while(1){if((y[e+802|0]|y[e+803|0]<<8)>>>0<=j>>>0){l=c&2;f=1;c=0;h:while(1){if(z[a+480192>>1]<=(c&65535)>>>0){break c}c=c+1|0;g=BE(a,c&65535,0);i=!g;d=fb-16|0;fb=d;j=e+108|0;bc(d+8|0,j,384);k=x[d+12>>2];lc(d,x[b>>2],x[b+8>>2],x[d+8>>2],x[d+12>>2]);h=x[d+4>>2];if((h|0)==(k|0)){Vb(b,x[d+12>>2])}fb=d+16|0;d=(h|0)==(k|0);if(!d){Rb(j,0,384)}if(!d|i){continue}i=f&65535;k=fb-32|0;fb=k;h=k+8|0;Ve(h,1,j);d=k+20|0;Cc(d,h);zc(g+492|0,d);tb(d);i:{if(!(y[j+378|0]|y[j+379|0]<<8)){break i}h=g+236|0;d=0;while(1){x[k+20>>2]=120;x[k+8>>2]=116;if(A[Gb(k+20|0,k+8|0)>>2]<=d>>>0){break i}n=y[(d+j|0)+32|0];B=_b(h,d+12|0),C=i+n|0,w[B>>1]=C;d=d+1|0;continue}}d=y[j+376|0]|y[j+377|0]<<8;v[g+33|0]=1;x[g>>2]=d;BD(j,g+48|0,0);BD(j,g+68|0,1);BD(j,g+88|0,2);d=y[g+100|0];if(d&1){v[g+100|0]=d|16}if(!(x[g>>2]|v[g+60|0]&1)){x[g>>2]=32767}fb=k+32|0;j=0;while(1){d=y[e+486|0]|y[e+487|0]<<8;if(d>>>0<=j>>>0){f=d+f|0;continue h}v$(b,e+44|0);j:{d=f+j|0;i=d&65535;k:{if(i>>>0>=4e3){Vb(b,y[e+60|0]|y[e+61|0]<<8|(y[e+62|0]<<16|y[e+63|0]<<24));break k}w[a+480190>>1]=d;k=fb-32|0;fb=k;h=D(i,104)+a|0;n=h+484380|0;g=n;ld(g,0);m=k+8|0;jk(m,1,e+44|0);d=k+20|0;Cc(d,m);ze(g+43|0,d);tb(d);m=y[e+60|0]|y[e+61|0]<<8|(y[e+62|0]<<16|y[e+63|0]<<24);x[g>>2]=m;q=y[e+64|0]|y[e+65|0]<<8|(y[e+66|0]<<16|y[e+67|0]<<24);x[g+4>>2]=q;o=y[e+68|0]|y[e+69|0]<<8|(y[e+70|0]<<16|y[e+71|0]<<24);x[g+8>>2]=o;x[g+24>>2]=y[e+72|0]|y[e+73|0]<<8|(y[e+74|0]<<16|y[e+75|0]<<24);w[g+30>>1]=y[e+76|0]<<2;w[g+28>>1]=y[e+77|0];d=y[e+92|0];if(d&1){w[g+34>>1]=z[g+34>>1]|2;d=y[e+92|0]}if(d&2){w[g+34>>1]=z[g+34>>1]|4;d=y[e+92|0]}if(d&4){x[g+8>>2]=o>>>1;x[g+4>>2]=q>>>1;x[g>>2]=m>>>1;w[g+34>>1]=z[g+34>>1]|1;d=y[e+92|0]}if(d&8){w[g+34>>1]=z[g+34>>1]|32}fb=k+32|0;d=fb-16|0;fb=d;Pw(d+8|0,h+484423|0);g=e+24|0;Ep(g,x[d+8>>2],x[d+12>>2]);fb=d+16|0;zc(((i<<5)+a|0)+946304|0,g);tb(g);k=y[e+60|0]|y[e+61|0]<<8|(y[e+62|0]<<16|y[e+63|0]<<24);if(!k){break k}d=e+4|0;fe(d,b,k);k=ic(g,d);ub(d);if(l){d=Xc(d,w[h+484414>>1]&1?16:8,1,0,0);x[31737]=0;U(216,d|0,n|0,k|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break j}}ub(k)}j=j+1|0;continue}break}break}a=N()|0;break a}d=hh(b);q=hh(b);f=e+44|0;fe(f,b,d-4|0);k=ic(e+108|0,f);ub(f);l:{m:{if(!t){break m}x[31737]=0;f=U(197,m|0,j&65535,q|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break l}if(!f){break m}d=0;g=bh(e+24|0);n:while(1){u=d>>>0>=q>>>0;while(1){if(u){break m}x[31737]=0;i=R(198,k|0)|0;f=x[31737];x[31737]=0;o:{if((f|0)!=1){if(i){break o}d=d+1|0;continue n}break b}f=g;o=i&31;if(o>>>0<z[a+480188>>1]){f=Wb(x[m>>2],j);f=jd(x[f>>2],x[x[f+48>>2]+12>>2],d,o)}if(i&32){x[31737]=0;l=e+44|0;O(199,l|0,k|0);h=x[31737];x[31737]=0;if((h|0)==1){break g}h=y[e+44|0];v[f|0]=h;B=f,C=y[Jc(l)|0],v[B+1|0]=C;l=255;p:{if((h|0)==160){break p}l=0;if((h|0)==255){break p}h=(D(h>>>4|0,12)+(h&15)|0)+13|0;l=_Z(h)?h:0}v[f|0]=l}i=i&192;q:{if(!i){break q}if((i|0)==192){x[31737]=0;i=e+44|0;O(358,i|0,k|0);h=x[31737];x[31737]=0;if((h|0)!=1){h=Jc(i);l=$e(i);i=dj(i);r=e+4|0;CD(r,y[e+44|0],y[h|0]);h=Jc(r);r=e+494|0;CD(r,y[l|0],y[i|0]);mm(e+492|0,f,y[e+4|0],y[h|0],y[e+494|0],y[Jc(r)|0]);break q}break b}x[31737]=0;i=e+44|0;O(199,i|0,k|0);h=x[31737];x[31737]=0;r:{s:{if((h|0)!=1){h=e+4|0;CD(h,y[e+44|0],y[Jc(i)|0]);h=y[Jc(h)|0];i=y[e+4|0];if((i|0)!=13){break s}v[f+2|0]=1;i=f+4|0;break r}break b}v[f+3|0]=i;i=f+5|0}v[i|0]=h}Pc(e+44|0,n,o);if(!Hb(x[x[e+44>>2]>>2],x[e+48>>2])){continue}if(!v0(y[f+3|0],y[f+5|0])){continue}v[f+3|0]=0;continue}}}ub(k);j=j+1|0;continue}break}break b}break b}fb=e+1344|0;return s|0}a=N()|0}ub(k);Q(a|0);p()}function iqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=fb-1824|0;fb=e;xc(b);d=fb-16|0;fb=d;f=e+1224|0;eY(d+8|0,f);i=x[d+12>>2];lc(d,x[b>>2],x[b+8>>2],x[d+8>>2],x[d+12>>2]);m=x[d+4>>2];if((m|0)==(i|0)){Vb(b,x[d+12>>2])}fb=d+16|0;d=(i|0)==(m|0);if(!d){dY(f)}a:{if(!d){break a}if(!fY(f)){break a}if(!SC(b,16,0)){break a}d=e+1240|0;x[e+1216>>2]=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);d=y[e+1228|0]|y[e+1229|0]<<8|(y[e+1230|0]<<16|y[e+1231|0]<<24);x[e+1200>>2]=y[e+1224|0]|y[e+1225|0]<<8|(y[e+1226|0]<<16|y[e+1227|0]<<24);x[e+1204>>2]=d;d=e+1232|0;f=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);d=y[d+4|0]|y[d+5|0]<<8|(y[d+6|0]<<16|y[d+7|0]<<24);x[e+1208>>2]=f;x[e+1212>>2]=d;Bd(a,1);Lb(Lb(dg(a+1074312|0,83),84,1),85,1);w[a+480188>>1]=4;x[e+1196>>2]=0;w[a+480190>>1]=15;cd(b,20);l=a+480188|0;g=1;i=1;b:{while(1){c:{if((g|0)==16){d=e+1064|0;if(!NC(b,d)){JC(d)}d=a+484376|0;kw(Xb(x[a+484360>>2],y[d|0]),e+1066|0,128);m=nY(b,Xb(x[a+484360>>2],y[d|0]),y[e+1064|0],h,l,0,1);if(!(y[e+1065|0]|m>>>0>1)){g=0;if(!y[e+1064|0]){break a}}d=(m<<10)+h|0;x[e+1060>>2]=d;x[e+24>>2]=65536;g=0;if(!Mb(x[b>>2],x[b+8>>2],d-x[Gb(e+1060|0,e+24|0)>>2]|0)){break a}g=1;if((c|0)==64){break a}g=y[e+1065|0];if(!g){v[e+1065|0]=120;g=120}if(kd(e+1200|0,15036,6)){break c}v[e+1065|0]=120;x[a+480204>>2]=125e4;break b}d=e+24|0;LC(b,d);n=d;f=D(g,104)+a|0;m=f+484380|0;d=((g<<5)+a|0)+946304|0;UC(n,m,d,1);k=x[m>>2];d:{if(!y[xb(d,0)|0]){break d}e:{if(kd(d,16819,3)){if(kd(d,16823,3)){break e}}if(y[xb(d,5)|0]==58){break d}}i=0}d=Bb(y[e+52|0]|y[e+53|0]<<8);if(d>>>0>=2){n=d<<1;d=Bb(y[e+50|0]|y[e+51|0]<<8);x[f+484388>>2]=n+d;x[f+484384>>2]=d;_k(m)}f:{if(Bb(y[e+46|0]|y[e+47|0]<<8)>>>0<=4999){if(Bb(y[e+50|0]|y[e+51|0]<<8)>>>0<1e4){break f}}x[e+1064>>2]=5;s=e,t=x[Ye(e+1196|0,e+1064|0)>>2],x[s+1196>>2]=t}h=h+k|0;g=g+1|0;continue}break}x[a+480204>>2]=125e4;if((g|0)==120){break b}s=a,t=Ze(1773447.5/(+(240-g|0)*122)*1e4),x[s+480204>>2]=t;if(x[e+1196>>2]>=2){x[e+24>>2]=i&1?4:5;s=e,t=x[Ye(e+1196|0,e+24|0)>>2],x[s+1196>>2]=t;break b}x[e+24>>2]=i&1?1:2;s=e,t=x[Ye(e+1196|0,e+24|0)>>2],x[s+1196>>2]=t}x[a+480228>>2]=64;x[a+480260>>2]=452;x[a+480264>>2]=3424;x[a+480208>>2]=x[a+480208>>2]|2097152;f=e+1048|0;vi(f,3,e+1200|0);d=e+24|0;Cc(d,f);Ab(a+1298308|0,d);tb(d);Xh(a,0);f=i&1;n=x[b+8>>2];while(1){g:{if(m>>>0>(j&65535)>>>0){d=Xb(x[a+484360>>2],y[a+484376|0]);d=Ib(KC(wb(x[d>>2]),wb(x[d+4>>2]),j),wb(x[d+4>>2]));g=e+24|0;bY(b,g);h:{if(d){q=QC(g,0)+q|0;if(q>>>0>512){break h}}o=0;d=x[e+1196>>2];h=0;i=0;i:while(1){if((i|0)==64){break g}g=0;while(1)if((g|0)==4){i=i+1|0;continue i}else{k=yb(Xd(e+24|0,i),g);p=y[xb(k,2)|0]&15;l=y[xb(k,3)|0];j:{if(!(!(h&255)|(y[k|0]|y[k+1|0]<<8|(y[k+2|0]<<16|y[k+3|0]<<24)))){h=h+1|0;if((h&255)>>>0<33){break j}d=6;x[e+1196>>2]=6;break j}h=0}k:{l:{m:{n:{switch(p-1|0){case 0:case 1:if((d|0)==1&l>>>0>=32){break l}k=(p|0)!=1;if(!(k|!l|l>>>0>2)){x[e+1048>>2]=2;d=x[Ye(e+1196|0,e+1048|0)>>2];break m}if(k|(l|0)!=55&(l|0)!=71){break k}if((d|0)<=2){break l}break k;case 10:d=6;break m;case 11:case 12:case 13:x[e+1048>>2]=2;d=x[Ye(e+1196|0,e+1048|0)>>2];x[e+1196>>2]=d;if((p|0)!=13){break k}o=((i|l)!=0)+o|0;h=1;break k;case 14:break n;default:break k}}x[e+1048>>2]=3;d=x[Ye(e+1196|0,e+1048|0)>>2]}x[e+1196>>2]=d;break k}x[e+1196>>2]=f;d=f}g=g+1|0;continue}}}g=0;break a}if(!(x[e+1196>>2]!=6|m+32>>>0>=r>>>0)){x[e+1196>>2]=5}cd(b,n);p=c&1;if(p){Vf(a+484344|0,m)}o=a+484344|0;l=0;while(1)if((l|0)==(m|0)){g=22303;d=x[e+1196>>2];if(d>>>0<7){g=x[(d<<2)+25308>>2]}d=e+24|0;f=tc(d,8304);Ab(a+1298344|0,f);tb(f);f=tc(d,10801);Ab(a+1298356|0,f);tb(f);bi(a+1298368|0,g);s=a+1298404|0,t=x[Fc(d,28)>>2],x[s>>2]=t;g=1;if(!(c&2)){break a}while(1)if((g|0)==16){g=1;break a}else{c=D(g,104)+a|0;d=c+484384|0;Vb(b,x[d>>2]);f=x[d>>2];x[d>>2]=0;d=c+484380|0;x[d>>2]=x[d>>2]-f;c=c+484388|0;x[c>>2]=x[c>>2]-f;c=e+24|0;Xc(c,8,1,1,0);fg(c,d,b);g=g+1|0;continue}}else{bY(b,e+24|0);o:{if(!p){break o}if(!Ng(o,l&65535,64)){break o}i=0;x[e+20>>2]=0;p:while(1){if((i|0)==64){break o}d=Wb(x[o>>2],l);bf(e+1048|0,x[d>>2],x[x[d+48>>2]+12>>2],i);g=0;while(1)if((g|0)==4){i=i+1|0;continue p}else{d=Wc(x[e+1048>>2],g);f=yb(Xd(e+24|0,i),g);f=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);x[e+8>>2]=f;x[e+12>>2]=f;f=e+18|0;ip(f,e+8|0,d);k=(e+20|0)+g|0;h=y[e+18|0];f=Jc(f);j=y[f|0];q:{r:{if(!((h|0)!=14?j:0)){v[k|0]=0;if(h|j){break r}break q}j=y[k|0];if(!j){break r}n=j;q=j>>>4|0;j=j>>>0<16;v[d+4|0]=j?n:q;v[d+2|0]=j?4:3}s:{t:{u:{v:{w:{switch(h-12|0){case 1:h=x[e+1196>>2];if((h|0)!=6){v[e+18|0]=10;break u}v[f|0]=0;break v;case 0:v[f|0]=y[f|0]&127;break v;case 2:h=y[f|0];if(h>>>0<=1){j=14;if(x[e+1196>>2]>3){break t}}v[e+18|0]=10;v[k|0]=y[f|0];break v;case 3:break w;default:break v}}v[f|0]=y[f|0]&15}h=x[e+1196>>2]}if((h|0)<2){break s}h=y[f|0];j=y[e+18|0]}Bf(d,j,h&255);break q}f=y[f|0];v[d+5|0]=f;x:{y:{z:{switch(y[e+18|0]){case 0:if(f>>>0>2){break y}break;case 2:break x;case 1:break y;default:break z}}v[d+3|0]=0;break q}v[d+3|0]=1;break q}h=f&15;if(h){v[d+5|0]=h;v[d+3|0]=2;break q}if(f>>>0<16){break q}v[d+3|0]=3;v[d+5|0]=(f&240)>>>4}g=g+1|0;continue}}}l=l+1|0;continue}}if((o-1&255)>>>0<2){x[e+1196>>2]=6}j=j+1|0;r=(o&255)+r|0;continue}}fb=e+1824|0;return g|0}function CL(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,z=0,A=0,B=0,E=0,F=0,G=0,H=0;i=fb-80|0;fb=i;x[i+76>>2]=b;E=e-192|0;F=d-384|0;H=i+55|0;s=i+56|0;a:{b:{c:{d:while(1){h=0;e:while(1){k=b;if((r^2147483647)<(h|0)){break c}r=h+r|0;f:{g:{h:{h=b;j=y[h|0];if(j){while(1){i:{b=j&255;j:{if(!b){b=h;break j}if((b|0)!=37){break i}j=h;while(1){if(y[j+1|0]!=37){b=j;break j}h=h+1|0;l=y[j+2|0];b=j+2|0;j=b;if((l|0)==37){continue}break}}h=h-k|0;G=r^2147483647;if((h|0)>(G|0)){break c}if(a){Kf(a,k,h)}if(h){continue e}x[i+76>>2]=b;h=b+1|0;q=-1;l=v[b+1|0];if(!(!Oh(l)|y[b+2|0]!=36)){q=l-48|0;t=1;h=b+3|0}x[i+76>>2]=h;n=0;j=v[h|0];b=j-32|0;k:{if(b>>>0>31){l=h;break k}l=h;b=1<<b;if(!(b&75913)){break k}while(1){l=h+1|0;x[i+76>>2]=l;n=b|n;j=v[h+1|0];b=j-32|0;if(b>>>0>=32){break k}h=l;b=1<<b;if(b&75913){continue}break}}l:{if((j|0)==42){b=v[l+1|0];m:{if(!(!Oh(b)|y[l+2|0]!=36)){n:{if(!a){x[(b<<2)+E>>2]=10;p=0;break n}p=x[(b<<3)+F>>2]}b=l+3|0;t=1;break m}if(t){break h}b=l+1|0;if(!a){x[i+76>>2]=b;t=0;p=0;break l}h=x[c>>2];x[c>>2]=h+4;p=x[h>>2];t=0}x[i+76>>2]=b;if((p|0)>=0){break l}p=0-p|0;n=n|8192;break l}p=BL(i+76|0);if((p|0)<0){break c}b=x[i+76>>2]}h=0;m=-1;j=0;o:{if(y[b|0]!=46){break o}if(y[b+1|0]==42){l=v[b+2|0];p:{if(!(!Oh(l)|y[b+3|0]!=36)){b=b+4|0;q:{if(!a){x[(l<<2)+E>>2]=10;m=0;break q}m=x[(l<<3)+F>>2]}break p}if(t){break h}b=b+2|0;m=0;if(!a){break p}l=x[c>>2];x[c>>2]=l+4;m=x[l>>2]}x[i+76>>2]=b;j=(m|0)>=0;break o}x[i+76>>2]=b+1;m=BL(i+76|0);b=x[i+76>>2];j=1}z=j;while(1){u=h;o=28;A=b;l=v[b|0];if(l-123>>>0<4294967238){break b}b=b+1|0;h=y[(l+D(h,58)|0)+93007|0];if(h-1>>>0<8){continue}break}x[i+76>>2]=b;r:{if((h|0)!=27){if(!h){break b}if((q|0)>=0){if(!a){x[(q<<2)+e>>2]=h;continue d}h=(q<<3)+d|0;l=x[h+4>>2];x[i+64>>2]=x[h>>2];x[i+68>>2]=l;break r}if(!a){break f}AL(i- -64|0,h,c,g);break r}if((q|0)>=0){break b}h=0;if(!a){continue e}}o=-1;if(y[a|0]&32){break a}j=n&-65537;n=n&8192?j:n;q=0;B=5286;l=s;s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{h=v[A|0];h=u?(h&15)==3?h&-33:h:h;switch(h-88|0){case 11:break s;case 9:case 13:case 14:case 15:break t;case 27:break y;case 12:case 17:break B;case 23:break C;case 0:case 32:break D;case 24:break E;case 22:break F;case 29:break G;case 1:case 2:case 3:case 4:case 5:case 6:case 7:case 8:case 10:case 16:case 18:case 19:case 20:case 21:case 25:case 26:case 28:case 30:case 31:break g;default:break H}}I:{switch(h-65|0){case 0:case 4:case 5:case 6:break t;case 2:break w;case 1:case 3:break g;default:break I}}if((h|0)==83){break x}break g}k=x[i+64>>2];j=x[i+68>>2];b=5286;break A}h=0;J:{switch(u&255){case 0:x[x[i+64>>2]>>2]=r;continue e;case 1:x[x[i+64>>2]>>2]=r;continue e;case 2:k=x[i+64>>2];x[k>>2]=r;x[k+4>>2]=r>>31;continue e;case 3:w[x[i+64>>2]>>1]=r;continue e;case 4:v[x[i+64>>2]]=r;continue e;case 6:x[x[i+64>>2]>>2]=r;continue e;case 7:break J;default:continue e}}k=x[i+64>>2];x[k>>2]=r;x[k+4>>2]=r>>31;continue e}m=m>>>0<=8?8:m;n=n|8;h=120}b=s;u=h&32;k=x[i+64>>2];j=x[i+68>>2];if(k|j){while(1){b=b-1|0;v[b|0]=u|y[(k&15)+93536|0];A=!j&k>>>0>15|(j|0)!=0;o=j;j=j>>>4|0;k=(o&15)<<28|k>>>4;if(A){continue}break}}k=b;if(!(n&8)|!(x[i+64>>2]|x[i+68>>2])){break z}B=(h>>>4|0)+5286|0;q=2;break z}b=s;h=x[i+68>>2];j=h;k=x[i+64>>2];if(h|k){while(1){b=b-1|0;v[b|0]=k&7|48;o=!j&k>>>0>7|(j|0)!=0;h=j;j=h>>>3|0;k=(h&7)<<29|k>>>3;if(o){continue}break}}k=b;if(!(n&8)){break z}b=s-b|0;m=(b|0)<(m|0)?m:b+1|0;break z}k=x[i+64>>2];b=x[i+68>>2];j=b;if((b|0)<0){h=0-(b+((k|0)!=0)|0)|0;j=h;k=0-k|0;x[i+64>>2]=k;x[i+68>>2]=h;q=1;b=5286;break A}if(n&2048){q=1;b=5287;break A}q=n&1;b=q?5288:5286}B=b;k=oo(k,j,s)}if((m|0)<0&z){break c}n=z?n&-65537:n;b=x[i+64>>2];h=x[i+68>>2];if(!((b|h)!=0|m)){k=s;m=0;break g}b=!(b|h)+(s-k|0)|0;m=(b|0)<(m|0)?m:b;break g}b=x[i+64>>2];k=b?b:17118;b=k;h=m>>>0>=2147483647?2147483647:m;l=Kz(b,0,h);b=l?l-b|0:h;l=b+k|0;if((m|0)>=0){n=j;m=b;break g}n=j;m=b;if(y[l|0]){break c}break g}if(m){j=x[i+64>>2];break v}h=0;Yf(a,32,p,0,n);break u}x[i+12>>2]=0;x[i+8>>2]=x[i+64>>2];j=i+8|0;x[i+64>>2]=j;m=-1}h=0;K:{while(1){k=x[j>>2];if(!k){break K}k=zL(i+4|0,k);l=(k|0)<0;if(!(l|k>>>0>m-h>>>0)){j=j+4|0;h=h+k|0;if(m>>>0>h>>>0){continue}break K}break}if(l){break a}}o=61;if((h|0)<0){break b}Yf(a,32,p,h,n);if(!h){h=0;break u}l=0;j=x[i+64>>2];while(1){k=x[j>>2];if(!k){break u}m=i+4|0;k=zL(m,k);l=k+l|0;if(l>>>0>h>>>0){break u}Kf(a,m,k);j=j+4|0;if(h>>>0>l>>>0){continue}break}}Yf(a,32,p,h,n^8192);h=(h|0)<(p|0)?p:h;continue e}if((m|0)<0&z){break c}o=61;h=ib[f|0](a,C[i+64>>3],p,m,n,h)|0;if((h|0)>=0){continue e}break b}v[i+55|0]=x[i+64>>2];m=1;k=H;n=j;break g}j=y[h+1|0];h=h+1|0;continue}}o=r;if(a){break a}if(!t){break f}h=1;while(1){a=x[(h<<2)+e>>2];if(a){AL((h<<3)+d|0,a,c,g);o=1;h=h+1|0;if((h|0)!=10){continue}break a}break}o=1;if(h>>>0>=10){break a}while(1){if(x[(h<<2)+e>>2]){break h}h=h+1|0;if((h|0)!=10){continue}break}break a}o=28;break b}l=l-k|0;j=(l|0)<(m|0)?m:l;if((j|0)>(q^2147483647)){break c}o=61;b=j+q|0;h=(b|0)<(p|0)?p:b;if((G|0)<(h|0)){break b}Yf(a,32,h,b,n);Kf(a,B,q);Yf(a,48,h,b,n^65536);Yf(a,48,j,l,0);Kf(a,k,l);Yf(a,32,h,b,n^8192);b=x[i+76>>2];continue}break}break}o=0;break a}o=61}x[31612]=o;o=-1}fb=i+80|0;return o}function bsa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0,F=0,G=0,H=0;g=fb-192|0;fb=g;n=gk(b,13935);if(n){if(d){v[d|0]=1}k=a+480204|0;o=a+480216|0;q=a+480220|0;r=a+480224|0;l=a+1074368|0;u=a+480228|0;B=a+480232|0;s=a+480200|0;m=a+480268|0;C=a+1298320|0;E=a+480248|0;F=Qv(a+1074312|0);a:{b:{c:{d:{e:{f:{g:{h:{while(1){if(!Mb(x[b>>2],x[b+8>>2],7)){break a}e=Pg(b);f=hh(b);if((e|0)==70791730){Gh(b,6);break a}if(!(e&1616928864)|e&-2139062144){break a}if(!Mb(x[b>>2],x[b+8>>2],f)){break a}i=g+152|0;fe(i,b,f);h=ic(g+172|0,i);ub(i);i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{if((e|0)!=1127099950){if((e|0)==1129797166){break v}if((e|0)==1130917459){break o}if((e|0)==1145525806){break t}d=B;if((e|0)==1448301654){break s}if((e|0)==1196316499){break m}if((e|0)==1213486401){break p}if((e|0)==1280530262){break u}if((e|0)==1297303086){break l}if((e|0)==1347243310){break w}if((e|0)==1347244882){break q}if((e|0)!=1380340804){if((e|0)==1380986414){break r}d=o;if((e|0)==1380991534){break s}d=q;if((e|0)==1380994350){break s}if((e|0)==1397052739){break n}d=u;if((e|0)==1397768494){break s}if((e|0)==1414344238){break k}if((e|0)!=1146367534){break j}x[31737]=0;S(452,h|0,f|0,i|0);d=x[31737];x[31737]=0;if((d|0)==1){break i}x[k>>2]=D(x[g+152>>2],1e4)+(A[k>>2]%1e4|0);break j}x[31737]=0;S(452,h|0,f|0,g+152|0);d=x[31737];x[31737]=0;if((d|0)!=1){d=x[k>>2];x[k>>2]=d-((d>>>0)%1e4|0)+A[g+152>>2]%1e4;break j}e=N()|0;break b}if(c){break j}x[31737]=0;w[g+152>>1]=0;S(453,h|0,f|0,g+152|0);d=x[31737];x[31737]=0;if((d|0)!=1){G=a,H=Kd(z[g+152>>1],z[a+480188>>1],127),w[G+480188>>1]=H;break j}e=N()|0;break b}x[31737]=0;S(454,h|0,f|0,l|0);d=x[31737];x[31737]=0;if((d|0)!=1){break j}break c}x[31737]=0;x[g+152>>2]=0;S(452,h|0,f|0,g+152|0);d=x[31737];x[31737]=0;if((d|0)!=1){x[a+1074304>>2]=x[g+152>>2];break j}e=N()|0;break b}x[31737]=0;x[g+152>>2]=0;S(452,h|0,f|0,g+152|0);d=x[31737];x[31737]=0;if((d|0)==1){break h}d=x[g+152>>2];if(!d){break j}x[a+1074308>>2]=d;break j}d=s}x[31737]=0;S(452,h|0,f|0,d|0);d=x[31737];x[31737]=0;if((d|0)==1){break c}break j}if(x[a+480180>>2]==4){break j}x[31737]=0;S(453,h|0,f|0,g+152|0);d=x[31737];x[31737]=0;if((d|0)!=1){af(Xb(x[a+484360>>2],y[a+484376|0]),z[g+152>>1]);break j}e=N()|0;break b}x[31737]=0;S(455,h|0,f|0,m|0);d=x[31737];x[31737]=0;if((d|0)==1){break c}if(zp(y[m|0])){break j}v[m|0]=5;break j}d=Fb(g+152|0);e=x[h>>2];x[31737]=0;e=R(155,e|0)|0;f=x[31737];x[31737]=0;x:{if((f|0)==1){break x}x[31737]=0;S(456,h|0,d|0,e|0);e=x[31737];x[31737]=0;if((e|0)==1){break x}x[31737]=0;e=g+140|0;S(259,e|0,0,d|0);f=x[31737];x[31737]=0;if((f|0)==1){break x}Ab(C,e);tb(e);tb(d);break j}e=N()|0;tb(d);break b}if(f&1|f>>>0>126){break j}d=64;w[g+152>>1]=(f>>>1|0)- -64;w[g+140>>1]=127;e=z[Nc(g+152|0,g+140|0)>>1];i=e>>>0<=64?64:e;while(1){if((d|0)==(i|0)){break j}x[31737]=0;f=g+152|0;O(199,f|0,h|0);e=x[31737];x[31737]=0;if((e|0)==1){break g}e=y[g+152|0];y:{if((e|0)==255){break y}j=y[Jc(f)|0];f=(d<<5)+a|0;t=f+480284|0;w[t>>1]=128;w[f+480286>>1]=j;f=f+480280|0;j=(e&128)<<3;x[f>>2]=j;e=e&127;if(e>>>0<65){w[t>>1]=e<<2;break y}if((e|0)!=100){break y}x[f>>2]=j|256}d=d+1|0;continue}}if(f>>>0<3){break j}x[31737]=0;d=R(190,h|0)|0;e=x[31737];x[31737]=0;if((e|0)==1){break f}if(z[a+480190>>1]<=(d-1&65535)>>>0){break j}d=(D(d,104)+a|0)+484448|0;f=RZ(d);while(1){if((d|0)==(f|0)){break j}e=x[h>>2];x[31737]=0;i=U(151,e|0,x[g+180>>2],4)|0;e=x[31737];x[31737]=0;z:{if((e|0)!=1){e=268435456;if(!i){break z}x[31737]=0;e=R(152,h|0)|0;i=x[31737];x[31737]=0;if((i|0)!=1){break z}}e=N()|0;break b}x[d>>2]=e;d=d+4|0;continue}}if(f>>>0<3){break j}x[31737]=0;f=g+140|0;O(457,f|0,h|0);d=x[31737];x[31737]=0;A:{B:{C:{D:{if((d|0)!=1){x[31737]=0;e=g+152|0;S(458,e|0,x[g+140>>2],x[g+144>>2]);d=x[31737];x[31737]=0;if((d|0)==1){break D}x[31737]=0;d=P(104,g|0,e|0)|0;i=x[31737];x[31737]=0;if((i|0)==1){break C}tb(e);dc(f);e=x[h>>2];x[31737]=0;R(155,e|0)|0;e=x[31737];x[31737]=0;if((e|0)==1){break A}x[31737]=0;S(459,d|0,E|0,d|0);e=x[31737];x[31737]=0;if((e|0)==1){break A}Ff(d);break j}e=N()|0;break b}e=N()|0;break B}e=N()|0;tb(g+152|0)}dc(g+140|0);break b}e=N()|0;Ff(d);break b}e=0;f=Qv(F);E:while(1){d=x[h>>2];x[31737]=0;d=U(151,d|0,x[g+180>>2],1)|0;i=x[31737];x[31737]=0;if((i|0)==1){break d}if(!(e>>>0<122&d)){break j}x[31737]=0;i=R(198,h|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break e}d=0;while(1){if((d|0)==8){continue E}F:{if(!(i>>>d&1)|e>>>0>121){break F}x[31737]=0;U(267,f|0,e|0,1)|0;j=x[31737];x[31737]=0;if((j|0)!=1){break F}e=N()|0;break b}e=e+1|0;d=d+1|0;continue}}}x[31737]=0;S(460,h|0,f|0,r|0);d=x[31737];x[31737]=0;if((d|0)==1){break c}}ub(h);continue}break}e=N()|0;break b}e=N()|0;break b}e=N()|0;break b}e=N()|0;break b}e=N()|0;break b}e=N()|0;break b}e=N()|0}ub(h);Q(e|0);p()}b=x[a+8>>2];Kp(k,D(x[b+20>>2],1e4),D(x[b+24>>2],1e4));if(y[a+480224|0]>=3){v[r|0]=0}if(y[l|0]>=6){v[l|0]=0}wc(s,256);wc(o,65536);wc(q,65536)}fb=g+192|0;return n|0}function Yoa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;d=fb-352|0;fb=d;a:{b:{c:{if(!cd(b,60)){break c}e=d+332|0;if(!Sp(b,e)){break c}f=15;if(tv(e,15)){break b}}e=0;if(!cd(b,124)){break a}g=d+332|0;if(!Sp(b,g)){break a}f=31;if(!tv(g,31)){break a}}Bd(a,536870912);w[a+480190>>1]=f;xc(b);e=0;d:{while(1){if(z[a+480190>>1]>e>>>0){g=sp(b);x[(d+208|0)+(e<<2)>>2]=g;e=e+1|0;if(g>>>0<=131072){continue}break d}break}Vb(b,20);f=0;w[a+480192>>1]=0;w[a+480188>>1]=4;e=y[d+336|0]|y[d+337|0]<<8;x[a+480260>>2]=56;x[a+480264>>2]=13696;x[a+480196>>2]=6;o=a,q=Ze(1776930/+(Bb(e)>>>0)*1e4),x[o+480204>>2]=q;x[a+480228>>2]=64;Xh(a,1);m=1;e:while(1){l=m&65535;if(l>>>0<=z[a+480190>>1]){LC(b,d+52|0);e=x[((l<<2)+d|0)+204>>2];h=fb-16|0;fb=h;i=(D(l,104)+a|0)+484380|0;ld(i,1);x[i>>2]=e;v[i+37|0]=y[d+76|0]<<4;v[h+15|0]=y[d+77|0];v[h+14|0]=64;o=i,q=y[Qb(h+15|0,h+14|0)|0]<<2,w[o+30>>1]=q;f:{if(!e){break f}g=Bb(y[d+80|0]|y[d+81|0]<<8);k=Bb(y[d+78|0]|y[d+79|0]<<8);x[i+4>>2]=k;g=(g<<1)+k|0;x[i+8>>2]=g;if(e>>>0<=k>>>0){k=e-1|0;x[i+4>>2]=k}if(e>>>0<g>>>0){x[i+8>>2]=e;g=e}if(!(!(g>>>0<4|g>>>0<k>>>0)&g-k>>>0>3)){x[i+4>>2]=0;x[i+8>>2]=0;break f}if(g>>>0<=k>>>0){break f}w[i+34>>1]=z[i+34>>1]|2}fb=h+16|0;e=0;while(1)if((e|0)==22){if(f>>>0>=128){break d}g=d+184|0;Xk(g,3,d+52|0);e=d+196|0;Cc(e,g);zc(((l<<5)+a|0)+946304|0,e);m=m+1|0;tb(e);continue e}else{g=(d+52|0)+e|0;if((y[g|0]-1&255)>>>0<=30){v[g|0]=32;f=f+1|0}e=e+1|0;continue}}break}m=1;g:{h:{f=a+946336|0;e=Dc(d+52|0,14097);if(!$W(f,e)){x[31737]=0;g=P(36,d+196|0,14108)|0;i=x[31737];x[31737]=0;if((i|0)==1){break h}m=$W(f,g);tb(g)}tb(e);e=0;g=d+52|0;f=NC(b,g);if(!f){JC(g)}if(!f){break a}g=y[d+52|0];if(!bX(g)){break a}e=1;if((c|0)==64){break a}e=0;w[d+50>>1]=0;while(1)if((e|0)==(g|0)){e=a+484376|0;h=Xb(x[a+484360>>2],y[e|0]);f=y[d+53|0];af(h,g>>>0>f>>>0?f:0);Fw(Xb(x[a+484360>>2],y[e|0]),d+54|0,y[d+52|0],65535,65535);if(z[a+480190>>1]==31){Vb(b,4)}x[d+44>>2]=0;x[d+40>>2]=0;x[d+36>>2]=0;v[d+35|0]=0;n=c&1;if(n){Vf(a+484344|0,z[d+50>>1])}l=a+484344|0;i=0;while(1){i:{j:{k:{if(z[d+50>>1]<=i>>>0){if(!(c&2)){break k}e=1;while(1){f=z[a+480190>>1];c=e&65535;if(f>>>0<c>>>0){break j}c=(D(c,104)+a|0)+484380|0;if(x[c>>2]){fg(Xc(d+184|0,8,1,0,0),c,b)}e=e+1|0;continue}}l:{if(n){k=0;if(Ng(l,i&65535,64)){break l}}Vb(b,1024);break i}m:while(1){if((k|0)==64){break i}e=Wb(x[l>>2],i);bf(d+184|0,x[e>>2],x[x[e+48>>2]+12>>2],k);e=0;while(1)if((e|0)==4){k=k+1|0;continue m}else{g=Wc(x[d+184>>2],e);f=d+12|0;sm(f,b);n:{o:{p:{q:{if(y[xb(f,0)|0]!=255){break q}v[(d+44|0)+e|0]=0;v[(d+36|0)+e|0]=0;f=xb(f,1);h=y[f|0];if((h|0)==252&m){v[f|0]=254;break o}switch(h-252|0){case 1:break n;case 2:break o;case 0:break p;default:break q}}f=x[d+12>>2];x[d+28>>2]=f;x[d+8>>2]=f;f=d+33|0;ip(f,d+8|0,g);h=Jc(f);f=y[g|0];r:{if(!f){break r}v[(d+36|0)+e|0]=0;v[(d+44|0)+e|0]=f;if(f>>>0>48){break r}v[d+27|0]=8;o=d,q=y[df(d+35|0,d+27|0)|0],v[o+35|0]=q}j=y[d+33|0];f=y[h|0];s:{if(j|f){v[g+5|0]=f;t:{u:{v:{switch(j-1|0){case 0:v[g+3|0]=1;break n;case 1:if(f>>>0>=16){v[g+3|0]=3;v[g+5|0]=(f&240)>>>4;break n}if(!f){break u}v[g+5|0]=f;v[g+3|0]=2;break n;case 2:if(y[(d+36|0)+e|0]){break u}v[g+5|0]=0;v[g+3|0]=19;break n;case 3:if(y[(d+36|0)+e|0]){break u}v[g+5|0]=1;v[g+3|0]=19;break n;case 4:h=y[g+1|0];if(!h){break u}v[d+27|0]=63;v[d+26|0]=f+(z[(D(h,104)+a|0)+484410>>1]>>>2|0);f=y[Qb(d+27|0,d+26|0)|0];v[g+5|0]=f;v[g+3|0]=13;if(!y[(d+36|0)+e|0]){break n}h=g+3|0;v[g+4|0]=f;v[g+2|0]=1;break t;case 5:h=g+3|0;j=y[g+1|0];if(!j){break t}v[g+3|0]=13;j=z[(D(j,104)+a|0)+484410>>1]>>>2|0;f=f>>>0<=j>>>0?j-f|0:0;v[g+5|0]=f;if(!y[(d+36|0)+e|0]){break n}v[g+4|0]=f;v[g+2|0]=1;break t;case 6:h=f&15;v[(d+36|0)+e|0]=h;j=y[(d+44|0)+e|0];f=j-((f&240)>>>4|0)|0;v[(d+40|0)+e|0]=f;o=g,q=_W(h,f&255,j),v[o+5|0]=q;v[g+3|0]=3;break n;case 7:h=f&15;v[(d+36|0)+e|0]=h;j=(f&240)>>>4|0;f=y[(d+44|0)+e|0];j=j+f|0;v[(d+40|0)+e|0]=j;o=g,q=_W(h,f,j&255),v[o+5|0]=q;v[g+3|0]=2;break n;case 8:break v;default:break u}}v[d+27|0]=8;o=d,q=y[df(d+35|0,d+27|0)|0],v[o+35|0]=q}h=g+3|0}v[h|0]=0;break s}if(y[g+3|0]){break n}}h=y[(d+36|0)+e|0];if(!h){break n}j=(d+40|0)+e|0;f=y[j|0];if(f){v[(d+44|0)+e|0]=f;v[g+5|0]=h;v[g|0]=f;v[j|0]=0}v[g+3|0]=4;break n}v[g+3|0]=14;v[d+35|0]=9;break n}v[g+3|0]=13}e=e+1|0;continue}}}f=z[a+480190>>1]}w:{x:{if((f&65535)==15){b=d+12|0;ig(b,4418);x[31737]=0;S(210,d+184|0,b|0,d+35|0);c=x[31737];x[31737]=0;if((c|0)!=1){break x}f=N()|0;Eb(b);break g}x[31737]=0;P(1,d+184|0,12406)|0;b=x[31737];x[31737]=0;if((b|0)==1){break w}}b=d+184|0;Ab(a+1298344|0,b);tb(b);if((f&65535)==15){Eb(d+12|0)}bi(a+1298356|0,z[a+480190>>1]==15?5282:15220);o=a+1298404|0,q=x[Fc(d+184|0,28)>>2],x[o>>2]=q;e=1;break a}f=N()|0;break g}i=i+1|0;continue}}else{w[d+184>>1]=y[(d+e|0)+54|0]+1;o=d,q=z[pe(d+50|0,d+184|0)>>1],w[o+50>>1]=q;e=e+1|0;continue}}f=N()|0;tb(e)}Q(f|0);p()}e=0}fb=d+352|0;return e|0}function Opa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0;f=fb-272|0;fb=f;xc(b);a:{b:{c:{e=f+206|0;if(!V$(b,e)){break c}if(!TX(e)){break c}if(!Mb(x[b>>2],x[b+8>>2],Bc(SX(e),hb))){break c}d=1;if((c|0)==64){break c}Bd(a,16);e=f+44|0;vi(e,2,f+210|0);d=f- -64|0;Cc(d,e);Ab(a+1298308|0,d);tb(d);w[a+480190>>1]=y[f+236|0];w[a+480188>>1]=y[f+239|0];g=tc(d,8365);Ab(a+1298344|0,g);tb(g);g=tc(d,10145);Ab(a+1298356|0,g);tb(g);ig(e,4211);g=y[f+209|0];x[f+24>>2]=g>>>4;x[31737]=0;x[f+12>>2]=g&15;V(308,d|0,e|0,f+24|0,f+12|0);g=x[31737];x[31737]=0;if((g|0)!=1){Ab(a+1298368|0,d);tb(d);Eb(e);t=a+1298404|0,u=x[Fc(d,4)>>2],x[t>>2]=u;d=1;while(1){h=d&65535;if(h>>>0>z[a+480190>>1]){d=0;while(1)if(z[a+480188>>1]<=d>>>0){e=f- -64|0;d=fb-16|0;fb=d;k=b;d:{if(!Mb(x[b>>2],x[b+8>>2],128)){b=0;while(1){if((b|0)!=128){eh(b+e|0);b=b+1|0;continue}break}break d}oZ(d+8|0,e);rd(d,k,x[d+8>>2],x[d+12>>2])}fb=d+16|0;Fw(Xb(x[a+484360>>2],y[a+484376|0]),e,y[f+233|0]+1|0,255,254);b=y[f+238|0];d=f+24|0;fe(d,k,D(y[f+230|0]|y[f+231|0]<<8,192));l=ic(f+44|0,d);ub(d);e:{o=c&1;if(!o){break e}x[31737]=0;O(224,a+484344|0,y[f+232|0]+1|0);d=x[31737];x[31737]=0;if((d|0)!=1){break e}break b}q=b?b:64;r=a+484344|0;b=0;while(1){f:{g:{h:{if(y[f+232|0]<m>>>0){if(!(b&s)){break g}t=f,u=wb(x[a+484344>>2]),x[t+12>>2]=u;j=wb(x[a+484348>>2]);break h}i:{if(o){x[31737]=0;d=U(197,r|0,m&65535,q|0)|0;e=x[31737];x[31737]=0;if((e|0)==1){break b}n=0;if(d){break i}}x[31737]=0;P(184,k|0,64)|0;d=x[31737];x[31737]=0;if((d|0)!=1){break f}break b}while(1){d=n&65535;if(d>>>0>31){break f}x[31737]=0;e=R(190,k|0)|0;g=x[31737];x[31737]=0;if((g|0)==1){break b}j:{if((e-1&65535)>>>0>=(y[f+230|0]|y[f+231|0]<<8)>>>0|d>>>0>=z[a+480188>>1]){break j}x[31737]=0;P(150,l|0,D(e,192)-192|0)|0;e=x[31737];x[31737]=0;if((e|0)==1){break b}e=0;g=Wb(x[r>>2],m);d=jd(x[g>>2],x[x[g+48>>2]+12>>2],0,d);while(1){if((e|0)==(q|0)){break j}j=b;x[31737]=0;b=f+24|0;O(550,b|0,l|0);g=x[31737];x[31737]=0;k:{l:{m:{n:{o:{if((g|0)!=1){h=Jc(b);g=$e(b);b=y[f+24|0];if(b>>>0>=4){v[d|0]=(b>>>2|0)+37;b=y[f+24|0]}v[d+1|0]=b<<4&48|y[h|0]>>>4;b=v[g|0];g=0;i=0;p:{q:{h=y[h|0]&15;switch(h-8|0){case 0:break n;case 2:break p;case 6:break q;default:break o}}h=14;if(!(435>>>((b+16&240)>>>4)&1)|(b|0)<=-17){break m}break n}g=b&-16;b=g?g:b&15;h=10;break m}break b}g=h;i=b}h=g;b=i;if(!(g|b)){break l}}Bf(d,h,b&255);b=1;r:{switch(y[d+3|0]-16|0){case 0:break k;case 1:break r;default:break l}}s=1}b=j}e=e+1|0;d=D(z[a+480188>>1],6)+d|0;continue}}n=n+1|0;continue}}while(1){s:{b=x[f+12>>2];if(Ib(b,j)){g=0;t:while(1){if(A[b+12>>2]<=g>>>0){break s}bf(f+24|0,x[b>>2],x[x[b+48>>2]+12>>2],g);t=f,u=wb(x[f+24>>2]),x[t+20>>2]=u;e=0;h=jw(x[f+24>>2],x[f+28>>2]);i=0;while(1){m=x[f+20>>2];if(Ib(m,h)){d=1;u:{switch(y[m+3|0]-16|0){case 1:i=1;default:d=e;break;case 0:break u}}vg(f+20|0);e=d;continue}else{g=g+1|0;if(!(e&i&1)){continue t}break g}}}}h=wb(x[a+484344>>2]);x[f+20>>2]=h;b=wb(x[a+484348>>2]);v:while(1){if(!Ib(h,b)){break g}e=0;w:while(1){if(A[h+12>>2]<=e>>>0){h=x[am(f+20|0)>>2];continue v}bf(f+12|0,x[h>>2],x[x[h+48>>2]+12>>2],e);t=f,u=wb(x[f+12>>2]),x[t+8>>2]=u;d=jw(x[f+12>>2],x[f+16>>2]);while(1){x:{g=x[f+8>>2];if(Ib(g,d)){g=y[g+3|0];if((g&254)!=16){break x}d=(g|0)==16;ye(h,Xe(Ne(f+24|0,d?17:16,d?125:6),e))}e=e+1|0;continue w}vg(f+8|0);continue}}}}am(f+12|0);continue}}y:{b=y[f+234|0]|y[f+235|0]<<8;if(!b){break y}x[31737]=0;aa(317,a+1298332|0,k|0,b|0,39,1);b=x[31737];x[31737]=0;if((b|0)!=1){break y}break b}z:{if(!(c&2)){break z}d=1;while(1){b=d&65535;if(b>>>0>z[a+480190>>1]){break z}b=D(b,104)+a|0;c=Xc(f+24|0,w[b+484414>>1]&1?16:8,1,0,1);x[31737]=0;U(216,c|0,b+484380|0,k|0)|0;b=x[31737];x[31737]=0;if((b|0)!=1){d=d+1|0;continue}break}break b}x[a+480260>>2]=64;x[a+480264>>2]=32767;ub(l);d=1;break c}m=m+1|0;continue}}else{e=(d<<5)+a|0;We(e+480280|0);w[e+480284>>1]=(y[(d+f|0)+240|0]<<4|8)&248;d=d+1|0;continue}}else{i=f- -64|0;fF(b,i);j=fb-16|0;fb=j;e=(D(h,104)+a|0)+484380|0;ld(e,0);w[j+14>>1]=y[i+35|0]<<2;w[j+12>>1]=256;t=e,u=z[Nc(j+14|0,j+12|0)>>1],w[t+30>>1]=u;g=y[i+22|0]|y[i+23|0]<<8|(y[i+24|0]<<16|y[i+25|0]<<24);A:{if(g>>>0<3){break A}x[e>>2]=g;x[e+4>>2]=y[i+26|0]|y[i+27|0]<<8|(y[i+28|0]<<16|y[i+29|0]<<24);x[j+8>>2]=y[i+30|0]|y[i+31|0]<<8|(y[i+32|0]<<16|y[i+33|0]<<24);x[j+4>>2]=1;t=e,u=x[ad(j+8|0,j+4|0)>>2]-1|0,x[t+8>>2]=u;wc(e+8|0,g);g=x[e+8>>2];k=x[e+4>>2];B:{if(g>>>0<=k+4>>>0){x[e+4>>2]=0;x[e+8>>2]=0;g=0;k=0;break B}if(g>>>0<3){break B}w[e+34>>1]=z[e+34>>1]|2}l=v[i+34|0];v[e+37|0]=l;t=e,u=tw(0,l<<4),x[t+24>>2]=u;if(!(v[i+36|0]&1)){break A}x[e+8>>2]=g>>>1;x[e+4>>2]=k>>>1;w[e+34>>1]=z[e+34>>1]|1;x[e>>2]=x[e>>2]>>>1}fb=j+16|0;g=f+24|0;Xk(g,2,i);e=f+44|0;Cc(e,g);zc(((h<<5)+a|0)+946304|0,e);d=d+1|0;tb(e);continue}}}d=N()|0;Eb(f+44|0);break a}fb=f+272|0;return d|0}d=N()|0;ub(l)}Q(d|0);p()}function eM(a,b,c,d,e,f){var g=0,h=E(0),i=0,j=E(0),k=0,l=E(0),m=E(0),n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,x=0,y=0,z=0,A=E(0),C=E(0),F=0,G=0,H=E(0),I=E(0),J=E(0),K=E(0),L=E(0),M=E(0),N=E(0),O=E(0),P=0,Q=0;F=(d|0)>0?d:0;while(1){if((s|0)!=(F|0)){G=D(s,2304)+b|0;t=0;q=(c|0)>0?c:0;k=fb-128|0;x=k+96|0;y=k- -64|0;g=k+32|0;while(1){if((q|0)!=(t|0)){n=G+(t<<2)|0;v=0;i=k;p=i;o=0;while(1){if((o|0)!=8){j=B[D(15-o|0,72)+n>>2];z=D(o,72)+n|0;h=B[z+1152>>2];l=E(j+h);m=B[z>>2];A=B[D(31-o|0,72)+n>>2];C=E(m+A);B[p>>2]=l+C;z=D(o,12);j=E(E(j-h)*B[z+87760>>2]);h=E(E(m-A)*B[z+87764>>2]);B[p+64>>2]=j+h;m=E(C-l);l=B[z+87768>>2];B[p+32>>2]=m*l;B[p+96>>2]=l*E(h-j);p=p+4|0;o=o+1|0;continue}break}while(1){if((v|0)!=4){l=B[i+8>>2];m=B[i+20>>2];h=E(l+m);A=B[i+4>>2];C=B[i+24>>2];H=E(A+C);j=E(h+H);I=B[i+12>>2];J=B[i+16>>2];K=E(I+J);L=B[i>>2];M=B[i+28>>2];N=E(L+M);O=E(K+N);B[i>>2]=j+O;B[i+16>>2]=E(O-j)*E(.7071067690849304);j=E(N-K);h=E(E(j+E(H-h))*E(.7071067690849304));B[i+24>>2]=E(j-h)*E(1.3065630197525024);B[i+8>>2]=E(j+h)*E(.5411961078643799);j=E(L-M);h=E(l-m);l=E(A-C);m=E(E(h+l)*E(.7071067690849304));A=E(j+m);C=E(E(I-J)+h);h=E(l+j);l=E(C-E(h*E(.1989123672246933)));h=E(E(l*E(.3826834261417389))+h);B[i+28>>2]=E(A-h)*E(2.562915563583374);B[i+4>>2]=E(A+h)*E(.509795606136322);j=E(j-m);h=E(l-E(h*E(.1989123672246933)));B[i+20>>2]=E(j+h)*E(.8999761939048767);B[i+12>>2]=E(j-h)*E(.601344883441925);i=i+32|0;v=v+1|0;continue}break}i=0;while(1){if((i|0)!=7){p=i<<2;B[n>>2]=B[p+k>>2];j=B[p+x>>2];i=i+1|0;o=i<<2;h=B[o+x>>2];B[n+72>>2]=E(B[p+y>>2]+j)+h;B[n+144>>2]=B[g+p>>2]+B[g+o>>2];B[n+216>>2]=h+E(j+B[o+y>>2]);n=n+288|0;continue}break}B[n>>2]=B[k+28>>2];j=B[k+124>>2];B[n+72>>2]=B[k+92>>2]+j;h=B[k+60>>2];B[n+216>>2]=j;B[n+144>>2]=h;t=t+1|0;continue}break}s=s+1|0;continue}break}z=yc(f,a,3840);F=d<<5;s=0;while(1){if((c|0)>(s|0)){i=fb-32|0;fb=i;o=z+(s<<8)|0;t=(s<<2)+b|0;B[o+4080>>2]=B[t+1152>>2];f=d-1|0;v=t+D(f,2304)|0;B[o+4084>>2]=B[v+1152>>2];B[o+4088>>2]=B[t>>2];B[o+4092>>2]=B[v>>2];B[o+4336>>2]=B[t+1156>>2];B[o+4340>>2]=B[v+1156>>2];B[o+4344>>2]=B[t+4>>2];B[o+4348>>2]=B[v+4>>2];x=(D(s,F)<<1)+e|0;y=x+(f<<1)|0;Rt(y,d,o+244|0);f=d<<6;Rt(f+y|0,d,o+500|0);Rt(x,d,o+240|0);Rt(f+x|0,d,o+496|0);G=o+3840|0;p=14;n=87856;while(1){if((p|0)>=0){g=p<<4;k=g+G|0;f=D(31-p|0,72);B[k>>2]=B[f+t>>2];B[k+4>>2]=B[f+v>>2];f=f|4;B[k+8>>2]=B[f+t>>2];B[k+12>>2]=B[f+v>>2];f=D(p,72);q=f+76|0;B[k+256>>2]=B[q+t>>2];B[k+260>>2]=B[q+v>>2];f=f+72|0;B[k-248>>2]=B[f+t>>2];B[k-244>>2]=B[f+v>>2];q=g+o|0;j=B[n+4>>2];h=B[n>>2];f=0;while(1){if((f|0)!=4){g=f<<2;l=B[g+k>>2];m=B[g+q>>2];B[g+(i+16|0)>>2]=E(l*h)-E(j*m);B[i+g>>2]=E(l*j)+E(h*m);f=f+1|0;continue}break}q=k-3584|0;u=k-256|0;j=B[n+12>>2];h=B[n+8>>2];f=0;while(1){if((f|0)!=4){g=f<<2;r=g+i|0;l=B[g+u>>2];m=B[g+q>>2];B[r>>2]=B[r>>2]+E(E(l*j)+E(h*m));g=g+(i+16|0)|0;B[g>>2]=E(E(m*j)-E(h*l))+B[g>>2];f=f+1|0;continue}break}q=k-3328|0;u=k-512|0;j=B[n+20>>2];h=B[n+16>>2];f=0;while(1){if((f|0)!=4){g=f<<2;r=g+i|0;l=B[g+u>>2];m=B[g+q>>2];B[r>>2]=B[r>>2]+E(E(l*j)+E(h*m));g=g+(i+16|0)|0;B[g>>2]=E(E(l*h)-E(j*m))+B[g>>2];f=f+1|0;continue}break}q=k-3072|0;u=k-768|0;j=B[n+28>>2];h=B[n+24>>2];f=0;while(1){if((f|0)!=4){g=f<<2;r=g+i|0;l=B[g+u>>2];m=B[g+q>>2];B[r>>2]=B[r>>2]+E(E(l*j)+E(h*m));g=g+(i+16|0)|0;B[g>>2]=E(E(m*j)-E(h*l))+B[g>>2];f=f+1|0;continue}break}q=k-2816|0;u=k-1024|0;j=B[n+36>>2];h=B[n+32>>2];f=0;while(1){if((f|0)!=4){g=f<<2;r=g+i|0;l=B[g+u>>2];m=B[g+q>>2];B[r>>2]=B[r>>2]+E(E(l*j)+E(h*m));g=g+(i+16|0)|0;B[g>>2]=E(E(l*h)-E(j*m))+B[g>>2];f=f+1|0;continue}break}q=k-2560|0;u=k-1280|0;j=B[n+44>>2];h=B[n+40>>2];f=0;while(1){if((f|0)!=4){g=f<<2;r=g+i|0;l=B[g+u>>2];m=B[g+q>>2];B[r>>2]=B[r>>2]+E(E(l*j)+E(h*m));g=g+(i+16|0)|0;B[g>>2]=E(E(m*j)-E(h*l))+B[g>>2];f=f+1|0;continue}break}q=k-2304|0;u=k-1536|0;j=B[n+52>>2];h=B[n+48>>2];f=0;while(1){if((f|0)!=4){g=f<<2;r=g+i|0;l=B[g+u>>2];m=B[g+q>>2];B[r>>2]=B[r>>2]+E(E(l*j)+E(h*m));g=g+(i+16|0)|0;B[g>>2]=E(E(l*h)-E(j*m))+B[g>>2];f=f+1|0;continue}break}g=k-2048|0;q=k-1792|0;j=B[n+60>>2];h=B[n+56>>2];f=0;while(1){if((f|0)!=4){k=f<<2;u=k+i|0;l=B[k+q>>2];m=B[g+k>>2];B[u>>2]=B[u>>2]+E(E(l*j)+E(h*m));k=k+(i+16|0)|0;B[k>>2]=E(E(m*j)-E(h*l))+B[k>>2];f=f+1|0;continue}break}f=D(15-p|0,d)<<1;P=f+y|0,Q=Bj(B[i+20>>2]),w[P>>1]=Q;k=D(p+17|0,d)<<1;P=k+y|0,Q=Bj(B[i+4>>2]),w[P>>1]=Q;P=f+x|0,Q=Bj(B[i+16>>2]),w[P>>1]=Q;P=k+x|0,Q=Bj(B[i>>2]),w[P>>1]=Q;f=D(47-p|0,d)<<1;P=f+y|0,Q=Bj(B[i+28>>2]),w[P>>1]=Q;k=D(p+49|0,d)<<1;P=k+y|0,Q=Bj(B[i+12>>2]),w[P>>1]=Q;P=f+x|0,Q=Bj(B[i+24>>2]),w[P>>1]=Q;P=k+x|0,Q=Bj(B[i+8>>2]),w[P>>1]=Q;p=p-1|0;n=n- -64|0;continue}break}fb=i+32|0;s=s+2|0;continue}break}b=z+(c<<8)|0;a:{if((d|0)==1){s=0;while(1){if(s>>>0>959){break a}c=s<<2;B[c+a>>2]=B[b+c>>2];s=s+2|0;continue}}yc(a,b,3840)}}function bta(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0;f=fb-272|0;fb=f;xc(b);e=fb-16|0;fb=e;g=f+66|0;B_(e+8|0,g);i=x[e+12>>2];lc(e,x[b>>2],x[b+8>>2],x[e+8>>2],x[e+12>>2]);j=x[e+4>>2];if((j|0)==(i|0)){Vb(b,x[e+12>>2])}fb=e+16|0;e=(i|0)==(j|0);if(!e){A_(g)}a:{if(!e){break a}if(!D_(g)){break a}if(!Mb(x[b>>2],x[b+8>>2],Bc(C_(g),hb))){break a}d=1;if((c|0)==64){break a}Bd(a,16777216);gg(a);x[a+480208>>2]=x[a+480208>>2]|16777216;d=f+44|0;vr(d,32);g=x[f+56>>2];e=a+1074320|0;x[e>>2]=x[f+52>>2];x[e+4>>2]=g;e=x[f+48>>2];x[a+1074312>>2]=x[f+44>>2];x[a+1074316>>2]=e;Lb(a+1074312|0,114,1);r=a,s=Bb(y[f+266|0]|y[f+267|0]<<8),w[r+480188>>1]=s;Xh(a,1);e=tc(d,8557);Ab(a+1298368|0,e);tb(e);e=f+24|0;ig(e,3924);x[31737]=0;S(371,d|0,e|0,y[f+69|0]);g=x[31737];x[31737]=0;b:{c:{d:{e:{if((g|0)!=1){Ab(a+1298344|0,d);tb(d);Eb(e);g=tc(d,10805);Ab(a+1298356|0,g);tb(g);r=a+1298404|0,s=x[Fc(d,26)>>2],x[r>>2]=s;Ve(e,3,f+70|0);Cc(d,e);Ab(a+1298308|0,d);tb(d);e=160;while(1){f:{d=e;if(!d){d=0;break f}e=d-1|0;if(y[(f+e|0)+102|0]==32){continue}}break}z_(a+1298332|0,f+102|0,d,4);d=Bb(y[f+262|0]|y[f+263|0]<<8);w[a+480190>>1]=d;i=1;while(1){g:{e=d&65535;d=i&65535;if(e>>>0<d>>>0){e=a+484376|0;af(Xb(x[a+484360>>2],y[e|0]),Bb(y[f+270|0]|y[f+271|0]<<8));d=f+24|0;fe(d,b,512);j=ic(f+44|0,d);ub(d);d=y[e|0];e=x[a+484360>>2];g=y[f+268|0]|y[f+269|0]<<8;x[31737]=0;S(277,Xb(e,d)|0,j|0,Bb(g)|0);d=x[31737];x[31737]=0;if((d|0)!=1){break g}d=N()|0;break d}j=D(d,104)+a|0;m=j+484380|0;ld(m,1);kp(m);U$(b,((d<<5)+a|0)+946304|0,y[f+69|0]==1?32:28);n=1;d=y[f+69|0];if(d>>>0>=3){Vb(b,14);d=JD(b);if((d|0)>=0){e=j+484414|0;w[e>>1]=z[e>>1]|32;r=j+484408|0,s=Bc((((d&65535)<<8)+2047>>>0)/4095|0,0),w[r>>1]=s}d=y[f+69|0]}if((d&255)>>>0>=2){n=Uk(b);r=j+484404|0,s=Uk(b),x[r>>2]=s}e=f+44|0;g=fb-16|0;fb=g;h:{if(!Mb(x[b>>2],x[b+8>>2],12)){x[g>>2]=0;d=e;h=3;while(1){if(h){l=y[g|0]|y[g+1|0]<<8|(y[g+2|0]<<16|y[g+3|0]<<24);v[d|0]=l;v[d+1|0]=l>>>8;v[d+2|0]=l>>>16;v[d+3|0]=l>>>24;h=h-1|0;d=d+4|0;continue}break}break h}Fr(g+8|0,e);rd(g,b,x[g+8>>2],x[g+12>>2])}fb=g+16|0;g=ec(e);d=zb(e);h=$b(x[f+44>>2]);x[m>>2]=h;l=j+484384|0;e=$b(y[g|0]|y[g+1|0]<<8|(y[g+2|0]<<16|y[g+3|0]<<24));x[l>>2]=e;k=j+484388|0;o=$b(y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24))+e|0;x[k>>2]=o;g=j+484414|0;i:{j:{if(!e){if($b(y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24))>>>0<3){break j}}d=z[g>>1]|2;break i}d=z[g>>1]&-3}w[g>>1]=d;if((n|0)==2){w[g>>1]=d|1;x[m>>2]=h>>>1;x[l>>2]=e>>>1;x[k>>2]=o>>>1}r=j+484410|0,s=Uk(b),w[r>>1]=s;d=JD(b);if(d){gm(m,+(d|0)/96)}v[j+484417|0]=d<<4;i=i+1|0;d=z[a+480190>>1];continue}break}d=wb(x[Xb(x[a+484360>>2],y[a+484376|0])>>2]);g=wb(x[Xb(x[a+484360>>2],y[a+484376|0])+4>>2]);e=fb-16|0;fb=e;k:{if(!Ib(d,g)){break k}x[e+12>>2]=d;while(1){i=x[Md(e+12|0)>>2];if(!Ib(i,g)){break k}d=bl(z[d>>1],z[i>>1])?i:d;continue}}fb=e+16|0;d=z[d>>1];x[31737]=0;l=a+484344|0;o=d+1&65535;O(224,l|0,o|0);d=x[31737];x[31737]=0;if((d|0)==1){break e}d=y[f+69|0];x[f+20>>2]=x[a+480204>>2];x[f+16>>2]=x[a+480196>>2];n=d>>>0<4?4:5;q=c&1;i=0;while(1){if((i|0)==(o|0)){if(!(c&2)){break b}d=1;while(1){c=d&65535;if(c>>>0>z[a+480190>>1]){break b}c=D(c,104)+a|0;e=Xc(f+8|0,w[c+484414>>1]&1?16:8,1,1,0);x[31737]=0;U(216,e|0,c+484380|0,b|0)|0;c=x[31737];x[31737]=0;if((c|0)!=1){d=d+1|0;continue}break}d=N()|0;break d}l:{if(!q){break l}d=y[f+264|0]|y[f+265|0]<<8;e=x[b+8>>2];g=x[b>>2];h=z[a+480188>>1];x[31737]=0;d=U(151,g|0,e|0,D(h,D(Bb(d),n))|0)|0;e=x[31737];x[31737]=0;m:{n:{if((e|0)==1){break n}if(!d){break l}d=y[f+264|0]|y[f+265|0]<<8;x[31737]=0;d=U(197,l|0,i&65535,Bb(d)|0)|0;e=x[31737];x[31737]=0;if((e|0)==1){break n}if(!d){break l}d=z[a+480188>>1];v[f|0]=0;e=de(f+8|0,0,f);x[31737]=0;m=U(372,f+24|0,d|0,e|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break m}e=0;o:while(1){if(Bb(y[f+264|0]|y[f+265|0]<<8)>>>0<=e>>>0){md(m);break l}d=Wb(x[l>>2],i);bf(f+8|0,x[d>>2],x[x[d+48>>2]+12>>2],e);d=0;while(1){if(z[a+480188>>1]<=d>>>0){e=e+1|0;continue o}g=Wc(x[f+8>>2],d);v[f+4|0]=0;x[31737]=0;x[f>>2]=0;S(373,b|0,f|0,n|0);h=x[31737];x[31737]=0;p:{if((h|0)==1){break p}h=x[m>>2];k=y[f|0];if((k-24&255)>>>0<=59){k=k+13|0;v[g|0]=k;r=_b(h,d),s=k,v[r|0]=s}k=y[f+1|0];q:{if(!k){h=_b(h,d);break q}v[g+1|0]=k;h=_b(h,d);v[h+1|0]=k}k=y[h+1|0];h=y[h|0];x[31737]=0;ya(374,a|0,g|0,y[f+2|0],y[f+3|0],0-y[f+69|0]|0,h|0,k|0,f+20|0,f+16|0);h=x[31737];x[31737]=0;if((h|0)==1){break p}h=y[f+4|0];if(h){v[g+2|0]=1;v[g+4|0]=h+1>>>2}d=d+1|0;continue}break}break}d=N()|0;md(m);break d}d=N()|0;break d}d=N()|0;break d}i=i+1|0;continue}}d=N()|0;Eb(f+24|0);break c}d=N()|0}ub(j)}Q(d|0);p()}ub(j);d=1}fb=f+272|0;return d|0}function uoa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;e=fb-112|0;fb=e;xc(c);a:{b:{c:{d:{if(!lp(c,e+100|0)|(y[e+100|0]|y[e+101|0]<<8|(y[e+102|0]<<16|y[e+103|0]<<24))!=1297239878){break d}d=y[e+108|0]|y[e+109|0]<<8|(y[e+110|0]<<16|y[e+111|0]<<24);if(!((d|0)==1482052408|(d|0)==1448293937)&(d|0)!=1146437965){break d}d=fb-32|0;fb=d;f=e+88|0;l=Nb(f);e:{f:{g:{h:{i:{while(1){j=x[c+8>>2];g=x[c>>2];x[31737]=0;j=U(151,g|0,j|0,8)|0;g=x[31737];x[31737]=0;if((g|0)==1){break g}if(!j){break h}x[31737]=0;j=d+4|0;O(833,j|0,c|0);g=x[31737];x[31737]=0;if((g|0)!=1){x[31737]=0;O(834,l|0,j|0);g=x[31737];x[31737]=0;if((g|0)==1){break i}Fd(j);continue}break}a=N()|0;break f}a=N()|0;Fd(d+4|0);break f}fb=d+32|0;break e}a=N()|0}ie(l);Q(a|0);p()}x[31737]=0;j=R(169,e+68|0)|0;c=x[31737];x[31737]=0;j:{k:{l:{m:{n:{o:{p:{if((c|0)!=1){l=Xc(e- -64|0,8,1,1,0);if((y[e+108|0]|y[e+109|0]<<8|(y[e+110|0]<<16|y[e+111|0]<<24))!=1146437965){break n}x[31737]=0;d=e+44|0;S(743,d|0,f|0,1296581714);c=x[31737];x[31737]=0;if((c|0)==1){break m}x[31737]=0;c=e+24|0;S(743,c|0,f|0,1296318804);f=x[31737];x[31737]=0;if((f|0)==1){break l}f=hd(j,c);ub(c);c=0;x[31737]=0;i=R(744,d|0)|0;h=x[31737];x[31737]=0;if((h|0)==1){break l}h=0;if(!i){break o}f=x[f>>2];x[31737]=0;f=R(173,f|0)|0;i=x[31737];x[31737]=0;if((i|0)==1){break l}if(!f){break o}x[31737]=0;h=R(282,d|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break l}x[31737]=0;i=R(274,d|0)|0;c=x[31737];x[31737]=0;q:{if((c|0)==1){break q}x[31737]=0;P(184,d|0,2)|0;c=x[31737];x[31737]=0;if((c|0)==1){break q}x[31737]=0;c=R(282,d|0)|0;d=x[31737];x[31737]=0;if((d|0)!=1){break p}}break l}f=N()|0;break a}x[31737]=0;f=e+24|0;O(654,f|0,e+44|0);d=x[31737];x[31737]=0;if((d|0)==1){break l}d=s_(f);g=Bb(z[e+24>>1]);if(!g){break o}c=(c>>>0)/(g>>>0)|0;g=ec(f);f=$e(f);g=Bb(y[g|0]|y[g+1|0]<<8);if((g|0)!=(Bb(y[f|0]|y[f+1|0]<<8)+1|0)){break o}if((g|0)==2){Bp(l,2)}r:{if((i|0)!=16){if((i|0)!=8){break o}s:{switch(Bb(y[d|0]|y[d+1|0]<<8)|0){case 0:k=1;yg(l,1);break o;case 2:yg(l,17);break r;case 3:break s;default:break o}}yg(l,16);break r}if(Bb(y[d|0]|y[d+1|0]<<8)){break o}fd(l,16)}k=1}ub(e+44|0);d=0;i=0;f=0;if(!k){break j}break k}x[31737]=0;o=e+44|0;c=e+88|0;S(743,o|0,c|0,1447576658);d=x[31737];x[31737]=0;t:{u:{v:{if((d|0)!=1){x[31737]=0;r=e+24|0;S(743,r|0,c|0,1128808782);d=x[31737];x[31737]=0;if((d|0)==1){break v}x[31737]=0;g=e+4|0;S(743,g|0,c|0,1112491097);c=x[31737];x[31737]=0;if((c|0)==1){break u}q=hd(j,g);ub(g);c=x[q>>2];x[31737]=0;d=R(173,c|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break u}f=0;c=0;m=0;w:{if(!d){break w}x[31737]=0;d=R(173,x[e+44>>2])|0;c=x[31737];x[31737]=0;if((c|0)==1){break u}c=0;m=0;if(!d){break w}x[31737]=0;g=P(745,o|0,g|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break u}c=0;m=0;if(!g){break w}d=y[e+108|0]|y[e+109|0]<<8|(y[e+110|0]<<16|y[e+111|0]<<24);x[31737]=0;c=R(282,r|0)|0;h=x[31737];x[31737]=0;if((h|0)==1){break u}i=(d|0)!=1482052408;if(i){fd(l,16)}if((c|0)==6){Bp(l,3)}g=$b(x[e+4>>2]);d=x[e+8>>2];k=x[e+12>>2];h=$b(k);x:{if(h>>>0<33){break x}n=$b(d);if(n>>>0<=h>>>0){break x}d=(n>>>0)%(h>>>0)|0?d:k}h=x[q>>2];x[31737]=0;n=x[e+20>>2];q=z[e+16>>1];h=R(155,h|0)|0;o=x[31737];x[31737]=0;k=1;if((o|0)==1){break u}m=g;g=i+((c|0)==6)|0;i=m>>>g|0;h=h>>>g|0;n=$b(n);c=Bb(q);m=$b(d)>>>g|0}d=m;ub(e+24|0);ub(e+44|0);if(k){break k}break j}f=N()|0;break b}f=N()|0;break t}f=N()|0;ub(e+24|0)}ub(e+44|0);break b}f=N()|0;break b}f=N()|0;ub(e+44|0);break b}Uu(a,b);x[31737]=0;f=D(b,104)+a|0;k=f+484380|0;O(280,k|0,0);g=x[31737];x[31737]=0;y:{if((g|0)!=1){x[k>>2]=h;d=d+i|0;x[f+484388>>2]=d;x[f+484384>>2]=i;if(!(d>>>0<=i+4>>>0|d>>>0>h>>>0)){d=f+484414|0;w[d>>1]=z[d>>1]|2}d=D(b,104)+a|0;x[d+484404>>2]=c>>>0<2?22050:c;g=d+484410|0;c=n+128|0;d=c>>>8|0;w[g>>1]=(c&16776960)>>>0>65536?256:d&65535?d:256;bC(k,x[a+480180>>2]);x[31737]=0;c=e+44|0;S(743,c|0,e+88|0,1312902469);d=x[31737];x[31737]=0;if((d|0)==1){break y}x[31737]=0;d=R(173,x[e+44>>2])|0;f=x[31737];x[31737]=0;if((f|0)==1){break c}z:{A:{if(d){x[31737]=0;d=R(155,x[e+44>>2])|0;f=x[31737];x[31737]=0;if((f|0)==1){break c}x[31737]=0;S(332,c|0,((b<<5)+a|0)+946304|0,d|0);b=x[31737];x[31737]=0;if((b|0)!=1){break A}break c}x[31737]=0;c=P(36,e+24|0,22303)|0;d=x[31737];x[31737]=0;if((d|0)==1){break z}zc(((b<<5)+a|0)+946304|0,c);tb(c)}x[31737]=0;U(216,l|0,k|0,j|0)|0;b=x[31737];x[31737]=0;f=1;if((b|0)==1){break c}Pj(k,a);ub(e+44|0);break j}break c}f=N()|0;break b}f=N()|0;break b}ub(j);ie(e+88|0)}fb=e+112|0;return f|0}f=N()|0;ub(e+44|0)}ub(j)}ie(e+88|0);Q(f|0);p()}function eoa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0;i=fb-160|0;fb=i;xc(b);a:{b:{d=i+112|0;c:{if(!OD(b,d)){break c}if(!QV(d)){break c}g=1;if((c|0)==64){break c}g=0;if(!Mb(x[b>>2],x[b+8>>2],Bc(PV(y[i+159|0]),hb))){break c}Bd(a,128);g=i+100|0;Ve(g,2,i+127|0);d=i+32|0;Cc(d,g);Ab(a+1298308|0,d);tb(d);e=tc(d,8453);Ab(a+1298344|0,e);tb(e);e=tc(d,6056);Ab(a+1298356|0,e);tb(e);g=tc(g,18199);x[31737]=0;S(758,d|0,g|0,x[(y[i+126|0]<<2)+25276>>2]);e=x[31737];x[31737]=0;if((e|0)==1){break b}Ab(a+1298368|0,d);tb(d);tb(g);A=a+1298404|0,B=x[Fc(d,4)>>2],x[A>>2]=B;x[a+480208>>2]=12;hE(a+1298332|0,b,y[i+159|0]<<5,32,0);f=Zd(b);w[a+480190>>1]=f;g=1;while(1){k=g&65535;if(k>>>0>(f&65535)>>>0){fk(Xb(x[a+484360>>2],y[a+484376|0]),b,256,255,254);g=0;d=Zd(b);if(d>>>0>=127){break c}w[a+480188>>1]=d+1;d=Zd(b);while(1){if(z[a+480188>>1]<=g>>>0){o=a+484344|0;r=d+1|0;Vf(o,r);f=0;while(1){e=f&65535;if(e>>>0>d>>>0){d:while(1){t=s&65535;g=z[a+480188>>1];if(t>>>0>=g>>>0){d=Xo(i);v[d+16|0]=0;w[d+14>>1]=0;w[d+12>>1]=g;x[31737]=0;O(760,d|0,g|0);g=x[31737];x[31737]=0;if((g|0)==1){a=N()|0;tf(d);Q(a|0);p()}x[31737]=0;O(759,o|0,d|0);e=x[31737];x[31737]=0;g=1;if((e|0)!=1){tf(d);if(!(c&2)){break c}while(1){c=g&65535;if(c>>>0>z[a+480190>>1]){g=1;break c}else{c=D(c,104)+a|0;fg(Xc(i+32|0,w[c+484414>>1]&1?16:8,1,0,0),c+484380|0,b);g=g+1|0;continue}}}f=N()|0;tf(d);break a}m=0;e=bh(i+32|0);e:while(1){f:{if((m|0)!=(r|0)){if(Mb(x[b>>2],x[b+8>>2],5)){break f}}s=s+1|0;continue d}f=0;d=Wb(x[o>>2],m);g=jd(x[d>>2],x[x[d+48>>2]+12>>2],0,t);while(1){g:{h:{if(f>>>0>63){break h}j=y[i+126|0];h=fb-16|0;fb=h;q=1;d=Zd(b);if((d|0)==252){q=Zd(b);d=Zd(b)}v[e|0]=(d-1&255)>>>0<60?d+36|0:0;d=h+12|0;sm(d,b);k=Jc(d);l=$e(d);d=dj(d);v[e+1|0]=y[h+12|0];n=h+10|0;u=y[k|0];OV(n,u&15,y[l|0],j);k=Jc(n);l=h+8|0;OV(l,u>>>4|0,y[d|0],j);j=Jc(l);l=y[h+10|0];n=(l|0)!=10;d=y[h+8|0];i:{if(!(n|(d|0)!=10)){k=y[k|0];d=y[j|0];v[e+3|0]=10;k=k|d<<8;v[e+5|0]=k>>>6;if(k>>>0<16384){break i}v[e+2|0]=15;v[e+4|0]=d>>>6;break i}j:{k:{l:{m:{n:{if(!n){l=y[k|0];n=l<<2;A=k,B=yi(n),v[A|0]=B;if(l>>>0<64){break n}if(xi(d)>>>0>=xi(10)>>>0){break m}v[e+5|0]=n;v[e+2|0]=15;v[e+3|0]=10;v[e+4|0]=l>>>6;break i}if((d|0)==10){d=y[j|0];l=d<<2;A=j,B=yi(l),v[A|0]=B;if(d>>>0<64){break n}if(xi(y[h+10|0])>>>0>=xi(10)>>>0){break n}v[e+5|0]=l;v[e+2|0]=15;v[e+3|0]=10;v[e+4|0]=d>>>6;break i}if((d|0)!=(l|0)){break n}v[h+8|0]=0;break l}d=y[h+8|0]}if((d|0)==13){break k}if(d){break j}l=y[h+10|0]}if((l|0)==13){break j}}tg(h+10|0,h+8|0);tg(k,j)}GE(h+8|0,j,h+10|0,k);mm(h+6|0,e,y[h+10|0],y[k|0],y[h+8|0],y[j|0])}fb=h+16|0;h=f+q|0;f=h>>>0>64?64-f|0:q;if(!f){break h}while(1){if(!f){break g}d=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);v[g|0]=d;v[g+1|0]=d>>>8;v[g+2|0]=d>>>16;v[g+3|0]=d>>>24;d=y[e+4|0]|y[e+5|0]<<8;v[g+4|0]=d;v[g+5|0]=d>>>8;f=f-1|0;g=D(z[a+480188>>1],6)+g|0;continue}}m=m+1|0;continue e}f=h>>>0>=64?64:h;continue}}}}f=f+1|0;g=0;if(Ng(o,e,64)){continue}break}}else{e=(g<<5)+a|0;We(e+480280|0);f=e+480284|0;o:{if(y[i+126|0]>=51){e=(Zd(b)<<4|8)&248;break o}e=g&1?192:64}w[f>>1]=e;g=g+1|0;continue}break}}else{p:{if(y[i+126|0]>=52){d=i+32|0;if(!z$(b,d)){kE(d)}break p}f=i+32|0;d=fb-32|0;fb=d;x[d+28>>2]=64;x[d+8>>2]=66;h=x[b>>2];j=x[b+8>>2];e=x[Gb(d+28|0,d+8|0)>>2];if(!Mb(h,j,e)){e=kf(b)}h=d+8|0;hw(h,f);j=gc(d+16|0,x[d+8>>2],e);m=x[j>>2];lc(d,x[b>>2],x[b+8>>2],m,x[j+4>>2]);hw(h,f);Rb(x[d+8>>2]+e|0,0,66-e|0);Vb(b,x[d+28>>2]);fb=d+32|0;d=y[i+94|0]|y[i+95|0]<<8;v[i+96|0]=d;v[i+97|0]=d>>>8;v[i+94|0]=171;v[i+95|0]=32}h=fb-32|0;fb=h;f=(D(k,104)+a|0)+484380|0;ld(f,0);kp(f);j=h+8|0;e=i+32|0;Pk(j,2,e+32|0);d=h+20|0;Cc(d,j);ze(f+43|0,d);tb(d);j=y[e+56|0]|y[e+57|0]<<8|(y[e+58|0]<<16|y[e+59|0]<<24);m=y[e+52|0]|y[e+53|0]<<8|(y[e+54|0]<<16|y[e+55|0]<<24);q:{if(j>>>0<=m>>>0){break q}x[f>>2]=j-m;x[f+12>>2]=y[e+44|0]|y[e+45|0]<<8|(y[e+46|0]<<16|y[e+47|0]<<24);x[h+20>>2]=y[e+48|0]|y[e+49|0]<<8|(y[e+50|0]<<16|y[e+51|0]<<24);A=f,B=x[Gb(d,f)>>2],x[A+16>>2]=B;w[f+30>>1]=y[e+60|0];x[f+24>>2]=y[e+62|0]|y[e+63|0]<<8;d=y[e+64|0]|y[e+65|0]<<8;if(d){gm(f,+(d<<16>>16)/393216)}d=y[e+61|0];if(d&8){w[f+34>>1]=z[f+34>>1]|8;d=y[e+61|0]}if(d&16){w[f+34>>1]=z[f+34>>1]|16;d=y[e+61|0]}if(!(d&4)){break q}w[f+34>>1]=z[f+34>>1]|1;x[f+12>>2]=x[f+12>>2]>>>1;x[f+16>>2]=x[f+16>>2]>>>1}fb=h+32|0;f=i+20|0;Ve(f,2,e);d=i+100|0;Cc(d,f);zc(((k<<5)+a|0)+946304|0,d);g=g+1|0;tb(d);f=z[a+480190>>1];continue}break}}fb=i+160|0;return g|0}f=N()|0;tb(g)}Q(f|0);p()}function Wd(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;k=fb-96|0;fb=k;u=i&65535;o=(e^i)&-2147483648;r=e&65535;z=r;R=i>>>16&32767;S=e>>>16&32767;a:{b:{if(R-32767>>>0>4294934529&S-32767>>>0>=4294934530){break b}s=e&2147483647;q=s;j=d;if(!(!d&(q|0)==2147418112?!(b|c):q>>>0<2147418112)){m=d;o=e|32768;break a}s=i&2147483647;p=s;e=h;if(!(!e&(p|0)==2147418112?!(f|g):p>>>0<2147418112)){m=e;o=i|32768;b=f;c=g;break a}if(!(b|j|(q^2147418112|c))){if(!(e|f|(g|p))){o=2147450880;b=0;c=0;break a}o=o|2147418112;b=0;c=0;break a}if(!(e|f|(p^2147418112|g))){e=b|j;d=c|q;b=0;c=0;if(!(d|e)){o=2147450880;break a}o=o|2147418112;break a}if(!(b|j|(c|q))){b=0;c=0;break a}if(!(e|f|(g|p))){b=0;c=0;break a}if((q|0)==65535|q>>>0<65535){j=!(d|r);i=j?b:d;s=j<<6;e=G(i)+32|0;i=G(j?c:r);i=s+((i|0)==32?e:i)|0;bg(k+80|0,b,c,d,r,i-15|0);t=16-i|0;d=x[k+88>>2];z=x[k+92>>2];c=x[k+84>>2];b=x[k+80>>2]}if(p>>>0>65535){break b}i=!(h|u);e=i?f:h;r=i<<6;j=G(e)+32|0;e=G(i?g:u);e=r+((e|0)==32?j:e)|0;bg(k- -64|0,f,g,h,u,e-15|0);t=(t-e|0)+16|0;h=x[k+72>>2];u=x[k+76>>2];f=x[k+64>>2];g=x[k+68>>2]}e=f;f=g<<15|f>>>17;i=e<<15;e=0;v=i&-32768;L=c;s=Sua(v,e,c,0);e=hb;A=e;M=f;q=b;c=Sua(f,0,b,0);b=c+s|0;f=hb+e|0;i=b;c=b>>>0<c>>>0?f+1|0:f;f=b;j=0;b=Sua(q,l,v,l);p=j+b|0;e=hb+f|0;e=b>>>0>p>>>0?e+1|0:e;r=e;N=(f|0)==(e|0)&j>>>0>p>>>0|e>>>0<f>>>0;O=d;w=Sua(v,l,d,0);P=hb;b=Sua(L,l,M,l);y=b+w|0;j=hb+P|0;j=b>>>0>y>>>0?j+1|0:j;b=u<<15|h>>>17;B=h<<15|g>>>17;d=Sua(B,0,q,l);C=d+y|0;f=hb+j|0;f=d>>>0>C>>>0?f+1|0:f;D=f;d=(c|0)==(A|0)&i>>>0<s>>>0|c>>>0<A>>>0;E=c+C|0;f=d+f|0;f=c>>>0>E>>>0?f+1|0:f;u=f;g=E;c=f;F=z|65536;z=Sua(v,l,F,n);Q=hb;d=Sua(O,m,M,l);H=d+z|0;e=hb+Q|0;e=d>>>0>H>>>0?e+1|0:e;i=e;I=b|-2147483648;b=Sua(I,0,q,l);J=b+H|0;f=hb+e|0;f=b>>>0>J>>>0?f+1|0:f;d=Sua(B,m,L,l);b=d+J|0;K=f;f=f+hb|0;A=b;s=b>>>0<d>>>0?f+1|0:f;f=b;b=0;q=b+g|0;e=c+f|0;e=b>>>0>q>>>0?e+1|0:e;v=e;f=e;b=q+N|0;c=b>>>0<q>>>0?f+1|0:f;t=((S+R|0)+t|0)-16383|0;d=Sua(I,m,L,l);h=hb;e=Sua(F,m,M,l);g=e+d|0;f=hb+h|0;f=e>>>0>g>>>0?f+1|0:f;n=(h|0)==(f|0)&d>>>0>g>>>0|f>>>0<h>>>0;h=f;e=Sua(B,m,O,m);d=e+g|0;f=hb+f|0;f=d>>>0<e>>>0?f+1|0:f;e=f;g=(f|0)==(h|0)&d>>>0<g>>>0|f>>>0<h>>>0;f=0;h=g;g=g+n|0;f=h>>>0>g>>>0?1:f;h=g;g=Sua(I,m,F,m);h=h+g|0;f=hb+f|0;N=h;g=g>>>0>h>>>0?f+1|0:f;h=d;l=e;e=(j|0)==(P|0)&w>>>0>y>>>0|j>>>0<P>>>0;f=0;j=(j|0)==(D|0)&y>>>0>C>>>0|j>>>0>D>>>0;n=j;j=e+j|0;e=(n>>>0>j>>>0?1:f)+l|0;f=g;d=d+j|0;e=d>>>0<j>>>0?e+1|0:e;n=e;w=d;d=(e|0)==(l|0)&d>>>0<h>>>0|e>>>0<l>>>0;e=d;d=d+N|0;f=e>>>0>d>>>0?f+1|0:f;j=d;h=f;e=Sua(B,m,F,m);l=hb;g=Sua(I,m,O,m);d=g+e|0;f=hb+l|0;f=d>>>0<g>>>0?f+1|0:f;g=f;f=(l|0)==(f|0)&d>>>0<e>>>0|f>>>0<l>>>0;y=g+j|0;e=f+h|0;e=g>>>0>y>>>0?e+1|0:e;l=y;h=e;j=d;e=0;d=e+w|0;f=j+n|0;f=d>>>0<e>>>0?f+1|0:f;e=f;g=(n|0)==(f|0)&d>>>0<w>>>0|f>>>0<n>>>0;f=h;h=g;g=g+l|0;f=h>>>0>g>>>0?f+1|0:f;w=g;g=f;h=d;j=e;e=(s|0)==(K|0)&A>>>0<J>>>0|s>>>0<K>>>0;d=(i|0)==(Q|0)&z>>>0>H>>>0|i>>>0<Q>>>0;i=(i|0)==(K|0)&H>>>0>J>>>0|i>>>0>K>>>0;d=d+i|0;d=d+e|0;n=s;i=n+h|0;e=d+j|0;f=g;d=i;e=d>>>0<n>>>0?e+1|0:e;h=(e|0)==(j|0)&h>>>0>d>>>0|e>>>0<j>>>0;g=h+w|0;f=h>>>0>g>>>0?f+1|0:f;j=g;g=f;h=d;f=0;i=e;n=(u|0)==(v|0)&q>>>0<E>>>0|u>>>0>v>>>0;l=n;n=n+((u|0)==(D|0)&C>>>0>E>>>0|u>>>0<D>>>0)|0;e=e+(l>>>0>n>>>0?1:f)|0;f=g;d=d+n|0;e=d>>>0<n>>>0?e+1|0:e;h=(e|0)==(i|0)&d>>>0<h>>>0|e>>>0<i>>>0;g=h;h=h+j|0;f=g>>>0>h>>>0?f+1|0:f;i=f;c:{if(f&65536){t=t+1|0;break c}j=r>>>31|0;g=0;f=i<<1|h>>>31;h=h<<1|e>>>31;i=f;f=e<<1|d>>>31;d=d<<1|c>>>31;e=f;f=r<<1|p>>>31;p=p<<1;r=f;f=c<<1|b>>>31;b=b<<1|j;c=f|g}if((t|0)>=32767){o=o|2147418112;b=0;c=0;break a}d:{if((t|0)<=0){g=1-t|0;if(g>>>0<=127){f=t+127|0;bg(k+48|0,p,r,b,c,f);bg(k+32|0,d,e,h,i,f);gn(k+16|0,p,r,b,c,g);gn(k,d,e,h,i,g);p=x[k+32>>2]|x[k+16>>2]|(x[k+48>>2]|x[k+56>>2]|(x[k+52>>2]|x[k+60>>2]))!=0;r=x[k+36>>2]|x[k+20>>2];b=x[k+40>>2]|x[k+24>>2];c=x[k+44>>2]|x[k+28>>2];d=x[k>>2];e=x[k+4>>2];g=x[k+8>>2];f=x[k+12>>2];break d}b=0;c=0;break a}g=h;f=i&65535|t<<16}m=g|m;o=f|o;if(!(!b&(c|0)==-2147483648?!(p|r):(c|0)>0|(c|0)>=0)){b=d+1|0;j=b?e:e+1|0;e=o;c=j;d=!(j|b);m=d+m|0;o=d>>>0>m>>>0?e+1|0:e;break a}if(b|p|(c^-2147483648|r)){b=d;c=e;break a}f=e;b=d&1;c=b;b=b+d|0;f=c>>>0>b>>>0?f+1|0:f;c=f;d=(e|0)==(f|0)&b>>>0<d>>>0|e>>>0>f>>>0;f=o;m=d+m|0;o=m>>>0<d>>>0?f+1|0:f}x[a>>2]=b;x[a+4>>2]=c;x[a+8>>2]=m;x[a+12>>2]=o;fb=k+96|0}function Gpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;g=fb-128|0;fb=g;xc(b);a:{b:{c:{d:{e:{if(!LX(b,14208)){break e}k=Nb(g+116|0);j=Nb(g+104|0);x[31737]=0;x[g+96>>2]=0;x[g+100>>2]=0;O(247,a|0,32768);d=x[31737];x[31737]=0;if((d|0)==1){break b}x[31737]=0;d=P(1,g+84|0,8169)|0;i=x[31737];x[31737]=0;if((i|0)==1){break c}Ab(a+1298344|0,d);tb(d);x[31737]=0;d=P(1,g+72|0,6060)|0;i=x[31737];x[31737]=0;if((i|0)==1){break d}Ab(a+1298356|0,d);tb(d);o=a+1298404|0,q=x[Fc(g+44|0,28)>>2],x[o>>2]=q;m=(c|0)==64;i=a+480280|0;while(1){d=x[b+8>>2];f=x[b>>2];x[31737]=0;d=U(151,f|0,d|0,8)|0;f=x[31737];x[31737]=0;f:{g:{h:{if((f|0)!=1){i:{j:{k:{l:{m:{n:{if(!d){break n}x[31737]=0;d=P(653,b|0,g- -64|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break m}if(!d){break n}f=x[g+68>>2];x[31737]=0;d=g+24|0;S(186,d|0,b|0,$b(f)|0);f=x[31737];x[31737]=0;if((f|0)==1){break l}f=ic(g+44|0,d);ub(d);d=x[f>>2];x[31737]=0;d=R(173,d|0)|0;e=x[31737];x[31737]=0;if((e|0)==1){break j}if(d){break k}ub(f)}if(z[a+480188>>1]){break i}i=0;break g}a=N()|0;break a}a=N()|0;break a}o:{p:{q:{r:{s:{t:{u:{d=$b(x[g+64>>2]);if((d|0)!=1397769541){if((d|0)==1346458708){break t}if((d|0)==1346522948){break s}if((d|0)==1347175758){break u}if((d|0)!=1396788560){if((d|0)==1396854596){break r}if((d|0)==1397507406){break f}if((d|0)!=1129140036){break p}if(z[a+480188>>1]){break f}d=x[f>>2];x[31737]=0;d=R(155,d|0)|0;e=x[31737];x[31737]=0;if((e|0)==1){break j}if(d>>>0<8){break f}d=0;x[31737]=0;O(654,g+24|0,f|0);e=x[31737];x[31737]=0;if((e|0)==1){break j}while(1)if((d|0)==4){if(!m){break f}i=1;break o}else{h=_b(g+24|0,d);e=z[a+480188>>1];v:{if(!Bb(y[h|0]|y[h+1|0]<<8)){h=(d&3)-1|0;break v}h=g+96|0;o=xb(h,e),q=1,v[o|0]=q;o=xb(h,z[a+480188>>1]+1|0),q=255,v[o|0]=q;We(i+(z[a+480188>>1]<<5)|0);h=z[a+480188>>1];e=h+1|0;w[a+480188>>1]=e;l=i+(h<<5)|0;h=(d&3)-1|0;w[l+4>>1]=h>>>0<2?192:64}We(i+((e&65535)<<5)|0);e=z[a+480188>>1];w[a+480188>>1]=e+1;w[(i+(e<<5)|0)+4>>1]=h>>>0<2?192:64;d=d+1|0;continue}}if(z[a+480190>>1]){break f}x[31737]=0;O(655,f|0,a|0);d=x[31737];x[31737]=0;if((d|0)!=1){break f}break j}d=x[f>>2];x[31737]=0;d=R(155,d|0)|0;e=x[31737];x[31737]=0;if((e|0)==1){break j}if(d>>>0<2){break f}x[31737]=0;d=R(274,f|0)|0;e=x[31737];x[31737]=0;if((e|0)==1){break j}o=a,q=Kd(d,1,255),x[o+480196>>2]=q;break f}d=x[f>>2];x[31737]=0;d=R(155,d|0)|0;e=x[31737];x[31737]=0;if((e|0)==1){break j}if(d>>>0<2){break f}x[31737]=0;n=R(274,f|0)|0;d=x[31737];x[31737]=0;if((d|0)!=1){break f}break j}d=y[a+484376|0];e=x[a+484360>>2];h=x[f>>2];x[31737]=0;h=R(155,h|0)|0;l=x[31737];x[31737]=0;if((l|0)==1){break j}x[31737]=0;aa(349,Xb(e,d)|0,f|0,h|0,255,254);d=x[31737];x[31737]=0;if((d|0)==1){break j}break f}d=k;if(Uf(x[d>>2],x[d+4>>2])>>>0>=256){break f}break q}if(Uf(x[j>>2],x[j+4>>2])>>>0>3998){break f}d=x[f>>2];x[31737]=0;e=R(155,d|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break j}d=j;if(!e){break f}}x[31737]=0;O(656,d|0,f|0);d=x[31737];x[31737]=0;if((d|0)!=1){break f}break j}if(!(d&-2139062144)){break f}i=0}ub(f);break g}a=N()|0;ub(f);break a}x[a+480200>>2]=256;x[a+480204>>2]=125e4;x[a+480260>>2]=452;x[a+480264>>2]=3424;x[a+480228>>2]=48;x[a+480232>>2]=48;b=x[a+484360>>2];d=y[a+484376|0];x[31737]=0;O(331,Xb(b,d)|0,n&65535);b=x[31737];x[31737]=0;if((b|0)==1){break b}w:{if(!(c&1)){break w}b=x[k+4>>2];i=x[k>>2];d=0;x[31737]=0;O(224,a+484344|0,Uf(i,b)&65535);b=x[31737];x[31737]=0;if((b|0)==1){break b}while(1){e=x[k>>2];b=d&65535;if(Uf(e,x[k+4>>2])>>>0<=b>>>0){break w}x[31737]=0;i=x[g+100>>2];f=x[g+96>>2];x[g+16>>2]=f;x[g+20>>2]=i;x[g+8>>2]=f;x[g+12>>2]=i;V(657,dh(e,b)|0,b|0,a|0,g+8|0);b=x[31737];x[31737]=0;if((b|0)!=1){d=d+1|0;continue}break}a=N()|0;break a}f=c&2;i=1;d=1;b=0;while(1){if(z[a+480190>>1]<=d>>>0){break g}if(!f|Uf(x[j>>2],x[j+4>>2])>>>0<=b>>>0){break g}c=(D(d,104)+a|0)+484380|0;Cp(c);x:{if(x[c>>2]){e=x[dh(x[j>>2],b)>>2];x[31737]=0;e=R(155,e|0)|0;h=x[31737];x[31737]=0;if((h|0)==1){break h}wc(c,e);e=Xc(g+44|0,8,1,1,0);h=x[j>>2];x[31737]=0;U(216,e|0,c|0,dh(h,b)|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break x}b=b+1|0}d=d+1|0;continue}break}a=N()|0;break a}a=N()|0;break a}a=N()|0;break a}Qc(j);Qc(k);break e}ub(f);continue}}fb=g+128|0;return i|0}a=N()|0;break a}a=N()|0;break a}a=N()|0}Qc(j);Qc(k);Q(a|0);p()}function TS(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;h=fb-16|0;fb=h;a:{if(!Sc(d&255)){break a}m=a+1074376|0;g=D(b,872);j=(m+g|0)+616|0;b:{f=z[a+480192>>1];if(!(!(x[a+480180>>2]&17825824)|!f|e)){break b}if(Ij(x[j+656>>2])){break b}c=a+g|0;d=c+1075068|0;if(!x[d>>2]){break a}e=x[c+1075080>>2];if(e&1024){break a}g=c+1075012|0;c=c+1075016|0;if(!(x[g>>2]|x[c>>2])){break a}c:{if(!(e&512)){break c}e=x[a+1298300>>2];if(!Dd(e)){break c}Lj(e,b,0);break a}e=dB(a,b);if((e|0)==65535){break a}i=D(e,872);e=a+1074992|0;a=i+e|0;Kq(a,j);v[a+831|0]=0;v[a+805|0]=0;w[a+786>>1]=b+1;x[a+88>>2]=x[a+88>>2]&-918529;_o(a+788|0);x[a+696>>2]=0;x[a+88>>2]=x[a+88>>2]|2101248;x[d>>2]=0;x[j>>2]=0;x[j+4>>2]=0;a=e+D(b,872)|0;x[a+92>>2]=0;x[a+96>>2]=0;x[g>>2]=0;x[c>>2]=0;break a}e=D(b,872)+a|0;l=x[e+1075096>>2];c=c>>>0<=f>>>0?c:0;g=x[(c?((c<<2)+a|0)+900380|0:e+1075648|0)>>2];d:{if(!g){break d}k=d-1|0;c=z[_b(g+236|0,k)>>1];f=a+1074312|0;Kb(h+8|0,f,104);e:{if(Hb(x[x[h+8>>2]>>2],x[h+12>>2])){Kb(h,f,34);if(Hb(x[x[h>>2]>>2],x[h+4>>2])){break e}}d=y[xb(g+108|0,k)|0]}if((c-1&65535)>>>0<=3998){l=(D(c,104)+a|0)+484380|0;break d}Kb(h+8|0,f,43);if(!Hb(x[x[h+8>>2]>>2],x[h+12>>2])){break d}if(!Qj(y[g+31|0])){break a}}if(y[e+1075081|0]&4){break a}o=b>>>0<=256?256:b;k=a+1074312|0;p=b+1|0;c=b;f:{g:{while(1){if((c|0)==(o|0)){h:{c=0;if(Ij(x[j+656>>2])){break h}break g}}else{f=(b|0)==(c|0);i:{if(!f&z[a+480188>>1]>c>>>0){break i}e=D(c,872)+a|0;if(!f&z[e+1075778>>1]!=(p|0)){break i}n=e+1075648|0;f=x[n>>2];if(!f){break i}j:{k:{l:{m:{n:{o:{p:{switch(y[f+17|0]-1|0){case 0:if(!d){break i}i=(f|0)==(g|0)&y[e+1075789|0]==(d|0);if(!g){break o}if(i){break l}break i;case 1:if(!l|x[e+1075096>>2]!=(l|0)){break i}if((f|0)==(g|0)){break j}Kb(h+8|0,k,104);if(!Hb(x[x[h+8>>2]>>2],x[h+12>>2])){break j}break i;case 3:break n;case 2:break p;default:break i}}if(g){break m}i=(f|0)==(g|0)}if(i){break j}break i}if(!g){break i}i=y[g+34|0];if(!i){break i}if((i|0)==y[f+34|0]){break k}break i}if((f|0)!=(g|0)){break i}}if(!y[g+34|0]){break j}}if(!y[e+1075789|0]|y[f+18|0]>2){break j}f=e+1075793|0;i=y[f|0];if(!i){break j}bn(a,c&65535,i|256,0);v[f|0]=0}f=e+1074992|0;q:{r:{switch(y[x[n>>2]+18|0]){case 0:Jo(a,f);x[e+1075680>>2]=0;if(!(y[e+1075081|0]&2)){break q}f=x[a+1298300>>2];if(!Dd(f)){break q}Lj(f,c&65535,1);break q;case 1:Jo(a,f);if(!(y[e+1075081|0]&2)){break q}f=x[a+1298300>>2];if(!Dd(f)){break q}Dk(f,c&65535);break q;case 2:break r;default:break q}}i=e+1075080|0;f=x[i>>2];x[i>>2]=f|4096;if(!(f&512)){break q}if(!Dd(x[a+1298300>>2])){break q}Kb(h+8|0,k,105);if(Hb(x[x[h+8>>2]>>2],x[h+12>>2])){break q}Dk(x[a+1298300>>2],c&65535)}if(x[e+1075680>>2]){break i}x[e+1075688>>2]=0;e=e+1075080|0;x[e>>2]=x[e>>2]|2101248}c=c+1|0;continue}break}g=D(b,872)+a|0;if(!Sc(y[g+1075789|0])){break g}d=vm(a,m,b,2,1)-1|0;if((d&255)>>>0>249){break g}d=x[vd(a+906300|0,d)>>2];if(!d){break g}e=1;g=y[g+1075793|0];if(!g){break f}c=ib[x[x[d>>2]+104>>2]](d,g,b)|0;break f}e=0}if(!(Ti(x[j+8>>2],x[j+12>>2])|c)){break a}s:{if(!(c&e)){break s}c=D(b,872)+a|0;d=y[c+1075790|0];if(d>>>0>3|(d|0)==1){break s}bn(a,b,255,0);w[c+1075792>>1]=0}c=dB(a,b);if((c|0)==65535){break a}f=D(c,872);e=f+a|0;d=e+1075080|0;g=e+1074992|0;t:{if(!(y[e+1075081|0]&2)){break t}e=x[a+1298300>>2];if(!Dd(e)){break t}Lj(e,c,1)}l=Kq(g,j);e=x[d>>2];g=e&-917505;x[d>>2]=g;i=a+1074992|0;f=i+f|0;v[f+831|0]=0;m=z[a+480188>>1];v[f+805|0]=0;w[f+786>>1]=b>>>0<m>>>0?b+1|0:0;u:{v:{switch(y[(i+D(b,872)|0)+798|0]){case 2:Jo(a,l);if(!(y[d+1|0]&2)){break u}e=x[a+1298300>>2];if(!Dd(e)){break u}Dk(e,b);Kb(h+8|0,k,105);if(!Hb(x[x[h+8>>2]>>2],x[h+12>>2])){break u}TB(x[a+1298300>>2],b,c);break u;case 0:x[(D(c,872)+a|0)+1075688>>2]=0;x[d>>2]=g|4096;if(!(e&512)){break u}e=x[a+1298300>>2];if(!Dd(e)){break u}Lj(e,b,1);break u;case 3:x[d>>2]=g|4096;if(!(e&512)){break u}if(!Dd(x[a+1298300>>2])){break u}Kb(h+8|0,k,105);e=x[a+1298300>>2];if(Hb(x[x[h+8>>2]>>2],x[h+12>>2])){TB(e,b,c);break u}Dk(e,b);break u;case 1:break v;default:break u}}if(!(e&512)){break u}e=x[a+1298300>>2];if(!Dd(e)){break u}TB(e,b,c)}c=D(c,872)+a|0;if(!x[c+1075680>>2]){x[c+1075688>>2]=0;x[d>>2]=x[d>>2]|2101248}a=D(b,872)+a|0;x[a+1075068>>2]=0;x[j>>2]=0;x[j+4>>2]=0;a=a+1075084|0;x[a>>2]=0;x[a+4>>2]=0}fb=h+16|0}function h1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=fb-80|0;fb=g;xc(b);a:{if(!Tr(b,11790)){break a}i=g+69|0;if(!vw(b,i)){break a}if(!NE(y[g+70|0])){break a}if(!Mb(x[b>>2],x[b+8>>2],Bc(ME(i),hb))){break a}if(!Vb(b,y[g+78|0]|y[g+79|0]<<8)){break a}d=1;if((c|0)==64){break a}Bd(a,4096);x[a+480208>>2]=12;w[a+480188>>1]=(y[g+71|0]&31)+1;w[a+480190>>1]=y[g+72|0];Xh(a,1);d=g+20|0;e=tc(d,8476);Ab(a+1298344|0,e);tb(e);e=tc(d,7105);Ab(a+1298356|0,e);tb(e);e=fb-16|0;fb=e;f=tc(e+4|0,4247);_c(g,f);tb(f);fb=e+16|0;x[31737]=0;V(230,d|0,g|0,y[g+70|0],i|0);i=x[31737];x[31737]=0;b:{if((i|0)!=1){Ab(a+1298368|0,d);tb(d);Eb(g);l=a+1298404|0,m=x[Fc(d,4)>>2],x[l>>2]=m;d=y[g+72|0];i=g+56|0;x[i>>2]=0;x[i+4>>2]=0;Fc(i+8|0,0);if(d){$r(i,d);MF(i,d,0)}d=1;c:{while(1){e=d&65535;if(e>>>0>z[a+480190>>1]){x[31737]=0;P(231,b|0,a+1298308|0)|0;e=x[31737];x[31737]=0;d=1;d:{if((e|0)==1){break d}while(1){e=d&65535;if(e>>>0>z[a+480190>>1]){d=0;e:{while(1){if(z[a+480188>>1]<=d>>>0){d=0;x[31737]=0;e=a+484344|0;O(224,e|0,y[g+73|0]|y[g+74|0]<<8);f=x[31737];x[31737]=0;if((f|0)==1){break d}break e}e=(d<<5)+a|0;We(e+480280|0);x[31737]=0;O(232,b|0,e+480289|0);e=x[31737];x[31737]=0;if((e|0)!=1){d=d+1|0;continue}break}b=N()|0;break c}f:{g:{h:{i:{while(1){if((y[g+73|0]|y[g+74|0]<<8)>>>0<=d>>>0){x[31737]=0;f=R(190,b|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break g}if(!f){break h}d=x[b+8>>2];e=x[b>>2];x[31737]=0;d=U(151,e|0,d|0,f|0)|0;e=x[31737];x[31737]=0;if((e|0)==1){break g}if(d){break i}break h}x[31737]=0;f=g+20|0;h=P(233,b|0,f|0)|0;j=x[31737];x[31737]=0;j:{if((j|0)==1){break j}x[31737]=0;j=U(197,e|0,d&65535,64)|0;k=x[31737];x[31737]=0;if((k|0)==1){break j}if((h&j)==1){h=x[e>>2];x[31737]=0;O(234,Wb(h,d)|0,f|0);f=x[31737];x[31737]=0;if((f|0)==1){break j}}d=d+1|0;continue}break}b=N()|0;break c}e=Nb(g+20|0);x[31737]=0;S(235,b|0,e|0,f|0);d=x[31737];x[31737]=0;k:{if((d|0)!=1){d=Fb(g);x[31737]=0;O(115,d|0,f|0);f=x[31737];x[31737]=0;l:{if((f|0)==1){break l}l=g,m=wb(x[e>>2]),x[l+40>>2]=m;h=wb(x[e+4>>2]);while(1){m:{f=x[g+40>>2];if(!Ib(f,h)){x[31737]=0;h=g+40|0;S(236,h|0,20,d|0);f=x[31737];x[31737]=0;if((f|0)==1){break m}f=Ab(d,h);tb(h);h=Jb(f);j=y[f+11|0];k=x[f+4>>2];x[31737]=0;aa(237,a+1298332|0,h|0,Yc(k,j)|0,76,0);h=x[31737];x[31737]=0;if((h|0)==1){break l}tb(f);dc(e);break h}n:{f=v[f|0];if((f|0)<0){j=x[vb(g+52|0,Df(d))>>2];x[31737]=0;V(238,d|0,j|0,f&127,32);f=x[31737];x[31737]=0;if((f|0)!=1){break n}break l}x[31737]=0;O(116,d|0,f|0);f=x[31737];x[31737]=0;if((f|0)!=1){break n}break l}le(g+40|0);continue}break}}b=N()|0;tb(d);break k}b=N()|0}dc(e);break c}d=y[a+484376|0];e=x[a+484360>>2];x[31737]=0;S(239,Xb(e,d)|0,b|0,y[g+75|0]|y[g+76|0]<<8);d=x[31737];x[31737]=0;if((d|0)==1){break g}f=c&1;d=0;while(1){o:{p:{if((y[g+73|0]|y[g+74|0]<<8)>>>0>d>>>0){e=x[b+8>>2];h=x[b>>2];x[31737]=0;e=U(151,h|0,e|0,4)|0;h=x[31737];x[31737]=0;if((h|0)==1){break o}if(e){break p}}if(!(c&2)){break f}d=1;while(1){c=d&65535;if(c>>>0>z[a+480190>>1]){break f}e=D(c,104)+a|0;f=z[e+484414>>1];Kb(g+20|0,x[i>>2],c-1|0);c=Xc(g,f&1?16:8,1,0,Hb(x[x[g+20>>2]>>2],x[g+24>>2])?6:0);x[31737]=0;U(216,c|0,e+484380|0,b|0)|0;c=x[31737];x[31737]=0;if((c|0)!=1){d=d+1|0;continue}break}b=N()|0;break c}x[31737]=0;e=R(152,b|0)|0;h=x[31737];x[31737]=0;q:{r:{if((h|0)!=1){x[31737]=0;S(186,g|0,b|0,e|0);e=x[31737];x[31737]=0;if((e|0)==1){break r}e=ic(g+20|0,g);ub(g);if(!f){break q}h=x[a+484344>>2];if(!He(h,x[a+484348>>2],d&65535)){break q}x[31737]=0;S(240,Wb(h,d)|0,0,e|0);h=x[31737];x[31737]=0;if((h|0)!=1){break q}b=N()|0;ub(e);break c}b=N()|0;break c}b=N()|0;break c}ub(e);d=d+1|0;continue}break}b=N()|0;break c}b=N()|0;break c}tf(i);d=1;break a}x[31737]=0;P(241,b|0,((e<<5)+a|0)+946304|0)|0;e=x[31737];x[31737]=0;if((e|0)!=1){d=d+1|0;continue}break}b=N()|0;break c}b=N()|0;break c}x[31737]=0;f=g+20|0;O(242,b|0,f|0);h=x[31737];x[31737]=0;s:{if((h|0)==1){break s}x[31737]=0;O(243,f|0,(D(e,104)+a|0)+484380|0);f=x[31737];x[31737]=0;if((f|0)==1){break s}f=y[g+36|0];Kb(g,x[i>>2],e-1|0);If(g,(f&3)!=0);d=d+1|0;continue}break}b=N()|0}tf(i);break b}b=N()|0;Eb(g)}Q(b|0);p()}fb=g+80|0;return d|0}function cja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=E(0),m=0,n=0,o=0,q=0,r=0;d=fb-80|0;fb=d;h=-1;a:{b:{c:{d:{if(x[(x[x[b>>2]-12>>2]+b|0)+16>>2]){break d}$d(d- -64|0,b);e=x[d+72>>2];g=x[d+76>>2];f=d+56|0;el(f);b=Dj(b,f,8);if((y[d+56|0]|y[d+57|0]<<8|(y[d+58|0]<<16|y[d+59|0]<<24))!=1414681667|(y[d+60|0]|y[d+61|0]<<8|(y[d+62|0]<<16|y[d+63|0]<<24))!=776101705){Hi(b,e,g,0);break d}w[d+54>>1]=0;pg(b,d+54|0);k=w[d+54>>1];if((k-4&65535)>>>0<65534){break d}e=d+46|0;el(e);e=Dj(b,e,8);if((y[d+46|0]|y[d+47|0]<<8|(y[d+48|0]<<16|y[d+49|0]<<24))!=1933333571|(y[d+50|0]|y[d+51|0]<<8|(y[d+52|0]<<16|y[d+53|0]<<24))!=1111389030){break d}w[d+44>>1]=0;pg(e,d+44|0);g=w[d+44>>1];if((g-5&65535)>>>0<65534){break d}e:{f:{g:{h:{i:{j:{if(g>>>0<=3){b=Fb(d- -64|0);x[31737]=0;f=U(496,e|0,b|0,65535)|0;i=x[31737];x[31737]=0;if((i|0)==1){break b}if(!f){break i}x[31737]=0;f=d+32|0;S(497,f|0,c|0,b|0);i=x[31737];x[31737]=0;if((i|0)!=1){break j}break b}b=Fb(d- -64|0);x[31737]=0;f=P(499,e|0,b|0)|0;i=x[31737];x[31737]=0;if((i|0)==1){break c}if(!f){break h}x[31737]=0;f=d+32|0;S(497,f|0,c|0,b|0);i=x[31737];x[31737]=0;if((i|0)==1){break c}}Ab(a+40|0,f);tb(f);tb(b);w[d+30>>1]=0;pg(e,d+30|0);w[d+28>>1]=0;pg(e,d+28|0);w[a>>1]=z[d+28>>1];w[d+26>>1]=0;k:{if((g|0)<=3){x[d+64>>2]=0;Lk(e,d- -64|0);b=x[d+64>>2];if(b>>>0>65535){break d}b=jm(b);w[d+26>>1]=b;break k}pg(e,d+26|0);b=z[d+26>>1]}i=a+52|0;m=b&65535;n=(g|0)>3;b=0;l:{m:{while(1){if((b&65535)>>>0>=m>>>0){break l}g=Fb(d- -64|0);x[31737]=0;w[d+8>>1]=0;O(940,e|0,d+8|0);f=x[31737];x[31737]=0;if((f|0)==1){break g}n:{if(!n){x[31737]=0;f=U(496,e|0,g|0,65535)|0;j=x[31737];x[31737]=0;if((j|0)==1){break g}if(f){break n}break e}x[31737]=0;f=P(499,e|0,g|0)|0;j=x[31737];x[31737]=0;if((j|0)==1){break g}if(!f){break e}}x[31737]=0;f=d+32|0;S(497,f|0,c|0,g|0);j=x[31737];x[31737]=0;if((j|0)!=1){x[31737]=0;j=P(937,i|0,d+8|0)|0;o=x[31737];x[31737]=0;if((o|0)==1){break m}Ab(j,f);tb(f);tb(g);b=b+1|0;continue}break}h=N()|0;break f}h=N()|0;tb(d+32|0);break f}b=d+32|0;el(b);b=Dj(e,b,8);if((y[d+32|0]|y[d+33|0]<<8|(y[d+34|0]<<16|y[d+35|0]<<24))!=1933333571|(y[d+36|0]|y[d+37|0]<<8|(y[d+38|0]<<16|y[d+39|0]<<24))!=1161720678){break d}c=z[a>>1];if(c>>>0>3|(c|0)==2){break d}c=a+4|0;o:{if((k|0)<=2){if(ZQ(b,c)){break o}break d}if(!YQ(b,c)){break d}}q=d,r=wb(x[a+4>>2]),x[q+64>>2]=r;c=wb(x[a+8>>2]);while(1){e=x[d+64>>2];if(Ib(e,c)){if(!_m(B[e>>2])){break d}Je(d- -64|0);continue}break}c=a+16|0;p:{if((k|0)<=2){if(ZQ(b,c)){break p}break d}if(!YQ(b,c)){break d}}q=d,r=wb(x[a+16>>2]),x[q+64>>2]=r;c=wb(x[a+20>>2]);while(1){e=x[d+64>>2];if(Ib(e,c)){if(!_m(B[e>>2])){break d}Je(d- -64|0);continue}break}q=a,r=oc(x[a+16>>2],x[a+20>>2]),x[q+36>>2]=r;w[d+24>>1]=0;pg(b,d+24|0);c=z[d+24>>1];w[a+28>>1]=c;if((c-201&65535)>>>0<65135){break d}w[d+22>>1]=0;pg(b,d+22|0);c=w[d+22>>1];w[a+30>>1]=c;if((c|0)<0){break d}x[d+16>>2]=0;Bq(b,d+16|0);l=aR(B[d+16>>2]);B[a+32>>2]=l;if(!_m(l)){break d}x[d+8>>2]=0;x[d+12>>2]=0;c=fb-32|0;fb=c;e=d+8|0;dl(c+16|0,e);Sm(c+24|0,b,x[c+16>>2],x[c+20>>2]);dl(c+8|0,e);fb=c+32|0;if(x[d+8>>2]!=1414681667|x[d+12>>2]!=776298313){break d}b=oc(x[a+4>>2],x[a+8>>2]);if(b>>>0>32767){break d}c=w[a+30>>1];e=z[a>>1];if(!(e?!(B[a+32>>2]<=E(0))&(c|0)>0:1)){break d}q:{switch(e-1|0){case 0:case 2:if(b>>>0<c>>>0){break d}break;default:break q}}b=0;c=x[a+36>>2];if(c){b=c-1|0;x[a+36>>2]=b}q=d,r=th(b),x[q+64>>2]=r;x[d+4>>2]=0;b=d- -64|0;q=a,r=x[dk(b,d+4|0,42336)>>2],x[q+36>>2]=r;Cq(a);h=1;if(z[a>>1]!=3){break d}c=w[a+30>>1];if((c-w[a+28>>1]|0)>(gR(oc(x[a+4>>2],x[a+8>>2]))|0)){break d}h=a+32|0;e=Nb(b);b=0;while(1){r:{if(c<<16>>16<=(b|0)){b=z[a+28>>1];w[d+4>>1]=b;q=d,r=(oc(x[a+4>>2],x[a+8>>2])+b|0)-1|0,w[q+6>>1]=r;x[31737]=0;w[d+2>>1]=0;ha(935,a|0,e|0,h|0,d+4|0,d+2|0)|0;a=x[31737];x[31737]=0;h=1;if((a|0)==1){break r}vc(e);break d}c=w[a+28>>1];g=x[a+4>>2];x[31737]=0;O(941,e|0,yb(g,b-c|0)|0);c=x[31737];x[31737]=0;if((c|0)!=1){b=b+1|0;c=z[a+30>>1];continue}}break}h=N()|0;vc(e);break a}tb(b);break d}tb(b);break d}h=N()|0}tb(g);break a}tb(g)}fb=d+80|0;return h|0}h=N()|0;tb(b);break a}h=N()|0;tb(b)}Q(h|0);p()}function Ws(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=fb-592|0;fb=e;x[e+572>>2]=6;x[e+576>>2]=364;x[e+564>>2]=11;x[e+568>>2]=161;x[e+556>>2]=23;x[e+560>>2]=31;x[e+548>>2]=59;x[e+552>>2]=55;x[e+584>>2]=0;x[e+588>>2]=0;x[e+580>>2]=-1;v[e+446|0]=c;v[e+445|0]=37;v[e+447|0]=0;h=e+448|0;fa(h|0,100,e+445|0,e+548|0,x[b>>2])|0;f=e+32|0;x[e+28>>2]=f;x[e+16>>2]=0;x[e+20>>2]=0;x[e+12>>2]=h;h=Gi(f,e+12|0,100,e+16|0,x[b>>2]);if((h|0)!=-1){l=b+484|0;i=b+460|0;j=b+172|0;k=b+4|0;h=(h<<2)+f|0;g=Fb(a);m=(c|0)!=120;a:while(1){b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{if((f|0)!=(h|0)){a=x[f>>2];x[31737]=0;a=U(1243,d|0,1,a|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break c}if(a){x[31737]=0;O(35,g|0,32);a=x[31737];x[31737]=0;if((a|0)==1){break c}while(1){f=f+4|0;if((h|0)==(f|0)){f=h;break b}a=x[f>>2];x[31737]=0;a=U(1243,d|0,1,a|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break c}if(a){continue}break}break b}x[e+8>>2]=f;x[31737]=0;x[e+4>>2]=0;a=ea(1339,e+8|0,h|0,k|0,j|0,d|0,e+4|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break c}p:{a=a-k|0;q:{if((a|0)<=167){x[31737]=0;O(35,g|0,37);c=x[31737];x[31737]=0;if((c|0)==1){break c}x[31737]=0;O(35,g|0,((a|0)<84?65:97)|0);a=x[31737];x[31737]=0;if((a|0)!=1){break q}break c}x[31737]=0;x[e+8>>2]=f;a=ea(1339,e+8|0,h|0,j|0,i|0,d|0,e+4|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break c}a=a-j|0;c=(a|0)/12|0;if((a|0)<=287){x[31737]=0;O(35,g|0,37);f=x[31737];x[31737]=0;if((f|0)==1){break c}x[31737]=0;O(35,g|0,((a|0)<144?66:98)|0);a=x[31737];x[31737]=0;if((a|0)==1){break c}if(m){break q}a=x[Vd((D(c,12)+b|0)+172|0,0)>>2];x[31737]=0;a=U(1243,d|0,64,a|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break c}if(!a){break q}n=(Jb(g)+(Cb(x[g+4>>2],y[g+11|0])<<2)|0)-4|0,o=109,x[n>>2]=o;break q}if((Cb(x[b+464>>2],y[b+471|0])|0)==(0-Cb(x[b+476>>2],y[b+483|0])|0)){break p}x[31737]=0;x[e+8>>2]=f;a=ea(1339,e+8|0,h|0,i|0,l|0,d|0,e+4|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break c}if((a-i|0)>23){break p}x[31737]=0;O(35,g|0,37);a=x[31737];x[31737]=0;if((a|0)==1){break c}x[31737]=0;O(35,g|0,112);a=x[31737];x[31737]=0;if((a|0)==1){break c}}f=x[e+8>>2];break b}x[e+8>>2]=f;a=x[f>>2];x[31737]=0;a=U(1243,d|0,64,a|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break c}if(a){x[31737]=0;a=ba(1340,e+28|0,h|0,e+4|0,d|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break c}r:{s:{switch(a-6|0){case 2:case 3:case 4:break r;case 0:break e;case 1:break f;case 5:break g;case 6:break h;default:break s}}t:{switch(a-55|0){case 0:break k;case 4:break l;case 6:break m;case 1:case 2:case 3:case 5:break r;default:break t}}if((a|0)==23){break i}if((a|0)==31){break j}if((a|0)==364){break n}if((a|0)==2061){break o}}a=x[e+28>>2];while(1){if((a|0)==(f|0)){f=a;continue a}c=x[f>>2];x[31737]=0;O(35,g|0,c|0);c=x[31737];x[31737]=0;if((c|0)==1){break c}f=f+4|0;continue}}a=x[f>>2];x[31737]=0;a=P(1341,d|0,a|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break c}u:{if((a|0)==37){x[31737]=0;O(35,g|0,37);a=x[31737];x[31737]=0;if((a|0)==1){break c}x[31737]=0;O(35,g|0,37);break u}a=x[f>>2];x[31737]=0;O(35,g|0,a|0)}a=x[31737];x[31737]=0;if((a|0)==1){break c}f=f+4|0;break b}fb=e+592|0;return}x[31737]=0;O(35,g|0,37);a=x[31737];x[31737]=0;c=89;break d}x[31737]=0;O(35,g|0,37);a=x[31737];x[31737]=0;c=106;break d}x[31737]=0;O(35,g|0,37);a=x[31737];x[31737]=0;c=121;break d}x[31737]=0;O(35,g|0,37);a=x[31737];x[31737]=0;c=83;break d}x[31737]=0;O(35,g|0,37);a=x[31737];x[31737]=0;c=77;break d}x[31737]=0;O(35,g|0,37);a=x[31737];x[31737]=0;c=100;break d}x[31737]=0;O(35,g|0,37);a=x[31737];x[31737]=0;c=72;break d}x[31737]=0;O(35,g|0,37);a=x[31737];x[31737]=0;c=109;break d}x[31737]=0;O(35,g|0,37);a=x[31737];x[31737]=0;c=73;break d}x[31737]=0;O(35,g|0,37);a=x[31737];x[31737]=0;c=117;break d}x[31737]=0;O(35,g|0,37);a=x[31737];x[31737]=0;c=119}if((a|0)==1){break c}x[31737]=0;O(35,g|0,c|0);a=x[31737];x[31737]=0;if((a|0)==1){break c}f=x[e+28>>2];continue}a=N()|0;Ub(g);Q(a|0);p()}x[e+28>>2]=f;continue}}io(12677);p()}function ija(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=E(0),j=0,k=0,l=0;d=fb-304|0;fb=d;e=-1;a:{b:{c:{if(!tk(x[(x[x[b>>2]-12>>2]+b|0)+16>>2])){f=Pm(d+192|0,b);x[31737]=0;b=P(462,d+180|0,14062)|0;e=x[31737];x[31737]=0;d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{if((e|0)!=1){x[31737]=0;x[d+160>>2]=83886084;x[d+164>>2]=0;e=d+160|0;S(463,f|0,b|0,e|0);g=x[31737];x[31737]=0;if((g|0)==1){break A}Eb(b);v[d+179|0]=0;x[31737]=0;b=P(462,e|0,14789)|0;e=x[31737];x[31737]=0;if((e|0)==1){break z}x[31737]=0;S(464,f|0,d+179|0,b|0);e=x[31737];x[31737]=0;if((e|0)==1){break y}Eb(b);c=Fc(d+156|0,y[d+179|0]?0:c);x[31737]=0;b=P(462,d+144|0,15880)|0;e=x[31737];x[31737]=0;if((e|0)==1){break x}e=x[c>>2];x[31737]=0;V(929,f|0,a+40|0,b|0,e|0);e=x[31737];x[31737]=0;if((e|0)==1){break w}Eb(b);w[d+142>>1]=65535;x[31737]=0;b=P(462,d+128|0,15577)|0;e=x[31737];x[31737]=0;if((e|0)==1){break v}x[31737]=0;U(492,f|0,d+142|0,b|0)|0;e=x[31737];x[31737]=0;if((e|0)==1){break u}Eb(b);w[d+126>>1]=0;x[31737]=0;b=P(462,d+112|0,15478)|0;e=x[31737];x[31737]=0;if((e|0)==1){break t}x[31737]=0;U(492,f|0,d+126|0,b|0)|0;e=x[31737];x[31737]=0;if((e|0)==1){break s}Eb(b);w[a>>1]=z[d+126>>1];x[31737]=0;b=P(462,d+100|0,15151)|0;e=x[31737];x[31737]=0;if((e|0)==1){break r}c=x[c>>2];x[31737]=0;V(930,f|0,a+52|0,b|0,c|0);c=x[31737];x[31737]=0;if((c|0)==1){break q}Eb(b);x[31737]=0;b=P(462,d+88|0,15092)|0;c=x[31737];x[31737]=0;if((c|0)==1){break p}x[31737]=0;S(919,f|0,a+36|0,b|0);c=x[31737];x[31737]=0;if((c|0)==1){break o}Eb(b);x[31737]=0;b=P(462,d+76|0,15579)|0;c=x[31737];x[31737]=0;if((c|0)==1){break n}x[31737]=0;h=a+4|0;S(931,f|0,h|0,b|0);c=x[31737];x[31737]=0;if((c|0)==1){break m}Eb(b);x[31737]=0;b=P(462,d- -64|0,15480)|0;c=x[31737];x[31737]=0;if((c|0)==1){break l}x[31737]=0;c=a+28|0;S(932,f|0,c|0,b|0);e=x[31737];x[31737]=0;if((e|0)==1){break k}Eb(b);x[31737]=0;b=P(462,d+52|0,15335)|0;e=x[31737];x[31737]=0;if((e|0)==1){break j}x[31737]=0;S(932,f|0,a+30|0,b|0);e=x[31737];x[31737]=0;if((e|0)==1){break i}Eb(b);x[31737]=0;b=P(462,d+40|0,15116)|0;e=x[31737];x[31737]=0;if((e|0)==1){break h}x[31737]=0;S(933,f|0,a+32|0,b|0);e=x[31737];x[31737]=0;if((e|0)==1){break g}Eb(b);w[d+38>>1]=0;x[31737]=0;b=P(462,d+24|0,15071)|0;e=x[31737];x[31737]=0;if((e|0)==1){break c}x[31737]=0;U(492,f|0,d+38|0,b|0)|0;e=x[31737];x[31737]=0;if((e|0)==1){break f}Eb(b);i=aR(B[a+32>>2]);B[a+32>>2]=i;e=-1;if(!_m(i)){break d}b=wb(x[a+4>>2]);x[d+20>>2]=b;g=wb(x[a+8>>2]);while(1){if(!Ib(b,g)){break e}if(!_m(B[b>>2])){break d}b=x[Je(d+20|0)>>2];continue}}a=N()|0;break a}a=N()|0;Eb(b);break a}a=N()|0;break a}a=N()|0;Eb(b);break a}a=N()|0;break a}a=N()|0;Eb(b);break a}a=N()|0;break a}a=N()|0;Eb(b);break a}a=N()|0;break a}a=N()|0;Eb(b);break a}a=N()|0;break a}a=N()|0;Eb(b);break a}a=N()|0;break a}a=N()|0;Eb(b);break a}a=N()|0;break a}a=N()|0;Eb(b);break a}a=N()|0;break a}a=N()|0;Eb(b);break a}a=N()|0;break a}a=N()|0;Eb(b);break a}a=N()|0;break a}a=N()|0;Eb(b);break a}a=N()|0;Eb(b);break a}if(vl(y[f|0])){break d}b=z[c>>1];if((b-301&65535)>>>0<64935){break d}g=z[a>>1];if(g>>>0>3|(g|0)==2){break d}j=w[a+30>>1];if((j|0)<0){break d}k=d,l=th(x[a+36>>2]),x[k+20>>2]=l;x[d+16>>2]=0;k=a,l=x[dk(d+20|0,d+16|0,42336)>>2],x[k+36>>2]=l;if(oc(x[a+4>>2],x[a+8>>2])>>>0>32767){break d}B:{C:{switch(g-1|0){case 2:c=w[d+38>>1];if((c|0)<=0){break d}w[d+14>>1]=j;B[d+20>>2]=B[a+32>>2];x[31737]=0;w[d+16>>1]=b;w[d+18>>1]=(b+c|0)-1;a=ba(934,a|0,d+14|0,d+20|0,d+16|0)|0;b=x[31737];x[31737]=0;if((b|0)!=1){if(a){break B}break d}a=N()|0;break a;case 0:g=w[d+38>>1];if((g|0)<=0){break d}B[d+20>>2]=B[a+32>>2];x[31737]=0;w[d+16>>1]=b;w[d+18>>1]=(b+g|0)-1;a=ha(935,a|0,h|0,d+20|0,d+16|0,c|0)|0;b=x[31737];x[31737]=0;if((b|0)!=1){if(a){break B}break d}a=N()|0;break a;default:break C}}x[31737]=0;W(936,a|0);a=x[31737];x[31737]=0;if((a|0)==1){break b}}e=1}Ah(f)}fb=d+304|0;return e|0}a=N()|0;break a}a=N()|0}Ah(f);Q(a|0);p()}function M7(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0;h=fb-48|0;fb=h;x[h+44>>2]=b;x[e>>2]=0;bd(h,x[d+28>>2]);x[31737]=0;i=R(1211,x[h>>2])|0;j=x[31737];x[31737]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{if((j|0)!=1){Zb(h);switch(g-65|0){case 54:break j;case 19:break k;case 18:break l;case 17:break m;case 49:break n;case 47:break o;case 45:case 51:break p;case 12:break q;case 44:break r;case 41:break s;case 8:break t;case 7:break u;case 5:break v;case 3:break w;case 35:case 36:break x;case 34:break y;case 1:case 33:case 39:break z;case 0:case 32:break A;case 2:case 4:case 6:case 9:case 10:case 11:case 13:case 14:case 15:case 16:case 20:case 21:case 22:case 25:case 26:case 27:case 28:case 29:case 30:case 31:case 37:case 38:case 40:case 42:case 43:case 46:case 48:case 50:case 52:case 53:break d;case 24:break f;case 56:break g;case 23:break h;case 55:break i;default:break e}}a=N()|0;Zb(h);Q(a|0);p()}gK(a,f+24|0,h+44|0,c,e,i);break b}fK(a,f+16|0,h+44|0,c,e,i);break b}b=ib[x[x[a+8>>2]+12>>2]](a+8|0)|0;g=a;i=x[h+44>>2];a=Jb(b);k=h,l=vk(g,i,c,d,e,f,a,a+(Cb(x[b+4>>2],y[b+11|0])<<2)|0),x[k+44>>2]=l;break b}a=pj(h+44|0,c,e,i,2);b=x[e>>2];B:{if(!(b&4|a-1>>>0>30)){x[f+12>>2]=a;break B}x[e>>2]=b|4}break b}g=x[27967];x[h+24>>2]=x[27966];x[h+28>>2]=g;g=x[27965];x[h+16>>2]=x[27964];x[h+20>>2]=g;g=x[27963];x[h+8>>2]=x[27962];x[h+12>>2]=g;g=x[27961];x[h>>2]=x[27960];x[h+4>>2]=g;k=h,l=vk(a,b,c,d,e,f,h,h+32|0),x[k+44>>2]=l;break b}g=x[27975];x[h+24>>2]=x[27974];x[h+28>>2]=g;g=x[27973];x[h+16>>2]=x[27972];x[h+20>>2]=g;g=x[27971];x[h+8>>2]=x[27970];x[h+12>>2]=g;g=x[27969];x[h>>2]=x[27968];x[h+4>>2]=g;k=h,l=vk(a,b,c,d,e,f,h,h+32|0),x[k+44>>2]=l;break b}a=pj(h+44|0,c,e,i,2);b=x[e>>2];C:{if(!(b&4|(a|0)>23)){x[f+8>>2]=a;break C}x[e>>2]=b|4}break b}a=pj(h+44|0,c,e,i,2);b=x[e>>2];D:{if(!(b&4|a-1>>>0>11)){x[f+8>>2]=a;break D}x[e>>2]=b|4}break b}a=pj(h+44|0,c,e,i,3);b=x[e>>2];E:{if(!(b&4|(a|0)>365)){x[f+28>>2]=a;break E}x[e>>2]=b|4}break b}a=pj(h+44|0,c,e,i,2);b=x[e>>2];a=a-1|0;F:{if(!(b&4|a>>>0>11)){x[f+16>>2]=a;break F}x[e>>2]=b|4}break b}a=pj(h+44|0,c,e,i,2);b=x[e>>2];G:{if(!(b&4|(a|0)>59)){x[f+4>>2]=a;break G}x[e>>2]=b|4}break b}a=h+44|0;b=fb-16|0;fb=b;x[b+12>>2]=c;while(1){H:{if(li(a,b+12|0)){break H}if(!yj(i,1,zl(x[a>>2]))){break H}lo(a);continue}break}if(li(a,b+12|0)){x[e>>2]=x[e>>2]|2}fb=b+16|0;break b}b=h+44|0;a=ib[x[x[a+8>>2]+8>>2]](a+8|0)|0;I:{if((Cb(x[a+4>>2],y[a+11|0])|0)==(0-Cb(x[a+16>>2],y[a+23|0])|0)){x[e>>2]=x[e>>2]|4;break I}c=it(b,c,a,a+24|0,i,e,0);b=x[f+8>>2];if(!((c|0)!=(a|0)|(b|0)!=12)){x[f+8>>2]=0;break I}if(!((c-a|0)!=12|(b|0)>11)){x[f+8>>2]=b+12}}break b}g=yc(h,111904,44);k=g,l=vk(a,b,c,d,e,f,g,g+44|0),x[k+44>>2]=l;break b}x[h+16>>2]=x[27992];g=x[27991];x[h+8>>2]=x[27990];x[h+12>>2]=g;g=x[27989];x[h>>2]=x[27988];x[h+4>>2]=g;k=h,l=vk(a,b,c,d,e,f,h,h+20|0),x[k+44>>2]=l;break b}a=pj(h+44|0,c,e,i,2);b=x[e>>2];J:{if(!(b&4|(a|0)>60)){x[f>>2]=a;break J}x[e>>2]=b|4}break b}g=x[28003];x[h+24>>2]=x[28002];x[h+28>>2]=g;g=x[28001];x[h+16>>2]=x[28e3];x[h+20>>2]=g;g=x[27999];x[h+8>>2]=x[27998];x[h+12>>2]=g;g=x[27997];x[h>>2]=x[27996];x[h+4>>2]=g;k=h,l=vk(a,b,c,d,e,f,h,h+32|0),x[k+44>>2]=l;break b}a=pj(h+44|0,c,e,i,1);b=x[e>>2];K:{if(!(b&4|(a|0)>6)){x[f+24>>2]=a;break K}x[e>>2]=b|4}break b}a=ib[x[x[a>>2]+20>>2]](a,b,c,d,e,f)|0;break a}b=ib[x[x[a+8>>2]+24>>2]](a+8|0)|0;g=a;i=x[h+44>>2];a=Jb(b);k=h,l=vk(g,i,c,d,e,f,a,a+(Cb(x[b+4>>2],y[b+11|0])<<2)|0),x[k+44>>2]=l;break b}eK(f+20|0,h+44|0,c,e,i);break b}a=pj(h+44|0,c,e,i,4);if(!(y[e|0]&4)){x[f+20>>2]=a-1900}break b}if((g|0)==37){break c}}x[e>>2]=x[e>>2]|4;break b}a=fb-16|0;fb=a;x[a+12>>2]=c;b=6;c=h+44|0;d=a+12|0;L:{M:{if(li(c,d)){break M}b=4;if((uk(i,zl(x[c>>2]))|0)!=37){break M}b=2;if(!li(lo(c),d)){break L}}x[e>>2]=x[e>>2]|b}fb=a+16|0}a=x[h+44>>2]}fb=h+48|0;return a|0}function FL(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0;i=fb-560|0;fb=i;g=c;c=(c-3|0)/24|0;t=(c|0)>0?c:0;k=g+D(t,-24)|0;n=x[(e<<2)+90224>>2];j=d-1|0;if((n+j|0)>=0){g=d+n|0;c=t-j|0;while(1){C[(i+320|0)+(h<<3)>>3]=(c|0)<0?0:+x[(c<<2)+90240>>2];c=c+1|0;h=h+1|0;if((g|0)!=(h|0)){continue}break}}q=k-24|0;g=0;h=(n|0)>0?n:0;m=(d|0)<=0;while(1){a:{if(m){f=0;break a}r=g+j|0;c=0;f=0;while(1){f=C[(c<<3)+a>>3]*C[(i+320|0)+(r-c<<3)>>3]+f;c=c+1|0;if((d|0)!=(c|0)){continue}break}}C[(g<<3)+i>>3]=f;c=(g|0)==(h|0);g=g+1|0;if(!c){continue}break}y=47-k|0;r=48-k|0;u=(k|0)<25;z=k-25|0;g=n;while(1){f=C[(g<<3)+i>>3];c=0;h=g;o=(g|0)<=0;if(!o){while(1){m=(i+480|0)+(c<<2)|0;l=f*5.960464477539063e-8;b:{if(F(l)<2147483648){j=~~l;break b}j=-2147483648}l=+(j|0);f=l*-16777216+f;c:{if(F(f)<2147483648){j=~~f;break c}j=-2147483648}x[m>>2]=j;h=h-1|0;f=C[(h<<3)+i>>3]+l;c=c+1|0;if((g|0)!=(c|0)){continue}break}}f=pk(f,q);f=f+J(f*.125)*-8;d:{if(F(f)<2147483648){m=~~f;break d}m=-2147483648}f=f-+(m|0);e:{f:{g:{h:{if(!u){h=(g<<2)+i|0;j=x[h+476>>2];c=j>>r;s=h;h=j-(c<<r)|0;x[s+476>>2]=h;m=c+m|0;j=h>>y;break h}if(q){break g}j=x[((g<<2)+i|0)+476>>2]>>23}if((j|0)<=0){break e}break f}j=2;if(f>=.5){break f}j=0;break e}c=0;h=0;if(!o){while(1){s=(i+480|0)+(c<<2)|0;o=x[s>>2];v=16777215;i:{j:{if(h){break j}v=16777216;if(o){break j}h=0;break i}x[s>>2]=v-o;h=1}c=c+1|0;if((g|0)!=(c|0)){continue}break}}k:{if(u){break k}c=8388607;l:{switch(z|0){case 1:c=4194303;break;case 0:break l;default:break k}}o=(g<<2)+i|0;x[o+476>>2]=x[o+476>>2]&c}m=m+1|0;if((j|0)!=2){break e}f=1-f;j=2;if(!h){break e}f=f-pk(1,q)}m:{n:{if(f==0){h=0;c=g;if((c|0)<=(n|0)){break m}while(1){c=c-1|0;h=x[(i+480|0)+(c<<2)>>2]|h;if((c|0)>(n|0)){continue}break}if(!h){break m}k=q;while(1){k=k-24|0;g=g-1|0;if(!x[(i+480|0)+(g<<2)>>2]){continue}break}break n}f=pk(f,24-k|0);o:{if(f>=16777216){d=(i+480|0)+(g<<2)|0;l=f*5.960464477539063e-8;p:{if(F(l)<2147483648){c=~~l;break p}c=-2147483648}f=+(c|0)*-16777216+f;q:{if(F(f)<2147483648){a=~~f;break q}a=-2147483648}x[d>>2]=a;g=g+1|0;break o}if(F(f)<2147483648){c=~~f}else{c=-2147483648}k=q}x[(i+480|0)+(g<<2)>>2]=c}f=pk(1,k);if((g|0)>=0){d=g;while(1){a=d;C[(a<<3)+i>>3]=f*+x[(i+480|0)+(a<<2)>>2];d=a-1|0;f=f*5.960464477539063e-8;if(a){continue}break}h=g;while(1){f=0;c=0;a=g-h|0;d=(a|0)>(n|0)?n:a;if((d|0)>=0){while(1){f=C[(c<<3)+93008>>3]*C[(c+h<<3)+i>>3]+f;k=(c|0)!=(d|0);c=c+1|0;if(k){continue}break}}C[(i+160|0)+(a<<3)>>3]=f;a=(h|0)>0;h=h-1|0;if(a){continue}break}}r:{s:{t:{switch(e|0){case 3:u:{if((g|0)<=0){break u}d=(i+160|0)+(g<<3)|0;f=C[d>>3];c=g;while(1){l=f;e=i+160|0;a=c-1|0;h=e+(a<<3)|0;w=C[h>>3];f=w+f;C[e+(c<<3)>>3]=l+(w-f);C[h>>3]=f;e=c>>>0>1;c=a;if(e){continue}break}if((g|0)<2){break u}f=C[d>>3];c=g;while(1){l=f;d=i+160|0;a=c-1|0;e=d+(a<<3)|0;p=C[e>>3];f=p+f;C[d+(c<<3)>>3]=l+(p-f);C[e>>3]=f;d=c>>>0>2;c=a;if(d){continue}break}p=0;while(1){p=p+C[(i+160|0)+(g<<3)>>3];a=(g|0)>2;g=g-1|0;if(a){continue}break}}f=C[i+160>>3];if(j){break s}C[b>>3]=f;f=C[i+168>>3];C[b+16>>3]=p;C[b+8>>3]=f;break r;case 0:f=0;if((g|0)>=0){while(1){a=g;g=g-1|0;f=f+C[(i+160|0)+(a<<3)>>3];if(a){continue}break}}C[b>>3]=j?-f:f;break r;case 1:case 2:break t;default:break r}}f=0;if((g|0)>=0){d=g;while(1){a=d;d=a-1|0;f=f+C[(i+160|0)+(a<<3)>>3];if(a){continue}break}}C[b>>3]=j?-f:f;f=C[i+160>>3]-f;c=1;if((g|0)>0){while(1){f=f+C[(i+160|0)+(c<<3)>>3];a=(c|0)!=(g|0);c=c+1|0;if(a){continue}break}}C[b+8>>3]=j?-f:f;break r}C[b>>3]=-f;f=C[i+168>>3];C[b+16>>3]=-p;C[b+8>>3]=-f}fb=i+560|0;return m&7}c=1;while(1){h=c;c=c+1|0;if(!x[(i+480|0)+(n-h<<2)>>2]){continue}break}h=g+h|0;while(1){j=d+g|0;g=g+1|0;C[(i+320|0)+(j<<3)>>3]=x[(t+g<<2)+90240>>2];c=0;f=0;if((d|0)>0){while(1){f=C[(c<<3)+a>>3]*C[(i+320|0)+(j-c<<3)>>3]+f;c=c+1|0;if((d|0)!=(c|0)){continue}break}}C[(g<<3)+i>>3]=f;if((g|0)<(h|0)){continue}break}g=h;continue}}function fpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,C=0,E=0;e=fb-736|0;fb=e;xc(b);d=fb-16|0;fb=d;f=e+128|0;lX(d+8|0,f);g=x[d+12>>2];lc(d,x[b>>2],x[b+8>>2],x[d+8>>2],x[d+12>>2]);i=x[d+4>>2];if((i|0)==(g|0)){Vb(b,x[d+12>>2])}fb=d+16|0;d=(g|0)==(i|0);if(!d){kX(f)}a:{if(!d){break a}if(!nX(f)){break a}if(!Mb(x[b>>2],x[b+8>>2],Bc(mX(y[e+162|0]|y[e+163|0]<<8),hb))){break a}s=1;if((c|0)==64){break a}Bd(a,262144);g=e+92|0;aj(g,2,f);d=e+12|0;Cc(d,g);Ab(a+1298308|0,d);tb(d);f=tc(d,8317);Ab(a+1298344|0,f);tb(f);f=tc(d,10141);Ab(a+1298356|0,f);tb(f);f=fb-16|0;fb=f;i=tc(f+4|0,4193);_c(g,i);tb(i);fb=f+16|0;v[e|0]=y[e+158|0];x[31737]=0;v[e+115|0]=y[e+157|0];f=e+116|0;O(693,f|0,e+115|0);i=x[31737];x[31737]=0;b:{c:{d:{if((i|0)!=1){x[31737]=0;V(251,d|0,g|0,e|0,f|0);i=x[31737];x[31737]=0;if((i|0)!=1){Ab(a+1298368|0,d);tb(d);tb(f);Eb(g);C=a+1298404|0,E=x[Fc(d,4)>>2],x[C>>2]=E;x[a+480208>>2]=12;w[a+480188>>1]=y[e+166|0]|y[e+167|0]<<8;w[e+12>>1]=y[e+162|0]|y[e+163|0]<<8;w[e+92>>1]=3999;C=a,E=z[Nc(d,g)>>1],w[C+480190>>1]=E;Q_(Xb(x[a+484360>>2],y[a+484376|0]),e+224|0,y[e+160|0]|y[e+161|0]<<8);d=0;while(1)if(z[a+480188>>1]<=d>>>0){d=e+12|0;fe(d,b,D(y[e+162|0]|y[e+163|0]<<8,80));l=c&2;i=ic(e+92|0,d);ub(d);m=e+60|0;d=0;e:{f:{while(1){if(z[a+480190>>1]<=d>>>0){if(c&1){break f}break b}x[31737]=0;f=e+12|0;O(694,i|0,f|0);g=x[31737];x[31737]=0;if((g|0)==1){break e}aj(e,2,m);x[31737]=0;g=e+116|0;O(219,g|0,e|0);j=x[31737];x[31737]=0;if((j|0)==1){break e}d=d+1|0;zc(((d<<5)+a|0)+946304|0,g);tb(g);x[31737]=0;h=f;f=(D(d,104)+a|0)+484380|0;S(695,g|0,h|0,f|0);j=x[31737];x[31737]=0;g:{if((j|0)==1){break g}if(!l|!x[f>>2]){continue}x[31737]=0;j=P(150,b|0,y[e+30|0]|y[e+31|0]<<8|(y[e+32|0]<<16|y[e+33|0]<<24))|0;k=x[31737];x[31737]=0;if((k|0)==1){break g}if(!j){continue}x[31737]=0;U(216,g|0,f|0,b|0)|0;g=x[31737];x[31737]=0;if((g|0)!=1){continue}}break}break e}x[31737]=0;o=a+484344|0;O(224,o|0,y[e+164|0]|y[e+165|0]<<8);c=x[31737];x[31737]=0;if((c|0)==1){break e}q=e+16|0;t=e+14|0;r=e+15|0;u=e+17|0;A=e+13|0;c=0;while(1){if((y[e+164|0]|y[e+165|0]<<8)>>>0<=c>>>0){break b}x[31737]=0;d=U(197,o|0,c&65535,64)|0;g=x[31737];x[31737]=0;if((g|0)==1){break e}h:{if(!d){break h}d=(c<<1)+e|0;d=y[d+480|0]|y[d+481|0]<<8;if(!d){break h}x[31737]=0;d=P(150,b|0,d<<4)|0;g=x[31737];x[31737]=0;if((g|0)==1){break e}if(!d){break h}l=0;d=Wb(x[o>>2],c);m=jd(x[d>>2],x[x[d+48>>2]+12>>2],0,0);i:while(1){B=l>>>0>63;while(1){if(B){break h}d=x[b+8>>2];g=x[b>>2];x[31737]=0;d=U(151,g|0,d|0,1)|0;g=x[31737];x[31737]=0;j:{if((g|0)!=1){if(!d){break h}x[31737]=0;d=R(198,b|0)|0;g=x[31737];x[31737]=0;if((g|0)==1){break e}j=d<<24>>24;if(j){break j}l=l+1|0;m=D(z[a+480188>>1],6)+m|0;continue i}break e}w[q>>1]=0;x[e+12>>2]=0;g=j&31;d=D(g,6)+m|0;f=bh(e+12|0);g=g>>>0<z[a+480188>>1];k=g?d:f;h=j&255;k:{if(!(h&32)){break k}x[31737]=0;n=e+116|0;O(199,n|0,b|0);f=x[31737];x[31737]=0;if((f|0)==1){break e}f=y[e+116|0];v[k|0]=f;C=g?d+1|0:A,E=y[Jc(n)|0],v[C|0]=E;l:{if(f){if((f|0)==254){break l}if(f>>>0<121){break k}}f=0}v[k|0]=f}m:{if(!(h&64)){break m}x[31737]=0;h=e+116|0;O(199,h|0,b|0);f=x[31737];x[31737]=0;if((f|0)==1){break e}f=g?d+5|0:u;n=y[Jc(h)|0];v[f|0]=n;h=y[e+116|0];n:{if(h>>>0<=15){Bf(k,h,n);break n}v[(g?d+3|0:r)|0]=h>>>0<=23?y[h+25415|0]:0}k=g?d+3|0:r;h=y[k|0];if((h|0)!=23){if((h|0)!=9){break m}v[k|0]=20;v[e|0]=y[f|0]>>>3;v[e+115|0]=1;C=f,E=y[df(e,e+115|0)|0]-1&15|128,v[C|0]=E;break m}v[e|0]=64;C=f,E=y[Qb(f,e)|0]<<1,v[C|0]=E}if((j|0)>=0){continue}v[(g?d+2|0:t)|0]=1;x[31737]=0;f=R(198,b|0)|0;j=x[31737];x[31737]=0;if((j|0)==1){break e}v[(g?d+4|0:q)|0]=f;continue}}}c=c+1|0;continue}}b=N()|0;ub(i);break c}else{g=(d<<5)+a|0;We(g+480280|0);w[g+480284>>1]=(y[(e+d|0)+192|0]<<4|4)&244;d=d+1|0;continue}}b=N()|0;tb(e+116|0);break d}b=N()|0}Eb(e+92|0)}Q(b|0);p()}ub(i)}fb=e+736|0;return s|0}function B1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;f=fb-864|0;fb=f;xc(b);e=fb-16|0;fb=e;d=f+92|0;yF(e+8|0,d);i=x[e+12>>2];lc(e,x[b>>2],x[b+8>>2],x[e+8>>2],x[e+12>>2]);g=x[e+4>>2];if((g|0)==(i|0)){Vb(b,x[e+12>>2])}fb=e+16|0;e=(g|0)==(i|0);if(!e){xF(d)}a:{if(!e){break a}if(!AF(d)){break a}if(!Mb(x[b>>2],x[b+8>>2],zF(y[f+607|0]))){break a}k=1;if((c|0)==64){break a}Bd(a,2);x[a+480204>>2]=15e5;x[a+480208>>2]=x[a+480208>>2]|16777216;e=y[f+606|0];x[a+480188>>2]=4194322;x[a+480196>>2]=e;e=a+484376|0;fk(Xb(x[a+484360>>2],y[e|0]),b,y[f+607|0],65535,65535);e=Xb(x[a+484360>>2],y[e|0]);o=f,q=wb(x[e>>2]),x[o+40>>2]=q;e=wb(x[e+4>>2]);b:{while(1){d=x[f+40>>2];if(Ib(d,e)){if(z[d>>1]>127){break b}Md(f+40|0);continue}break}gg(a);while(1){i=k&65535;if(i>>>0>z[a+480190>>1]){c:{k=1;d:{e:{f:{if(!(c&1)){break f}n=x[b+8>>2];i=a+484344|0;Vf(i,128);c=0;g:{while(1){if((c|0)==128){break g}d=f+16|0;e=(c<<1)+f|0;vF(d,b,(y[e+608|0]|y[e+609|0]<<8)+n|0,4674);e=ic(f+40|0,d);ub(d);g=x[e>>2];x[31737]=0;g=R(173,g|0)|0;h=x[31737];x[31737]=0;if((h|0)==1){break d}h:{if(!g){break h}x[31737]=0;g=U(197,i|0,c&65535,32)|0;h=x[31737];x[31737]=0;if((h|0)==1){break d}if(!g){break h}g=0;j=d;d=Wb(x[i>>2],c);bf(j,x[d>>2],x[x[d+48>>2]+12>>2],0);while(1){i:{d=x[e>>2];x[31737]=0;d=U(151,d|0,x[f+48>>2],1)|0;h=x[31737];x[31737]=0;j:{k:{l:{m:{n:{if((h|0)!=1){if(!d){break i}x[31737]=0;d=R(198,e|0)|0;h=x[31737];x[31737]=0;if((h|0)==1){break c}o:{switch(d-251|0){case 0:break k;case 1:break l;case 2:break m;case 3:break n;case 4:break o;default:break j}}x[31737]=0;d=R(198,e|0)|0;h=x[31737];x[31737]=0;if((h|0)==1){break c}if(!d){break i}g=d+g|0;if(g>>>0>=32){break i}d=Wb(x[i>>2],c);bf(f- -64|0,x[d>>2],x[x[d+48>>2]+12>>2],g);d=x[f+68>>2];x[f+16>>2]=x[f+64>>2];x[f+20>>2]=d;continue}break c}x[31737]=0;d=f- -64|0;O(199,d|0,e|0);h=x[31737];x[31737]=0;if((h|0)==1){break c}j=z[a+480188>>1];h=y[xb(d,0)|0];if(j>>>0<=h>>>0){break e}d=y[xb(d,1)|0];if(d>>>0>63){break e}o=Wc(x[f+16>>2],h),q=d+1|0,v[o+1|0]=q;continue}x[31737]=0;d=f- -64|0;O(199,d|0,e|0);h=x[31737];x[31737]=0;if((h|0)==1){break c}j=z[a+480188>>1];h=y[xb(d,0)|0];if(j>>>0<=h>>>0){break e}d=y[xb(d,1)|0];if(d>>>0>63){break e}h=Wc(x[f+16>>2],h);v[h+4|0]=63-d;v[h+2|0]=1;continue}x[31737]=0;d=R(198,e|0)|0;h=x[31737];x[31737]=0;if((h|0)!=1){h=Wc(x[f+16>>2],0);v[h+5|0]=d;v[h+3|0]=12;continue}break c}d=Wc(x[f+16>>2],0);v[d+5|0]=0;v[d+3|0]=14;continue}if(d>>>0>=z[a+480188>>1]){break e}x[31737]=0;h=R(198,e|0)|0;j=x[31737];x[31737]=0;if((j|0)==1){break c}if(h>>>0>=124){break e}o=Wc(x[f+16>>2],d),q=(D(h>>>4|0,12)+(h&15)|0)+13|0,v[o|0]=q;l=d|l;m=!(d&1)|m;continue}break}ub(e);c=c+1|0;continue}break}ub(e)}if(!(l&m&1)){break f}c=z[a+480188>>1];b=0;while(1){if((b|0)==(c|0)){break f}w[((b<<5)+a|0)+480284>>1]=b<<8&256;b=b+1|0;continue}}bi(a+1298344|0,14810);bi(a+1298356|0,14819);bi(a+1298368|0,14810);o=a+1298404|0,q=x[Fc(f+40|0,4)>>2],x[o>>2]=q;break a}ub(e);break b}}}else{e=f+81|0;d=fb-16|0;fb=d;p:{if(!Mb(x[b>>2],x[b+8>>2],11)){v[d|0]=0;Vh(e,11,d);break p}Hw(d+8|0,e);rd(d,b,x[d+8>>2],x[d+12>>2])}fb=d+16|0;x[f+48>>2]=0;x[f+40>>2]=0;x[f+44>>2]=0;g=xb(e,1);d=f+40|0;o=xb(d,0),q=y[g|0],v[o|0]=q;g=xb(e,6);o=xb(d,1),q=y[g|0],v[o|0]=q;g=xb(e,2);o=xb(d,2),q=y[g|0],v[o|0]=q;g=xb(e,7);o=xb(d,3),q=y[g|0],v[o|0]=q;g=xb(e,3);o=xb(d,4),q=y[g|0],v[o|0]=q;g=xb(e,8);o=xb(d,5),q=y[g|0],v[o|0]=q;g=xb(e,4);o=xb(d,6),q=y[g|0],v[o|0]=q;g=xb(e,9);o=xb(d,7),q=y[g|0],v[o|0]=q;g=xb(e,5);o=xb(d,8),q=y[g|0],v[o|0]=q;g=xb(e,10);o=xb(d,9),q=y[g|0],v[o|0]=q;e=xb(e,0);o=xb(d,10),q=y[e|0],v[o|0]=q;e=(D(i,104)+a|0)+484380|0;ld(e,2);x[f+8>>2]=x[f+48>>2];d=x[f+44>>2];x[f>>2]=x[f+40>>2];x[f+4>>2]=d;Yk(e,1,f);d=f- -64|0;uF(d,((i<<3)+f|0)+86|0);e=f+16|0;Cc(e,d);zc(((i<<5)+a|0)+946304|0,e);k=k+1|0;tb(e);continue}break}a=N()|0;ub(e);Q(a|0);p()}k=0}fb=f+864|0;return k|0}function Bua(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;g=fb-3056|0;fb=g;xc(b);e=fb-16|0;fb=e;f=g+1102|0;E0(e+8|0,f);i=x[e+12>>2];lc(e,x[b>>2],x[b+8>>2],x[e+8>>2],x[e+12>>2]);h=x[e+4>>2];if((h|0)==(i|0)){Vb(b,x[e+12>>2])}fb=e+16|0;e=(h|0)==(i|0);if(!e){D0(f)}a:{if(!e){break a}if(!G0(f)){break a}d=1;if((c|0)==64){break a}d=0;if(!Mb(x[b>>2],x[b+8>>2],Bc(1024,0))){break a}C0(b,g+576|0);C0(b,g- -64|0);e=0;while(1){if((e|0)!=128){f=e<<2;i=x[f+(g+576|0)>>2];if(i>>>0>16777215){break a}f=x[f+(g- -64|0)>>2];if(f-4097>>>0<4294963202){break a}e=e+1|0;if(Cm(x[b>>2],(f+i|0)+2978|0)){continue}break a}break}Bd(a,2);gg(a);d=g+40|0;e=tc(d,13940);Ab(a+1298344|0,e);tb(e);e=tc(d,14806);Ab(a+1298356|0,e);tb(e);e=tc(d,15595);Ab(a+1298368|0,e);tb(e);q=a+1298404|0,r=x[Fc(d,4)>>2],x[q>>2]=r;d=y[g+1102|0];x[a+480204>>2]=143e4;x[a+480196>>2]=d;af(Xb(x[a+484360>>2],y[a+484376|0]),y[g+1103|0]);x[a+480188>>2]=4194317;Lb(a+1074312|0,95,1);x[a+480208>>2]=x[a+480208>>2]|16777216;d=0;e=0;while(1){if((e|0)==4){b:{while(1){c:{if((d|0)==32){e=0;break c}e=d+1|0;f=D(e,104)+a|0;h=f+484380|0;ld(h,2);j=g+20|0;B0(j,(D(d,13)+g|0)+1104|0);i=g+40|0;Cc(i,j);zc(((e<<5)+a|0)+946304|0,i);tb(i);d=(g+1102|0)+(d<<4)|0;i=y[d+422|0]|y[d+423|0]<<8|(y[d+424|0]<<16|y[d+425|0]<<24);x[h>>2]=i;m=i;i=y[d+430|0]|y[d+431|0]<<8|(y[d+432|0]<<16|y[d+433|0]<<24);if(m>>>0>=i>>>0){d=y[d+426|0]|y[d+427|0]<<8|(y[d+428|0]<<16|y[d+429|0]<<24);w[f+484414>>1]=2;x[f+484388>>2]=i;x[f+484384>>2]=d}x[f+484404>>2]=8287;d=e;continue}break}while(1){if((e|0)!=32){f=e+33|0;i=(D(f,104)+a|0)+484380|0;ld(i,2);h=g+20|0;B0(h,(D(e,13)+g|0)+2032|0);d=g+40|0;Cc(d,h);zc(((f<<5)+a|0)+946304|0,d);tb(d);x[g+48>>2]=0;x[g+40>>2]=0;x[g+44>>2]=0;f=(D(e,11)+g|0)+2448|0;h=xb(f,1);q=xb(d,0),r=y[h|0],v[q|0]=r;h=xb(f,6);q=xb(d,1),r=y[h|0],v[q|0]=r;h=xb(f,2);q=xb(d,2),r=y[h|0],v[q|0]=r;h=xb(f,7);q=xb(d,3),r=y[h|0],v[q|0]=r;h=xb(f,3);q=xb(d,4),r=y[h|0],v[q|0]=r;h=xb(f,8);q=xb(d,5),r=y[h|0],v[q|0]=r;h=xb(f,4);q=xb(d,6),r=y[h|0],v[q|0]=r;h=xb(f,9);q=xb(d,7),r=y[h|0],v[q|0]=r;h=xb(f,5);q=xb(d,8),r=y[h|0],v[q|0]=r;h=xb(f,10);q=xb(d,9),r=y[h|0],v[q|0]=r;f=xb(f,0);q=xb(d,10),r=y[f|0],v[q|0]=r;x[g+16>>2]=x[g+48>>2];d=x[g+44>>2];x[g+8>>2]=x[g+40>>2];x[g+12>>2]=d;Yk(i,1,g+8|0);e=e+1|0;continue}break}Vr(Xb(x[a+484360>>2],y[a+484376|0]),g+2800|0,256,255,65535);n=a+484344|0;Vf(n,128);o=c&1;i=0;while(1){d:{e:{if((i|0)!=128){d=i<<2;cd(b,x[d+(g+576|0)>>2]+2978|0);e=g+20|0;fe(e,b,x[d+(g- -64|0)>>2]);d=ic(g+40|0,e);ub(e);if(!o){break d}x[31737]=0;e=U(197,n|0,i&65535,64)|0;f=x[31737];x[31737]=0;if((f|0)==1){break b}if(!e){break d}e=0;h=Wb(x[n>>2],i);while(1){m=e>>>0>63;while(1){if(m){break d}f=x[d>>2];x[31737]=0;f=U(151,f|0,x[g+48>>2],1)|0;j=x[31737];x[31737]=0;f:{if((j|0)!=1){if(!f){break d}x[31737]=0;f=R(198,d|0)|0;j=x[31737];x[31737]=0;if((j|0)==1){break b}if(f>>>0>12){break f}j=jd(x[h>>2],x[x[h+48>>2]+12>>2],e,f);x[31737]=0;k=g+20|0;O(199,k|0,d|0);l=x[31737];x[31737]=0;if((l|0)==1){break b}l=y[g+20|0];f=f>>>0>3;v[j|0]=((l&15)+(f?13:37)|0)+D(l>>>4&7,12);k=Jc(k);v[j+1|0]=((y[k|0]>>>4|0)+(f?33:1)|0)+(y[g+20|0]>>>3&16);A0(j,y[k|0],f);continue}break b}j=f-32|0;if((j&255)>>>0<=12){j=jd(x[h>>2],x[x[h+48>>2]+12>>2],e,j&65535);x[31737]=0;k=R(198,d|0)|0;l=x[31737];x[31737]=0;if((l|0)==1){break b}A0(j,k,f>>>0>35);continue}break}if((f|0)!=64){if((f|0)!=96){break e}if(!e){break d}q=jd(x[h>>2],x[x[h+48>>2]+12>>2],e-1|0,0),r=14,v[q+3|0]=r;break d}x[31737]=0;f=R(198,d|0)|0;j=x[31737];x[31737]=0;if((j|0)==1){break b}e=e+f|0;continue}}d=1;if(!(c&2)){break a}while(1)if((d|0)==33){d=1;break a}else{fg(Xc(g+40|0,8,1,0,1),(D(d,104)+a|0)+484380|0,b);d=d+1|0;continue}}ub(d);d=0;break a}ub(d);i=i+1|0;continue}}}else{w[((e<<5)+a|0)+480284>>1]=e&1?192:64;e=e+1|0;continue}break}a=N()|0;ub(d);Q(a|0);p()}fb=g+3056|0;return d|0}function eqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=fb-192|0;fb=d;xc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{g=d+180|0;l:{if(!lp(b,g)){break l}if(!_X(g)){break l}g=ai(d+160|0);h=Fb(d+148|0);aw(d+84|0);x[31737]=0;f=P(618,b|0,d+76|0)|0;e=x[31737];x[31737]=0;if((e|0)==1){break h}m:{if(!f){break m}n=d,o=$b($b(x[d+80>>2])-4|0),x[n+80>>2]=o;j=(c|0)!=64;while(1){f=$b($b(x[d+80>>2])-8|0);x[d+80>>2]=f;n:{if(j){break n}if(($b(x[d+76>>2])|0)!=1347699796){break n}k=1;break m}x[31737]=0;e=d+56|0;S(186,e|0,b|0,$b(f)|0);f=x[31737];x[31737]=0;if((f|0)==1){break d}f=ic(d,e);ub(e);e=x[f>>2];x[31737]=0;i=R(173,e|0)|0;e=x[31737];x[31737]=0;if((e|0)==1){break b}o:{if(!i){break o}p:{e=$b(x[d+76>>2]);if((e|0)!=1129139796){if((e|0)!=1229866575){if((e|0)==1347699796){break p}if((e|0)!=1447383635){break o}x[31737]=0;P(184,f|0,4)|0;e=x[31737];x[31737]=0;if((e|0)==1){break b}x[31737]=0;e=R(619,f|0)|0;l=x[31737];x[31737]=0;if((l|0)==1){break b}if(!e){break o}e=$b(x[d+80>>2]);if(e>>>0<7){break o}l=x[Fc(d+52|0,28)>>2];x[31737]=0;V(620,f|0,h|0,l|0,e-6|0);e=x[31737];x[31737]=0;if((e|0)==1){break b}break o}x[31737]=0;m=P(621,f|0,d+84|0)|0;e=x[31737];x[31737]=0;if((e|0)!=1){break o}break b}Xw(g,f);break o}x[31737]=0;k=U(622,a|0,f|0,c|0)|0;e=x[31737];x[31737]=0;if((e|0)==1){break b}}ub(f);if(i){x[31737]=0;f=P(618,b|0,d+76|0)|0;e=x[31737];x[31737]=0;if((e|0)==1){break i}if(f){continue}}break}if(Ad(x[h+4>>2],y[h+11|0])){x[31737]=0;b=P(1,d+56|0,14989)|0;c=x[31737];x[31737]=0;if((c|0)==1){break g}Ab(h,b);tb(b)}q:{if(!(k&m&1)){break q}b=y[d+126|0]|y[d+127|0]<<8;x[31737]=0;b=Bb(b)&256;U(267,a+1074312|0,5,!b|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break f}c=Bb(y[d+122|0]|y[d+123|0]<<8);if(c){w[d>>1]=64;w[d+40>>1]=c;n=a,o=z[Nc(d,d+40|0)>>1],x[n+480228>>2]=o}c=!b;b=Bb(y[d+124|0]|y[d+125|0]<<8);if(!(c|!b)){x[a+480204>>2]=D(b,1e4)}if(y[d+84|0]){b=d+40|0;Ve(b,2,d+84|0);x[31737]=0;O(219,d|0,b|0);b=x[31737];x[31737]=0;if((b|0)==1){break e}Ab(a+1298308|0,d);tb(d)}c=y[d+130|0]|y[d+131|0]<<8;if(!hr(c,1,12)){break q}f=y[d+128|0]|y[d+129|0]<<8;if(!hr(f,1,31)){break q}e=y[d+134|0]|y[d+135|0]<<8;if(!hr(e,0,23)){break q}i=y[d+136|0]|y[d+137|0]<<8;if(!hr(i,0,59)){break q}j=y[d+138|0]|y[d+139|0]<<8;if(!hr(j,0,59)){break q}x[a+1298408>>2]=0;b=op(d);n=b,o=Bb(y[d+132|0]|y[d+133|0]<<8)+1900|0,x[n>>2]=o;n=b,o=Bb(c),x[n+4>>2]=o;n=b,o=Bb(f),x[n+8>>2]=o;n=b,o=Bb(e),x[n+12>>2]=o;n=b,o=Bb(i),x[n+16>>2]=o;n=b,o=Bb(j),x[n+24>>2]=o;x[b+28>>2]=0;x[31737]=0;O(448,a+1298412|0,b|0);b=x[31737];x[31737]=0;if((b|0)!=1){break q}a=N()|0;break a}if(k&1){b=x[g>>2];x[31737]=0;b=R(173,b|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break h}if(b){b=Fb(d);x[31737]=0;S(271,g|0,b|0,32);c=x[31737];x[31737]=0;if((c|0)==1){break c}if(!Ld(b,13859)){x[31737]=0;c=d+40|0;S(259,c|0,28,b|0);f=x[31737];x[31737]=0;if((f|0)==1){break c}Ab(a+1298320|0,c);tb(c)}c=x[g+8>>2];f=x[g>>2];x[31737]=0;c=P(623,f|0,c|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break c}if(!c){x[31737]=0;c=R(203,g|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break c}x[31737]=0;aa(317,a+1298332|0,g|0,c|0,40,0);c=x[31737];x[31737]=0;if((c|0)==1){break c}}tb(b)}x[31737]=0;b=P(1,d+40|0,18187)|0;c=x[31737];x[31737]=0;if((c|0)==1){break k}x[31737]=0;S(490,d|0,b|0,h|0);c=x[31737];x[31737]=0;if((c|0)==1){break j}Ab(a+1298368|0,d);tb(d);tb(b)}x[a+480208>>2]=x[a+480208>>2]|2097152;x[31737]=0;a=U(267,a+1074312|0,84,1)|0;b=x[31737];x[31737]=0;if((b|0)==1){break h}x[31737]=0;a=U(267,a|0,83,1)|0;b=x[31737];x[31737]=0;if((b|0)==1){break h}x[31737]=0;P(268,a|0,85)|0;a=x[31737];x[31737]=0;if((a|0)==1){break h}}tb(h);ub(g)}fb=d+192|0;return k&1}a=N()|0;break a}a=N()|0;tb(b);break a}a=N()|0;break a}a=N()|0;break a}a=N()|0;break a}a=N()|0;break a}a=N()|0;break a}a=N()|0;break a}a=N()|0;tb(b);break a}a=N()|0;ub(f)}tb(h);ub(g);Q(a|0);p()}function Gz(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;l=fb-48|0;fb=l;x[l+44>>2]=0;a:{if(d|g|h|i){j=g?l+44|0:0;b:{if(!j){break b}k=x[j>>2];if(!k){break b}Db(k);x[j>>2]=0}x[31737]=0;X(85);k=x[31737];x[31737]=0;c:{d:{if((k|0)==1){m=Va(125048,47504,47560,48540,125236,125340,125288,125180,125168,125484,125452,125420,125408,125632,0)|0;e:{f:{n=gb;if((n|0)==($(125048)|0)){k=Y(m|0)|0;x[31737]=0;O(1104,j|0,k|0);j=x[31737];x[31737]=0;k=277;if((j|0)==1){break f}break c}if(($(47504)|0)==(n|0)){k=Y(m|0)|0;x[31737]=0;O(1104,j|0,k|0);j=x[31737];x[31737]=0;k=358;if((j|0)!=1){break c}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)!=1){break d}break e}if(($(47560)|0)==(n|0)){k=Y(m|0)|0;x[31737]=0;O(1104,j|0,k|0);j=x[31737];x[31737]=0;k=359;if((j|0)!=1){break c}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)!=1){break d}break e}if(($(48540)|0)==(n|0)){k=Y(m|0)|0;x[31737]=0;O(1104,j|0,k|0);j=x[31737];x[31737]=0;k=357;if((j|0)!=1){break c}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)!=1){break d}break e}if(($(125236)|0)==(n|0)){k=Y(m|0)|0;x[31737]=0;O(1104,j|0,k|0);j=x[31737];x[31737]=0;k=300;if((j|0)!=1){break c}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)!=1){break d}break e}if(($(125340)|0)==(n|0)){k=Y(m|0)|0;x[31737]=0;O(1104,j|0,k|0);j=x[31737];x[31737]=0;k=299;if((j|0)!=1){break c}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)!=1){break d}break e}if(($(125288)|0)==(n|0)){k=Y(m|0)|0;x[31737]=0;O(1104,j|0,k|0);j=x[31737];x[31737]=0;k=298;if((j|0)!=1){break c}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)!=1){break d}break e}if(($(125180)|0)==(n|0)){k=Y(m|0)|0;x[31737]=0;O(1104,j|0,k|0);j=x[31737];x[31737]=0;k=297;if((j|0)!=1){break c}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)!=1){break d}break e}if(($(125168)|0)==(n|0)){k=Y(m|0)|0;x[31737]=0;O(1104,j|0,k|0);j=x[31737];x[31737]=0;k=296;if((j|0)!=1){break c}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)!=1){break d}break e}if(($(125484)|0)==(n|0)){k=Y(m|0)|0;x[31737]=0;O(1104,j|0,k|0);j=x[31737];x[31737]=0;k=289;if((j|0)!=1){break c}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)!=1){break d}break e}if(($(125452)|0)==(n|0)){k=Y(m|0)|0;x[31737]=0;O(1104,j|0,k|0);j=x[31737];x[31737]=0;k=288;if((j|0)!=1){break c}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)!=1){break d}break e}if(($(125420)|0)==(n|0)){k=Y(m|0)|0;x[31737]=0;O(1104,j|0,k|0);j=x[31737];x[31737]=0;k=287;if((j|0)!=1){break c}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)!=1){break d}break e}if(($(125408)|0)==(n|0)){k=Y(m|0)|0;x[31737]=0;O(1104,j|0,k|0);j=x[31737];x[31737]=0;k=286;if((j|0)!=1){break c}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)!=1){break d}break e}o=$(125632)|0;k=257;m=Y(m|0)|0;if((n|0)!=(o|0)){break c}x[31737]=0;O(1104,j|0,m|0);j=x[31737];x[31737]=0;k=267;if((j|0)!=1){break c}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)==1){break e}break d}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)!=1){break d}}T(0)|0;Sb()}p()}Q(a|0);p()}Z();m=!g;if(d){j=ib[d|0](k,e)|0}else{j=3}if(!(m|!(j&2))){x[g+16>>2]=k;m=g;g=x[l+44>>2];q=m,r=Bg(g?g:22303),x[q+20>>2]=r}if(h){x[h>>2]=k}g=x[l+44>>2];if(i){q=i,r=Bg(g?g:22303),x[q>>2]=r;g=x[l+44>>2]}if(g){Db(g);x[l+44>>2]=0}if(!(j&1)){break a}}x[31737]=0;g=l+32|0;O(1102,g|0,a|0);h=x[31737];x[31737]=0;g:{h:{if((h|0)!=1){i:{if(f){h=x[f+24>>2];x[31737]=0;O(1103,h|0,g|0);g=x[31737];x[31737]=0;if((g|0)!=1){break i}break h}g=Jb(l+32|0);if(b){x[31737]=0;O(b|0,g|0,c|0);g=x[31737];x[31737]=0;if((g|0)==1){break h}break i}iu(g,l)}tb(l+32|0);break a}g=T(0)|0;break g}g=T(0)|0;tb(l+32|0)}Y(g|0)|0;x[l+28>>2]=f;x[l+24>>2]=e;x[l+20>>2]=d;x[l+16>>2]=c;x[l+12>>2]=b;x[l+8>>2]=a?a:22303;x[l+4>>2]=254;x[l>>2]=9190;zP(18496,l);hu(125984);Z()}fb=l+48|0}function Qo(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0;f=fb+-64|0;fb=f;r=OB(x[a+24>>2],y[a+32|0]);t=Oj(r);c=t;e=x[a>>2];d=Ud(e,x[a+4>>2]);a:{if(c>>>0>d>>>0){k=fb-32|0;fb=k;c=c-d|0;d=x[zb(a)>>2];e=x[a+4>>2];b:{if(c>>>0<=(d-e|0)/12>>>0){e=fb-16|0;fb=e;c=rv(e+4|0,a,c);d=x[c+4>>2];g=x[c+8>>2];while(1){if((d|0)==(g|0)){hc(c);fb=e+16|0}else{cU(d);d=d+12|0;x[c+4>>2]=d;continue}break}break b}d=zb(a);d=Dm(k+12|0,Wp(a,Ud(x[a>>2],e)+c|0),Ud(x[a>>2],x[a+4>>2]),d);g=fb-16|0;fb=g;c=DW(g+4|0,d+8|0,c);e=x[c>>2];while(1){if(x[c+4>>2]!=(e|0)){cU(e);e=x[c>>2]+12|0;x[c>>2]=e;continue}break}he(c);fb=g+16|0;g=fb-16|0;fb=g;h=zb(a);c=vb(g+12|0,x[a+4>>2]);i=vb(g+8|0,x[a>>2]);j=vb(g+4|0,x[d+4>>2]);e=x[c>>2];i=x[i>>2];c=fb+-64|0;fb=c;j=x[j>>2];x[c+56>>2]=j;x[c+60>>2]=e;x[c+52>>2]=j;h=Re(c+24|0,h,c+52|0,c+56|0);x[c+16>>2]=x[h+8>>2];j=x[h+4>>2];x[c+8>>2]=x[h>>2];x[c+12>>2]=j;Qe(c+36|0,c+8|0);while(1){if(pd(e,i)){AC(Vp(x[c+56>>2]),il(e));e=qk(c+60|0);qk(c+56|0);e=x[e>>2];continue}break}Pe(c+36|0);j=x[c+56>>2];if(!y[c+48|0]){h=fb-16|0;fb=h;e=vb(h+12|0,x[x[c+44>>2]>>2]);n=x[vb(h+8|0,x[x[c+40>>2]>>2])>>2];i=fb-16|0;fb=i;e=x[e>>2];x[i+12>>2]=e;while(1){if(ci(e,n)){tf(ux(e));e=x[hl(i+12|0)>>2];continue}break}fb=i+16|0;fb=h+16|0}fb=c- -64|0;x[d+4>>2]=j;Tb(a,d+4|0);Tb(a+4|0,d+8|0);Tb(zb(a),nc(d));x[d>>2]=x[d+4>>2];fb=g+16|0;c=x[d+4>>2];while(1){e=x[d+8>>2];if((e|0)!=(c|0)){e=e-12|0;x[d+8>>2]=e;tf(e);continue}break}c=x[d>>2];if(c){ys(d);Db(c)}}fb=k+32|0;break a}if(c>>>0<d>>>0){iU(a,e+D(c,12)|0)}}if(b){c=a+12|0;Qq(c,ce(c));A=zb(c),B=0,x[A>>2]=B;d=c;c=ec(c);x[d>>2]=c;x[c>>2]=0;x[a+28>>2]=0}h=Nb(f+52|0);c=x[a+24>>2];c=Xu(x[c+484344>>2],x[c+484348>>2]);x[31737]=0;i=U(627,f+40|0,c|0,28636)|0;c=x[31737];x[31737]=0;c:{if((c|0)!=1){g=a+12|0;while(1){if((l|0)==(t|0)){md(i);dc(h);fb=f- -64|0;return}c=x[a+24>>2];d=x[c+484344>>2];c=x[c+484348>>2];j=z[_b(x[r>>2],l)>>1];d=nU(d,c,j);x[f+36>>2]=d;c=Hd(x[a>>2],l);d:{e:{f:{if(b){x[31737]=0;v[f+20|0]=0;S(806,c|0,d|0,f+20|0);d=x[31737];x[31737]=0;if((d|0)!=1){break f}d=N()|0;break e}x[31737]=0;O(760,c|0,d|0);d=x[31737];x[31737]=0;if((d|0)!=1){break f}d=N()|0;break e}if(!bj(r,l&65535)){break d}x[f+20>>2]=b?0:x[c+4>>2];c=f+20|0;s=x[Gb(c,f+36|0)>>2];n=Rf(g);d=z[_b(x[i>>2],j)>>1];if((d|0)!=65535){d=lU(g,z[hn(c,d,s)>>1],x[f+24>>2]);g:{if(Zg(d,Rf(g))){c=lU(g,z[hn(c,z[_b(x[i>>2],j)>>1],x[f+36>>2])>>1],x[f+24>>2]);break g}c=Rf(g)}x[f+32>>2]=d;while(1){h:{if(!Zg(d,c)){break d}e=Nb(f+20|0);d=Xn(td(d)+8|0);x[31737]=0;O(807,e|0,d|0);d=x[31737];x[31737]=0;if((d|0)!=1){d=Fc(f+12|0,n);k=hn(f+4|0,l,x[td(x[f+32>>2])+4>>2]);d=x[d>>2];x[31737]=0;d=ba(808,g|0,d|0,k|0,e|0)|0;k=x[31737];x[31737]=0;if((k|0)==1){break h}x[f+16>>2]=d;n=x[ah(f+16|0)>>2];Ae(e);d=x[ah(f+32|0)>>2];continue}}break}d=N()|0;Ae(e);break e}q=Wb(x[x[a+24>>2]+484344>>2],j);c=z[x[x[q+48>>2]+12>>2]+480188>>1];x[31737]=0;v[f+20|0]=0;S(781,h|0,c|0,f+20|0);c=x[31737];x[31737]=0;if((c|0)!=1){o=x[f+36>>2];i:while(1){j:{if((o|0)==(s|0)){if(s){break d}A=_b(x[i>>2],j),B=l,w[A>>1]=B;break d}c=1;k=0;e=x[x[q+48>>2]+12>>2];o=o-1|0;d=jd(x[q>>2],e,o,0);while(1){if(c>>>0<16&z[e+480188>>1]>k>>>0){u=xb(x[h>>2],k);e=y[u|0];k:{l:{m:{switch(y[d+3|0]-19|0){case 1:m=y[d+5|0];if((m&240)==176){break l}break k;case 0:break m;default:break k}}m=y[d+5|0];if((m&240)!=96){break k}}v[u|0]=m&15;m=y[xb(x[h>>2],k)|0];e=m?m:e}d=d+6|0;k=k+1|0;c=D((e&255)+1|0,c);e=x[x[q+48>>2]+12>>2];continue}else{n:{if(c>>>0<=1){continue i}e=Nb(f+20|0);x[31737]=0;O(807,e|0,c|0);c=x[31737];x[31737]=0;if((c|0)==1){break n}c=Fc(f,n);d=hn(f+4|0,l,o);c=x[c>>2];x[31737]=0;n=ba(808,g|0,c|0,d|0,e|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break j}Ae(e);continue i}}break}}break}d=N()|0;Ae(e);break e}d=N()|0}md(i);break c}l=l+1|0;continue}}d=N()|0}dc(h);Q(d|0);p()}function xsa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;j=fb-720|0;fb=j;a:{b:{if(d>>>0<=511){d=fb-16|0;fb=d;a=j+46|0;bc(d+8|0,a,554);e=x[d+12>>2];lc(d,x[b>>2],x[b+8>>2],x[d+8>>2],x[d+12>>2]);f=x[d+4>>2];if((f|0)==(e|0)){Vb(b,x[d+12>>2])}fb=d+16|0;b=(e|0)==(f|0);if(!b){Rb(a,0,554)}if(!b){break b}d=fb-32|0;fb=d;c:{if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=1229999433){break c}e=d+8|0;as(e,a+32|0);b=d+20|0;Cc(b,e);zc(c+492|0,b);tb(b);jk(e,1,a+4|0);Cc(b,e);zc(c+524|0,b);tb(b);b=y[a+24|0]|y[a+25|0]<<8;x[c+4>>2]=64;x[c+8>>2]=128;x[c>>2]=b<<6;v[c+16|0]=y[a+26|0];v[c+17|0]=y[a+27|0];f=c+108|0;k=c+236|0;b=0;while(1)if((b|0)==120){b=y[c+60|0]&-2|v[a+17|0]&1;v[c+60|0]=b;b=b&-3|y[a+17|0]&2;v[c+60|0]=b;v[c+60|0]=b&251|y[a+17|0]&4;k=c+61|0;v[k|0]=y[a+18|0];g=c+62|0;v[g|0]=y[a+19|0];h=c+63|0;v[h|0]=y[a+20|0];i=c- -64|0;v[i|0]=y[a+21|0];f=c+48|0;gh(f,25);e=x[c+48>>2];b=0;while(1){d:{if((b|0)!=25){l=yb(e,b);m=b<<1;n=y[(a+m|0)+504|0];w[l>>1]=n;if((n|0)!=255){break d}gh(f,b);e=x[f>>2]}b=df(k,g);a=Sd(e,x[c+52>>2]);if(a>>>0<=y[b|0]){v[c+60|0]=y[c+60|0]&253}if(a>>>0>y[df(h,i)|0]){break c}v[c+60|0]=y[c+60|0]&251;break c}v[l+2|0]=y[(a+(m|1)|0)+504|0];b=b+1|0;continue}}else{g=a+(b<<1)|0;e=y[g- -64|0];g=y[g+65|0];o=_b(k,b),q=g,w[o>>1]=q;o=xb(f,b),q=(e>>>0<120?e:b)+1|0,v[o|0]=q;b=b+1|0;continue}}fb=d+32|0;break b}k=x[b+8>>2];d=fb-32|0;fb=d;x[d+28>>2]=674;x[d+8>>2]=674;e=x[b>>2];g=x[b+8>>2];f=x[Gb(d+28|0,d+8|0)>>2];if(!Mb(e,g,f)){f=kf(b)}g=d+8|0;e=j+46|0;ZZ(g,e);h=gc(d+16|0,x[d+8>>2],f);i=x[h>>2];lc(d,x[b>>2],x[b+8>>2],i,x[h+4>>2]);ZZ(g,e);Rb(x[d+8>>2]+f|0,0,674-f|0);Vb(b,x[d+28>>2]);fb=d+32|0;g=x[a+480180>>2];a=0;d=fb-32|0;fb=d;if((y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24))==1229999433){f=d+8|0;as(f,e+32|0);a=d+20|0;Cc(a,f);zc(c+492|0,a);tb(a);jk(f,1,e+4|0);Cc(a,f);zc(c+524|0,a);tb(a);x[c>>2]=(y[e+20|0]|y[e+21|0]<<8)<<5;x[c+4>>2]=y[e+24|0]>>>1;wc(c+4|0,64);h=y[e+25|0]&127;x[c+8>>2]=h>>>0>64?128:h<<2;v[c+15|0]=y[c+15|0]&254|((y[e+25|0]^-1)&128)>>>7;v[d+20|0]=y[e+26|0];v[d+8|0]=100;o=c,q=y[Qb(a,f)|0],v[o+20|0]=q;v[d+20|0]=y[e+27|0];v[d+8|0]=64;o=c,q=y[Qb(a,f)|0],v[o+19|0]=q;v[c+16|0]=y[e+17|0];v[c+17|0]=y[e+18|0];v[c+18|0]=y[e+19|0];v[c+26|0]=y[e+22|0];v[c+27|0]=y[e+23|0];a=y[e+58|0];ik(c,a&127,a>>>7|0);a=y[e+59|0];hk(c,a&127,a>>>7|0);e:{f:{g:{h:{i:{j:{a=y[e+28|0]|y[e+29|0]<<8;switch(a-529|0){case 1:case 2:break h;case 0:case 3:break i;default:break j}}if((a|0)==544){break i}if((a|0)!=514){break h}}a=y[e+61|0];if((a|0)==255){break g}if(a>>>0<=128){v[c+30|0]=a}a=y[e+62|0]|y[e+63|0]<<8;if(a>>>0<129){break f}break e}a=v[e+61|0];if((a|0)<0){break g}v[c+30|0]=a+1}a=y[e+62|0];a=a<<24>>24>=0?a+1|0:0;f=v[e+63|0];if((f|0)<0){break f}a=((f&255)<<7)+a|0}w[c+28>>1]=a}a=v[e+60|0];v[c+31|0]=a;if((a|0)<0){v[c+31|0]=0;v[c+34|0]=a^128}a=0;f=g&16777216?240:25;Tw(e+304|0,c+48|0,0,f);Tw(e+386|0,c+68|0,32,f);Tw(e+468|0,c+88|0,32,f);v[c+100|0]=y[c+100|0]&239|y[e+468|0]>>>3&16;g=c+108|0;h=c+236|0;while(1){if((a|0)!=120){i=e+(a<<1)|0;f=y[i- -64|0];i=y[i+65|0];o=_b(h,a),q=i,w[o>>1]=q;o=xb(g,a),q=(f>>>0<120?f:a)+1|0,v[o|0]=q;a=a+1|0;continue}break}a=554}fb=d+32|0;d=0;k:{if(!a){break k}d=y[e+550|0]|y[e+551|0]<<8|(y[e+552|0]<<16|y[e+553|0]<<24);if(!((d|0)!=1481920589&(d|0)!=1297110104)){a=c+236|0;f=0;while(1){if((f|0)!=120){d=y[(e+f|0)+554|0];g=_b(a,f);w[g>>1]=z[g>>1]|d<<8;f=f+1|0;continue}break}a=674}d=a}cd(b,d+k|0);if(!gk(b,14092)){break b}d=j+4|0;fe(d,b,Pg(b));a=ic(j+24|0,d);ub(d);b=x[a>>2];x[31737]=0;R(155,b|0)|0;b=x[31737];x[31737]=0;if((b|0)==1){break a}x[31737]=0;b=P(413,a|0,13874)|0;d=x[31737];x[31737]=0;if((d|0)==1){break a}if(b){x[31737]=0;b=R(198,a|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break a}v[c+34|0]=b>>>0<=250?b:0}ub(a)}fb=j+720|0;return}b=N()|0;ub(a);Q(b|0);p()}function Nta(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0;d=fb-320|0;fb=d;xc(b);a:{e=d+308|0;if(!lp(b,e)){break a}if(!x$(e)){break a}if((y[d+308|0]|y[d+309|0]<<8|(y[d+310|0]<<16|y[d+311|0]<<24))==1179472708){Vb(b,4)}if(!Bi(b,d+300|0)|(y[d+300|0]|y[d+301|0]<<8|(y[d+302|0]<<16|y[d+303|0]<<24))!=1196314451){break a}i=1;if((c|0)==64){break a}f=d+108|0;K0(b,f,y[d+304|0]|y[d+305|0]<<8|(y[d+306|0]<<16|y[d+307|0]<<24));i=0;if((y[d+144|0]|y[d+145|0]<<8)>>>0>128|(y[d+150|0]|y[d+151|0]<<8)>>>0>16|((y[d+148|0]|y[d+149|0]<<8)>>>0>256|(y[d+142|0]|y[d+143|0]<<8)>>>0>128)){break a}Bd(a,8192);e=d+24|0;g=tc(e,6574);Ab(a+1298344|0,g);tb(g);g=tc(e,10157);Ab(a+1298356|0,g);tb(g);r=a+1298404|0,s=x[Fc(e,4)>>2],x[r>>2]=s;g=d+88|0;aj(g,2,f);Cc(e,g);Ab(a+1298308|0,e);tb(e);w[d+24>>1]=y[d+150|0]|y[d+151|0]<<8;w[d+88>>1]=1;f=z[pe(e,g)>>1];w[a+480188>>1]=f;x[a+480196>>2]=y[d+154|0];x[a+480204>>2]=D(y[d+155|0],1e4);v[d+24|0]=y[d+152|0];v[d+88|0]=64;e=y[Qb(e,g)|0];x[a+480200>>2]=e<<2;if(!e){x[a+480200>>2]=256}e=y[d+153|0];b:{if((e|0)==128){x[d+24>>2]=256/(f>>>0);x[d+88>>2]=128;e=x[Gb(d+24|0,d+88|0)>>2];break b}e=e&127}x[a+480228>>2]=e;e=0;while(1){if((e|0)==16){f=Xb(x[a+484360>>2],y[a+484376|0]);h=d+172|0;g=fb-16|0;fb=g;x[g+12>>2]=y[d+144|0]|y[d+145|0]<<8;e=g+12|0;wc(e,128);wc(e,65535);j=z[g+12>>1];xg(f,j);e=0;while(1){if((e|0)==(j|0)){fb=g+16|0}else{i=y[e+h|0];r=Wr(x[f>>2],x[f+4>>2],e),s=(i|0)==255?-1:(i|0)==254?-2:i,w[r>>1]=s;e=e+1|0;continue}break}e=y[d+142|0]|y[d+143|0]<<8;if(e>>>0<(y[d+144|0]|y[d+145|0]<<8)>>>0){af(Xb(x[a+484360>>2],y[a+484376|0]),e)}n=c&2;j=a+484344|0;i=1;o=c&1;q=d+60|0;while(1){if(!Bi(b,d+300|0)){break a}e=d+24|0;fe(e,b,y[d+304|0]|y[d+305|0]<<8|(y[d+306|0]<<16|y[d+307|0]<<24));c=ic(d+88|0,e);ub(e);c:{d:{if(!(!o|(y[d+300|0]|y[d+301|0]<<8|(y[d+302|0]<<16|y[d+303|0]<<24))!=1414807888)){x[31737]=0;k=m&65535;e=U(197,j|0,k|0,64)|0;g=x[31737];x[31737]=0;if((g|0)==1){break d}if(!e){break c}x[31737]=0;P(184,c|0,2)|0;e=x[31737];x[31737]=0;if((e|0)==1){break d}g=0;e:{while(1){e=x[c>>2];x[31737]=0;e=U(151,e|0,x[d+96>>2],1)|0;f=x[31737];x[31737]=0;f:{if((f|0)!=1){if(!(e&g>>>0<64)){break e}x[31737]=0;e=R(198,c|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break d}h=e<<24>>24;if(h){break f}g=g+1|0;continue}break d}e=d+24|0;f=h&15;if(f>>>0<z[a+480188>>1]){e=Wb(x[j>>2],k);e=jd(x[e>>2],x[x[e+48>>2]+12>>2],g,f)}g:{if((h|0)>=0){break g}x[31737]=0;f=R(198,c|0)|0;l=x[31737];x[31737]=0;if((l|0)==1){break d}if(!f){break g}v[e|0]=f>>>0<109?f+12|0:f}f=h&255;if(f&64){x[31737]=0;h=R(198,c|0)|0;l=x[31737];x[31737]=0;if((l|0)==1){break d}v[e+1|0]=h}if(f&32){v[e+2|0]=1;x[31737]=0;h=R(198,c|0)|0;l=x[31737];x[31737]=0;if((l|0)==1){break d}v[d+12|0]=h;v[d|0]=64;r=e,s=y[Qb(d+12|0,d)|0],v[r+4|0]=s}if(!(f&16)){continue}x[31737]=0;f=d+12|0;O(199,f|0,c|0);h=x[31737];x[31737]=0;if((h|0)!=1){Bf(e,y[d+12|0],y[Jc(f)|0]);continue}break}break d}m=m+1|0;break c}if((y[d+300|0]|y[d+301|0]<<8|(y[d+302|0]<<16|y[d+303|0]<<24))!=1414745673){break c}e=z[a+480190>>1];if(!ui(e)){break c}e=e+1|0;w[a+480190>>1]=e;x[31737]=0;g=d+24|0;O(325,c|0,g|0);f=x[31737];x[31737]=0;h:{if((f|0)==1){break h}x[31737]=0;k=(D(e&65535,104)+a|0)+484380|0;O(326,g|0,k|0);e=x[31737];x[31737]=0;if((e|0)==1){break h}aj(d,2,q);x[31737]=0;e=d+12|0;O(219,e|0,d|0);g=x[31737];x[31737]=0;if((g|0)==1){break h}zc(((z[a+480190>>1]<<5)+a|0)+946304|0,e);tb(e);if(!n){break c}g=y[d+37|0]|y[d+38|0]<<8;f=2;h=Xc(e,8,1,0,1);i:{if(!(g&64)){f=0;if(!(g&2)){break i}}yg(h,f)}if(g&4){fd(h,16)}x[31737]=0;U(216,e|0,k|0,c|0)|0;e=x[31737];x[31737]=0;if((e|0)!=1){break c}}}a=N()|0;ub(c);Q(a|0);p()}ub(c);continue}}g=(e<<5)+a|0;We(g+480280|0);f=y[(d+e|0)+156|0];if(f>>>0<=128){w[g+480284>>1]=f<<1}e=e+1|0;continue}}fb=d+320|0;return i|0}function Lsa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0;g=fb-32|0;fb=g;a:{b:{if(!c){break b}f=Zh(a,b);a=wb(x[d>>2]);x[g+28>>2]=a;d=wb(x[d+4>>2]);while(1){if(!Ib(a,d)){break b}xc(a);c:{if((Uk(a)|0)==(c|0)){Vb(a,20);d=Uk(a);l=qg(g+16|0);c=em(g+12|0,0,b?32:64);x[31737]=0;O(403,f|0,c|0);c=x[31737];x[31737]=0;if((c|0)==1){break c}o=(b|0)==2?4096:(b|0)==1?2048:16384;c=24;d=d+24|0;q=1;m=1;d:{while(1){i=o;while(1){e=x[a+8>>2];h=x[a>>2];x[31737]=0;e=U(151,h|0,e|0,1)|0;h=x[31737];x[31737]=0;e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{if((h|0)!=1){if(!e){break d}e=x[f+4>>2];h=x[f>>2];j=x[a+8>>2];x[31737]=0;x[g+12>>2]=j;j=P(404,l|0,g+12|0)|0;r=x[31737];x[31737]=0;if((r|0)==1){break a}u=j,A=Sd(h,e),x[u>>2]=A;x[31737]=0;e=R(198,a|0)|0;h=x[31737];x[31737]=0;if((h|0)==1){break a}q:{switch(e-128|0){case 5:case 6:case 9:case 10:break h;case 2:break i;case 1:break j;case 0:break k;case 3:case 4:case 7:case 8:break e;default:break q}}r:{switch(e|0){case 0:break g;case 5:break l;case 4:break m;case 3:break n;case 2:break o;case 1:break p;default:break r}}s:{switch(e-160|0){case 5:case 6:break h;case 2:break i;case 1:break j;case 0:break k;case 3:case 4:break e;default:break s}}switch(e-192|0){case 2:break i;case 1:break j;case 0:break k;default:break e}}break a}if(y[f+12|0]&4){break e}x[31737]=0;e=R(274,a|0)|0;h=x[31737];x[31737]=0;t:{if((h|0)==1){break t}x[31737]=0;x[g+12>>2]=e;e=P(404,l|0,g+12|0)|0;h=x[31737];x[31737]=0;if((h|0)==1){break t}v[f+15|0]=x[e>>2];u=f,A=Sd(x[f>>2],x[f+4>>2])-1|0,v[u+16|0]=A;v[f+12|0]=y[f+12|0]|4;break e}break a}x[31737]=0;e=R(274,a|0)|0;h=x[31737];x[31737]=0;if((h|0)==1){break a}w[g+12>>1]=e;w[g+10>>1]=1;h=g+12|0;j=g+10|0;e=z[pe(h,j)>>1];i=D(e,D(s<<16>>16,m))+i|0;u:{if(e>>>0<2){break u}u=g,A=jm((e+z[xf(x[f+4>>2])>>1]|0)-1|0),w[u+12>>1]=A;e=Sv(b,i);x[31737]=0;v[g+10|0]=e;S(405,f|0,h|0,j|0);e=x[31737];x[31737]=0;if((e|0)!=1){break u}break a}u=g,A=jm(z[xf(x[f+4>>2])>>1]+1|0),w[u+12>>1]=A;e=Sv(b,i);x[31737]=0;v[g+10|0]=e;S(405,f|0,g+12|0,g+10|0);e=x[31737];x[31737]=0;if((e|0)!=1){break e}break a}x[31737]=0;k=R(198,a|0)|0;e=x[31737];x[31737]=0;if((e|0)==1){break a}t=x[a+8>>2];break e}x[31737]=0;e=R(274,a|0)|0;h=x[31737];x[31737]=0;if((h|0)==1){break a}e=c+e|0;x[g+12>>2]=e;if(!(!(k&255)|e>>>0<t>>>0)){k=k-1|0;if(!(k&255)){break f}x[31737]=0;P(150,a|0,e|0)|0;e=x[31737];x[31737]=0;if((e|0)!=1){break e}break a}if(!(k&255)){break f}x[31737]=0;e=P(406,l|0,g+12|0)|0;h=x[31737];x[31737]=0;if((h|0)==1){break a}v[f+13|0]=x[e>>2];u=f,A=Sd(x[f>>2],x[f+4>>2])-1|0,v[u+14|0]=A;v[f+12|0]=y[f+12|0]|2;break e}q=0;n=1;break e}x[31737]=0;i=R(274,a|0)|0;e=x[31737];x[31737]=0;if((e|0)==1){break a}e=Sv(b,i);u=xf(x[f+4>>2]),A=e,v[u+2|0]=A;break e}x[31737]=0;s=R(407,a|0)|0;e=x[31737];x[31737]=0;if((e|0)!=1){break e}break a}x[31737]=0;e=R(198,a|0)|0;m=x[31737];x[31737]=0;if((m|0)!=1){v[g+12|0]=e;v[g+10|0]=1;m=y[df(g+12|0,g+10|0)|0];break e}break a}x[31737]=0;P(184,a|0,1)|0;e=x[31737];x[31737]=0;if((e|0)==1){break a}break e}n=1;if(c>>>0<d>>>0){break e}break d}k=0}if(!n|c>>>0>=d>>>0){continue}break}x[31737]=0;c=P(150,a|0,d|0)|0;i=x[31737];x[31737]=0;if((i|0)==1){break a}if(!c){break d}c=x[a+8>>2];i=x[a>>2];x[31737]=0;c=U(151,i|0,c|0,2)|0;i=x[31737];x[31737]=0;if((i|0)==1){break a}if(!c){break d}c=x[f+4>>2];i=y[f+12|0];if(!(i&4)&q){e=x[f>>2];v[f+12|0]=i|4;i=Sd(e,c)-1|0;v[f+15|0]=i;v[f+16|0]=i}u=g,A=jm(z[xf(c)>>1]+1|0),w[u+12>>1]=A;c=Sv(b,o);x[31737]=0;v[g+10|0]=c;S(405,f|0,g+12|0,g+10|0);c=x[31737];x[31737]=0;if((c|0)!=1){n=1;v[f+17|0]=y[f+16|0]+1;c=d;continue}break}break a}v[f+12|0]=y[f+12|0]|1;k_(l);break b}a=x[Sf(g+28|0)>>2];continue}break}break a}fb=g+32|0;return}a=N()|0;k_(l);Q(a|0);p()}function Mz(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=fb-256|0;fb=f;g=x[b+4>>2];a:{if(!g){i=x[b>>2];break a}i=x[b>>2];h=y[Gl(i,g)|0];if((h|0)==33){e=1}else{if((h|0)!=63){break a}e=0}Sl(f+96|0,i,g,g-1|0);g=x[f+100>>2];i=x[f+96>>2];x[b>>2]=i;x[b+4>>2]=g}j=f+96|0;ge(j);h=x[f+96>>2];k=f+236|0;ge(k);h=Fl(h,x[f+240>>2],b);ge(j);b:{c:{d:{e:{if(x[f+100>>2]==(h|0)){h=qc(f+248|0,22303);a=x[h+4>>2];x[f+8>>2]=x[h>>2];x[f+12>>2]=a;if(Ic(i,g,f+8|0)){e=ac(8);x[31737]=0;c=fi(k,c,d);a=x[31737];x[31737]=0;f:{g:{h:{if((a|0)!=1){x[31737]=0;S(1017,j|0,18282,c|0);a=x[31737];x[31737]=0;if((a|0)==1){break h}pc(e,j);a=0;x[31737]=0;S(98,e|0,48540,1006);b=x[31737];x[31737]=0;if((b|0)!=1){break b}g=N()|0;tb(j);break g}g=N()|0;break f}g=N()|0;a=1}tb(c);if(!a){break c}}jc(e);break c}if(!e){break e}h=ac(8);e=x[b>>2];a=x[b+4>>2];x[31737]=0;i=fi(f+212|0,e,a);a=x[31737];x[31737]=0;i:{j:{k:{l:{m:{n:{o:{p:{q:{if((a|0)!=1){x[31737]=0;b=f+224|0;S(1017,b|0,18318,i|0);a=x[31737];x[31737]=0;if((a|0)==1){break q}x[31737]=0;e=f+236|0;O(1019,e|0,b|0);b=x[31737];x[31737]=0;a=1;if((b|0)==1){break p}x[31737]=0;d=fi(f+200|0,c,d);a=x[31737];x[31737]=0;if((a|0)==1){break o}x[31737]=0;c=f+96|0;S(1021,c|0,e|0,d|0);b=x[31737];x[31737]=0;a=1;if((b|0)==1){break n}pc(h,c);x[31737]=0;S(98,h|0,48540,1006);a=x[31737];x[31737]=0;if((a|0)!=1){break b}g=N()|0;tb(c);a=0;break m}g=N()|0;break i}g=N()|0;a=1;break j}g=N()|0;break k}g=N()|0;a=1;break l}g=N()|0}tb(d)}tb(f+236|0)}tb(f+224|0)}tb(i);if(!a){break c}}jc(h);break c}e=qc(f+192|0,22303);b=x[e+4>>2];x[f+88>>2]=x[e>>2];x[f+92>>2]=b;if(Ic(i,g,f+88|0)){e=ac(8);x[31737]=0;d=fi(f+236|0,c,d);a=x[31737];x[31737]=0;r:{s:{t:{if((a|0)!=1){x[31737]=0;c=f+96|0;S(1017,c|0,18282,d|0);a=x[31737];x[31737]=0;if((a|0)==1){break t}pc(e,c);a=0;x[31737]=0;S(98,e|0,48540,1006);b=x[31737];x[31737]=0;if((b|0)!=1){break b}g=N()|0;tb(c);break s}g=N()|0;break r}g=N()|0;a=1}tb(d);if(!a){break c}}jc(e);break c}e=qc(f+184|0,12437);b=x[e+4>>2];x[f+80>>2]=x[e>>2];x[f+84>>2]=b;if(Ic(i,g,f+80|0)){e=qc(f+176|0,5601);b=x[e+4>>2];x[f+32>>2]=x[e>>2];x[f+36>>2]=b;if(Ic(c,d,f+32|0)){x[a+52>>2]=0;break e}e=qc(f+168|0,11301);b=x[e+4>>2];x[f+24>>2]=x[e>>2];x[f+28>>2]=b;if(Ic(c,d,f+24|0)){x[a+52>>2]=1;break e}e=qc(f+160|0,9222);b=x[e+4>>2];x[f+16>>2]=x[e>>2];x[f+20>>2]=b;if(Ic(c,d,f+16|0)){x[a+52>>2]=2;break e}e=ac(8);x[31737]=0;d=fi(f+236|0,c,d);a=x[31737];x[31737]=0;u:{v:{w:{if((a|0)!=1){x[31737]=0;c=f+96|0;S(1017,c|0,14667,d|0);a=x[31737];x[31737]=0;if((a|0)==1){break w}pc(e,c);a=0;x[31737]=0;S(98,e|0,48540,1006);b=x[31737];x[31737]=0;if((b|0)!=1){break b}g=N()|0;tb(c);break v}g=N()|0;break u}g=N()|0;a=1}tb(d);if(!a){break c}}jc(e);break c}e=qc(f+152|0,11538);b=x[e+4>>2];x[f+72>>2]=x[e>>2];x[f+76>>2]=b;if(!Ic(i,g,f+72|0)){break e}e=qc(f+144|0,15670);b=x[e+4>>2];x[f+64>>2]=x[e>>2];x[f+68>>2]=b;b=0;x:{if(Ic(c,d,f- -64|0)){break x}e=qc(f+136|0,15675);b=x[e+4>>2];x[f+56>>2]=x[e>>2];x[f+60>>2]=b;b=1;if(Ic(c,d,f+56|0)){break x}e=qc(f+128|0,12711);b=x[e+4>>2];x[f+48>>2]=x[e>>2];x[f+52>>2]=b;b=2;if(Ic(c,d,f+48|0)){break x}e=qc(f+120|0,9286);b=x[e+4>>2];x[f+40>>2]=x[e>>2];x[f+44>>2]=b;b=3;if(Ic(c,d,f+40|0)){break x}c=ac(8);x[31737]=0;b=P(36,f+96|0,11574)|0;a=x[31737];x[31737]=0;if((a|0)==1){break d}pc(c,b);x[31737]=0;S(98,c|0,48540,1006);a=x[31737];x[31737]=0;if((a|0)!=1){break b}g=N()|0;tb(b);break c}x[a+56>>2]=b;d=x[a+24>>2];if(!x[d+24668>>2]){break e}c=d+24664|0;a=x[c+4>>2];x[f+112>>2]=x[c>>2];x[f+116>>2]=a;c=d+24656|0;a=x[c+4>>2];x[f+104>>2]=x[c>>2];x[f+108>>2]=a;a=x[d+24652>>2];x[f+96>>2]=x[d+24648>>2];x[f+100>>2]=a;l=f,m=aN(b),x[l+116>>2]=m;a=f+96|0;if(!xz(a,d+24648|0)){break e}JA(d,a)}fb=f+256|0;return}g=N()|0;jc(c)}Q(g|0)}p()}function S7(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0;h=fb-16|0;fb=h;x[h+12>>2]=b;x[e>>2]=0;bd(h,x[d+28>>2]);x[31737]=0;i=R(28,x[h>>2])|0;j=x[31737];x[31737]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{if((j|0)!=1){Zb(h);switch(g-65|0){case 54:break j;case 19:break k;case 18:break l;case 17:break m;case 49:break n;case 47:break o;case 45:case 51:break p;case 12:break q;case 44:break r;case 41:break s;case 8:break t;case 7:break u;case 5:break v;case 3:break w;case 35:case 36:break x;case 34:break y;case 1:case 33:case 39:break z;case 0:case 32:break A;case 2:case 4:case 6:case 9:case 10:case 11:case 13:case 14:case 15:case 16:case 20:case 21:case 22:case 25:case 26:case 27:case 28:case 29:case 30:case 31:case 37:case 38:case 40:case 42:case 43:case 46:case 48:case 50:case 52:case 53:break d;case 24:break f;case 56:break g;case 23:break h;case 55:break i;default:break e}}a=N()|0;Zb(h);Q(a|0);p()}jK(a,f+24|0,h+12|0,c,e,i);break b}iK(a,f+16|0,h+12|0,c,e,i);break b}b=ib[x[x[a+8>>2]+12>>2]](a+8|0)|0;g=a;i=x[h+12>>2];a=Jb(b);k=h,l=wk(g,i,c,d,e,f,a,Cb(x[b+4>>2],y[b+11|0])+a|0),x[k+12>>2]=l;break b}a=qj(h+12|0,c,e,i,2);b=x[e>>2];B:{if(!(b&4|a-1>>>0>30)){x[f+12>>2]=a;break B}x[e>>2]=b|4}break b}x[h>>2]=623865125;x[h+4>>2]=2032480100;k=h,l=wk(a,b,c,d,e,f,h,h+8|0),x[k+12>>2]=l;break b}x[h>>2]=623728933;x[h+4>>2]=1680158061;k=h,l=wk(a,b,c,d,e,f,h,h+8|0),x[k+12>>2]=l;break b}a=qj(h+12|0,c,e,i,2);b=x[e>>2];C:{if(!(b&4|(a|0)>23)){x[f+8>>2]=a;break C}x[e>>2]=b|4}break b}a=qj(h+12|0,c,e,i,2);b=x[e>>2];D:{if(!(b&4|a-1>>>0>11)){x[f+8>>2]=a;break D}x[e>>2]=b|4}break b}a=qj(h+12|0,c,e,i,3);b=x[e>>2];E:{if(!(b&4|(a|0)>365)){x[f+28>>2]=a;break E}x[e>>2]=b|4}break b}a=qj(h+12|0,c,e,i,2);b=x[e>>2];a=a-1|0;F:{if(!(b&4|a>>>0>11)){x[f+16>>2]=a;break F}x[e>>2]=b|4}break b}a=qj(h+12|0,c,e,i,2);b=x[e>>2];G:{if(!(b&4|(a|0)>59)){x[f+4>>2]=a;break G}x[e>>2]=b|4}break b}a=h+12|0;b=fb-16|0;fb=b;x[b+12>>2]=c;while(1){H:{if(sh(a,b+12|0)){break H}c=Al(x[a>>2]);if(!Jf(x[i+8>>2],1,c)){break H}Km(a);continue}break}if(sh(a,b+12|0)){x[e>>2]=x[e>>2]|2}fb=b+16|0;break b}b=h+12|0;a=ib[x[x[a+8>>2]+8>>2]](a+8|0)|0;I:{if((Cb(x[a+4>>2],y[a+11|0])|0)==(0-Cb(x[a+16>>2],y[a+23|0])|0)){x[e>>2]=x[e>>2]|4;break I}c=mt(b,c,a,a+24|0,i,e,0);b=x[f+8>>2];if(!((c|0)!=(a|0)|(b|0)!=12)){x[f+8>>2]=0;break I}if(!((c-a|0)!=12|(b|0)>11)){x[f+8>>2]=b+12}}break b}g=y[111816]|y[111817]<<8|(y[111818]<<16|y[111819]<<24);v[h+7|0]=g;v[h+8|0]=g>>>8;v[h+9|0]=g>>>16;v[h+10|0]=g>>>24;g=y[111813]|y[111814]<<8|(y[111815]<<16|y[111816]<<24);x[h>>2]=y[111809]|y[111810]<<8|(y[111811]<<16|y[111812]<<24);x[h+4>>2]=g;k=h,l=wk(a,b,c,d,e,f,h,h+11|0),x[k+12>>2]=l;break b}v[h+4|0]=y[111824];x[h>>2]=y[111820]|y[111821]<<8|(y[111822]<<16|y[111823]<<24);k=h,l=wk(a,b,c,d,e,f,h,h+5|0),x[k+12>>2]=l;break b}a=qj(h+12|0,c,e,i,2);b=x[e>>2];J:{if(!(b&4|(a|0)>60)){x[f>>2]=a;break J}x[e>>2]=b|4}break b}x[h>>2]=624576549;x[h+4>>2]=1394948685;k=h,l=wk(a,b,c,d,e,f,h,h+8|0),x[k+12>>2]=l;break b}a=qj(h+12|0,c,e,i,1);b=x[e>>2];K:{if(!(b&4|(a|0)>6)){x[f+24>>2]=a;break K}x[e>>2]=b|4}break b}a=ib[x[x[a>>2]+20>>2]](a,b,c,d,e,f)|0;break a}b=ib[x[x[a+8>>2]+24>>2]](a+8|0)|0;g=a;i=x[h+12>>2];a=Jb(b);k=h,l=wk(g,i,c,d,e,f,a,Cb(x[b+4>>2],y[b+11|0])+a|0),x[k+12>>2]=l;break b}hK(f+20|0,h+12|0,c,e,i);break b}a=qj(h+12|0,c,e,i,4);if(!(y[e|0]&4)){x[f+20>>2]=a-1900}break b}if((g|0)==37){break c}}x[e>>2]=x[e>>2]|4;break b}a=fb-16|0;fb=a;x[a+12>>2]=c;b=6;c=h+12|0;d=a+12|0;L:{M:{if(sh(c,d)){break M}b=4;if((rl(i,Al(x[c>>2]))|0)!=37){break M}b=2;if(!sh(Km(c),d)){break L}}x[e>>2]=x[e>>2]|b}fb=a+16|0}a=x[h+12>>2]}fb=h+16|0;return a|0}function sk(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;i=1;o(+b);e=j(1)|0;a:{b:{f=j(0)|0;p=e&2147483647;c:{if(!(f|p)){break c}o(+a);c=j(1)|0;g=j(0)|0;if(!g&(c|0)==1072693248){break c}t=g;r=c&2147483647;if(!(!(r>>>0>2146435072|(r|0)==2146435072&(g|0)!=0|p>>>0>2146435072)&(!f|(p|0)!=2146435072))){return a+b}g=0;d:{e:{f:{g:{h:{q=c;if((c|0)>0){q=1}else{q=(q|0)>=0}i:{if(q){break i}g=2;if(p>>>0>1128267775){break i}g=0;if(p>>>0<1072693248){break i}q=p>>>20|0;if(p>>>0<1094713344){break h}m=1075-q|0;q=f>>>m|0;if((f|0)!=q<<m){break i}g=2-(q&1)|0}m=g;if(f){break f}if((p|0)!=2146435072){break g}if(!(r-1072693248|t)){break c}if(r>>>0<1072693248){break e}return(e|0)>0|(e|0)>=0?b:0}if(f){break f}g=1043-q|0;f=p>>>g|0;if((p|0)!=f<<g){break g}m=2-(f&1)|0}if((p|0)==1072693248){if((e|0)>0|(e|0)>=0){return a}return 1/a}if((e|0)==1073741824){return a*a}if((e|0)!=1071644672|(c|0)<0){break f}return M(a)}d=F(a);if(t){break d}j:{if((c|0)<0){if((c|0)==-2147483648|(c|0)==-1074790400|(c|0)==-1048576){break j}break d}if(!c|(c|0)==2146435072){break j}if((c|0)!=1072693248){break d}}i=(e|0)<0?1/d:d;if((c|0)>0|(c|0)>=0){break c}if(!(r-1072693248|m)){a=i-i;return a/a}return(m|0)==1?-i:i}return(e|0)>0|(e|0)>=0?0:-b}k:{if((c|0)>0|(c|0)>=0){break k}l:{switch(m|0){case 0:a=a-a;return a/a;case 1:break l;default:break k}}i=-1}m:{if(p>>>0>=1105199105){if(p>>>0>=1139802113){if(r>>>0<=1072693247){return(e|0)<0?Infinity:0}return(e|0)>0?Infinity:0}if(r>>>0<=1072693246){return(e|0)<0?i*1e300*1e300:i*1e-300*1e-300}if(r>>>0>=1072693249){return(e|0)>0?i*1e300*1e300:i*1e-300*1e-300}a=d+-1;d=a*1.9259629911266175e-8+a*a*(.5-a*(a*-.25+.3333333333333333))*-1.4426950408889634;h=d;d=a*1.4426950216293335;o(+(h+d));c=j(1)|0;j(0)|0;l(0,0);l(1,c|0);a=+n();d=h-(a-d);break m}a=d*9007199254740992;f=r>>>0<1048576;d=f?a:d;o(+a);c=j(1)|0;j(0)|0;m=f?c:r;g=m&1048575;c=g|1072693248;m=(m>>20)+(f?-1076:-1023)|0;f=0;n:{if(g>>>0<235663){break n}if(g>>>0<767610){f=1;break n}c=g|1071644672;m=m+1|0}g=((f<<18)+(c>>>1|0)|0)+537395200|0;f=f<<3;w=C[f+3536>>3];o(+d);j(1)|0;q=0;l(0,j(0)|q);l(1,c|0);k=+n();s=C[f+3520>>3];h=k-s;u=1/(s+k);d=h*u;o(+d);c=j(1)|0;j(0)|0;l(0,0);l(1,c|0);a=+n();x=a;l(0,q|0);l(1,g|0);v=a*a;y=h;h=+n();k=u*(y-a*h-a*(k-(h-s)));h=k*(d+a);a=d*d;s=h+a*a*(a*(a*(a*(a*(a*.20697501780033842+.23066074577556175)+.272728123808534)+.33333332981837743)+.4285714285785502)+.5999999999999946);o(+(v+3+s));c=j(1)|0;j(0)|0;l(0,0);l(1,c|0);a=+n();h=x*a;d=k*a+d*(s-(a+-3-v));o(+(h+d));c=j(1)|0;j(0)|0;l(0,0);l(1,c|0);a=+n();d=w+(a*-7.028461650952758e-9+(d-(a-h))*.9617966939259756);h=d;k=C[f+3552>>3];d=a*.9617967009544373;s=+(m|0);o(+(k+(h+d)+s));c=j(1)|0;j(0)|0;l(0,0);l(1,c|0);a=+n();d=h-(a-s-k-d)}l(0,0);l(1,e|0);k=+n();d=(b-k)*a+d*b;b=a*k;a=d+b;o(+a);e=j(1)|0;c=j(0)|0;o:{if((e|0)>=1083179008){if(c|e-1083179008){break b}if(!(d+8008566259537294e-32>a-b)){break o}break b}if((e&2147482624)>>>0<1083231232){break o}if(c|e+1064252416){break a}if(!(d<=a-b)){break o}break a}f=0;g=e&2147483647;if(g>>>0>=1071644673){c=e+(1048576>>>(g>>>20|0)-1022|0)|0;g=c>>>20&2047;f=(c&1048575|1048576)>>>1043-g|0;f=(e|0)<0?0-f|0:f;l(0,0);l(1,c&-1048576>>g-1023);b=b-+n();o(+(d+b));e=j(1)|0;j(0)|0}l(0,0);l(1,e|0);a=+n();k=a*.6931471824645996;d=(d-(a-b))*.6931471805599453+a*-1.904654299957768e-9;a=k+d;b=a*a;b=a-b*(b*(b*(b*(b*4.1381367970572385e-8+-16533902205465252e-22)+6613756321437934e-20)+-.0027777777777015593)+.16666666666666602);h=a*b/(b+-2);b=a;a=d-(a-k);a=b-(h-(b*a+a))+1;o(+a);e=j(1)|0;c=j(0)|0;e=(f<<20)+e|0;p:{if((e|0)<=1048575){a=pk(a,f);break p}l(0,c|0);l(1,e|0);a=+n()}i=i*a}return i}return i*1e300*1e300}return i*1e-300*1e-300}function Rna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=fb-176|0;fb=e;a:{b:{if(Mb(x[c>>2],x[c+8>>2],8)){Vb(c,4);while(1){if(Mv(x[c>>2],x[c+8>>2])){break b}m=fb-288|0;fb=m;f=HU(m+6|0);i=fb-368|0;fb=i;l=yc(f,HU(i+80|0),282);f=0;g=fb-32|0;fb=g;x[g+28>>2]=0;j=gc(g+8|0,g+28|0,4);h=x[j>>2];lc(g+20|0,x[c>>2],x[c+8>>2],h,x[j+4>>2]);j=x[g+24>>2]==4&x[g+28>>2]==1399285583;if(j){Vb(c,4)}fb=g+32|0;c:{d:{e:{f:{g:{if(j){IU(c,4);j=q0(i+60|0,c);x[31737]=0;g=P(792,j|0,l|0)|0;h=x[31737];x[31737]=0;if((h|0)==1){break g}h:{if(!g){break h}g=x[j+8>>2];h=x[j>>2];k=y[l+26|0];x[31737]=0;g=U(793,h|0,g|0,k|0)|0;h=x[31737];x[31737]=0;if((h|0)==1){break g}if(!g){break h}g=0;i:{while(1){if(y[l+26|0]<=f>>>0){h=x[j+8>>2];k=x[j>>2];f=0;x[31737]=0;n=h;h=g&65535;g=U(793,k|0,n|0,h|0)|0;k=x[31737];x[31737]=0;if((k|0)==1){break e}if(!g){break h}x[31737]=0;O(794,j|0,h|0);f=x[31737];x[31737]=0;if((f|0)==1){break e}IU(j,JU(l));g=sc(i+56|0);f=i+80|0;QB(f);x[31737]=0;O(795,j|0,f|0);k=x[31737];x[31737]=0;if((k|0)!=1){w[i+102>>1]=0;w[i+104>>1]=0;f=GU(g,f,i+107|0);g=y[l+26|0];x[31737]=0;O(794,j|0,g|0);g=x[31737];x[31737]=0;if((g|0)!=1){break i}}f=N()|0;break d}x[31737]=0;h=R(796,j|0)|0;k=x[31737];x[31737]=0;if((k|0)!=1){v[(f+l|0)+27|0]=h;f=f+1|0;g=g+h|0;continue}break}f=N()|0;break d}n=f;f=l+27|0;g=GU(n,f,f+y[l+26|0]|0);x[31737]=0;k=i+36|0;S(797,k|0,j|0,h|0);f=x[31737];x[31737]=0;if((f|0)==1){break f}f=0;x[31737]=0;O(576,i+16|0,k|0);h=x[31737];x[31737]=0;if((h|0)==1){f=N()|0;ub(k);break d}n=i+16|0;gG(i+8|0,n);h=wb(x[i+8>>2]);o=Wk(x[i+8>>2],x[i+12>>2]);k=fb-16|0;fb=k;x[k+12>>2]=h;while(1){if(Ib(h,o)){EU(g,y[h|0]);h=x[le(k+12|0)>>2];continue}else{fb=k+16|0}break}Kc(n);ub(i+36|0);if(x[g>>2]!=(y[l+22|0]|y[l+23|0]<<8|(y[l+24|0]<<16|y[l+25|0]<<24))){break h}f=JU(l);x[31737]=0;O(794,c|0,f|0);g=x[31737];x[31737]=0;f=1;if((g|0)==1){break e}}ub(j)}fb=i+368|0;break c}f=N()|0;break d}f=N()|0;break d}f=N()|0}ub(j);Q(f|0);p()}fb=m+288|0;if(f){continue}break}}xc(c);fg(b,a,c);a=1;break a}v[d|0]=1;xc(c);f=Pg(c);d=e+136|0;fe(d,c,kf(c));g=ic(e+156|0,d);ub(d);c=z[a+34>>1]&-66|y[b|0]>15;b=y[b+1|0]!=1;c=c|b<<6;w[a+34>>1]=c;x[a>>2]=f>>>(c&1)>>>b;x[e+132>>2]=0;x[e+128>>2]=0;x[31737]=0;O(576,d|0,g|0);b=x[31737];x[31737]=0;j:{k:{l:{m:{if((b|0)!=1){c=_e(d);d=x[e+136>>2];i=ZC(c,th(d),e+132|0,e+128|0);x[31737]=0;b=x[e+132>>2];P(184,g|0,b|0)|0;f=x[31737];x[31737]=0;if((f|0)!=1){if(!i){break j}Eh(a);l=b+c|0;d=d-b|0;b=x[e+128>>2];c=0;while(1){n:{if(b){if(!d|(b|0)!=1){break k}b=x[a>>2];if(c>>>0<b>>>0){break n}break k}b=x[a>>2];if(c>>>0>=b>>>0){break k}}if(!je(b,x[a+20>>2])){break k}x[e+124>>2]=0;x[e+120>>2]=0;b=e+120|0;j=CY(i,l,th(d),e+124|0,e+116|0,b);x[31737]=0;P(184,g|0,j|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break m}Ai(b,th(x[a>>2]-c|0));b=x[e+120>>2];o:{if((b|0)<=0){break o}f=x[e+124>>2];m=z[a+34>>1];if((_d(m)|0)!=(f|0)){break o}h=D(c,f);k=x[a+20>>2];if(m&1){x[e+112>>2]=b;x[e+100>>2]=b;x[e- -64>>2]=b;x[e+48>>2]=b;x[e+96>>2]=f;x[e+92>>2]=x[e+116>>2];x[e+108>>2]=f;x[e+104>>2]=k+(h<<1);x[31737]=0;f=x[e+96>>2];x[e+40>>2]=x[e+92>>2];x[e+44>>2]=f;f=x[e+108>>2];x[e+56>>2]=x[e+104>>2];x[e+60>>2]=f;O(577,e+56|0,e+40|0);f=x[31737];x[31737]=0;if((f|0)!=1){break o}break m}x[e+88>>2]=b;x[e+76>>2]=b;x[e+32>>2]=b;x[e+16>>2]=b;x[e+72>>2]=f;x[e+68>>2]=x[e+116>>2];x[e+84>>2]=f;x[e+80>>2]=h+k;x[31737]=0;f=x[e+72>>2];x[e+8>>2]=x[e+68>>2];x[e+12>>2]=f;f=x[e+84>>2];x[e+24>>2]=x[e+80>>2];x[e+28>>2]=f;O(578,e+24|0,e+8|0);f=x[31737];x[31737]=0;if((f|0)==1){break m}}d=d-j|0;l=j+l|0;c=b+c|0;b=BY(i);continue}}break m}c=N()|0;break l}c=N()|0;Kc(e+136|0)}ub(g);Q(c|0);p()}AY(i)}Kc(e+136|0);ub(g);a=(i|0)!=0}fb=e+176|0;return a|0}function oy(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=fb-32|0;fb=e;j=a+32|0;Pc(e+8|0,j,11);a:{b:{c:{if(Hb(x[x[e+8>>2]>>2],x[e+12>>2])|x[a+8>>2]){b=x[a+76>>2]+x[a+20>>2]|0;f=x[a+16>>2];c=f+x[a+72>>2]|0;Hi(x[a+36>>2],c,c>>>0<f>>>0?b+1|0:b,0);b=x[a+36>>2];if(tk(x[(x[x[b>>2]-12>>2]+b|0)+16>>2])){Qh(a,2,256);break a}b=x[a+104>>2];c=a+52|0;f=x[c>>2];d=oj(f,x[c+4>>2]);d:{if(b>>>0>d>>>0){n=fb-32|0;fb=n;f=b-d|0;d=x[zb(c)>>2];g=x[c+4>>2];e:{if(f>>>0<=(d-g|0)/24>>>0){d=fb-16|0;fb=d;c=EJ(d+4|0,c,f);b=x[c+4>>2];f=x[c+8>>2];while(1){if((b|0)==(f|0)){hc(c);fb=d+16|0}else{CJ(b);b=b+24|0;x[c+4>>2]=b;continue}break}break e}b=zb(c);d=SJ(n+12|0,YJ(c,oj(x[c>>2],g)+f|0),oj(x[c>>2],x[c+4>>2]),b);g=fb-16|0;fb=g;h=x[d+8>>2];b=g+4|0;x[b+8>>2]=d+8;x[b>>2]=h;x[b+4>>2]=h+D(f,24);f=x[b>>2];while(1){if(x[b+4>>2]!=(f|0)){CJ(f);f=x[b>>2]+24|0;x[b>>2]=f;continue}break}he(b);fb=g+16|0;k=fb-16|0;fb=k;b=vb(k+12|0,x[c+4>>2]);g=vb(k+8|0,x[c>>2]);h=x[vb(k+4|0,x[d+4>>2])>>2];m=fb-16|0;fb=m;p=m+8|0;f=fb-32|0;fb=f;Id(f+24|0,x[b>>2],x[g>>2]);q=f+16|0;b=x[f+24>>2];r=x[f+28>>2];g=fb-16|0;fb=g;x[g+8>>2]=h;x[g+12>>2]=b;while(1){if(pd(b,r)){b=ol(b);h=ol(x[g+8>>2]);l=z[b+18>>1]|z[b+20>>1]<<16;o=z[b+14>>1]|z[b+16>>1]<<16;w[h+14>>1]=o;w[h+16>>1]=o>>>16;w[h+18>>1]=l;w[h+20>>1]=l>>>16;l=x[b+12>>2];x[h+8>>2]=x[b+8>>2];x[h+12>>2]=l;l=x[b+4>>2];x[h>>2]=x[b>>2];x[h+4>>2]=l;b=$s(g+12|0);$s(g+8|0);b=x[b>>2];continue}break}Ac(q,b,g+8|0);fb=g+16|0;b=x[f+16>>2];x[f+12>>2]=x[f+20>>2];Ac(p,b,f+12|0);fb=f+32|0;fb=m+16|0;x[d+4>>2]=x[m+12>>2];Tb(c,d+4|0);Tb(c+4|0,d+8|0);Tb(zb(c),nc(d));x[d>>2]=x[d+4>>2];fb=k+16|0;NJ(d)}fb=n+32|0;break d}if(b>>>0<d>>>0){JJ(c,f+D(b,24)|0)}}f=a+40|0;vo(f,x[a+104>>2]<<2);while(1){if(A[a+104>>2]>i>>>0){c=x[a+36>>2];if(tk(x[(x[x[c>>2]-12>>2]+c|0)+16>>2])){Qh(a,2,1024);break a}b=z[a+24>>1];w[e>>1]=b;if((b|0)==65535){zy(c,e);b=z[e>>1]}c=Vc(x[a+40>>2],x[a+44>>2]);d=b&65535;f:{if(!d){b=0;break f}if(d>>>0>(c^-1)>>>0){break f}Nk(f,c+d|0);Dj(x[a+36>>2],xb(x[a+40>>2],c),d)}d=wf(x[a+52>>2],i);x[d>>2]=c;w[d+20>>1]=b;b=e+8|0;Pc(b,j,6);if(Hb(x[x[e+8>>2]>>2],x[e+12>>2])){tl(x[a+36>>2],b);b=x[e+8>>2];c=x[e+12>>2];if(!uy(b,c)){break c}d=wf(x[a+52>>2],i);x[d+8>>2]=b;x[d+12>>2]=c}c=x[a+8>>2];g:{if(c){b=wf(x[a+52>>2],i);x[b+16>>2]=c;break g}Pc(e+8|0,j,7);if(!Hb(x[x[e+8>>2]>>2],x[e+12>>2])){b=wf(x[a+52>>2],i);break g}tl(x[a+36>>2],e+8|0);c=x[e+8>>2];if(!uy(c,x[e+12>>2])){break b}b=wf(x[a+52>>2],i);x[b+16>>2]=c}h:{if(x[b+16>>2]==-1){break h}Pc(e+8|0,j,6);if(Hb(x[x[e+8>>2]>>2],x[e+12>>2])){break h}i:{if(!i){c=0;d=wf(x[a+52>>2],0);b=0;break i}d=x[a+52>>2];b=wf(d,i-1|0);g=x[b+16>>2];c=x[b+8>>2]+g|0;b=x[b+12>>2];d=wf(d,i);b=c>>>0<g>>>0?b+1|0:b}x[d+8>>2]=c;x[d+12>>2]=b}b=e+8|0;Pc(b,j,8);if(Hb(x[x[e+8>>2]>>2],x[e+12>>2])){w[e+30>>1]=0;zy(x[a+36>>2],e+30|0);Pc(b,j,9);Tm(x[a+36>>2],z[e+30>>1]<<Hb(x[x[e+8>>2]>>2],x[e+12>>2]))}i=i+1|0;continue}break}$d(e+8|0,x[a+36>>2]);b=x[e+20>>2];x[a+80>>2]=x[e+16>>2];x[a+84>>2]=b}d=e+8|0;Pc(d,j,4);If(d,1);f=x[a+80>>2];g=x[a+84>>2];b=x[a+96>>2];h=x[a+16>>2];i=b+h|0;k=x[a+100>>2];c=k+x[a+20>>2]|0;c=i>>>0<h>>>0?c+1|0:c;h=i;i=(b|0)==x[a+72>>2]&(k|0)==x[a+76>>2];b=i?f:h;x[a+88>>2]=b;c=i?g:c;x[a+92>>2]=c;Hi(x[a+36>>2],b,c,0);Pc(d,j,6);if(Hb(x[x[e+8>>2]>>2],x[e+12>>2])){break a}Pc(e,j,7);if(!(Hb(x[x[e>>2]>>2],x[e+4>>2])|x[a+8>>2])){break a}c=x[a+88>>2];d=x[a+16>>2];b=c-d|0;f=x[a+92>>2]-(x[a+20>>2]+(c>>>0<d>>>0)|0)|0;j=x[a+52>>2];g=x[a+104>>2];a=0;while(1){if((a|0)==(g|0)){break a}c=wf(j,a);d=c;h=x[c+8>>2];i=h+b|0;c=x[c+12>>2]+f|0;x[d+8>>2]=i;x[d+12>>2]=i>>>0<h>>>0?c+1|0:c;a=a+1|0;continue}}Qh(a,2,2048);break a}Qh(a,2,2048)}fb=e+32|0}function hta(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0;f=fb-320|0;fb=f;xc(b);d=fb-16|0;fb=d;h=f+102|0;L_(d+8|0,h);g=x[d+12>>2];lc(d,x[b>>2],x[b+8>>2],x[d+8>>2],x[d+12>>2]);i=x[d+4>>2];if((i|0)==(g|0)){Vb(b,x[d+12>>2])}fb=d+16|0;a:{b:{c:{if((g|0)!=(i|0)){break c}if(!N_(h)){break c}if(!Mb(x[b>>2],x[b+8>>2],Bc(M_(y[f+318|0],y[f+319|0]),hb))){break c}e=1;if((c|0)==64){break c}Bd(a,2);gg(a);x[a+480188>>2]=524296;t=a,u=Ze(455e3),x[t+480204>>2]=u;Lb(a+1074312|0,110,1);x[a+480208>>2]=x[a+480208>>2]|16777216;d=f+72|0;Ve(d,2,f+133|0);e=f+88|0;Cc(e,d);Ab(a+1298308|0,e);tb(e);e=0;d:{e:{while(1){if((e|0)==8){f:{d=Xb(x[a+484360>>2],y[a+484376|0]);o=y[f+318|0];m=o+1|0;fk(d,b,m,65535,65535);d=Nb(f+88|0);x[31737]=0;S(235,b|0,d|0,m|0);e=x[31737];x[31737]=0;if((e|0)==1){break f}t=f,u=wb(x[d>>2]),x[t+72>>2]=u;e=wb(x[d+4>>2]);while(1){g=x[f+72>>2];q=Ib(g,e);if(q){if((y[g|0]-1&255)>>>0>7){break d}le(f+72|0);continue}break}t=a,u=y[xb(x[d>>2],0)|0],x[t+480196>>2]=u;e=y[f+317|0];h=y[f+319|0];g=Nb(f+72|0);x[31737]=0;n=h+1|0;S(235,b|0,g|0,n|0);h=x[31737];x[31737]=0;g:{if((h|0)==1){break g}x[31737]=0;h=a+484344|0;O(224,h|0,n|0);i=x[31737];x[31737]=0;if((i|0)==1){break g}r=e+1|0;if(!(c&1)){break e}c=0;while(1){if((c|0)==(n|0)){break e}e=y[xb(x[g>>2],c)|0];x[31737]=0;e=U(197,h|0,e|0,r|0)|0;i=x[31737];x[31737]=0;h:{if((i|0)!=1){if(!e){break e}i=0;l=Wb(x[h>>2],y[xb(x[g>>2],c)|0]);i:while(1){s=i&65535;if(s>>>0>7){break h}i=i+1|0;e=0;while(1){if(A[l+12>>2]<=e>>>0){continue i}x[31737]=0;j=R(198,b|0)|0;k=x[31737];x[31737]=0;j:{k:{if((k|0)!=1){j=j<<24>>24;if((j|0)>=0){break k}e=(j&127)+e|0;break j}break b}k=jd(x[l>>2],x[x[l+48>>2]+12>>2],e,s);if((j|0)==1){v[k|0]=254;break j}if((j-1&255)>>>0>96){break j}v[k+1|0]=i;v[k|0]=j+12}e=e+1|0;continue}}}break b}c=c+1|0;continue}}break b}}else{h=f+88|0;d=(f+102|0)+D(e,19)|0;ND(h,d+63|0);g=f+72|0;Cc(g,h);om(((e<<5)+a|0)+480289|0,g);tb(g);e=e+1|0;i=D(e,104)+a|0;j=i+484380|0;ld(j,2);v[f+83|0]=0;g=y[d+78|0]|y[d+79|0]<<8|(y[d+80|0]<<16|y[d+81|0]<<24);v[f+79|0]=g;v[f+80|0]=g>>>8;v[f+81|0]=g>>>16;v[f+82|0]=g>>>24;g=y[d+75|0]|y[d+76|0]<<8|(y[d+77|0]<<16|y[d+78|0]<<24);d=y[d+71|0]|y[d+72|0]<<8|(y[d+73|0]<<16|y[d+74|0]<<24);x[f+16>>2]=x[f+80>>2];x[f+72>>2]=d;x[f+76>>2]=g;d=x[f+76>>2];x[f+8>>2]=x[f+72>>2];x[f+12>>2]=d;Yk(j,1,f+8|0);x[i+484404>>2]=8215;d=f+60|0;Cc(d,h);zc(((e<<5)+a|0)+946304|0,d);tb(d);continue}break}e=N()|0;break a}i=o+1|0;e=0;while(1){l:{if((e|0)==(i|0)){x[31737]=0;b=P(1,f+60|0,8632)|0;c=x[31737];x[31737]=0;if((c|0)!=1){break l}break b}b=Xb(x[a+484360>>2],y[a+484376|0]);j=e&65535;m:{if(!bj(b,j)){x[31737]=0;c=P(368,h|0,r|0)|0;b=x[31737];x[31737]=0;if((b|0)==1){break b}if((c|0)==65535){break m}b=Xb(x[a+484360>>2],y[a+484376|0]);t=_b(x[b>>2],e),u=c,w[t>>1]=u}b=MD(wb(x[Wb(x[h>>2],z[_b(x[b>>2],e)>>1])+4>>2]),1);c=y[b+5|0];l=y[xb(x[d>>2],(e+1>>>0)%(m>>>0)|0)|0];if((c|0)==(l|0)){break m}n:{if(y[b+3|0]!=16){break n}c=y[a+484376|0];k=x[a+484360>>2];x[31737]=0;c=P(369,Xb(k,c)|0,j|0)|0;j=x[31737];x[31737]=0;if((j|0)==1){break b}if((c|0)==65535){break n}b=MD(wb(x[Wb(x[h>>2],c)+4>>2]),1)}v[b+5|0]=l;v[b+3|0]=16}e=e+1|0;continue}break}Ab(a+1298344|0,b);tb(b);x[31737]=0;b=P(1,f+48|0,6049)|0;c=x[31737];x[31737]=0;if((c|0)==1){break b}Ab(a+1298356|0,b);tb(b);c=f+24|0;vi(c,2,f+113|0);x[31737]=0;b=f+36|0;S(370,b|0,4,c|0);c=x[31737];x[31737]=0;if((c|0)==1){break b}Ab(a+1298368|0,b);tb(b);t=a+1298404|0,u=x[Fc(b,4)>>2],x[t>>2]=u;dc(g)}dc(d);e=q^1}fb=f+320|0;return e|0}e=N()|0;dc(g)}dc(d);Q(e|0);p()}function bS(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;j=fb-16|0;fb=j;a:{b:{c:{if(!Sc(c)|!d|x[b+480180>>2]!=16777216|z[b+480192>>1]<d>>>0){break c}d=x[((d<<2)+b|0)+900380>>2];if(!d){break c}d=x[d+44>>2];if(!d){break c}w[j+14>>1]=c-61;b=fb+-64|0;fb=b;d:{e:{e=w[d+28>>1];i=j+14|0;c=w[i>>1];if((e|0)<=(c|0)){if((c|0)<=(oc(x[d+4>>2],x[d+8>>2])+e|0)-1<<16>>16){break e}}Fb(a);break d}f:{e=z[d+30>>1];if(!e){c=d+52|0;d=iA(c,i);if(!Zg(d,Rf(c))){break f}Bm(a,td(d)+4|0);break d}e=hA(c,e<<16>>16);w[b+62>>1]=e;c=Fb(a);g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{a=d+52|0;f=iA(a,b+62|0);t:{if(Zg(f,Rf(a))){x[31737]=0;O(130,c|0,td(f)+4|0);a=x[31737];x[31737]=0;if((a|0)==1){break t}a=w[d+30>>1];d=w[i>>1];x[31737]=0;n=b,o=gA(d,a)+5|0,x[n+36>>2]=o;a=b+48|0;O(127,a|0,b+36|0);d=x[31737];x[31737]=0;u:{if((d|0)!=1){x[31737]=0;P(75,c|0,a|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break u}tb(a);break d}a=N()|0;break g}a=N()|0;tb(b+48|0);break g}if(w[d+30>>1]>26){break q}x[31737]=0;e=U(543,b+36|0,1,e+65<<24>>24)|0;a=x[31737];x[31737]=0;if((a|0)==1){break s}x[31737]=0;a=b+48|0;S(603,a|0,0,e|0);f=x[31737];x[31737]=0;if((f|0)==1){break r}f=Ab(c,a);tb(a);tb(e);x[31737]=0;P(128,f|0,14690)|0;a=x[31737];x[31737]=0;if((a|0)!=1){break p}}a=N()|0;break g}a=N()|0;break g}a=N()|0;tb(e);break g}x[31737]=0;g=e<<16>>16;a=(g|0)/16|0;x[b+32>>2]=e-(a<<4)<<16>>16;e=b+36|0;O(884,e|0,b+32|0);f=x[31737];x[31737]=0;if((f|0)==1){break o}x[31737]=0;x[b+16>>2]=(a<<16>>16)%16;a=b+20|0;O(884,a|0,b+16|0);f=x[31737];x[31737]=0;if((f|0)==1){break n}x[31737]=0;f=b+48|0;S(2,f|0,e|0,a|0);h=x[31737];x[31737]=0;if((h|0)==1){break m}k=Ab(c,f);tb(f);tb(a);tb(e);if((g|0)<256){break p}x[31737]=0;g=b+4|0;O(885,g|0,k|0);a=x[31737];x[31737]=0;if((a|0)==1){break k}h=zd(g);l=Df(g);m=zd(g);a=fb-16|0;fb=a;x[a+8>>2]=m;x[a+12>>2]=h;while(1){if(Ib(h,l)){n=x[a+8>>2],o=Oq(v[h|0]),v[n|0]=o;h=le(a+12|0);le(a+8|0);h=x[h>>2];continue}break}fb=a+16|0;_c(e,g);x[31737]=0;S(603,f|0,0,e|0);a=x[31737];x[31737]=0;if((a|0)==1){break j}Ab(k,f);tb(f);tb(e);tb(g)}a=w[d+30>>1];d=w[i>>1];x[31737]=0;n=b,o=gA(d,a)+5|0,x[n+20>>2]=o;a=b+48|0;O(127,a|0,b+20|0);d=x[31737];x[31737]=0;if((d|0)==1){break i}x[31737]=0;P(75,c|0,a|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break h}tb(a);break d}a=N()|0;break g}a=N()|0;break l}a=N()|0;tb(b+20|0)}tb(b+36|0);break g}a=N()|0;break g}a=N()|0;tb(b+36|0);tb(b+4|0);break g}a=N()|0;break g}a=N()|0;tb(b+48|0)}tb(c);Q(a|0);p()}f=fb-16|0;fb=f;e=f+4|0;c=fb-32|0;fb=c;d=rf(c+20|0,1,0);v:{while(1){g=Jb(d);ws(c+12|0,g,Cb(x[d+4>>2],y[d+11|0])+g|0,w[i>>1]);if(!x[c+16>>2]){break v}g=qi(Cb(x[d+4>>2],y[d+11|0]));x[31737]=0;O(45,d|0,g|0);g=x[31737];x[31737]=0;if((g|0)!=1){continue}break}break a}g=x[c+12>>2];i=Jb(d);x[31737]=0;O(46,d|0,g-i|0);g=x[31737];x[31737]=0;w:{if((g|0)!=1){x[31737]=0;O(47,e|0,d|0);g=x[31737];x[31737]=0;if((g|0)!=1){break w}break a}break a}tb(d);fb=c+32|0;Sh(a,e);tb(e);fb=f+16|0}fb=b- -64|0;break b}e=x[b>>2];b=fb-32|0;fb=b;x:{if(Ml(c)){x[b+16>>2]=x[7640];d=x[7639];x[b+8>>2]=x[7638];x[b+12>>2]=d;d=x[7637];x[b>>2]=x[7636];x[b+4>>2]=d;tc(a,(b+(c<<2)|0)-1004|0);break x}if(Sc(c)){d=Fb(b);x[31737]=0;c=c-1|0;f=(c|0)/12|0;c=P(886,d|0,e+(D(f,-12)+c<<16>>16<<2)|0)|0;e=x[31737];x[31737]=0;y:{if((e|0)==1){break y}x[31737]=0;c=P(887,c|0,f+48&255)|0;e=x[31737];x[31737]=0;if((e|0)==1){break y}x[31737]=0;P(3,a|0,c|0)|0;a=x[31737];x[31737]=0;if((a|0)==1){break y}tb(c);break x}break a}if(!c){tc(a,16811);break x}tc(a,14661)}fb=b+32|0}fb=j+16|0;return}a=N()|0;tb(d);Q(a|0);p()}function MS(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=fb-16|0;fb=f;g=a+1074376|0;h=D(b,872);e=(g+h|0)+616|0;d=c&15;a:{b:{switch(c-16>>>4|0){case 0:a=(a+h|0)+1075080|0;x[a>>2]=x[a>>2]&-1048577|((d|0)!=0)<<20;break a;case 1:if(!(y[a+480209|0]&16)){break a}if(Rj(x[e+656>>2])){a=D(b,872)+a|0;w[a+1075764>>1]=d-8;a=a+1075843|0;v[a|0]=y[a|0]|64;break a}if(x[a+480180>>2]!=64){b=D(b,872)+a|0;c=d<<28>>24;w[b+1075764>>1]=c;e=z[(d<<1)+31760>>1];x[b+1075696>>2]=e;d=b+1075692|0;if(!x[d>>2]){break a}l=d,m=wh(a,y[b+1075789|0],c,e),x[l>>2]=m;break a}a=D(b,872)+a|0;b=x[a+1075096>>2];if(!b){break a}x[a+1075696>>2]=x[b+24>>2]+D(d,80);break a;case 2:if(x[a+480180>>2]==2){v[(D(b,872)+a|0)+1075814|0]=c&3;break a}Kb(f+8|0,a+1074312|0,21);if(Hb(x[x[f+8>>2]>>2],x[f+12>>2])){v[(D(b,872)+a|0)+1075814|0]=d>>>0<4?d:0;break a}v[(D(b,872)+a|0)+1075814|0]=c&7;break a;case 3:if(x[a+480180>>2]==2){v[(D(b,872)+a|0)+1075817|0]=c&3;break a}Kb(f+8|0,a+1074312|0,21);if(Hb(x[x[f+8>>2]>>2],x[f+12>>2])){v[(D(b,872)+a|0)+1075817|0]=d>>>0<4?d:0;break a}v[(D(b,872)+a|0)+1075817|0]=c&7;break a;case 4:Kb(f+8|0,a+1074312|0,21);if(Hb(x[x[f+8>>2]>>2],x[f+12>>2])){a=D(b,872)+a|0;v[a+1075813|0]=0;v[a+1075820|0]=d>>>0<4?d:0;break a}v[(D(b,872)+a|0)+1075820|0]=c&7;break a;case 5:if(x[a+1074392>>2]|!(y[a+480209|0]&16)){break a}a=a+1074400|0;x[a>>2]=x[a>>2]+d;break a;case 6:if(!(y[a+480209|0]&16)){break a}if(d>>>0<=2){c=z[a+480188>>1];h=c>>>0<=256?256:c;i=a+906300|0;j=b+1|0;k=d-1|0;while(1){if((c|0)==(h|0)){break a}e=D(c,872)+a|0;c:{if((j|0)!=z[e+1075778>>1]){break c}d:{e:{switch(k|0){case 0:Jo(a,e+1074992|0);if(!(y[e+1075081|0]&2)){break d}d=x[a+1298300>>2];if(!Dd(d)){break d}Dk(d,c&65535);break d;case 1:g=e+1075080|0;d=x[g>>2];x[g>>2]=d|4096;if(!(d&512)){break d}d=x[a+1298300>>2];if(!Dd(d)){break d}Dk(d,c&65535);break d;default:break e}}x[e+1075688>>2]=0;g=e+1075080|0;d=x[g>>2];x[g>>2]=d|4096;if(!(d&512)){break d}d=x[a+1298300>>2];if(!Dd(d)){break d}Lj(d,c&65535,1)}d=x[e+1075648>>2];if(!d){break c}g=y[d+34|0];if(!g){break c}g=x[vd(i,g-1|0)>>2];if(!g){break c}ib[x[x[g>>2]+96>>2]](g,d,y[e+1075789|0]|256,0,b)}c=c+1|0;continue}}qV(e,d,x[a+480180>>2]);break a;case 7:if(!(y[a+480209|0]&16)){break a}dn(a,e,d,4);break a;case 8:b=x[a+480208>>2];f:{if(!(b&4096)){break f}g:{switch(d|0){case 0:x[e+88>>2]=x[e+88>>2]&-257;break f;case 1:x[e+692>>2]=128;x[e+88>>2]=x[e+88>>2]|256;break f;case 8:x[e+88>>2]=x[e+88>>2]&-25165825|16777216;break f;case 9:x[e+88>>2]=x[e+88>>2]&-25165825|8388608;break f;case 10:x[a+480208>>2]=b&-16385;break f;case 11:x[a+480208>>2]=b|16384;break f;case 12:x[a+480208>>2]=b&-8193;break f;case 13:x[a+480208>>2]=b|8192;break f;case 14:x[e+88>>2]=x[e+88>>2]&-129;break f;case 15:break g;default:break f}}h:{if(x[e>>2]|x[e+4>>2]){break h}a=x[e+76>>2];if(!a){break h}if(!(l=Sc(y[e+788|0]),m=1,n=y[e+88|0]&2,n?l:m)){break h}x[e>>2]=-1;x[e+4>>2]=a-1}x[e+88>>2]=x[e+88>>2]|128}break a;case 9:if(!(y[a+480209|0]&16)){break a}b=D(b,872)+a|0;v[b+1075828|0]=d;Kb(f+8|0,a+1074312|0,35);if(Hb(x[x[f+8>>2]>>2],x[f+12>>2])){break a}if(!Sc(y[b+1075780|0])){break a}a=d<<16;if(a>>>0>=A[b+1075068>>2]){break a}x[e+4>>2]=a;break a;case 10:if(!(y[a+480209|0]&16)){break a}uB(a,g,b,d);break a;case 11:i:{if(d){break i}d=1;c=x[a+480180>>2];if(c&16777248){break i}d=0;if((c|0)==2){break a}}Kb(f+8|0,a+1074312|0,30);cB(a,b,d,Hb(x[x[f+8>>2]>>2],x[f+12>>2])|x[a+480180>>2]==2);break a;case 14:break b;default:break a}}if(x[a+480180>>2]==2){break a}v[(D(b,872)+a|0)+1075836|0]=d}fb=f+16|0}function jta(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0;f=fb-960|0;fb=f;xc(b);d=fb-16|0;fb=d;e=f+862|0;T_(d+8|0,e);g=x[d+12>>2];lc(d,x[b>>2],x[b+8>>2],x[d+8>>2],x[d+12>>2]);h=x[d+4>>2];if((h|0)==(g|0)){Vb(b,x[d+12>>2])}fb=d+16|0;d=(g|0)==(h|0);if(!d){S_(e)}a:{if(!d){break a}if(!V_(e)){break a}if(!Mb(x[b>>2],x[b+8>>2],Bc(U_(y[f+909|0]|y[f+910|0]<<8),hb))){break a}l=1;if((c|0)==64){break a}Bd(a,512);x[a+480228>>2]=32;w[a+480188>>1]=16;x[a+480196>>2]=y[f+937|0];x[a+480208>>2]=16;x[a+480200>>2]=256;x[a+480204>>2]=8e5;Lb(a+1074312|0,7,1);d=f+88|0;e=tc(d,8224);Ab(a+1298344|0,e);tb(e);e=tc(d,8928);Ab(a+1298356|0,e);tb(e);t=a+1298404|0,u=x[Fc(d,4)>>2],x[t>>2]=u;e=f+12|0;R_(e,f+866|0);Cc(d,e);Ab(a+1298308|0,d);tb(d);d=0;while(1){if((d|0)==16){b:{d=y[f+958|0]|y[f+959|0]<<8;if(d){hE(a+1298332|0,b,d,132,0)}d=fb-16|0;fb=d;e=f+88|0;bc(d+8|0,e,771);g=x[d+12>>2];lc(d,x[b>>2],x[b+8>>2],x[d+8>>2],x[d+12>>2]);h=x[d+4>>2];if((h|0)==(g|0)){Vb(b,x[d+12>>2])}fb=d+16|0;l=(g|0)==(h|0);if(!l){Rb(e,0,771)}if(!l){break a}d=a+484376|0;Q_(Xb(x[a+484360>>2],y[d|0]),e,y[f+345|0]);af(Xb(x[a+484360>>2],y[d|0]),y[f+346|0]);cd(b,y[f+909|0]|y[f+910|0]<<8);j=a+484344|0;q=c&1;e=0;while(1){c:{if((e|0)==256){if(!(c&2)){break a}u0(b,f+60|0);d=0;while(1){if((d|0)==64){break a}if(!(y[f+60+(d>>>3)|0]>>>(d&7)&1)){d=d+1|0;continue}c=f+12|0;if(!OD(b,c)){break a}d=d+1|0;w[a+480190>>1]=d;Ve(f,1,c);h=f+68|0;Cc(h,f);zc(((z[a+480190>>1]<<5)+a|0)+946304|0,h);tb(h);e=(D(d,104)+a|0)+484380|0;ld(e,0);j=y[c+32|0]|y[c+33|0]<<8|(y[c+34|0]<<16|y[c+35|0]<<24);x[e>>2]=j;g=y[c+38|0]|y[c+39|0]<<8|(y[c+40|0]<<16|y[c+41|0]<<24);x[e+4>>2]=g;i=y[c+42|0]|y[c+43|0]<<8|(y[c+44|0]<<16|y[c+45|0]<<24);x[e+24>>2]=16726;x[e+8>>2]=i;w[e+30>>1]=y[c+37|0]<<4;if(v[c+46|0]&1){i=i>>>1|0;x[e+8>>2]=i;g=g>>>1|0;x[e+4>>2]=g;x[e>>2]=j>>>1}if(!(!(y[c+47|0]&8)|g>>>0>=i>>>0)){w[e+34>>1]=z[e+34>>1]|2}Xc(h,v[f+58|0]&1?16:8,1,0,0);fg(h,e,b);continue}}d:{d=(e<<1)+f|0;h=y[d+347|0]|y[d+348|0]<<8;if(h){g=f+68|0;fe(g,b,h);i=ic(f+12|0,g);ub(g);n=((y[d+347|0]|y[d+348|0]<<8)-2|0)/64|0;e:{if(!q){break e}x[31737]=0;d=U(197,j|0,e&65535,n|0)|0;g=x[31737];x[31737]=0;if((g|0)==1){break d}if(!d){break e}x[31737]=0;d=R(198,i|0)|0;g=x[31737];x[31737]=0;if((g|0)==1){break b}x[31737]=0;P(184,i|0,1)|0;g=x[31737];x[31737]=0;if((g|0)==1){break b}r=d?d>>>0>=n-2>>>0?-1:d+1|0:-1;g=0;f:while(1){if((g|0)!=(n|0)){d=Wb(x[j>>2],e);bf(f+68|0,x[d>>2],x[x[d+48>>2]+12>>2],g);t=f,u=wb(x[f+68>>2]),x[t>>2]=u;s=jw(x[f+68>>2],x[f+72>>2]);while(1){d=x[f>>2];if(!Ib(d,s)){g=g+1|0;continue f}x[31737]=0;h=f+60|0;O(358,h|0,i|0);k=x[31737];x[31737]=0;if((k|0)==1){break c}m=$e(h);k=dj(h);o=y[f+60|0];if((o-1&255)>>>0<=71){v[d|0]=o+36;t=d,u=y[Jc(h)|0]+1|0,v[t+1|0]=u}h=y[m|0];if((h-1&255)>>>0<=15){v[d+2|0]=1;v[d+4|0]=(((h<<6)+-64&65472)>>>0)/15}m=y[k|0];h=m&15;v[d+5|0]=h;g:{h:{switch((y[k|0]>>>4|0)-1|0){case 0:case 1:v[d+5|0]=m|240;break g;case 2:v[d+5|0]=h<<2;break g;case 3:v[d+5|0]=(6/(h+1>>>0)|0)+1;break g;case 5:case 6:v[d+5|0]=h<<3;break g;case 9:v[d+2|0]=1;v[d+4|0]=(h<<2)+4;break g;case 10:v[d+5|0]=h|128;break g;case 11:break h;default:break g}}v[d+5|0]=(6/(h+1>>>0)|0)+1|13}v[d+3|0]=y[(y[k|0]>>>4|0)+24784|0];vg(f);continue}}break}ye(Wb(x[j>>2],e),Yh(Xe(Ne(f+68|0,14,0),r)))}ub(i)}e=e+1|0;continue}}break}}}else{e=(d<<5)+a|0;g=e+480280|0;We(g);h=g;g=(f+862|0)+d|0;x[h>>2]=!y[g+50|0]<<10;w[e+480284>>1]=(y[g+76|0]<<4|8)&248;d=d+1|0;continue}break}a=N()|0;ub(i);Q(a|0);p()}fb=f+960|0;return l|0}function y1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=fb-560|0;fb=f;xc(b);d=fb-16|0;fb=d;g=f+63|0;pF(d+8|0,g);e=x[d+12>>2];lc(d,x[b>>2],x[b+8>>2],x[d+8>>2],x[d+12>>2]);h=x[d+4>>2];if((h|0)==(e|0)){Vb(b,x[d+12>>2])}fb=d+16|0;d=(e|0)==(h|0);if(!d){oF(g)}a:{b:{if(!d){break b}if(!rF(g)){break b}d=1;if((c|0)==64){break a}if(!Mb(x[b>>2],x[b+8>>2],Bc(qF(y[f+173|0],y[f+174|0]),hb))){break b}Bd(a,64);x[a+480204>>2]=78e4;x[a+480260>>2]=112;x[a+480264>>2]=13696;x[a+480196>>2]=4;w[a+480188>>1]=8;Lb(a+1074312|0,7,1);d=f+36|0;g=tc(d,14703);Ab(a+1298344|0,g);tb(g);g=tc(d,14736);Ab(a+1298356|0,g);tb(g);bi(a+1298368|0,(y[f+63|0]|y[f+64|0]<<8)==26217?14703:14731);o=a+1298404|0,p=x[Fc(d,4)>>2],x[o>>2]=p;e=y[f+173|0];w[a+480190>>1]=e;g=1;while(1){h=g&65535;if(h>>>0<=e>>>0){e=fb-16|0;fb=e;d=f+36|0;bc(e+8|0,d,25);i=x[e+12>>2];lc(e,x[b>>2],x[b+8>>2],x[e+8>>2],x[e+12>>2]);j=x[e+4>>2];if((j|0)==(i|0)){Vb(b,x[e+12>>2])}fb=e+16|0;if((i|0)!=(j|0)){v[d|0]=0;v[d+1|0]=0;v[d+2|0]=0;v[d+3|0]=0;v[d+4|0]=0;v[d+5|0]=0;v[d+6|0]=0;v[d+7|0]=0;v[d+24|0]=0;v[d+16|0]=0;v[d+17|0]=0;v[d+18|0]=0;v[d+19|0]=0;v[d+20|0]=0;v[d+21|0]=0;v[d+22|0]=0;v[d+23|0]=0;v[d+8|0]=0;v[d+9|0]=0;v[d+10|0]=0;v[d+11|0]=0;v[d+12|0]=0;v[d+13|0]=0;v[d+14|0]=0;v[d+15|0]=0}if((y[f+49|0]|y[f+50|0]<<8|(y[f+51|0]<<16|y[f+52|0]<<24))>>>0>67108863){break b}e=(D(h,104)+a|0)+484380|0;ld(e,0);x[e+24>>2]=8363;j=y[d+13|0]|y[d+14|0]<<8|(y[d+15|0]<<16|y[d+16|0]<<24);x[e>>2]=j;k=y[d+17|0]|y[d+18|0]<<8|(y[d+19|0]<<16|y[d+20|0]<<24);x[e+4>>2]=k;i=y[d+21|0]|y[d+22|0]<<8|(y[d+23|0]<<16|y[d+24|0]<<24);x[e+8>>2]=i;c:{if(!(k|i>>>0<=j>>>0)){x[e+8>>2]=0;break c}if(i){w[e+34>>1]=2;_k(e)}}e=f+12|0;jk(e,2,d);d=f+24|0;Cc(d,e);zc(((h<<5)+a|0)+946304|0,d);g=g+1|0;tb(d);e=z[a+480190>>1];continue}break}g=f+24|0;e=f+65|0;wg(g,3,e,36);d=f+36|0;Cc(d,g);Ab(a+1298308|0,d);tb(d);g=0;mF(a+1298332|0,e,108,36,0);d=a+484376|0;Fw(Xb(x[a+484360>>2],y[d|0]),f+176|0,128,255,254);d=Xb(x[a+484360>>2],y[d|0]);e=y[f+175|0];if(z[_b(x[d>>2],e)>>1]<y[f+174|0]){af(d,e)}while(1)if((g|0)==8){i=a+484344|0;Vf(i,y[f+174|0]);n=c&1;h=0;while(1){d:{e:{if(y[f+174|0]<=h>>>0){d=1;if(!(c&2)){break a}c=Xc(f+36|0,8,1,0,1);g=1;break e}f:{if(n){if(Ng(i,h&65535,64)){break f}}Vb(b,1536);break d}x[f+24>>2]=-1;x[f+28>>2]=-1;j=0;g:while(1){if((j|0)==64){d=x[i>>2];g=(f+63|0)+h|0;e=y[g+369|0];if(e>>>0<63){ye(Wb(d,h),Yh(Xe(Ne(f+36|0,14,0),e)));d=x[i>>2]}ye(Wb(d,h),Yh(Ne(f+36|0,16,y[g+241|0])));break d}g=0;d=Wb(x[i>>2],h);e=jd(x[d>>2],x[x[d+48>>2]+12>>2],j,0);while(1){if((g|0)==8){j=j+1|0;continue g}d=f+36|0;Xr(d,b);k=Jc(d);l=$e(d);k=y[k|0];d=y[f+36|0];if(d>>>0<=253){v[e|0]=(d>>>2|0)+37;v[e+1|0]=(d<<4&48|k>>>4)+1;v[(f+24|0)+g|0]=255;d=y[f+36|0]}if((d&255)!=255){v[e+2|0]=1;v[e+4|0]=(((k&15)<<6|8)>>>0)/15}d=y[l|0];if((d|0)!=255){v[(f+24|0)+g|0]=d}k=(f+24|0)+g|0;h:{i:{if(!(d&15)&(d|0)!=48){break i}l=y[k|0];if((l|0)==255){break h}m=l<<24>>24;d=m&15;v[e+5|0]=d;j:{if((m|0)<0){break j}l=l>>>4|0;v[e+3|0]=y[l+24584|0];k:{switch(l-3|0){case 0:v[e+5|0]=d|32;break i;case 1:v[e+5|0]=d|m<<4;break h;case 2:break i;case 3:break k;default:break h}}l:{switch(d|0){case 0:v[e+5|0]=79;break h;case 1:break l;default:break j}}v[e+5|0]=244;break h}v[e+3|0]=0;break h}v[k|0]=255}e=e+6|0;g=g+1|0;continue}}}while(1){d=g&65535;if(d>>>0<=z[a+480190>>1]){fg(c,(D(d,104)+a|0)+484380|0,b);g=g+1|0;continue}break}d=1;break a}h=h+1|0;continue}}else{d=(g<<5)+a|0;We(d+480280|0);w[d+480284>>1]=g&1?208:48;g=g+1|0;continue}}d=0}fb=f+560|0;return d|0}function $A(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,B=0;f=fb-16|0;fb=f;g=D(b,872)+a|0;o=g;m=g+1075800|0;j=y[m|0];k=a+1074312|0;Kb(f+8|0,k,23);h=c&15;a:{b:{c:{d:{e:{f:{g:{h:{i:{if(Hb(x[x[f+8>>2]>>2],x[f+12>>2])){if(!(x[a+1074392>>2]|!y[g+1075780|0])){v[m|0]=h;break i}e=y[m|0];if(e){g=e-1|0;v[m|0]=g;e=0;if(g&255){break c}}v[m|0]=h;e=1;break c}Kb(f+8|0,k,52);g=c&256;if(!(!g|!Hb(x[x[f+8>>2]>>2],x[f+12>>2]))){g=x[a+480208>>2]&4096;if(!g){break e}e=D(b,872)+a|0;if(y[e+1075781|0]){j=_Z(y[e+1075780|0])?1:j}i=D(b,872)+a|0;if(y[i+1075784|0]?y[e+1075782|0]==1:0){break b}e=0;if(h>>>0>j>>>0){break c}if(!g){break d}if(Sc(y[i+1075780|0])){break c}break d}i=x[a+480180>>2];if(i&16777250){if(j){g=(j>>>0)%((h>>>0<=1?1:h)>>>0)|0}else{g=1}e=!g;j=j+1|0;break c}if((i|0)==16){break g}if((i|0)!=1){break f}e=A[a+1074392>>2]%A[a+1074416>>2]|0;if(!e){if(Sc(y[(D(b,872)+a|0)+1075780|0])){break a}}if(h){break h}}e=0;break c}e=!((e>>>0)%(h>>>0)|0);break c}e=x[a+1074392>>2]==(h|0)&(h|0)!=0;break c}j:{if(!g){break j}e=D(b,872)+a|0;if(y[e+1075782|0]!=1){break j}h=(y[e+1075785|0]>15)+h|0}k:{if(x[a+480208>>2]&4096?g:1){h=h>>>0<=1?1:h;e=0;if(!(!x[a+1074416>>2]|g)){e=!(A[a+1074392>>2]%(h>>>0)|0)}j=j+1|0;break k}e=0;j=i&1048580?0:j}l:{if((j&255)>>>0<h>>>0){break l}if(!x[a+1074392>>2]){if(y[(D(b,872)+a|0)+1075780|0]|!g){break l}}e=1}Kb(f+8|0,k,52);if(!Hb(x[x[f+8>>2]>>2],x[f+12>>2])|c){break c}e=!x[a+1074392>>2];break c}if(h>>>0>j>>>0){break c}}j=0;e=1}h=o+1074992|0;q=(D(b,872)+a|0)+1075068|0;m:{if(x[q>>2]){break m}Kb(f+8|0,k,38);if(!Hb(x[x[f+8>>2]>>2],x[f+12>>2])){break m}if(!Ij(x[h+656>>2])){break a}}Kb(f+8|0,k,106);if(Hb(x[x[f+8>>2]>>2],x[f+12>>2])){if(!x[(D(b,872)+a|0)+1075688>>2]){break a}}if(e){i=D(b,872)+a|0;r=i+1075680|0;g=x[r>>2];x[f+4>>2]=g;e=c>>>4&15;n:{if(!e){e=x[i+1075080>>2];break n}Kb(f+8|0,k,52);o:{if(Hb(x[x[f+8>>2]>>2],x[f+12>>2])){if(y[(D(b,872)+a|0)+1075782|0]==1){break o}}if(!(16191>>>e&1)){x[f+4>>2]=(D(g,v[e+32176|0])|0)/16;break o}x[f+4>>2]=g+(v[e+32192|0]<<2)}Fe(f+4|0,0,256);g=(D(b,872)+a|0)+1075080|0;e=x[g>>2]|2097152;x[g>>2]=e}l=D(b,872)+a|0;s=l+1075692|0;t=x[s>>2];g=y[l+1075794|0];i=0;if(e&512){Kb(f+8|0,k,108);i=Hb(x[x[f+8>>2]>>2],x[f+12>>2])}if(!((i^-1)&x[a+480180>>2]==2|(!x[q>>2]|(g-1&255)>>>0>119))){TS(a,b,0,g,1)}p:{if(!(x[a+480180>>2]&1048580)){o=0;break p}o=(c|0)<256;if((c|0)>255){break p}e=y[(D(b,872)+a|0)+1075781|0];if(!e){break p}o=1;Po(a,h,e,0,0,1)}l=l+1075080|0;Kb(f+8|0,k,85);q:{if(!Hb(x[x[f+8>>2]>>2],x[f+12>>2])){break q}e=D(b,872)+a|0;n=y[e+1075781|0];if(!n){break q}e=e+1075764|0;p=z[e>>1];Po(a,h,n,0,0,1);w[e>>1]=p}n=D(b,872)+a|0;p=n+1075652|0;u=x[p>>2];B=x[l>>2];x[p>>2]=0;Kb(f+8|0,k,23);e=1;r:{if(Hb(x[x[f+8>>2]>>2],x[f+12>>2])){break r}e=0;if(x[a+480180>>2]!=2){break r}e=(i^1)&x[q>>2]!=0}Qu(a,h,g,e,o,0,b);if(!y[n+1075781|0]){x[p>>2]=u}if(!(!(B&4096)|x[a+480180>>2]!=4)){x[l>>2]=x[l>>2]|4096}i=n+1075780|0;x[r>>2]=x[f+4>>2];if(z[a+480192>>1]){v[i|0]=g;RS(a,b)}g=x[a+480180>>2];if(!(!(g&16777248)|(y[i|0]|!t))){x[s>>2]=t}if(e){x[h>>2]=0;x[h+4>>2]=0}e=g&16777250;s:{if(d-11>>>0<4294967286){break s}g=D(b,872)+a|0;i=x[g+1075096>>2];if(!i){break s}t:{if((d|0)==1){b=x[g+1075656>>2];break t}g=(D(b,872)+a|0)+1075656|0;b=x[yb(i+68|0,d-2|0)>>2];x[g>>2]=b}Oo(a,h,b)}j=e?j:0}a=f+8|0;Kb(a,k,52);b=x[x[f+8>>2]>>2];d=x[f+12>>2];Kb(a,k,23);if(Hb(x[x[f+8>>2]>>2],x[f+12>>2])){break a}j=(Hb(b,d)&c>>>8)+j|0}v[m|0]=j}fb=f+16|0}function Us(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=fb-160|0;fb=e;x[e+148>>2]=-1;x[e+140>>2]=6;x[e+144>>2]=364;x[e+132>>2]=11;x[e+136>>2]=161;x[e+124>>2]=23;x[e+128>>2]=31;x[e+116>>2]=59;x[e+120>>2]=55;x[e+152>>2]=0;x[e+156>>2]=0;v[e+14|0]=c;v[e+13|0]=37;v[e+15|0]=0;l=b+484|0;i=b+460|0;j=b+172|0;k=b+4|0;f=e+16|0;h=f+(fa(f|0,100,e+13|0,e+116|0,x[b>>2])|0)|0;x[e+8>>2]=f;g=Fb(a);m=(c|0)!=120;a:while(1){b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{if((f|0)!=(h|0)){if(Jf(x[d+8>>2],1,v[f|0])){x[31737]=0;O(116,g|0,32);a=x[31737];x[31737]=0;if((a|0)==1){break c}a=x[d+8>>2];while(1){f=f+1|0;if((h|0)==(f|0)){f=h;break b}if(Jf(a,1,v[f|0])){continue}break}break b}x[e+4>>2]=f;x[31737]=0;x[e>>2]=0;a=ea(1342,e+4|0,h|0,k|0,j|0,d|0,e|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break c}p:{a=a-k|0;q:{if((a|0)<=167){x[31737]=0;O(116,g|0,37);c=x[31737];x[31737]=0;if((c|0)==1){break c}x[31737]=0;O(116,g|0,((a|0)<84?65:97)|0);a=x[31737];x[31737]=0;if((a|0)!=1){break q}break c}x[31737]=0;x[e+4>>2]=f;a=ea(1342,e+4|0,h|0,j|0,i|0,d|0,e|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break c}a=a-j|0;c=(a|0)/12|0;if((a|0)<=287){x[31737]=0;O(116,g|0,37);f=x[31737];x[31737]=0;if((f|0)==1){break c}x[31737]=0;O(116,g|0,((a|0)<144?66:98)|0);a=x[31737];x[31737]=0;if((a|0)==1){break c}if(m){break q}if(!Jf(x[d+8>>2],64,v[cc((D(c,12)+b|0)+172|0,0)|0])){break q}n=wz(g),o=109,v[n|0]=o;break q}if((Cb(x[b+464>>2],y[b+471|0])|0)==(0-Cb(x[b+476>>2],y[b+483|0])|0)){break p}x[31737]=0;x[e+4>>2]=f;a=ea(1342,e+4|0,h|0,i|0,l|0,d|0,e|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break c}if((a-i|0)>23){break p}x[31737]=0;O(116,g|0,37);a=x[31737];x[31737]=0;if((a|0)==1){break c}x[31737]=0;O(116,g|0,112);a=x[31737];x[31737]=0;if((a|0)==1){break c}}f=x[e+4>>2];break b}x[e+4>>2]=f;a=v[f|0];if(Jf(x[d+8>>2],64,a)){x[31737]=0;a=ba(1343,e+8|0,h|0,e|0,d|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break c}r:{s:{switch(a-6|0){case 2:case 3:case 4:break r;case 0:break e;case 1:break f;case 5:break g;case 6:break h;default:break s}}t:{switch(a-55|0){case 0:break k;case 4:break l;case 6:break m;case 1:case 2:case 3:case 5:break r;default:break t}}if((a|0)==23){break i}if((a|0)==31){break j}if((a|0)==364){break n}if((a|0)==2061){break o}}a=x[e+8>>2];while(1){if((a|0)==(f|0)){f=a;continue a}c=v[f|0];x[31737]=0;O(116,g|0,c|0);c=x[31737];x[31737]=0;if((c|0)==1){break c}f=f+1|0;continue}}u:{if((a|0)==37){x[31737]=0;O(116,g|0,37);a=x[31737];x[31737]=0;if((a|0)==1){break c}x[31737]=0;O(116,g|0,37);break u}x[31737]=0;O(116,g|0,a|0)}a=x[31737];x[31737]=0;if((a|0)==1){break c}f=f+1|0;break b}fb=e+160|0;return}x[31737]=0;O(116,g|0,37);a=x[31737];x[31737]=0;c=89;break d}x[31737]=0;O(116,g|0,37);a=x[31737];x[31737]=0;c=106;break d}x[31737]=0;O(116,g|0,37);a=x[31737];x[31737]=0;c=121;break d}x[31737]=0;O(116,g|0,37);a=x[31737];x[31737]=0;c=83;break d}x[31737]=0;O(116,g|0,37);a=x[31737];x[31737]=0;c=77;break d}x[31737]=0;O(116,g|0,37);a=x[31737];x[31737]=0;c=100;break d}x[31737]=0;O(116,g|0,37);a=x[31737];x[31737]=0;c=72;break d}x[31737]=0;O(116,g|0,37);a=x[31737];x[31737]=0;c=109;break d}x[31737]=0;O(116,g|0,37);a=x[31737];x[31737]=0;c=73;break d}x[31737]=0;O(116,g|0,37);a=x[31737];x[31737]=0;c=117;break d}x[31737]=0;O(116,g|0,37);a=x[31737];x[31737]=0;c=119}if((a|0)==1){break c}x[31737]=0;O(116,g|0,c|0);a=x[31737];x[31737]=0;if((a|0)==1){break c}f=x[e+8>>2];continue}a=N()|0;tb(g);Q(a|0);p()}x[e+8>>2]=f;continue}}function Ina(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;h=fb-48|0;fb=h;xc(b);a:{m=Zd(b);if((m-5&255)>>>0<253){break a}if(!Mb(x[b>>2],x[b+8>>2],4355)){break a}f=1;while(1){if((f&65535)>>>0<=256){k=h+32|0;gE(b,k);if(!FV(k,m)){break a}j=0;g=fb-32|0;fb=g;i=y[k+11|0];l=y[k+9|0]|y[k+10|0]<<8;v[g+14|0]=0;v[g+26|0]=i;w[g+24>>1]=l;w[g+12>>1]=0;while(1){if((j|0)!=3){i=y[xb(g+24|0,j)|0];o=xb(g+12|0,j),p=i,v[o|0]=p;j=j+1|0;continue}break}i=eg(g+12|0);l=y[k+8|0];k=y[k+6|0]|y[k+7|0]<<8;j=0;v[g+10|0]=0;v[g+18|0]=l;w[g+16>>1]=k;w[g+8>>1]=0;while(1){if((j|0)!=3){k=y[xb(g+16|0,j)|0];o=xb(g+8|0,j),p=k,v[o|0]=p;j=j+1|0;continue}break}j=eg(g+8|0);fb=g+32|0;d=i>>>0>j>>>0?f:d;f=f+1|0;continue}break}if(!(d&65535)){break a}e=1;if((c|0)==64){break a}Bd(a,1);w[a+480190>>1]=d;x[a+480228>>2]=(m|0)==3?192:48;x[a+480208>>2]=x[a+480208>>2]&-25165825|16777216;cd(b,1);k=d+1|0;j=k&65535;f=1;while(1)if((f|0)==(j|0)){cd(b,4097);fk(Xb(x[a+484360>>2],y[a+484376|0]),b,256,255,65535);e=0;f=Zd(b);if(f>>>0>31){break a}w[a+480188>>1]=f+1;f=Zd(b);d=z[a+480188>>1];g=f+1|0;if(!Mb(x[b>>2],x[b+8>>2],D(D(d,g),384)+d|0)){break a}while(1)if(z[a+480188>>1]<=e>>>0){j=a+484344|0;Vf(j,g);i=c&1;e=0;while(1){b:{if((e|0)!=(g|0)){c:{if(i){if(Ng(j,e&65535,64)){break c}}Vb(b,D(z[a+480188>>1],384));break b}l=bh(h+32|0);f=Wb(x[j>>2],e);o=h,p=wb(x[f>>2]),x[o+16>>2]=p;n=wb(x[f+4>>2]);while(1){f=x[h+16>>2];if(!Ib(f,n)){break b}d=h+20|0;__(d,b);d=y[xb(d,0)|0];if((d-1&255)>>>0<=76){v[f|0]=d+36}d=h+20|0;o=f,p=y[xb(d,1)|0],v[o+1|0]=p;d:{if(!EV(f,y[xb(d,2)|0],y[xb(d,5)|0],m)){break d}if(!EV(l,y[xb(d,3)|0],y[xb(d,4)|0],m)){break d}d=y[h+35|0];if(d){mm(h+14|0,f,y[f+3|0],y[f+5|0],d,y[h+37|0])}vg(h+16|0);continue}break}e=0;break a}e:{if(!(c&2)){break e}c=k&65535;f=1;while(1){if((c|0)==(f|0)){break e}d=D(f,104)+a|0;fg(Xc(h+32|0,w[d+484414>>1]&1?16:8,1,0,0),d+484380|0,b);f=f+1|0;continue}}bi(a+1298344|0,14231);bi(a+1298356|0,11152);sf(a+1298368|0);o=a+1298404|0,p=x[Fc(h+32|0,4)>>2],x[o>>2]=p;e=1;break a}e=e+1|0;continue}}else{f=(e<<5)+a|0;We(f+480280|0);o=f+480284|0,p=D(Zd(b),17),w[o>>1]=p;e=e+1|0;continue}}else{gE(b,h+32|0);e=0;d=fb-16|0;fb=d;g=(D(f,104)+a|0)+484380|0;ld(g,1);i=y[h+43|0];l=y[h+41|0]|y[h+42|0]<<8;v[d+6|0]=0;v[d+10|0]=i;w[d+8>>1]=l;w[d+4>>1]=0;while(1){if((e|0)!=3){i=y[xb(d+8|0,e)|0];o=xb(d+4|0,e),p=i,v[o|0]=p;e=e+1|0;continue}break}i=eg(d+4|0);l=y[h+40|0];n=y[h+38|0]|y[h+39|0]<<8;e=0;v[d+2|0]=0;v[d+10|0]=l;w[d+8>>1]=n;w[d>>1]=0;while(1){if((e|0)!=3){l=y[xb(d+8|0,e)|0];o=xb(d,e),p=l,v[o|0]=p;e=e+1|0;continue}break}o=g,p=i-eg(d)|0,x[o>>2]=p;i=y[h+34|0];l=y[h+32|0]|y[h+33|0]<<8;e=0;v[d+6|0]=0;v[d+10|0]=i;w[d+8>>1]=l;w[d+4>>1]=0;while(1){if((e|0)!=3){i=y[xb(d+8|0,e)|0];o=xb(d+4|0,e),p=i,v[o|0]=p;e=e+1|0;continue}break}o=g,p=eg(d+4|0)+1|0,x[o+4>>2]=p;i=y[h+37|0];l=y[h+35|0]|y[h+36|0]<<8;e=0;v[d+6|0]=0;v[d+10|0]=i;w[d+8>>1]=l;w[d+4>>1]=0;while(1){if((e|0)!=3){i=y[xb(d+8|0,e)|0];o=xb(d+4|0,e),p=i,v[o|0]=p;e=e+1|0;continue}break}o=g,p=eg(d+4|0)+1|0,x[o+8>>2]=p;e=y[h+45|0];i=e>>>2|0;i=z[g+34>>1]&-7|i&2|i&4;w[g+34>>1]=i;if(e&4){w[g+34>>1]=i|1;x[g>>2]=x[g>>2]>>>1}w[g+30>>1]=y[h+44|0];if((m|0)!=2){x[g+24>>2]=y[h+46|0]|y[h+47|0]<<8}DV(g);fb=d+16|0;d=Dc(h+20|0,22303);zc(((f<<5)+a|0)+946304|0,d);tb(d);f=f+1|0;continue}}fb=h+48|0;return e|0}function hla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=fb-96|0;fb=e;h=e+76|0;i=a+140|0;_j(h,i,1296125513);x[31737]=0;f=R(173,x[e+76>>2])|0;g=x[31737];x[31737]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{if((g|0)!=1){if(f){f=Fb(e+28|0);x[31737]=0;g=R(155,x[e+76>>2])|0;j=x[31737];x[31737]=0;if((j|0)==1){break p}x[31737]=0;S(817,h|0,f|0,g|0);h=x[31737];x[31737]=0;if((h|0)==1){break p}g=z[a+174>>1];x[31737]=0;h=e- -64|0;S(818,h|0,g|0,f|0);g=x[31737];x[31737]=0;if((g|0)==1){break o}x[31737]=0;g=e+4|0;S(819,g|0,c|0,h|0);c=x[31737];x[31737]=0;if((c|0)==1){break n}zc(d,g);tb(g);tb(h);tb(f)}if(y[a+176|0]){x[31737]=0;c=e+28|0;O(820,c|0,d|0);f=x[31737];x[31737]=0;if((f|0)==1){break e}ze(b+43|0,c);tb(c)}x[31737]=0;c=e+28|0;S(812,c|0,i|0,1413894985);f=x[31737];x[31737]=0;if((f|0)==1){break l}x[31737]=0;h=R(821,c|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break k}ub(c);f=a+40|0;xc(f);x[31737]=0;c=P(822,f|0,c|0)|0;g=x[31737];x[31737]=0;if((g|0)==1){break j}if(c){q:{if((y[e+56|0]|y[e+57|0]<<8|(y[e+58|0]<<16|y[e+59|0]<<24))>>>0<2){break q}x[31737]=0;c=e+4|0;g=P(823,f|0,c|0)|0;i=x[31737];x[31737]=0;if((i|0)==1){break i}if(!g){break q}HR(c,b+12|0,b+16|0,x[b>>2],b+34|0,8,16,h)}x[31737]=0;c=e+4|0;f=P(823,f|0,c|0)|0;g=x[31737];x[31737]=0;if((g|0)==1){break i}if(f){HR(c,b+4|0,b+8|0,x[b>>2],b+34|0,2,4,h)}c=y[e+40|0]|y[e+41|0]<<8|(y[e+42|0]<<16|y[e+43|0]<<24);v[b+42|0]=c&128?0:c+1|0;_k(b)}r:{if(y[b+42|0]){break r}c=x[a+60>>2];x[31737]=0;c=P(680,c|0,7)|0;f=x[31737];x[31737]=0;if((f|0)==1){break j}if(!c){break r}c=a+60|0;xc(c);x[31737]=0;c=P(824,c|0,e+4|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break d}if(!c){break r}c=v[e+4|0];v[b+42|0]=(c|0)>=0?c+1|0:0}c=x[a+120>>2];x[31737]=0;c=R(173,c|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break j}if(!c){break f}x[31737]=0;g=a+120|0;c=R(152,g|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break c}x[e+64>>2]=c;wc(e- -64|0,9);f=b+68|0;h=x[e+64>>2];c=0;while(1){if((c|0)==(h|0)){break g}x[31737]=0;O(825,g|0,e+4|0);i=x[31737];x[31737]=0;if((i|0)==1){break h}i=y[e+8|0]|y[e+9|0]<<8|(y[e+10|0]<<16|y[e+11|0]<<24);k=yb(f,c),l=i,x[k>>2]=l;c=c+1|0;continue}}a=N()|0;break a}a=N()|0;break m}a=N()|0;break m}a=N()|0;tb(e- -64|0)}tb(f);break a}a=N()|0;break a}a=N()|0;ub(e+28|0);break a}a=N()|0;break a}a=N()|0;break a}a=N()|0;break a}aA(f+(h<<2)|0,RZ(f),41188)}c=a+80|0;xc(c);x[31737]=0;f=P(826,c|0,e+4|0)|0;h=x[31737];x[31737]=0;s:{if((h|0)==1){break s}if(!f){break b}if(y[e+4|0]&32){w[b+34>>1]=z[b+34>>1]|32}w[e+64>>1]=z[e+8>>1];w[e+2>>1]=256;k=b,l=z[Nc(e- -64|0,e+2|0)>>1],w[k+28>>1]=l;w[e+64>>1]=z[e+10>>1];w[e+2>>1]=256;k=b,l=z[Nc(e- -64|0,e+2|0)>>1],w[k+30>>1]=l;w[e+64>>1]=z[e+12>>1];w[e+2>>1]=64;k=b,l=z[Nc(e- -64|0,e+2|0)>>1],w[k+32>>1]=l;v[b+38|0]=y[e+16|0];v[b+39|0]=y[e+17|0];v[b+40|0]=y[e+18|0];v[b+41|0]=y[e+19|0];f=x[a+88>>2];a=x[a+80>>2];x[31737]=0;a=U(151,a|0,f|0,32)|0;f=x[31737];x[31737]=0;if((f|0)==1){break s}if(!a){break b}x[31737]=0;O(827,c|0,d|0);a=x[31737];x[31737]=0;if((a|0)==1){break s}x[31737]=0;a=R(203,c|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break s}x[31737]=0;S(828,c|0,b+43|0,a|0);a=x[31737];x[31737]=0;if((a|0)!=1){break b}}a=N()|0;break a}a=N()|0;break a}a=N()|0;break a}a=N()|0;break a}ub(e+76|0);fb=e+96|0;return}ub(e+76|0);Q(a|0);p()}function Kta(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=fb-128|0;fb=f;xc(b);a:{d=f- -64|0;if(!Er(b,d)){break a}if(!q$(d)){break a}if(!Mb(x[b>>2],x[b+8>>2],p$(d))){break a}j=1;if((c|0)==64){break a}Bd(a,1);x[a+480208>>2]=x[a+480208>>2]|16777216;w[a+480188>>1]=y[f+109|0];w[a+480190>>1]=y[f+110|0];n=a,o=Bc((((y[f+113|0]<<8|48)&65328)>>>0)/100|0,0),x[n+480200>>2]=o;e=f+52|0;vi(e,3,f+69|0);d=f+16|0;Cc(d,e);Ab(a+1298308|0,d);tb(d);vi(e,3,f+89|0);Kr(d,4,e);Ab(a+1298320|0,d);tb(d);d=0;while(1)if(z[a+480188>>1]<=d>>>0){d=a+484376|0;fk(Xb(x[a+484360>>2],y[d|0]),b,y[f+111|0],65535,65535);w[f+50>>1]=0;d=Xb(x[a+484360>>2],y[d|0]);n=f,o=wb(x[d>>2]),x[n+16>>2]=o;d=wb(x[d+4>>2]);while(1){e=x[f+16>>2];if(Ib(e,d)){w[f+52>>1]=z[e>>1];n=f,o=z[pe(f+52|0,f+50|0)>>1],w[n+50>>1]=o;Md(f+16|0);continue}else{d=z[f+50>>1]+1|0;w[f+50>>1]=d;j=Mb(x[b>>2],x[b+8>>2],D(D(z[a+480188>>1],d&65535),264)+(z[a+480190>>1]<<5)|0);if(!j){break a}d=0;while(1){e=z[a+480188>>1];if(e>>>0<=d>>>0){Vb(b,D(e,z[f+50>>1]-1|0)<<3);d=1;while(1){i=d&65535;if(i>>>0>z[a+480190>>1]){k=a+484344|0;Vf(k,z[f+50>>1]);l=c&1;g=0;while(1){b:{c:{if(z[f+50>>1]<=g>>>0){if(!(c&2)){break c}d=1;while(1){c=d&65535;if(c>>>0>A[a+480228>>2]){break c}c=D(c,104)+a|0;fg(Xc(f+16|0,w[c+484414>>1]&1?16:8,1,0,0),c+484380|0,b);d=d+1|0;continue}}d:{if(l){if(Ng(k,g&65535,64)){break d}}Vb(b,z[a+480188>>1]<<8);break b}d=Wb(x[k>>2],g);n=f,o=wb(x[d>>2]),x[n+16>>2]=o;m=wb(x[d+4>>2]);while(1){d=x[f+16>>2];if(!Ib(d,m)){break b}e=f+52|0;sm(e,b);e:{if(!y[xb(e,1)|0]){break e}if(y[xb(e,1)|0]>168){break e}n=d,o=(y[xb(e,1)|0]>>>1|0)+36|0,v[n|0]=o}h=f+52|0;n=d,o=y[xb(h,0)|0],v[n+1|0]=o;e=y[xb(h,3)|0];v[d+5|0]=e;f:{if(y[xb(h,2)|0]==8){g:{switch(e>>>4|0){case 0:v[d+3|0]=19;v[d+5|0]=e|128;break f;case 1:v[d+3|0]=11;v[d+5|0]=e<<4;break f;case 2:v[d+3|0]=19;v[d+5|0]=e|160;break f;case 3:case 4:break g;default:break f}}v[d+3|0]=19;v[d+5|0]=e-32;break f}if(y[xb(f+52|0,2)|0]==19){v[d+3|0]=9;i=e<<1&254;h=i+128|0;h:{if(e>>>0<=64){break h}h=384-i|0;if(e<<24>>24>=0){break h}h=128-i|0;if(e>>>0<=191){break h}h=i-128|0}n=d,o=yi(h),v[n+5|0]=o;break f}if((y[xb(f+52|0,2)|0]&240)==32){v[d+3|0]=10;e=y[xb(f+52|0,2)|0];v[d+2|0]=1;v[d+4|0]=(e<<2&60)+4;break f}i:{if(y[xb(f+52|0,2)|0]<16){break i}if(y[xb(f+52|0,2)|0]==17){break i}if(y[xb(f+52|0,2)|0]!=18){break f}}e=d;d=f+52|0;Bf(e,y[xb(d,2)|0]&15,y[xb(d,3)|0])}vg(f+16|0);continue}}b=f+16|0;c=tc(b,9526);Ab(a+1298344|0,c);tb(c);c=tc(b,10157);Ab(a+1298356|0,c);tb(c);n=a+1298404|0,o=x[Fc(b,4)>>2],x[n>>2]=o;break a}g=g+1|0;continue}}else{e=f+16|0;Dr(b,e);h=fb-16|0;fb=h;v[h+15|0]=64;g=(D(i,104)+a|0)+484380|0;n=g,o=y[Qb(e+26|0,h+15|0)|0]<<2,w[n+30>>1]=o;v[g+37|0]=y[e+25|0]<<4;x[g>>2]=y[e+23|0]|y[e+24|0]<<8;x[g+4>>2]=y[e+27|0]|y[e+28|0]<<8;x[g+8>>2]=(y[e+29|0]|y[e+30|0]<<8)+(y[e+27|0]|y[e+28|0]<<8);w[g+34>>1]=z[g+34>>1]&65532|((y[e+29|0]|y[e+30|0]<<8)>>>0>2)<<1|y[e+22|0]==16;fb=h+16|0;g=f+4|0;Xk(g,3,e);e=f+52|0;Cc(e,g);zc(((i<<5)+a|0)+946304|0,e);d=d+1|0;tb(e);continue}}}else{e=f+4|0;o$(e,b);g=f+52|0;uF(g,e);e=f+16|0;Cc(e,g);om(((d<<5)+a|0)+480289|0,e);d=d+1|0;tb(e);continue}}}}}else{e=(d<<5)+a|0;We(e+480280|0);n=e+480284|0,o=D(Zd(b)&15,17),w[n>>1]=o;d=d+1|0;continue}}fb=f+128|0;return j|0}function Woa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;f=fb-176|0;fb=f;xc(b);d=f+128|0;a:{if(!OD(b,d)){break a}if(!YW(d)){break a}if(!Mb(x[b>>2],x[b+8>>2],Bc(XW(y[f+159|0],y[f+161|0]),hb))){break a}e=1;if((c|0)==64){break a}Bd(a,256);g=f+16|0;vi(g,2,d);d=f+48|0;Cc(d,g);Ab(a+1298308|0,d);tb(d);e=tc(d,15441);Ab(a+1298344|0,e);tb(e);e=tc(d,10136);Ab(a+1298356|0,e);tb(e);ig(g,4271);x[31737]=0;e=f+116|0;O(250,e|0,f+159|0);h=x[31737];x[31737]=0;b:{c:{if((h|0)!=1){x[31737]=0;V(702,d|0,g|0,f+158|0,e|0);h=x[31737];x[31737]=0;if((h|0)!=1){Ab(a+1298368|0,d);tb(d);tb(e);Eb(g);o=a+1298404|0,q=x[Fc(d,4)>>2],x[o>>2]=q;d=Lb(a+1074312|0,107,1);x[a+480260>>2]=64;x[a+480264>>2]=32767;x[a+480188>>2]=2031620;Lb(d,107,1);e=y[f+160|0];d=y[f+159|0];if(d>>>0<=20){g=((e&255)>>>0)/10|0;e=g<<4|D(g,-10)+e}g=(e&255?e:96)&255;e=xC(g);x[a+480196>>2]=g>>>4;x[a+480204>>2]=e;if(d>>>0>=11){v[f+48|0]=64;o=a,q=y[Qb(f+162|0,f+48|0)|0]<<2,x[o+480200>>2]=q}e=0;while(1)if((e|0)==4){e=1;while(1){if((e|0)!=32){d=f+16|0;Dr(b,d);g=y[f+28|0];if(g?(g|0)!=46:0){break b}h=fb-32|0;fb=h;g=(D(e,104)+a|0)+484380|0;ld(g,0);j=h+8|0;Pk(j,2,d);i=h+20|0;Cc(i,j);ze(g+43|0,i);tb(i);x[g+24>>2]=y[d+24|0]|y[d+25|0]<<8;v[h+20|0]=y[d+22|0];v[h+8|0]=64;o=g,q=y[Qb(i,j)|0]<<2,w[o+30>>1]=q;i=y[d+16|0]|y[d+17|0]<<8;x[g>>2]=i;j=y[d+18|0]|y[d+19|0]<<8;x[g+4>>2]=j;k=y[d+20|0]|y[d+21|0]<<8;x[g+8>>2]=k;d:{if(i>>>0<=1){x[g>>2]=0;break d}if((k|0)==65535|i>>>0<=j>>>0|j>>>0>=k>>>0){break d}w[g+34>>1]=2;o=g,q=x[Gb(g+8|0,g)>>2],x[o+8>>2]=q}fb=h+32|0;g=f+4|0;Pk(g,2,d);d=f+116|0;Cc(d,g);zc(((e<<5)+a|0)+946304|0,d);tb(d);w[((e<<1)+f|0)+46>>1]=y[f+30|0]|y[f+31|0]<<8;e=e+1|0;continue}break}d=a+484376|0;fk(Xb(x[a+484360>>2],y[d|0]),b,y[f+159|0]?128:64,65535,65535);e=0;if(!VW(Xb(x[a+484360>>2],y[d|0]))){break a}m=c&1;if(m){Vf(a+484344|0,y[f+161|0])}j=a+484344|0;h=0;while(1)if(y[f+161|0]<=h>>>0){e=1;if(!(c&2)){break a}c=Xc(f+16|0,8,1,0,0);while(1)if((e|0)==32){e=1;break a}else{d=D(e,104)+a|0;g=d+484380|0;e:{if(!x[g>>2]|!z[d+484410>>1]){break e}d=z[((e<<1)+f|0)+46>>1];if(d>>>0<4){break e}if(!cd(b,d<<4)){break e}fg(c,g,b)}e=e+1|0;continue}}else{f:{g:{if(m){if(Ng(j,h&65535,64)){break g}}e=0;while(1){if((e|0)==256){break f}if((Zd(b)+2&255)>>>0<=252){Vb(b,3)}e=e+1|0;continue}}o=f,q=wb(x[Wb(x[j>>2],h)>>2]),x[o+116>>2]=q;w[f+2>>1]=65535;x[f+4>>2]=63;i=0;h:while(1){e=0;if((i|0)==64){d=z[f+2>>1];if((d|0)==65535){break f}ye(Wb(x[j>>2],h),Gn(Xe(Ne(f+16|0,12,d&255),x[f+4>>2])));break f}while(1){i:{j:{k:{if((e&65535)>>>0<=3){d=0;k=0;l=0;n=0;l:{m:{n:{o:{g=Zd(b);switch(g-251|0){case 1:break i;case 0:break m;case 2:break o;default:break n}}v[x[f+116>>2]]=254;break i}d=f+16|0;Xr(d,b);k=y[xb(d,0)|0];l=y[xb(d,1)|0];n=y[xb(d,2)|0];d=254;if((g|0)==254){break l}if(g>>>0>=96){break k}d=g}d=(D(d>>>4|0,12)+(d&15)|0)+37|0}g=d;d=x[f+116>>2];v[d|0]=g;break j}i=i+1|0;continue h}d=x[f+116>>2]}v[d+1|0]=(k&248)>>>3;g=l>>>1&120|k&7;if(g>>>0<=64){v[d+4|0]=g;v[d+2|0]=1}v[d+5|0]=n;UW(d,l&15,i,y[f+159|0],f+2|0,f+4|0)}e=e+1|0;IC(f+116|0);continue}}}h=h+1|0;continue}}else{d=(e<<5)+a|0;We(d+480280|0);w[d+480284>>1]=e&1?64:192;e=e+1|0;continue}}e=N()|0;tb(f+116|0);break c}e=N()|0}Eb(f+16|0);Q(e|0);p()}e=0}fb=f+176|0;return e|0}function Lka(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,A=0,B=0,C=0,F=0,G=0,H=0,I=0;l=fb-32|0;fb=l;s=x[a+4>>2];k=Ue(x[a+8>>2],b);t=x[k>>2];a:{if(t+1>>>0<2){break a}h=D(b,872)+s|0;i=h+616|0;if(!(Ti(x[i+8>>2],x[i+12>>2])|y[k+4|0])|!x[h+720>>2]){break a}j=x[h+704>>2]&2;f=x[(j?h+700|0:h+692|0)>>2];n=x[h+700>>2];e=x[h+696>>2];u=Ob(x[a>>2]+1074312|0,31);g=vf(x[h+624>>2],x[h+628>>2],c);m=y[h+704|0]&128;k=m?0-g|0:g;o=hb;m=m?0-(o+((g|0)!=0)|0)|0:o;g=0;o=f;f=j;w=f?g:0;r=f?e:0;n=n-e|0;B=n<<1;C=h+1316|0;p=h+1467|0;A=h+1362|0;F=(y[A|0]&17)!=1;b:{c:{while(1){if((q|0)!=(t|0)){d:{if(d>>>0>q>>>0){f=(y[A|0]&17)==1;break d}x[x[a+4>>2]+16>>2]=q-d;v[p|0]=y[p|0]&254|(d|0)==(q|0);f=x[a>>2];j=x[a+4>>2];e=Wb(x[f+484344>>2],z[j+70>>1]);e=jd(x[e>>2],x[x[e+48>>2]+12>>2],x[j+48>>2],b);g=y[e+3|0];e:{f:{switch(y[e+2|0]-11|0){case 0:j=l+8|0;vB(j,f,g,y[e+4|0],0);j=$e(j);Nu(x[a>>2],x[a+4>>2],b,z[l+8>>1]);f=1;if(!y[j|0]){break e}break d;case 1:qB(f,j,b,y[e+4|0]<<2&252,Ob(f+1074312|0,12));break e;case 2:break f;default:break e}}pB(f,j,b,y[e+4|0]<<2&252,Ob(f+1074312|0,12))}f=1;g:{h:{i:{j:{k:{switch(g-2|0){default:if(g-38>>>0<4){break h}if((g|0)==19){break j}if((g|0)!=28){break g}e=y[e+5|0];f=e&240;if((f|0)==32){break i}if((f|0)!=16){break g}oB(x[a>>2],i,e&15);break g;case 2:Nu(x[a>>2],x[a+4>>2],b,y[e+5|0]);break g;case 4:Nu(x[a>>2],x[a+4>>2],b,0);break g;case 0:e=y[e+5|0];g=x[a>>2];if(!e&(v[g+480180|0]&1)){break d}qB(g,x[a+4>>2],b,e,0);break g;case 1:break k;case 3:break d}}e=y[e+5|0];g=x[a>>2];if(!e&(v[g+480180|0]&1)){break d}pB(g,x[a+4>>2],b,e,0);break g}f=y[e+5|0];e=f&15;if(!(e|x[x[a>>2]+480180>>2]&1048580)){break g}f=f&240;if((f|0)!=32){if((f|0)!=16){break g}nB(x[a>>2],i,e);break g}mB(x[a>>2],i,e);break g}lB(x[a>>2],i,e&15);break g}lT(x[a>>2],i,y[e+5|0],(g|0)==38|(g|0)==40,(g&254)==40)}f=1}x[l+28>>2]=x[C>>2];if(u){Mu(x[a>>2],i)}if(!F){kT(x[a>>2],i,l+28|0);f=1}if(!u){Mu(x[a>>2],i)}x[l+24>>2]=0;jT(i,l+24|0);l:{if(y[h+705|0]&2){break l}m:{if(!f){if(!y[Ue(x[a+8>>2],b)+4|0]){break m}}if(y[p|0]&96){rV(i,E(1),0,x[a>>2]);k=y[p|0];v[p|0]=(k&64?-65:-33)&k}wB(l+8|0,x[a>>2],i,x[l+28>>2],0);e=x[l+12>>2];k=x[l+8>>2];x[h+624>>2]=k;x[h+628>>2]=e;H=Ue(x[a+8>>2],b),I=0,v[H+4|0]=I;e=vf(k,e,c);f=y[h+704|0]&128;k=f?0-e|0:e;g=hb;m=f?0-(g+((e|0)!=0)|0)|0:g}Pb(i,k,m);g=x[i>>2];e=x[i+4>>2];if((g>>>0<G>>>0&(e|0)<=(o|0)|(e|0)<(o|0))&((e|0)>=(r|0)&g>>>0>=w>>>0|(e|0)>(r|0)|((m|0)>0|(m|0)>=0))){break l}f=x[h+704>>2];if(!(f&2)){break c}if(f&4){j=x[h+696>>2];if(g>>>0<w>>>0&(e|0)<=(r|0)|(e|0)<(r|0)){H=i,I=ih(0,j<<1,g,e),x[H>>2]=I;e=hb;x[i+4>>2]=e;x[h+704>>2]=f^128;f=k;k=0-f|0;m=0-(((f|0)!=0)+m|0)|0}e=(e-j>>>0)%(B-Ob(x[a>>2]+1074312|0,33)>>>0)|0;n:{if(e>>>0<n>>>0){f=e+x[h+696>>2]|0;break n}f=x[h+700>>2]+(n-e|0)|0}x[i+4>>2]=f;f=x[h+704>>2];if((f&128)>>>7^e>>>0<n>>>0){break l}x[h+704>>2]=f^128;e=k;k=0-e|0;m=0-(((e|0)!=0)+m|0)|0;break l}f=e;j=x[h+700>>2];if(e>>>0>=j+n>>>0){f=j+((e-j>>>0)%(n>>>0)|0)|0}while(1){e=f;f=e-n|0;if(e>>>0>=j>>>0){continue}break}x[i>>2]=g;x[i+4>>2]=e}q=q+1|0;continue}break}x[x[a+4>>2]+16>>2]=0;break b}x[x[a+4>>2]+16>>2]=0;tV(i);x[(D(b,872)+s|0)+1324>>2]=0}H=Ue(x[a+8>>2],b),I=0,x[H>>2]=I}fb=l+32|0}function $P(a){var b=0,c=E(0),d=E(0),e=E(0),f=E(0),g=E(0),h=0,i=0,j=0,k=0,l=E(0),m=E(0),n=0,o=E(0),p=0,q=E(0),r=E(0),s=E(0),t=0,u=E(0);j=fb-16|0;fb=j;b=a+4208|0;i=Gk(E(B[yb(b,12)>>2]*E(3)));x[a+4264>>2]=i;d=E(x[x[a+16>>2]+24620>>2]>>>((i^-1)>>>1&1)>>>0);B[a+4268>>2]=d;t=a,u=E(E(B[yb(b,9)>>2]*E(100))*E(.0061803399585187435)),B[t+4272>>2]=u;t=j,u=Ce(E(10),E(E(ZP(a)+E(E(B[yb(b,5)>>2]*E(11e3))+E(-1e4)))/E(2e3))),B[t+12>>2]=u;x[j+8>>2]=1065353216;t=a,u=E(B[Xm(j+12|0,j+8|0)>>2]*E(.7609999775886536)),B[t+4280>>2]=u;c=Ce(E(10),E(E(E(E(B[yb(b,1)>>2]*E(1e4))+E(-1e4))/E(100))/E(10)));if(c!=E(1)){d=Aq(E(E(YP(a)*E(6.2831854820251465))/d));f=E(c+c);e=E(c*c);c=zB(E(E(E(E(d*f)+E(-2))+E(M(E(E(E(E(d*E(E(d*e)*E(4)))+E(c*E(8)))-E(e*E(4)))-E(E(d*c)*E(8))))))/E(f+E(-2))),E(0),E(1))}else{c=E(0)}B[a+4276>>2]=c;i=fb-16|0;fb=i;c=B[a+4268>>2];b=a+4208|0;d=E(B[yb(b,6)>>2]*E(.30000001192092896));t=i,u=E(B[yb(b,8)>>2]*E(.10000000149011612)),B[t+12>>2]=u;x[i+8>>2]=1000593162;f=B[Wz(i+12|0,i+8|0)>>2];e=E(c*E(E(d+f)+E(.007000000216066837)));a:{if(E(F(e))<E(2147483648)){b=~~e;break a}b=-2147483648}x[a+4352>>2]=b;b=1;while(1){if((b|0)==12){t=i,u=E(E(E(E(B[yb(a+4208|0,10)>>2]*E(100))/E(100))+E(.10000000149011612))*E(.9090999960899353)),B[t+12>>2]=u;x[i+8>>2]=1065353216;d=B[Xm(i+12|0,i+8|0)>>2];f=E(c*E(E(d*E(75))/E(1e3)));d=E(c*E(E(d*E(67))/E(1e3)));b=0;while(1){if((b|0)==6){h=a+4348|0;d=E(c*E(.0035299998708069324));b:{if(E(F(d))<E(2147483648)){b=~~d;break b}b=-2147483648}x[h>>2]=b;h=a+4344|0;d=E(c*E(.0032500000670552254));c:{if(E(F(d))<E(2147483648)){b=~~d;break c}b=-2147483648}x[h>>2]=b;h=a+4340|0;c=E(c*E(.009999999776482582));d:{if(E(F(c))<E(2147483648)){b=~~c;break d}b=-2147483648}x[h>>2]=b}else{h=(b<<2)+a|0;p=h+4316|0;n=b+n|0;e=Ce(E(.9300000071525574),E(n|0));g=E(f*e);e:{if(E(F(g))<E(2147483648)){k=~~g;break e}k=-2147483648}x[p>>2]=k;k=h+4292|0;e=E(d*e);f:{if(E(F(e))<E(2147483648)){h=~~e;break f}h=-2147483648}x[k>>2]=h;b=b+1|0;continue}break}b=0;while(1){if((b|0)!=15){cQ((D(b,24)+a|0)+4504|0,x[((b<<2)+a|0)+4292>>2]);b=b+1|0;continue}break}fb=i+16|0}else{k=((D(b&1,24)+a|0)+(b<<1&-4)|0)+4352|0;e=E(c*E(E(f*B[(b<<2)+45456>>2])+d));g:{if(E(F(e))<E(2147483648)){h=~~e;break g}h=-2147483648}x[k>>2]=h;b=b+1|0;continue}break}b=fb-16|0;fb=b;d=Rh(a,5);e=Rh(a,11);c=E(d*Rh(a,4));d=E(E(c*E(.03999999910593033))+E(E(d*E(.02250000089406967))+E(0)));f=E(e*Rh(a,10));e=E(E(f*E(.03999999910593033))+E(E(e*E(.02250000089406967))+E(0)));if(v[a+4264|0]&1){g=Rh(a,3);l=Rh(a,9);g=E(c*g);c=E(g*Rh(a,2));d=E(E(c*E(.1444000005722046))+E(E(g*E(.12250000238418579))+d));g=E(f*l);f=E(g*Rh(a,8));e=E(E(f*E(.1444000005722046))+E(E(g*E(.12250000238418579))+e))}Rh(a,12);g=B[a+4496>>2];l=Rh(a,1);m=Rh(a,7);q=Rh(a,0);r=Rh(a,6);t=b,u=Ce(E(10),E(E(ZP(a)+E(E(B[yb(a+4208|0,7)>>2]*E(12e3))+E(-1e4)))/E(2e3))),B[t+12>>2]=u;x[b+8>>2]=1065353216;o=B[Xm(b+12|0,b+8|0)>>2];s=c;c=E(g*g);g=E(l*E(s*c));l=E(q*g);c=E(m*E(f*c));f=E(r*c);m=E(E(E(l+f)*E(-.5))+E(1));B[a+4284>>2]=o*E(M(E(m/E(E(l*E(.1444000005722046))+E(E(c*E(.1444000005722046))+d)))));B[a+4288>>2]=o*E(M(E(m/E(E(f*E(.1444000005722046))+E(E(g*E(.1444000005722046))+e)))));fb=b+16|0;v[a+5046|0]=0;fb=j+16|0}function hH(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=fb-32|0;fb=g;d=x[b+28>>2];x[g+24>>2]=x[b+24>>2];x[g+28>>2]=d;d=x[b+20>>2];x[g+16>>2]=x[b+16>>2];x[g+20>>2]=d;d=x[b+12>>2];x[g+8>>2]=x[b+8>>2];x[g+12>>2]=d;d=x[b+4>>2];x[g>>2]=x[b>>2];x[g+4>>2]=d;d=fb-144|0;fb=d;k=Fb(d+132|0);n=Fb(d+120|0);x[31737]=0;b=P(1,d+108|0,c|0)|0;c=x[31737];x[31737]=0;a:{b:{c:{if((c|0)!=1){c=Ab(n,b);tb(b);if(!x[g>>2]){break b}x[31737]=0;b=d+96|0;O(74,b|0,g|0);e=x[31737];x[31737]=0;d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{if((e|0)!=1){x[31737]=0;i=P(75,k|0,b|0)|0;e=x[31737];x[31737]=0;if((e|0)==1){break q}tb(b);x[31737]=0;e=P(1,d+84|0,16845)|0;f=x[31737];x[31737]=0;if((f|0)==1){break p}x[31737]=0;f=d+72|0;O(76,f|0,g+4|0);h=x[31737];x[31737]=0;if((h|0)==1){break o}x[31737]=0;S(2,b|0,e|0,f|0);h=x[31737];x[31737]=0;if((h|0)==1){break n}x[31737]=0;i=P(75,i|0,b|0)|0;h=x[31737];x[31737]=0;if((h|0)==1){break m}tb(b);tb(f);tb(e);x[31737]=0;e=P(1,f|0,16845)|0;f=x[31737];x[31737]=0;if((f|0)==1){break j}x[31737]=0;f=d+60|0;O(76,f|0,g+8|0);h=x[31737];x[31737]=0;if((h|0)==1){break i}x[31737]=0;S(2,b|0,e|0,f|0);h=x[31737];x[31737]=0;if((h|0)==1){break h}x[31737]=0;i=P(75,i|0,b|0)|0;h=x[31737];x[31737]=0;if((h|0)==1){break g}tb(b);tb(f);tb(e);e=x[g+28>>2];o=e;b=x[g+24>>2];if(x[g+12>>2]|(x[g+16>>2]|!(e|b))){break d}break b}a=N()|0;break c}a=N()|0;tb(d+96|0);break c}a=N()|0;break c}a=N()|0;break k}a=N()|0;break l}a=N()|0;tb(d+96|0)}tb(d+72|0)}tb(e);break c}a=N()|0;break c}a=N()|0;break e}a=N()|0;break f}a=N()|0;tb(d+96|0)}tb(d+60|0)}tb(e);break c}x[31737]=0;e=P(1,d+96|0,13778)|0;f=x[31737];x[31737]=0;r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{if((f|0)!=1){x[31737]=0;l=P(75,i|0,e|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break J}tb(e);x[31737]=0;f=d+36|0;O(77,f|0,g+12|0);e=x[31737];x[31737]=0;if((e|0)==1){break I}x[31737]=0;e=P(1,d+24|0,14690)|0;i=x[31737];x[31737]=0;if((i|0)==1){break H}x[31737]=0;i=d+48|0;S(2,i|0,f|0,e|0);h=x[31737];x[31737]=0;if((h|0)==1){break G}x[31737]=0;h=d+12|0;O(77,h|0,g+16|0);j=x[31737];x[31737]=0;if((j|0)==1){break F}x[31737]=0;j=d+60|0;S(2,j|0,i|0,h|0);m=x[31737];x[31737]=0;if((m|0)==1){break E}x[31737]=0;l=P(75,l|0,j|0)|0;m=x[31737];x[31737]=0;if((m|0)==1){break D}tb(j);tb(h);tb(i);tb(e);tb(f);if(b|o){break y}x[31737]=0;S(78,a|0,l|0,c|0);a=x[31737];x[31737]=0;if((a|0)==1){break x}break a}a=N()|0;break c}a=N()|0;tb(e);break c}a=N()|0;break c}a=N()|0;break z}a=N()|0;break A}a=N()|0;break B}a=N()|0;break C}a=N()|0;tb(d+60|0)}tb(d+12|0)}tb(d+48|0)}tb(e)}tb(d+36|0);break c}x[31737]=0;b=P(1,d+48|0,14690)|0;e=x[31737];x[31737]=0;if((e|0)==1){break w}x[31737]=0;e=d+36|0;O(79,e|0,g+24|0);f=x[31737];x[31737]=0;if((f|0)==1){break v}x[31737]=0;f=d+60|0;S(2,f|0,b|0,e|0);i=x[31737];x[31737]=0;if((i|0)==1){break u}x[31737]=0;i=P(75,l|0,f|0)|0;h=x[31737];x[31737]=0;if((h|0)==1){break t}tb(f);tb(e);tb(b);x[31737]=0;P(75,i|0,c|0)|0;b=x[31737];x[31737]=0;if((b|0)!=1){break b}}a=N()|0;break c}a=N()|0;break c}a=N()|0;break r}a=N()|0;break s}a=N()|0;tb(d+60|0)}tb(d+36|0)}tb(b);break c}a=N()|0}tb(n);tb(k);Q(a|0);p()}_c(a,k)}tb(c);tb(k);fb=d+144|0;fb=g+32|0}function Pz(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=fb-240|0;fb=e;v[e+239|0]=c;g=x[b+4>>2];a:{if(!g){f=x[b>>2];break a}f=x[b>>2];h=y[Gl(f,g)|0];if((h|0)==33){d=1}else{if((h|0)!=63){break a}d=0}Sl(e+80|0,f,g,g-1|0);g=x[e+84>>2];f=x[e+80>>2];x[b>>2]=f;x[b+4>>2]=g}h=e+80|0;ge(h);i=x[e+80>>2];j=e+216|0;ge(j);i=Fl(i,x[e+220>>2],b);ge(h);b:{c:{d:{e:{f:{g:{h:{if(x[e+84>>2]==(i|0)){a=qc(e+228|0,22303);c=x[a+4>>2];x[e>>2]=x[a>>2];x[e+4>>2]=c;if(Ic(f,g,e)){g=ac(8);x[31737]=0;O(1010,j|0,e+239|0);a=x[31737];x[31737]=0;if((a|0)==1){break g}x[31737]=0;S(1017,h|0,18282,j|0);a=x[31737];x[31737]=0;if((a|0)==1){break f}pc(g,h);f=0;x[31737]=0;S(98,g|0,48540,1006);a=x[31737];x[31737]=0;if((a|0)!=1){break b}b=N()|0;tb(h);break e}if(!d){break h}g=ac(8);a=x[b>>2];b=x[b+4>>2];x[31737]=0;a=fi(e+192|0,a,b);b=x[31737];x[31737]=0;i:{j:{k:{l:{m:{n:{o:{p:{if((b|0)!=1){x[31737]=0;b=e+204|0;S(1017,b|0,18318,a|0);c=x[31737];x[31737]=0;if((c|0)==1){break p}x[31737]=0;f=e+216|0;O(1019,f|0,b|0);b=x[31737];x[31737]=0;c=1;if((b|0)==1){break o}x[31737]=0;b=e+180|0;O(1010,b|0,e+239|0);c=x[31737];x[31737]=0;if((c|0)==1){break n}x[31737]=0;d=e+80|0;S(1021,d|0,f|0,b|0);b=x[31737];x[31737]=0;c=1;if((b|0)==1){break m}pc(g,d);x[31737]=0;S(98,g|0,48540,1006);b=x[31737];x[31737]=0;if((b|0)!=1){break b}b=N()|0;tb(d);c=0;break l}b=N()|0;break d}b=N()|0;c=1;break i}b=N()|0;break j}b=N()|0;c=1;break k}b=N()|0}tb(e+180|0)}tb(e+216|0)}tb(e+204|0)}tb(a);if(c){break d}break c}b=qc(e+172|0,22303);d=x[b+4>>2];x[e+72>>2]=x[b>>2];x[e+76>>2]=d;if(Ic(f,g,e+72|0)){g=ac(8);x[31737]=0;b=e+216|0;O(1010,b|0,e+239|0);a=x[31737];x[31737]=0;q:{r:{if((a|0)!=1){x[31737]=0;a=e+80|0;S(1017,a|0,18282,b|0);b=x[31737];x[31737]=0;if((b|0)==1){break r}pc(g,a);f=0;x[31737]=0;S(98,g|0,48540,1006);b=x[31737];x[31737]=0;if((b|0)!=1){break b}b=N()|0;tb(a);break q}b=N()|0;break d}b=N()|0;f=1}tb(e+216|0);if(f){break d}break c}b=qc(e+164|0,7462);d=x[b+4>>2];x[e+64>>2]=x[b>>2];x[e+68>>2]=d;s:{if(!Ic(f,g,e- -64|0)){b=qc(e+156|0,7444);d=x[b+4>>2];x[e+56>>2]=x[b>>2];x[e+60>>2]=d;if(!Ic(f,g,e+56|0)){break s}}v[a+60|0]=c;break h}b=qc(e+148|0,6989);d=x[b+4>>2];x[e+48>>2]=x[b>>2];x[e+52>>2]=d;t:{if(!Ic(f,g,e+48|0)){b=qc(e+140|0,6970);d=x[b+4>>2];x[e+40>>2]=x[b>>2];x[e+44>>2]=d;if(!Ic(f,g,e+40|0)){break t}}v[a+61|0]=c;break h}b=qc(e+132|0,7073);d=x[b+4>>2];x[e+32>>2]=x[b>>2];x[e+36>>2]=d;if(Ic(f,g,e+32|0)){v[a+62|0]=c;break h}b=qc(e+124|0,6064);d=x[b+4>>2];x[e+24>>2]=x[b>>2];x[e+28>>2]=d;if(Ic(f,g,e+24|0)){v[a+63|0]=c;break h}b=qc(e+116|0,7511);d=x[b+4>>2];x[e+16>>2]=x[b>>2];x[e+20>>2]=d;if(Ic(f,g,e+16|0)){v[a+64|0]=c;break h}b=qc(e+108|0,13525);d=x[b+4>>2];x[e+8>>2]=x[b>>2];x[e+12>>2]=d;if(!Ic(f,g,e+8|0)){break h}b=x[a+24>>2];d=b+24664|0;f=x[d+4>>2];x[e+96>>2]=x[d>>2];x[e+100>>2]=f;d=b+24656|0;f=x[d+4>>2];x[e+88>>2]=x[d>>2];x[e+92>>2]=f;d=x[b+24652>>2];x[e+80>>2]=x[b+24648>>2];x[e+84>>2]=d;if(c){a=aN(x[a+56>>2])}else{a=0}x[e+100>>2]=a;a=e+80|0;if(!xz(a,b+24648|0)){break h}JA(b,a)}fb=e+240|0;return}b=N()|0;break d}b=N()|0;f=1}tb(e+216|0);if(!f){break c}}jc(g)}Q(b|0)}p()}function zH(){var a=0,b=0,c=0,d=0;if(y[500432]){return x[125107]}b=xd(502072,1);x[b>>2]=112024;c=BJ(b+8|0);x[31737]=0;d=P(36,b+152|0,14337)|0;a=x[31737];x[31737]=0;a:{b:{c:{if((a|0)!=1){Nf(c);yJ(501744,1);x[31737]=0;W(1252,b|0);a=x[31737];x[31737]=0;if((a|0)==1){break c}xJ(501752,1);x[31737]=0;W(1253,b|0);a=x[31737];x[31737]=0;if((a|0)==1){break c}wJ(501760,1);x[31737]=0;W(1254,b|0);a=x[31737];x[31737]=0;if((a|0)==1){break c}vJ(501776,1);x[31737]=0;W(1255,b|0);a=x[31737];x[31737]=0;if((a|0)==1){break c}xd(501784,1);x[125446]=113972;x[31737]=0;W(1256,b|0);a=x[31737];x[31737]=0;if((a|0)==1){break c}x[31737]=0;X(1257);a=x[31737];x[31737]=0;if((a|0)==1){break c}x[31737]=0;W(1258,b|0);a=x[31737];x[31737]=0;if((a|0)==1){break c}xd(501808,1);x[125452]=114120;x[31737]=0;W(1259,b|0);a=x[31737];x[31737]=0;if((a|0)==1){break c}xd(501816,1);x[125454]=114352;x[31737]=0;W(1260,b|0);a=x[31737];x[31737]=0;if((a|0)==1){break c}xd(501824,1);x[125456]=114236;x[31737]=0;W(1261,b|0);a=x[31737];x[31737]=0;if((a|0)==1){break c}xd(501832,1);x[125458]=114468;x[31737]=0;W(1262,b|0);a=x[31737];x[31737]=0;if((a|0)==1){break c}uJ(501840,1);x[31737]=0;W(1263,b|0);a=x[31737];x[31737]=0;if((a|0)==1){break c}tJ(501864,1);x[31737]=0;W(1264,b|0);a=x[31737];x[31737]=0;if((a|0)==1){break c}xd(501896,1);x[125474]=115188;x[31737]=0;W(1265,b|0);a=x[31737];x[31737]=0;if((a|0)==1){break c}xd(501904,1);x[125476]=115432;x[31737]=0;W(1266,b|0);a=x[31737];x[31737]=0;if((a|0)==1){break c}xd(501912,1);x[125478]=115644;x[31737]=0;W(1267,b|0);a=x[31737];x[31737]=0;if((a|0)==1){break c}xd(501920,1);x[125480]=115876;x[31737]=0;W(1268,b|0);a=x[31737];x[31737]=0;if((a|0)==1){break c}sJ(501928,1);x[31737]=0;W(1269,b|0);a=x[31737];x[31737]=0;if((a|0)==1){break c}rJ(501936,1);x[31737]=0;W(1270,b|0);a=x[31737];x[31737]=0;if((a|0)==1){break c}qJ(501944,1);x[31737]=0;W(1271,b|0);a=x[31737];x[31737]=0;if((a|0)==1){break c}pJ(501952,1);x[31737]=0;W(1272,b|0);a=x[31737];x[31737]=0;if((a|0)==1){break c}xd(501960,1);x[125490]=118568;x[31737]=0;W(1273,b|0);a=x[31737];x[31737]=0;if((a|0)==1){break c}xd(501968,1);x[125492]=118732;x[31737]=0;W(1274,b|0);a=x[31737];x[31737]=0;if((a|0)==1){break c}xd(501976,1);x[125494]=118896;x[31737]=0;W(1275,b|0);a=x[31737];x[31737]=0;if((a|0)==1){break c}xd(501984,1);x[125496]=119060;x[31737]=0;W(1276,b|0);a=x[31737];x[31737]=0;if((a|0)==1){break c}oJ(501992,1);x[31737]=0;W(1277,b|0);a=x[31737];x[31737]=0;if((a|0)==1){break c}nJ(502008,1);x[31737]=0;W(1278,b|0);a=x[31737];x[31737]=0;if((a|0)==1){break c}x[31737]=0;X(1279);a=x[31737];x[31737]=0;if((a|0)==1){break c}x[31737]=0;W(1280,b|0);a=x[31737];x[31737]=0;if((a|0)==1){break c}x[31737]=0;X(1281);a=x[31737];x[31737]=0;if((a|0)==1){break c}x[31737]=0;W(1282,b|0);a=x[31737];x[31737]=0;if((a|0)==1){break c}mJ(502056,1);x[31737]=0;W(1283,b|0);a=x[31737];x[31737]=0;if((a|0)==1){break c}lJ(502064,1);x[31737]=0;W(1284,b|0);b=x[31737];x[31737]=0;if((b|0)==1){break c}break a}b=N()|0;break b}b=N()|0;tb(d)}dy(c);Q(b|0);p()}x[125106]=502072;v[500432]=1;x[125107]=500424;return 500424}function zS(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,z=0,A=0,B=0,D=0;if(b){j=a+327720|0;c=fb-352|0;fb=c;m=c+340|0;DU(m,8);x[31737]=0;n=c+328|0;la(798,n|0,9);k=x[31737];x[31737]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{if((k|0)!=1){x[31737]=0;k=P(799,c+312|0,14)|0;f=x[31737];x[31737]=0;if((f|0)==1){break l}x[31737]=0;O(800,m|0,k|0);f=x[31737];x[31737]=0;if((f|0)==1){break k}x[31737]=0;O(800,n|0,k|0);f=x[31737];x[31737]=0;if((f|0)==1){break k}g=c+240|0;CU(g,4900);l=c+168|0;CU(l,32e3);s=c+96|0;uU(s,8377175819504598e-21,16754351639009197e-21,8377175819504598e-21,-1.991112714669597,.9911462233728751);x[31737]=0;i=P(801,c+72|0,m|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break j}f=c+84|0;av(f,g,i);Ae(i);x[31737]=0;g=P(801,c+48|0,n|0)|0;i=x[31737];x[31737]=0;if((i|0)==1){break i}i=c+60|0;av(i,l,g);Ae(g);x[31737]=0;g=P(801,c+24|0,f|0)|0;l=x[31737];x[31737]=0;if((l|0)==1){break h}l=c+36|0;av(l,s,g);Ae(g);x[31737]=0;g=P(801,c|0,i|0)|0;o=x[31737];x[31737]=0;if((o|0)==1){break g}o=c+12|0;av(o,s,g);Ae(g);Sq(f);Sq(l);Sq(i);Sq(o);Sq(n);Rq(x[c+84>>2],x[c+88>>2],Ro(j,0));Rq(x[c+36>>2],x[c+40>>2],Ro(j,1));Rq(x[c+60>>2],x[c+64>>2],Ro(j,2));Rq(x[c+12>>2],x[c+16>>2],Ro(j,3));Rq(x[c+328>>2],x[c+332>>2],Ro(j,4));Ae(o);Ae(l);Ae(i);Ae(f);pn(k);Ae(n);Ae(m);fb=c+352|0;break a}a=N()|0;break b}a=N()|0;break c}a=N()|0;break d}a=N()|0;break d}a=N()|0;break e}a=N()|0;break f}a=N()|0;Ae(c+36|0)}Ae(c+60|0)}Ae(c+84|0)}pn(k)}Ae(c+328|0)}Ae(c+340|0);Q(a|0);p()}zA(a+131112|0,9.6377,.97);zA(a+196648|0,8.5,.5);zA(a+262184|0,7,.425)}c=a+368680|0;if(!(A=0,B=KR(c,a),D=b,D?A:B)){k=a+24|0;v=C[a+8>>3];m=y[a+16|0];j=fb+-64|0;fb=j;m:while(1){if((r|0)!=8193){z=+(r-4096|0)*.0001220703125;b=0;t=0;while(1)if((b|0)==8){d=1/t;f=r<<3;b=0;while(1)if((b|0)==8){r=r+1|0;continue m}else{i=k+(b+f<<1)|0;h=J(C[j+(b<<3)>>3]*32768*d+.5);h=h<-32768?-32768:h>32768?32768:h;n:{if(F(h)<2147483648){g=~~h;break n}g=-2147483648}w[i>>1]=g;b=b+1|0;continue}}else{h=v;e=1;d=+(b|0)-z;u=d+-3.5;if(!(F(u)<1e-8)){o:{p:{switch(m|0){case 0:e=jf(d*.8975979010256552)*-.5+.5;break o;case 1:e=jf(d*.8975979010256552)*-.46+.54;break o;case 2:e=jf(d*1.7951958020513104)*.08+(jf(d*.8975979010256552)*-.5+.42);break o;case 3:e=jf(d*1.7951958020513104)*.05677+(jf(d*.8975979010256552)*-.49364+.44959);break o;case 4:e=jf(d*1.7951958020513104)*.07922+(jf(d*.8975979010256552)*-.49755+.42323);break o;case 5:e=jf(d*1.7951958020513104);q=jf(d*.8975979010256552);e=jf(d*2.6927937030769655)*-.01168+(e*.14128+(q*-.48829+.35875));break o;case 6:e=jf(d*1.7951958020513104);q=jf(d*.8975979010256552);e=jf(d*2.6927937030769655)*-.00183+(e*.09392+(q*-.49703+.40217));break o;case 7:break p;default:break o}}e=jf(d*1.7951958020513104);q=jf(d*.8975979010256552);e=jf(d*2.6927937030769655)*-.00122+(e*.09831+(q*-.49804+.40243))}d=u*3.141592653589793;h=Wi(d*h)/d}h=e*h;C[j+(b<<3)>>3]=h;t=t+h;b=b+1|0;continue}}break}fb=j- -64|0;b=x[a+20>>2];x[c+16>>2]=x[a+16>>2];x[c+20>>2]=b;b=x[a+12>>2];x[c+8>>2]=x[a+8>>2];x[c+12>>2]=b;b=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=b}}function Ira(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=fb-192|0;fb=g;l=g+80|0;$d(l,b);i=x[g+88>>2];m=x[g+92>>2];e=fb-32|0;fb=e;x[e+28>>2]=0;Lk(b,e+28|0);a:{b:{c:{if(x[e+28>>2]!=(Jn(14184)|0)){break c}x[e+24>>2]=0;h=fb-32|0;fb=h;x[h+28>>2]=0;Ux(h+8|0,h+28|0);j=h+20|0;Sm(j,b,x[h+8>>2],x[h+12>>2]);Qm(j,x[h+28>>2]);x[e+24>>2]=x[h+20>>2];fb=h+32|0;h=-1;f=x[e+24>>2];if(f-3>>>0<4294967294){break c}d:{e:{f:{if(f>>>0<=1){f=Fb(e+12|0);x[31737]=0;j=U(496,b|0,f|0,256)|0;k=x[31737];x[31737]=0;if((k|0)==1){break b}if(!j){break e}x[31737]=0;S(497,e|0,d|0,f|0);j=x[31737];x[31737]=0;if((j|0)!=1){break f}break b}f=Fb(e+12|0);x[31737]=0;j=P(499,b|0,f|0)|0;k=x[31737];x[31737]=0;if((k|0)==1){break b}if(!j){break d}x[31737]=0;S(497,e|0,d|0,f|0);j=x[31737];x[31737]=0;if((j|0)==1){break b}}Ab(c,e);tb(e);tb(f);pg(b,e);f=0;x[e+12>>2]=0;Lk(b,e+12|0);j=x[e+12>>2];if(j>>>0>50){break c}g:{while(1){if((f|0)==(j|0)){break g}f=f+1|0;if(XQ(a,b,d)){continue}break}break c}x[e+12>>2]=0;Lk(b,e+12|0);h=x[e+12>>2]==(Jn(14222)|0)?1:-1;break c}tb(f);break c}tb(f)}fb=e+32|0;break a}a=N()|0;tb(f);Q(a|0);p()}h:{if(h){break h}kg(x[x[b>>2]-12>>2]+b|0,0);b=Pm(l,Hi(b,i,m,0));x[31737]=0;h=P(462,g+68|0,14333)|0;i=x[31737];x[31737]=0;i:{if((i|0)!=1){x[31737]=0;x[g+48>>2]=3;x[g+52>>2]=0;i=g+48|0;S(463,b|0,h|0,i|0);e=x[31737];x[31737]=0;if((e|0)!=1){Eb(h);v[g+67|0]=0;x[31737]=0;h=P(462,i|0,14789)|0;i=x[31737];x[31737]=0;if((i|0)!=1){x[31737]=0;S(464,b|0,g+67|0,h|0);i=x[31737];x[31737]=0;if((i|0)!=1){Eb(h);h=Fc(g+44|0,y[g+67|0]?0:d);x[31737]=0;d=R(477,b|0)|0;i=x[31737];x[31737]=0;if((i|0)!=1){x[31737]=0;i=R(478,b|0)|0;e=x[31737];x[31737]=0;if((e|0)!=1){x[g+40>>2]=d;j:{k:{l:{m:{while(1){if(!Ib(d,i)){a=vl(y[b|0]);Ah(b);h=a?-1:1;break h}x[31737]=0;d=P(462,g+24|0,15880)|0;e=x[31737];x[31737]=0;if((e|0)==1){break l}e=x[b+44>>2];f=x[b+40>>2];x[31737]=0;e=ba(479,f|0,e|0,x[g+40>>2],d|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break k}Eb(d);n:{o:{if(e){d=x[h>>2];x[31737]=0;V(480,b|0,g+40|0,c|0,d|0);d=x[31737];x[31737]=0;if((d|0)!=1){break o}break j}x[31737]=0;d=P(462,g+12|0,15577)|0;e=x[31737];x[31737]=0;p:{q:{if((e|0)!=1){e=x[b+44>>2];f=x[b+40>>2];x[31737]=0;e=ba(479,f|0,e|0,x[g+40>>2],d|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break q}Eb(d);if(!e){break p}x[31737]=0;S(481,b|0,g+40|0,g+38|0);d=x[31737];x[31737]=0;if((d|0)==1){break j}break o}a=N()|0;break i}a=N()|0;Eb(d);break i}x[31737]=0;d=P(462,g|0,15478)|0;e=x[31737];x[31737]=0;if((e|0)==1){break n}e=x[b+44>>2];f=x[b+40>>2];x[31737]=0;e=ba(479,f|0,e|0,x[g+40>>2],d|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break m}Eb(d);if(!e){break o}d=x[h>>2];x[31737]=0;V(482,b|0,g+40|0,a|0,d|0);d=x[31737];x[31737]=0;if((d|0)==1){break j}}fA(g+40|0);d=x[g+40>>2];continue}break}a=N()|0;break i}a=N()|0;Eb(d);break i}a=N()|0;break i}a=N()|0;Eb(d);break i}a=N()|0;break i}a=N()|0;break i}a=N()|0;break i}a=N()|0;Eb(h);break i}a=N()|0;break i}a=N()|0;Eb(h);break i}a=N()|0}Ah(b);Q(a|0);p()}fb=g+192|0;return h|0}function jM(a,b,c,d,e,f){var g=0,h=0,i=0,j=0;g=fb-48|0;fb=g;a:{b:{if(St(c)){h=x[b+484344>>2];if(He(h,x[b+484348>>2],c&65535)){break b}}c=a;a=Fb(g+36|0);b=Fb(g+24|0);Ji(c,a,b);tb(b);tb(a);break a}c=Wb(h,c);if(!(x[c+12>>2]>(d|0)&(d|0)>=0)){c=a;a=Fb(g+36|0);b=Fb(g+24|0);Ji(c,a,b);tb(b);tb(a);break a}if(!(z[b+480188>>1]>e>>>0&(e|0)>=0)){c=a;a=Fb(g+36|0);b=Fb(g+24|0);Ji(c,a,b);tb(b);tb(a);break a}if(f>>>0>=6){c=a;a=Fb(g+36|0);b=Fb(g+24|0);Ji(c,a,b);tb(b);tb(a);break a}c=jd(x[c>>2],x[x[c+48>>2]+12>>2],d,e&65535);c:{d:{e:{f:{switch(f|0){case 0:g:{h:{i:{j:{k:{d=y[c|0];if(!Sc(d)){if(!Ml(d)){break k}}e=g+24|0;bS(e,b,d,y[c+1|0]);x[31737]=0;O(1065,g+36|0,e|0);b=x[31737];x[31737]=0;d=1;if((b|0)!=1){break j}c=N()|0;break g}d=0;x[31737]=0;P(36,g+36|0,16811)|0;b=x[31737];x[31737]=0;if((b|0)==1){break i}}b=9984;c=y[c|0];if(!Sc(c)){b=Ml(c)?10294:16811}x[31737]=0;b=P(36,g+12|0,b|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break h}c=a;a=g+36|0;Ji(c,a,b);tb(b);tb(a);if(!d){break a}tb(g+24|0);break a}c=N()|0;break d}c=N()|0;tb(g+36|0);if(!d){break d}}tb(g+24|0);break d;case 1:b=c+1|0;l:{if(y[c+1|0]){Dv(g+36|0,b);break l}Dc(g+36|0,16816)}b=y[b|0];x[31737]=0;b=P(36,g+24|0,(b?10817:16816)|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break e}c=a;a=g+36|0;Ji(c,a,b);tb(b);tb(a);break a;case 2:m:{if(Vg(y[c|0])){Dc(g+36|0,18465);break m}d=y[c+2|0];if(d){rf(g+36|0,1,yR(x[x[b+8>>2]+88>>2],d));break m}Dc(g+36|0,18465)}b=18465;if(!Vg(y[c|0])){b=y[c+2|0]?5505:18465}x[31737]=0;b=P(36,g+24|0,b|0)|0;c=x[31737];x[31737]=0;if((c|0)!=1){c=a;a=g+36|0;Ji(c,a,b);tb(b);tb(a);break a}c=N()|0;tb(g+36|0);break d;case 4:n:{if(Vg(y[c|0])){i=g,j=Jj(y[c+2|0],y[c+4|0])&255,x[i+12>>2]=j;_C(g+36|0,g+12|0);break n}if(y[c+2|0]){Dv(g+36|0,c+4|0);break n}Dc(g+36|0,16816)}b=5489;if(!Vg(y[c|0])){b=y[c+2|0]?5489:16816}x[31737]=0;b=P(36,g+24|0,b|0)|0;c=x[31737];x[31737]=0;if((c|0)!=1){c=a;a=g+36|0;Ji(c,a,b);tb(b);tb(a);break a}c=N()|0;tb(g+36|0);break d;case 3:o:{if(Vg(y[c|0])){i=g,j=(Jj(y[c+3|0],y[c+5|0])&3840)!=0,v[i+12|0]=j;b=fb-32|0;fb=b;x[b+12>>2]=-1;x[b+16>>2]=0;x[b+4>>2]=0;Fb(b+20|0);x[31737]=0;x[b+4>>2]=x[b+4>>2]&-1332|1058;x[b+8>>2]=1;d=b+4|0;S(1167,g+36|0,g+12|0,d|0);e=x[31737];x[31737]=0;p:{if((e|0)!=1){Hh(d);fb=b+32|0;break p}a=N()|0;Hh(b+4|0);Q(a|0);p()}break o}d=y[c+3|0];if(d){rf(g+36|0,1,xR(x[x[b+8>>2]+84>>2],d));break o}Dc(g+36|0,16817)}b=12391;if(!Vg(y[c|0])){b=y[c+3|0]?12391:16817}x[31737]=0;b=P(36,g+24|0,b|0)|0;c=x[31737];x[31737]=0;if((c|0)!=1){c=a;a=g+36|0;Ji(c,a,b);tb(b);tb(a);break a}c=N()|0;tb(g+36|0);break d;case 5:break f;default:break c}}q:{if(Vg(y[c|0])){i=g,j=Jj(y[c+3|0],y[c+5|0])&255,x[i+12>>2]=j;_C(g+36|0,g+12|0);break q}if(y[c+3|0]){Dv(g+36|0,c+5|0);break q}Dc(g+36|0,16816)}b=11178;if(!Vg(y[c|0])){b=y[c+3|0]?11178:16816}x[31737]=0;b=P(36,g+24|0,b|0)|0;c=x[31737];x[31737]=0;if((c|0)!=1){c=a;a=g+36|0;Ji(c,a,b);tb(b);tb(a);break a}c=N()|0;tb(g+36|0);break d}c=N()|0;tb(g+36|0)}Q(c|0);p()}c=a;a=Fb(g+36|0);b=Fb(g+24|0);Ji(c,a,b);tb(b);tb(a)}fb=g+48|0}function Oz(a,b,c,d){a=a|0;b=b|0;c=+c;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=fb-160|0;fb=e;C[e+152>>3]=c;f=x[b+4>>2];a:{if(!f){g=x[b>>2];break a}g=x[b>>2];h=y[Gl(g,f)|0];if((h|0)==33){d=1}else{if((h|0)!=63){break a}d=0}Sl(e+128|0,g,f,f-1|0);f=x[e+132>>2];g=x[e+128>>2];x[b>>2]=g;x[b+4>>2]=f}j=e+128|0;ge(j);h=x[e+128>>2];i=e+116|0;ge(i);h=Fl(h,x[e+120>>2],b);ge(j);b:{c:{d:{e:{if(x[e+132>>2]==(h|0)){h=qc(e+144|0,22303);a=x[h+4>>2];x[e+8>>2]=x[h>>2];x[e+12>>2]=a;if(Ic(g,f,e+8|0)){b=ac(8);x[31737]=0;O(1014,i|0,e+152|0);a=x[31737];x[31737]=0;f:{g:{h:{if((a|0)!=1){x[31737]=0;S(1017,j|0,18282,i|0);a=x[31737];x[31737]=0;if((a|0)==1){break h}pc(b,j);g=0;x[31737]=0;S(98,b|0,48540,1006);a=x[31737];x[31737]=0;if((a|0)!=1){break b}f=N()|0;tb(j);break g}f=N()|0;break f}f=N()|0;g=1}tb(e+116|0);if(!g){break c}}jc(b);break c}if(!d){break e}i=ac(8);d=x[b>>2];a=x[b+4>>2];x[31737]=0;h=fi(e+92|0,d,a);a=x[31737];x[31737]=0;i:{j:{k:{l:{m:{n:{o:{p:{q:{if((a|0)!=1){x[31737]=0;b=e+104|0;S(1017,b|0,18318,h|0);a=x[31737];x[31737]=0;if((a|0)==1){break q}x[31737]=0;d=e+116|0;O(1019,d|0,b|0);b=x[31737];x[31737]=0;a=1;if((b|0)==1){break p}x[31737]=0;b=e+80|0;O(1014,b|0,e+152|0);a=x[31737];x[31737]=0;if((a|0)==1){break o}x[31737]=0;g=e+128|0;S(1021,g|0,d|0,b|0);b=x[31737];x[31737]=0;a=1;if((b|0)==1){break n}pc(i,g);x[31737]=0;S(98,i|0,48540,1006);a=x[31737];x[31737]=0;if((a|0)!=1){break b}f=N()|0;tb(g);a=0;break m}f=N()|0;break i}f=N()|0;a=1;break j}f=N()|0;break k}f=N()|0;a=1;break l}f=N()|0}tb(e+80|0)}tb(e+116|0)}tb(e+104|0)}tb(h);if(!a){break c}}jc(i);break c}d=qc(e+72|0,22303);b=x[d+4>>2];x[e+40>>2]=x[d>>2];x[e+44>>2]=b;if(Ic(g,f,e+40|0)){h=ac(8);x[31737]=0;b=e+116|0;O(1014,b|0,e+152|0);a=x[31737];x[31737]=0;r:{s:{t:{if((a|0)!=1){x[31737]=0;d=e+128|0;S(1017,d|0,18282,b|0);a=x[31737];x[31737]=0;if((a|0)==1){break t}pc(h,d);g=0;x[31737]=0;S(98,h|0,48540,1006);a=x[31737];x[31737]=0;if((a|0)!=1){break b}f=N()|0;tb(d);break s}f=N()|0;break r}f=N()|0;g=1}tb(e+116|0);if(!g){break c}}jc(h);break c}d=qc(e- -64|0,7759);b=x[d+4>>2];x[e+32>>2]=x[d>>2];x[e+36>>2]=b;if(Ic(g,f,e+32|0)){if(!Gd(y[a+28|0])){break e}if(c<=0|c>4){d=ac(8);x[31737]=0;b=P(36,e+128|0,7854)|0;a=x[31737];x[31737]=0;if((a|0)==1){break d}pc(d,b);x[31737]=0;S(98,d|0,48540,1006);a=x[31737];x[31737]=0;if((a|0)!=1){break b}f=N()|0;tb(b);break c}a=x[a+24>>2];k=a,l=Ze(65536/c),x[k+480244>>2]=l;Gq(a);break e}d=qc(e+56|0,7811);b=x[d+4>>2];x[e+24>>2]=x[d>>2];x[e+28>>2]=b;if(Ic(g,f,e+24|0)){if(!Gd(y[a+28|0])){break e}if(c<=0|c>4){d=ac(8);x[31737]=0;b=P(36,e+128|0,7875)|0;a=x[31737];x[31737]=0;if((a|0)!=1){pc(d,b);x[31737]=0;S(98,d|0,48540,1006);a=x[31737];x[31737]=0;if((a|0)!=1){break b}f=N()|0;tb(b);break c}f=N()|0;jc(d);break c}a=x[a+24>>2];k=a,l=Ze(c*65536),x[k+480240>>2]=l;Gq(a);break e}d=qc(e+48|0,7829);b=x[d+4>>2];x[e+16>>2]=x[d>>2];x[e+20>>2]=b;if(!Ic(g,f,e+16|0)){break e}k=x[a+24>>2],l=Zi(c*65536),x[k+480236>>2]=l}fb=e+160|0;return}f=N()|0;jc(d)}Q(f|0)}p()}function aua(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=fb-720|0;fb=e;xc(b);f=fb-16|0;fb=f;g=e+110|0;$$(f+8|0,g);h=x[f+12>>2];lc(f,x[b>>2],x[b+8>>2],x[f+8>>2],x[f+12>>2]);i=x[f+4>>2];if((i|0)==(h|0)){Vb(b,x[f+12>>2])}fb=f+16|0;f=(h|0)==(i|0);if(!f){_$(g)}a:{b:{c:{d:{if(!f){break d}if(!a0(g)){break d}d=1;if((c|0)==64){break d}Bd(a,67108864);gg(a);d=y[e+135|0];w[a+480190>>1]=31;w[a+480188>>1]=d;x[a+480228>>2]=256/(d>>>0);d=tc(e,8179);Ab(a+1298344|0,d);tb(d);d=tc(e,10820);Ab(a+1298356|0,d);tb(d);f=e+84|0;ig(f,4174);g=y[e+134|0];x[e+64>>2]=g>>>4;d=0;x[31737]=0;x[e+104>>2]=g&15;V(308,e|0,f|0,e- -64|0,e+104|0);g=x[31737];x[31737]=0;if((g|0)==1){break c}Ab(a+1298368|0,e);tb(e);Eb(f);n=a+1298404|0,o=x[Fc(e,28)>>2],x[n>>2]=o;kw(Xb(x[a+484360>>2],y[a+484376|0]),e+158|0,y[e+157|0]+1|0);while(1){e:{if((d|0)==31){wE(b,a+1298308|0,32);d=1;break e}f=d+1|0;h=D(f,104)+a|0;i=h+484380|0;ld(i,1);g=(e+110|0)+(d<<2)|0;n=i,o=$b(y[g+176|0]|y[g+177|0]<<8|(y[g+178|0]<<16|y[g+179|0]<<24)),x[n>>2]=o;k=$b(y[g+300|0]|y[g+301|0]<<8|(y[g+302|0]<<16|y[g+303|0]<<24));x[h+484384>>2]=k;g=$b(y[g+424|0]|y[g+425|0]<<8|(y[g+426|0]<<16|y[g+427|0]<<24));x[h+484388>>2]=g+k;if(g){g=h+484414|0;w[g>>1]=z[g>>1]|2}_k(i);d=(e+110|0)+d|0;v[e|0]=y[d+548|0];v[e+84|0]=64;n=h+484410|0,o=y[Qb(e,e+84|0)|0]<<2,w[n>>1]=o;v[h+484417|0]=y[d+579|0]<<4;d=f;continue}break}while(1){if((d|0)!=32){Z$(b,((d<<5)+a|0)+946304|0,30);d=d+1|0;continue}break}k=c&1;if(k){Vf(a+484344|0,y[e+156|0]+1|0)}i=a+484344|0;g=0;f:{while(1){if(y[e+156|0]<g>>>0){d=1;if(!(c&2)){break d}c=Xc(e,8,1,1,0);break f}h=ai(e+84|0);g:{h:{if(y[e+136|0]){x[31737]=0;f=R(274,b|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break g}x[31737]=0;d=e- -64|0;S(186,d|0,b|0,f|0);f=x[31737];x[31737]=0;if((f|0)==1){break g}break h}f=z[a+480188>>1];x[31737]=0;d=e- -64|0;S(186,d|0,b|0,f<<8);f=x[31737];x[31737]=0;if((f|0)==1){break b}}f=ic(e,d);hd(h,f);ub(f);ub(d);i:{if(!k){break i}x[31737]=0;d=U(197,i|0,g&65535,64)|0;f=x[31737];x[31737]=0;if((f|0)==1){break b}if(!d){break i}f=0;if(y[e+136|0]){x[31737]=0;O(309,h|0,e|0);d=x[31737];x[31737]=0;if((d|0)==1){break b}j:while(1){if((f|0)==64){break i}d=Wb(x[i>>2],g);bf(e- -64|0,x[d>>2],x[x[d+48>>2]+12>>2],f);n=e,o=wb(x[e+64>>2]),x[n+104>>2]=o;l=e+f|0;d=128;j=jw(x[e+64>>2],x[e+68>>2]);while(1){m=x[e+104>>2];if(!Ib(m,j)){f=f+1|0;continue j}k:{if(!(y[l|0]&d)){break k}x[31737]=0;O(310,h|0,m|0);m=x[31737];x[31737]=0;if((m|0)!=1){break k}break b}d=d>>>1|0;vg(e+104|0);continue}}}l:while(1){d=0;l=f&65535;if(l>>>0>=z[a+480188>>1]){break i}while(1){if((d|0)==64){f=f+1|0;continue l}j=Wb(x[i>>2],g);j=jd(x[j>>2],x[x[j+48>>2]+12>>2],d,l);x[31737]=0;O(310,h|0,j|0);j=x[31737];x[31737]=0;if((j|0)!=1){d=d+1|0;continue}break}break}break b}ub(h);g=g+1|0;continue}break}break b}while(1){if((d|0)!=32){fg(c,(D(d,104)+a|0)+484380|0,b);d=d+1|0;continue}break}d=1}fb=e+720|0;return d|0}d=N()|0;Eb(e+84|0);break a}d=N()|0;ub(h)}Q(d|0);p()}function Sg(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;j=fb-112|0;fb=j;k=i&2147483647;a:{b:{m=e&2147483647;l=2147418112;n=!(b|c);if(!(d|m?m-l>>>0<2147549184:n)){o=k-l|0;if(!h&(o|0)==-2147418112?f|g:(o|0)==-2147418112&(h|0)!=0|o>>>0>2147549184){break b}}if(!(!d&(m|0)==2147418112?n:m>>>0<2147418112)){h=d;i=e|32768;f=b;g=c;break a}if(!(!h&(k|0)==2147418112?!(f|g):k>>>0<2147418112)){i=i|32768;break a}if(!(b|d|(m^2147418112|c))){l=d;d=!(b^f|d^h|(c^g|e^i^-2147483648));h=d?0:l;i=d?2147450880:e;f=d?0:b;g=d?0:c;break a}l=f|h;if(!(l|(k^2147418112|g))){break a}if(!(b|d|(c|m))){if(g|k|l){break a}f=b&f;g=c&g;h=d&h;i=e&i;break a}if(f|h|(g|k)){break b}f=b;g=c;h=d;i=e;break a}l=(k|0)==(m|0);r=l&(d|0)==(h|0)?(c|0)==(g|0)&b>>>0<f>>>0|c>>>0<g>>>0:l&d>>>0<h>>>0|k>>>0>m>>>0;n=r;m=n?f:b;o=n?g:c;l=n?i:e;s=l;n=n?h:d;q=l&65535;d=r?d:h;e=r?e:i;t=e;l=e>>>16&32767;p=s>>>16&32767;if(!p){e=!(n|q);i=e;k=e?m:n;e=e<<6;i=G(i?o:q);e=e+((i|0)==32?G(k)+32|0:i)|0;bg(j+96|0,m,o,n,q,e-15|0);n=x[j+104>>2];q=x[j+108>>2];o=x[j+100>>2];p=16-e|0;m=x[j+96>>2]}f=r?b:f;g=r?c:g;h=d;i=t&65535;if(!l){b=!(d|i);e=b;k=b?f:d;b=b<<6;e=G(e?g:i);b=b+((e|0)==32?G(k)+32|0:e)|0;bg(j+80|0,f,g,d,i,b-15|0);l=16-b|0;h=x[j+88>>2];i=x[j+92>>2];g=x[j+84>>2];f=x[j+80>>2]}c=i<<3|h>>>29;b=h<<3|g>>>29;c=c|524288;h=n<<3|o>>>29;i=q<<3|n>>>29;r=s^t;e=g<<3|f>>>29;d=f<<3;c:{if((l|0)==(p|0)){break c}f=p-l|0;if(f>>>0>127){b=0;c=0;e=0;d=1;break c}bg(j- -64|0,d,e,b,c,128-f|0);gn(j+48|0,d,e,b,c,f);b=x[j+56>>2];c=x[j+60>>2];e=x[j+52>>2];d=x[j+48>>2]|(x[j+64>>2]|x[j+72>>2]|(x[j+68>>2]|x[j+76>>2]))!=0}n=d;k=e;l=h;q=i|524288;e=o<<3|m>>>29;o=m<<3;m=e;d:{if((r|0)<0){f=0;g=0;h=0;i=0;if(!(n^o|b^l|(e^k|c^q))){break a}d=o-n|0;e=e-((n>>>0>o>>>0)+k|0)|0;f=l-b|0;g=(k|0)==(m|0)&n>>>0>o>>>0|k>>>0>m>>>0;h=f-g|0;b=(q-((b>>>0>l>>>0)+c|0)|0)-(f>>>0<g>>>0)|0;i=b;if(b>>>0>524287){break d}c=!(b|h);g=c;i=g?d:h;c=g<<6;g=G(g?e:b);c=c+((g|0)==32?G(i)+32|0:g)|0;f=b;b=c-12|0;bg(j+32|0,d,e,h,f,b);p=p-b|0;h=x[j+40>>2];i=x[j+44>>2];d=x[j+32>>2];e=x[j+36>>2];break d}e=k+m|0;d=n+o|0;e=d>>>0<o>>>0?e+1|0:e;f=(k|0)==(e|0)&d>>>0<n>>>0|e>>>0<k>>>0;k=c+q|0;b=b+l|0;k=b>>>0<l>>>0?k+1|0:k;h=b+f|0;i=h>>>0<b>>>0?k+1|0:k;if(!(i&1048576)){break d}d=n&1|((e&1)<<31|d>>>1);e=h<<31|e>>>1;p=p+1|0;h=(i&1)<<31|h>>>1;i=i>>>1|0}c=0;b=s&-2147483648;o=b;if((p|0)>=32767){h=c;i=b|2147418112;f=0;g=0;break a}l=0;e:{if((p|0)>0){l=p;break e}bg(j+16|0,d,e,h,i,p+127|0);gn(j,d,e,h,i,1-p|0);d=x[j>>2]|(x[j+16>>2]|x[j+24>>2]|(x[j+20>>2]|x[j+28>>2]))!=0;e=x[j+4>>2];h=x[j+8>>2];i=x[j+12>>2]}m=d&7;d=(e&7)<<29|d>>>3;f=(m>>>0>4)+d|0;b=h<<29|e>>>3;g=d>>>0>f>>>0?b+1|0:b;d=(b|0)==(g|0)&d>>>0>f>>>0|b>>>0>g>>>0;b=c|((i&7)<<29|h>>>3);h=d+b|0;i=o|(i>>>3&65535|l<<16);i=b>>>0>h>>>0?i+1|0:i;f:{if((m|0)==4){b=0;k=g+b|0;d=f;c=f&1;f=f+c|0;g=d>>>0>f>>>0?k+1|0:k;b=(b|0)==(g|0)&c>>>0>f>>>0|b>>>0>g>>>0;h=b+h|0;i=b>>>0>h>>>0?i+1|0:i;break f}if(!m){break a}}}x[a>>2]=f;x[a+4>>2]=g;x[a+8>>2]=h;x[a+12>>2]=i;fb=j+112|0}function Vra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=fb-368|0;fb=e;g=fb-32|0;fb=g;d=g+12|0;rD(d,b);Rn(g+4|0,d);x[31737]=0;f=e+216|0;S(476,f|0,x[g+4>>2],x[g+8>>2]);b=x[31737];x[31737]=0;a:{if((b|0)!=1){Kc(d);fb=g+32|0;break a}a=N()|0;Kc(g+12|0);Q(a|0);p()}x[31737]=0;b=e+104|0;S(458,b|0,x[e+216>>2],x[e+220>>2]);g=x[31737];x[31737]=0;b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{if((g|0)!=1){x[31737]=0;g=P(104,e+228|0,b|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break z}tb(b);dc(f);if(c>>>0<2189){break g}b=Pm(b,g);x[31737]=0;c=P(462,f|0,10140)|0;d=x[31737];x[31737]=0;if((d|0)==1){break x}x[31737]=0;x[e+88>>2]=20054022;x[e+92>>2]=0;d=e+88|0;S(463,b|0,c|0,d|0);f=x[31737];x[31737]=0;if((f|0)==1){break w}Eb(c);v[e+103|0]=0;x[31737]=0;c=P(462,d|0,11063)|0;d=x[31737];x[31737]=0;if((d|0)==1){break v}x[31737]=0;S(464,b|0,e+103|0,c|0);d=x[31737];x[31737]=0;if((d|0)==1){break u}Eb(c);d=Fc(e+84|0,y[e+103|0]?0:x[a+1298404>>2]);f=x[a+4>>2];x[31737]=0;c=P(462,e+72|0,15880)|0;h=x[31737];x[31737]=0;if((h|0)==1){break i}h=x[d>>2];x[31737]=0;V(465,b|0,f|0,c|0,h|0);f=x[31737];x[31737]=0;if((f|0)==1){break t}Eb(c);x[31737]=0;c=P(462,e+60|0,15577)|0;f=x[31737];x[31737]=0;if((f|0)==1){break s}d=x[d>>2];x[31737]=0;V(466,b|0,a|0,c|0,d|0);d=x[31737];x[31737]=0;if((d|0)==1){break r}Eb(c);x[31737]=0;c=P(462,e+48|0,15478)|0;d=x[31737];x[31737]=0;if((d|0)==1){break q}x[31737]=0;d=a+484360|0;S(467,b|0,d|0,c|0);f=x[31737];x[31737]=0;if((f|0)==1){break p}Eb(c);x[31737]=0;c=P(462,e+36|0,25062)|0;f=x[31737];x[31737]=0;if((f|0)==1){break o}x[31737]=0;S(468,b|0,a+484344|0,c|0);f=x[31737];x[31737]=0;if((f|0)==1){break n}Eb(c);f=x[a+1298404>>2];x[31737]=0;c=P(462,e+24|0,25068)|0;h=x[31737];x[31737]=0;if((h|0)==1){break m}x[31737]=0;V(469,b|0,d|0,c|0,f|0);d=x[31737];x[31737]=0;if((d|0)==1){break l}Eb(c);if(vl(y[b|0])){x[31737]=0;c=P(1,e+12|0,16354)|0;d=x[31737];x[31737]=0;if((d|0)==1){break k}a=x[a+1298472>>2];x[31737]=0;S(386,a|0,1,c|0);a=x[31737];x[31737]=0;if((a|0)==1){break j}tb(c)}Ah(b);break f}a=N()|0;break y}a=N()|0;tb(e+104|0)}dc(e+216|0);break b}a=N()|0;break h}a=N()|0;Eb(c);break h}a=N()|0;break h}a=N()|0;Eb(c);break h}a=N()|0;Eb(c);break h}a=N()|0;break h}a=N()|0;Eb(c);break h}a=N()|0;break h}a=N()|0;Eb(c);break h}a=N()|0;break h}a=N()|0;Eb(c);break h}a=N()|0;break h}a=N()|0;Eb(c);break h}a=N()|0;break h}a=N()|0;tb(c);break h}a=N()|0}Ah(b);break c}b=Fb(e+104|0);d=x[a+1298404>>2];f=x[a+4>>2];x[31737]=0;d=ba(470,f|0,g|0,b|0,d|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break e}A:{if((d|0)!=1){x[31737]=0;c=P(1,e+216|0,16660)|0;d=x[31737];x[31737]=0;B:{if((d|0)!=1){a=x[a+1298472>>2];x[31737]=0;S(386,a|0,1,c|0);a=x[31737];x[31737]=0;if((a|0)==1){break B}tb(c);break A}a=N()|0;break d}a=N()|0;tb(c);break d}d=x[a+1298404>>2];x[31737]=0;V(471,g|0,a|0,d|0,c>>>0<2188|0);a=x[31737];x[31737]=0;if((a|0)==1){break e}}tb(b)}Ff(g);fb=e+368|0;return}a=N()|0}tb(b)}Ff(g)}Q(a|0);p()}function Db(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{if(!a){break a}d=a-8|0;b=x[a-4>>2];a=b&-8;f=d+a|0;b:{if(b&1){break b}if(!(b&3)){break a}b=x[d>>2];d=d-b|0;if(d>>>0<A[31617]){break a}a=a+b|0;c:{d:{if(x[31618]!=(d|0)){if(b>>>0<=255){e=b>>>3|0;b=x[d+12>>2];c=x[d+8>>2];if((b|0)==(c|0)){i=126452,j=x[31613]&Vua(-2,e),x[i>>2]=j;break b}x[c+12>>2]=b;x[b+8>>2]=c;break b}h=x[d+24>>2];b=x[d+12>>2];if((d|0)!=(b|0)){c=x[d+8>>2];x[c+12>>2]=b;x[b+8>>2]=c;break c}e=d+20|0;c=x[e>>2];if(!c){c=x[d+16>>2];if(!c){break d}e=d+16|0}while(1){g=e;b=c;e=b+20|0;c=x[e>>2];if(c){continue}e=b+16|0;c=x[b+16>>2];if(c){continue}break}x[g>>2]=0;break c}b=x[f+4>>2];if((b&3)!=3){break b}x[31615]=a;x[f+4>>2]=b&-2;x[d+4>>2]=a|1;x[f>>2]=a;return}b=0}if(!h){break b}c=x[d+28>>2];e=(c<<2)+126756|0;e:{if(x[e>>2]==(d|0)){x[e>>2]=b;if(b){break e}i=126456,j=x[31614]&Vua(-2,c),x[i>>2]=j;break b}x[h+(x[h+16>>2]==(d|0)?16:20)>>2]=b;if(!b){break b}}x[b+24>>2]=h;c=x[d+16>>2];if(c){x[b+16>>2]=c;x[c+24>>2]=b}c=x[d+20>>2];if(!c){break b}x[b+20>>2]=c;x[c+24>>2]=b}if(d>>>0>=f>>>0){break a}b=x[f+4>>2];if(!(b&1)){break a}f:{g:{h:{i:{if(!(b&2)){if(x[31619]==(f|0)){x[31619]=d;a=x[31616]+a|0;x[31616]=a;x[d+4>>2]=a|1;if(x[31618]!=(d|0)){break a}x[31615]=0;x[31618]=0;return}if(x[31618]==(f|0)){x[31618]=d;a=x[31615]+a|0;x[31615]=a;x[d+4>>2]=a|1;x[a+d>>2]=a;return}a=(b&-8)+a|0;if(b>>>0<=255){e=b>>>3|0;b=x[f+12>>2];c=x[f+8>>2];if((b|0)==(c|0)){i=126452,j=x[31613]&Vua(-2,e),x[i>>2]=j;break g}x[c+12>>2]=b;x[b+8>>2]=c;break g}h=x[f+24>>2];b=x[f+12>>2];if((f|0)!=(b|0)){c=x[f+8>>2];x[c+12>>2]=b;x[b+8>>2]=c;break h}e=f+20|0;c=x[e>>2];if(!c){c=x[f+16>>2];if(!c){break i}e=f+16|0}while(1){g=e;b=c;e=b+20|0;c=x[e>>2];if(c){continue}e=b+16|0;c=x[b+16>>2];if(c){continue}break}x[g>>2]=0;break h}x[f+4>>2]=b&-2;x[d+4>>2]=a|1;x[a+d>>2]=a;break f}b=0}if(!h){break g}c=x[f+28>>2];e=(c<<2)+126756|0;j:{if(x[e>>2]==(f|0)){x[e>>2]=b;if(b){break j}i=126456,j=x[31614]&Vua(-2,c),x[i>>2]=j;break g}x[h+(x[h+16>>2]==(f|0)?16:20)>>2]=b;if(!b){break g}}x[b+24>>2]=h;c=x[f+16>>2];if(c){x[b+16>>2]=c;x[c+24>>2]=b}c=x[f+20>>2];if(!c){break g}x[b+20>>2]=c;x[c+24>>2]=b}x[d+4>>2]=a|1;x[a+d>>2]=a;if(x[31618]!=(d|0)){break f}x[31615]=a;return}if(a>>>0<=255){b=(a&-8)+126492|0;c=x[31613];a=1<<(a>>>3);k:{if(!(c&a)){x[31613]=a|c;a=b;break k}a=x[b+8>>2]}x[b+8>>2]=d;x[a+12>>2]=d;x[d+12>>2]=b;x[d+8>>2]=a;return}c=31;if(a>>>0<=16777215){b=G(a>>>8|0);c=((a>>>38-b&1)-(b<<1)|0)+62|0}x[d+28>>2]=c;x[d+16>>2]=0;x[d+20>>2]=0;b=(c<<2)+126756|0;l:{m:{e=x[31614];g=1<<c;n:{if(!(e&g)){x[31614]=e|g;x[b>>2]=d;x[d+24>>2]=b;break n}c=a<<((c|0)!=31?25-(c>>>1|0)|0:0);b=x[b>>2];while(1){e=b;if((x[b+4>>2]&-8)==(a|0)){break m}g=c>>>29|0;c=c<<1;g=b+(g&4)|0;b=x[g+16>>2];if(b){continue}break}x[g+16>>2]=d;x[d+24>>2]=e}x[d+12>>2]=d;x[d+8>>2]=d;break l}a=x[e+8>>2];x[a+12>>2]=d;x[e+8>>2]=d;x[d+24>>2]=0;x[d+12>>2]=e;x[d+8>>2]=a}a=x[31621]-1|0;x[31621]=a?a:-1}}function _R(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=E(0),j=0,k=0,l=E(0),m=E(0),n=0,o=0,p=0,q=0,r=0,s=0,t=E(0),u=0;if(b){KA(a);c=a+24596|0;x[c>>2]=0;x[c+4>>2]=0;x[a+24588>>2]=0;x[a+24592>>2]=0;dS(a)}ZR(a+24648|0);o=x[a+24620>>2];f=fb-144|0;fb=f;d=!b;e=a+397456|0;c=x[e+4>>2];if(c>>>0>=29){x[e+4>>2]=0;c=0}g=D(c,44)+46032|0;if(!((g|0)==x[e+8>>2]&d)){x[e+8>>2]=g;m=E(o>>>0);c=f+12|0;d=x[g+24>>2];x[c>>2]=d;j=x[g+16>>2];x[c+4>>2]=j;x[c+8>>2]=x[g+4>>2];k=(d|0)>(j|0)?d:j;if((k|0)<=-601){h=j;j=k+600|0;x[c+4>>2]=h-j;x[c>>2]=d-j}i=E(B[g+36>>2]*E(79.30999755859375));a:{if(E(F(i))<E(2147483648)){d=~~i;break a}d=-2147483648}x[c+16>>2]=d- -8192;i=E(E(E(B[g+32>>2]*E(.0036000001709908247))+E(.15000000596046448))*E(32767));b:{if(E(F(i))<E(2147483648)){d=~~i;break b}d=-2147483648}x[c+20>>2]=(d|0)>=32512?32512:d;j=0;i=B[g+8>>2];l=B[g+20>>2];l=E((l>E(.10000000149011612)?E(.10000000149011612):l)*m);c:{if(E(F(l))<E(2147483648)){d=~~l;break c}d=-2147483648}k=(d|0)<=96?96:d;h=k-7500|0;n=k>>>0>=h>>>0?h:0;l=E(B[g+28>>2]*m);d:{if(E(F(l))<E(2147483648)){h=~~l;break d}h=-2147483648}d=n+(h+((d|0)<96?d-96|0:0)|0)|0;h=(d|0)<=128?128:d;p=h>>>0>=3800?3800:h;x[c+24>>2]=p;n=(d|0)<128?d-128|0:0;i=E(i*m);e:{if(E(F(i))<E(2147483648)){q=~~i;break e}q=-2147483648}d=h-3800|0;h=(q+n|0)+(d>>>0<=h>>>0?d:0)|0;x[c+32>>2]=h;n=k>>>0>=7500?7500:k;while(1){if((j|0)==8){i=E(h|0);l=E(Ce(E(.0010000000474974513),(h|0)<4721?E(1):E(E(4720)/i))*E(32768));f:{if(E(F(l))<E(2147483648)){d=~~l;break f}d=-2147483648}x[c+12>>2]=d;i=E(B[g+12>>2]*i);s=c,t=Ce(E(.0010000000474974513),i<=E(4720)?E(1):E(E(4720)/i)),B[s+28>>2]=t}else{d=D(j,12);k=d+c|0;w[k+42>>1]=z[d+47322>>1];w[k+36>>1]=z[d+47316>>1];w[k+40>>1]=z[d+47320>>1];w[k+38>>1]=z[d+47318>>1];x[k+44>>2]=n+((D(x[d+47312>>2],p)+50|0)/100|0);j=j+1|0;continue}break}x[e+20>>2]=x[f+44>>2];r=+m;c=NP(OP(x[f+20>>2]),r);w[e+86>>1]=c;w[e+84>>1]=c;c=z[f+28>>1]<<1;w[e+94>>1]=c;w[e+92>>1]=c;c=0;while(1){if((c|0)==8){x[e+49892>>2]=x[f+36>>2];c=x[f+16>>2];if((c|0)>-9e3){c=MP(c)}else{c=0}x[e+80>>2]=c;d=e+49948|0;c=x[f+12>>2];if((c|0)>=-8999){c=MP(c)}else{c=0}x[d>>2]=c;c=x[f+32>>2];d=e+49932|0;x[d>>2]=268464128;x[d+4>>2]=1879052288;c=c>>>0>=32512?32512:c;w[e+49906>>1]=c;w[e+49904>>1]=c;w[e+49902>>1]=c;w[e+49900>>1]=c;x[f+8>>2]=x[f+24>>2];Fe(f+8|0,0,32752);c=z[f+8>>1];w[e+49914>>1]=c;w[e+49910>>1]=0;w[e+49912>>1]=0;w[e+49908>>1]=c;m=B[f+40>>2];s=f,u=NP(+E(m*m),r),x[s+4>>2]=u;Fe(f+4|0,256,32512);c=z[f+4>>1];w[e+49922>>1]=c;w[e+49918>>1]=0;w[e+49920>>1]=0;w[e+49916>>1]=c}else{d=(c<<4)+e|0;g=(f+12|0)+D(c,12)|0;j=x[g+44>>2];x[d+100>>2]=j;x[d+104>>2]=j;w[d+108>>1]=z[g+36>>1];w[d+110>>1]=z[g+42>>1];w[d+112>>1]=z[g+40>>1];w[d+114>>1]=z[g+38>>1];c=c+1|0;continue}break}}if(b){x[e+16>>2]=0;QP(e,a+397448|0,a+397452|0)}b=D(o,5);if(b>>>0>A[e+20>>2]){x[e+20>>2]=b}fb=f+144|0;b=x[a+1298300>>2];if(Dd(b)){OU(b,x[a+24620>>2])}}function Wfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=fb-112|0;fb=e;g=x[b+4>>2];h=y[b+11|0];a:{if(Ad(g,h)){break a}f=y[wz(b)|0];if((f|0)==33){d=1}else{if((f|0)!=63){break a}d=0}f=e+100|0;tx(f,b,0,Yc(g,h)-1|0);Ab(b,f);tb(f)}f=e+100|0;ge(f);g=x[e+100>>2];ge(e+88|0);g=bN(g,x[e+92>>2],b);ge(f);b:{c:{d:{e:{if((g|0)==x[e+104>>2]){if(Ld(b,22303)){a=ac(8);x[31737]=0;S(1008,f|0,18282,c|0);b=x[31737];x[31737]=0;if((b|0)==1){break d}pc(a,f);x[31737]=0;S(98,a|0,48540,1006);a=x[31737];x[31737]=0;if((a|0)!=1){break b}b=N()|0;tb(f);break c}if(!d){break e}a=ac(8);x[31737]=0;d=e+76|0;S(1008,d|0,18318,b|0);b=x[31737];x[31737]=0;f:{g:{h:{i:{j:{if((b|0)!=1){x[31737]=0;b=e+88|0;O(1019,b|0,d|0);d=x[31737];x[31737]=0;if((d|0)==1){break j}x[31737]=0;f=e+100|0;S(545,f|0,b|0,c|0);b=x[31737];x[31737]=0;d=1;if((b|0)==1){break i}pc(a,f);x[31737]=0;S(98,a|0,48540,1006);b=x[31737];x[31737]=0;if((b|0)!=1){break b}b=N()|0;tb(f);d=0;break h}b=N()|0;break f}b=N()|0;d=1;break g}b=N()|0}tb(e+88|0)}tb(e+76|0);if(!d){break c}}jc(a);break c}k:{switch(x[g+4>>2]){case 0:ee(e+68|0,b);b=fb-176|0;fb=b;g=b+12|0;Wf(g,c);x[31737]=0;f=b+24|0;O(125,f|0,g|0);c=x[31737];x[31737]=0;l:{m:{n:{o:{p:{if((c|0)!=1){x[31737]=0;c=P(104,b+36|0,f|0)|0;h=x[31737];x[31737]=0;if((h|0)==1){break p}tb(f);tb(g);g=x[x[c>>2]-12>>2];x[31737]=0;h=ca(105)|0;i=x[31737];x[31737]=0;if((i|0)==1){break n}x[31737]=0;i=b+8|0;S(106,i|0,c+g|0,h|0);g=x[31737];x[31737]=0;if((g|0)==1){break n}Zb(i);x[31737]=0;f=P(126,c|0,f|0)|0;g=x[31737];x[31737]=0;if((g|0)==1){break n}c=tk(x[(f+x[x[f>>2]-12>>2]|0)+16>>2]);g=x[b+24>>2];Ff(f);fb=b+176|0;b=(c^-1)&(g|0)!=0;break l}a=N()|0;break o}a=N()|0;tb(b+24|0)}tb(b+12|0);break m}a=N()|0;Ff(c)}Q(a|0);p()}c=x[e+72>>2];x[e>>2]=x[e+68>>2];x[e+4>>2]=c;Pz(a,e,b,d);break e;case 1:ee(e+60|0,b);b=fb-176|0;fb=b;g=b+12|0;Wf(g,c);x[31737]=0;f=b+24|0;O(125,f|0,g|0);c=x[31737];x[31737]=0;q:{r:{s:{t:{u:{if((c|0)!=1){x[31737]=0;c=P(104,b+36|0,f|0)|0;h=x[31737];x[31737]=0;if((h|0)==1){break u}tb(f);tb(g);g=x[x[c>>2]-12>>2];x[31737]=0;h=ca(105)|0;i=x[31737];x[31737]=0;if((i|0)==1){break s}x[31737]=0;i=b+8|0;S(106,i|0,c+g|0,h|0);g=x[31737];x[31737]=0;if((g|0)==1){break s}Zb(i);x[31737]=0;x[b+24>>2]=0;x[b+28>>2]=0;f=P(1135,c|0,f|0)|0;g=x[31737];x[31737]=0;if((g|0)==1){break s}c=tk(x[(f+x[x[f>>2]-12>>2]|0)+16>>2]);g=x[b+24>>2];h=x[b+28>>2];Ff(f);fb=b+176|0;b=c?0:g;c=c?0:h;break q}a=N()|0;break t}a=N()|0;tb(b+24|0)}tb(b+12|0);break r}a=N()|0;Ff(c)}Q(a|0);p()}f=x[e+64>>2];x[e+8>>2]=x[e+60>>2];x[e+12>>2]=f;Nz(a,e+8|0,b,c,d);break e;case 2:ee(e+52|0,b);j=p_(c);b=x[e+56>>2];x[e+16>>2]=x[e+52>>2];x[e+20>>2]=b;Oz(a,e+16|0,j,d);break e;case 3:break k;default:break e}}ee(e+44|0,b);ee(e+32|0,c);b=x[e+48>>2];x[e+24>>2]=x[e+44>>2];x[e+28>>2]=b;Mz(a,e+24|0,x[e+32>>2],x[e+36>>2],d)}fb=e+112|0;return}b=N()|0;jc(a)}Q(b|0)}p()}function Coa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,D=0;h=fb-4128|0;fb=h;i=Bb(y[a+14|0]|y[a+15|0]<<8);if(!(!i|i>>>0>20|z[b+480190>>1]<=y[a+23|0])){ld(d,32);w[d+34>>1]=1;j=h+12|0;g=j;i=a+20|0;x[g>>2]=i;x[g+4>>2]=(i+80|0)-i>>2;vW(h+4120|0,x[h+12>>2],x[h+16>>2],Bb(y[a+14|0]|y[a+15|0]<<8));f=x[h+4120>>2];i=y[yb(f,0)+3|0];x[h+12>>2]=1;g=x[ad(ti(b,i+1|0)+24|0,g)>>2];i=x[h+4124>>2];vW(j,f,i,c?i:1);C=h,D=wb(x[h+12>>2]),x[C+4108>>2]=D;r=1/+(g>>>0);i=fb-16|0;fb=i;o=x[vb(i+12|0,x[h+12>>2]+(x[h+16>>2]<<2)|0)>>2];fb=i+16|0;f=x[d>>2];q=x[h+4120>>2];l=z[b+480190>>1];while(1){g=x[h+4108>>2];if(Ib(g,o)){i=y[g+3|0];a:{if(i>>>0>=l>>>0){break a}j=v[g+1|0];if((j|0)<0){break a}g=ti(b,i+1|0);i=x[g>>2];f=Ze(r*(Di(+(j-v[yb(q,0)+1|0]|0)/-12)*+(i>>>0)*+A[g+24>>2]))+f|0;x[d>>2]=f}Je(h+4108|0);continue}else{b:{s=Eh(d);if(!s){break b}i=(e<<12>>>0)/1e4|0;g=x[h+4124>>2];f=fb-16|0;fb=f;k=h+4108|0;x[k>>2]=0;x[k+4>>2]=0;sc(k+8|0);Rd(f+8|0,x[vb(f+4|0,k)>>2]);c:{if(!g){break c}x[31737]=0;O(756,k|0,g|0);e=x[31737];x[31737]=0;if((e|0)!=1){x[31737]=0;hW(k,g);e=x[31737];x[31737]=0;if((e|0)!=1){break c}}a=N()|0;gW(f+8|0);Q(a|0);p()}e=f+8|0;Qd(e);gW(e);fb=f+16|0;o=x[k>>2];t=x[h+4120>>2];q=x[h+4124>>2];f=0;while(1){if((f|0)==(q|0)){i=b+24648|0}else{g=yb(t,f);e=uW(o,f);l=y[g+3|0];d:{if(l>>>0>=z[b+480190>>1]){break d}j=v[g+1|0];if((j|0)<0){break d}u=0;g=y[g+2|0];if((g+14&255)>>>0<=5){u=v[g+25214|0]}n=ti(b,l+1|0);g=x[n+24>>2];B=r*(Di(+(u<<24>>24)/96+ +(j-v[yb(t,0)+1|0]|0)/12)*+(g>>>0));if(B<=0){break d}l=tW(B);x[e+8>>2]=l;j=hb;x[e+12>>2]=j;x[e+16>>2]=x[n+20>>2];g=x[n>>2];x[e+76>>2]=g;x[e+88>>2]=z[n+34>>1]&1023;e:{if(c){x[e+664>>2]=m;m=Ze(+(g>>>0)/rC(l,j))+m|0;g=i;break e}g=(i>>>0)/(Bb(y[a+14|0]|y[a+15|0]<<8)>>>0)|0}x[e+20>>2]=g;x[e+24>>2]=g}f=f+1|0;continue}break}b=0;while(1){f:{a=x[d>>2];if(a>>>0>b>>>0){Rb(h+12|0,0,4096);x[h+8>>2]=512;x[h+4>>2]=a-b;j=x[Gb(h+8|0,h+4|0)>>2];C=h,D=wb(x[k>>2]),x[C+8>>2]=D;c=wb(x[k+4>>2]);while(1){f=x[h+8>>2];if(!Ib(f,c)){break f}g:{h:{if(!x[f+16>>2]){break h}g=x[f+664>>2];if(g>>>0>=j>>>0){x[f+664>>2]=g-j;break h}e=x[f+88>>2];x[h+4>>2]=j-g;C=h,D=Ze((+A[f+76>>2]-rC(x[f>>2],x[f+4>>2]))/rC(x[f+8>>2],x[f+12>>2])),x[C>>2]=D;a=x[Gb(h+4|0,h)>>2];x[31737]=0;V(x[((e&1|(e&64?18:16))<<2)+25808>>2],f|0,i|0,(h+12|0)+(g<<3)|0,a|0);a=x[31737];x[31737]=0;if((a|0)==1){break g}x[f+664>>2]=0;if(A[f+76>>2]>A[f+4>>2]){break h}x[f+16>>2]=0}x[h+8>>2]=x[h+8>>2]+872;continue}break}a=N()|0;sW(k);Q(a|0);p()}sW(k);break b}e=x[d+20>>2]+(b<<1)|0;f=h+12|0;c=fb-16|0;fb=c;x[c+12>>2]=j;wc(c+12|0,512);m=x[c+12>>2];while(1){if(m){a=qd(x[f>>2]+2048|0,12);a=(a|0)>=32767?32767:a;w[e>>1]=(a|0)<=-32768?-32768:a;f=f+8|0;e=e+2|0;m=m-1|0;continue}break}fb=c+16|0;b=b+j|0;continue}}f=(s|0)!=0}break}}fb=h+4128|0;return f|0}function Ev(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=a+b|0;c=x[a+4>>2];a:{b:{if(c&1){break b}if(!(c&3)){break a}c=x[a>>2];b=c+b|0;c:{d:{e:{a=a-c|0;if((a|0)!=x[31618]){if(c>>>0<=255){d=x[a+8>>2];e=x[a+12>>2];if((d|0)!=(e|0)){break e}i=126452,j=x[31613]&Vua(-2,c>>>3|0),x[i>>2]=j;break b}h=x[a+24>>2];c=x[a+12>>2];if((c|0)!=(a|0)){d=x[a+8>>2];x[d+12>>2]=c;x[c+8>>2]=d;break c}e=a+20|0;d=x[e>>2];if(!d){d=x[a+16>>2];if(!d){break d}e=a+16|0}while(1){g=e;c=d;e=c+20|0;d=x[e>>2];if(d){continue}e=c+16|0;d=x[c+16>>2];if(d){continue}break}x[g>>2]=0;break c}c=x[f+4>>2];if((c&3)!=3){break b}x[31615]=b;x[f+4>>2]=c&-2;x[a+4>>2]=b|1;x[f>>2]=b;return}x[d+12>>2]=e;x[e+8>>2]=d;break b}c=0}if(!h){break b}d=x[a+28>>2];e=(d<<2)+126756|0;f:{if(x[e>>2]==(a|0)){x[e>>2]=c;if(c){break f}i=126456,j=x[31614]&Vua(-2,d),x[i>>2]=j;break b}x[h+(x[h+16>>2]==(a|0)?16:20)>>2]=c;if(!c){break b}}x[c+24>>2]=h;d=x[a+16>>2];if(d){x[c+16>>2]=d;x[d+24>>2]=c}d=x[a+20>>2];if(!d){break b}x[c+20>>2]=d;x[d+24>>2]=c}g:{h:{i:{j:{c=x[f+4>>2];if(!(c&2)){if(x[31619]==(f|0)){x[31619]=a;b=x[31616]+b|0;x[31616]=b;x[a+4>>2]=b|1;if(x[31618]!=(a|0)){break a}x[31615]=0;x[31618]=0;return}if(x[31618]==(f|0)){x[31618]=a;b=x[31615]+b|0;x[31615]=b;x[a+4>>2]=b|1;x[a+b>>2]=b;return}b=(c&-8)+b|0;if(c>>>0<=255){e=c>>>3|0;c=x[f+12>>2];d=x[f+8>>2];if((c|0)==(d|0)){i=126452,j=x[31613]&Vua(-2,e),x[i>>2]=j;break h}x[d+12>>2]=c;x[c+8>>2]=d;break h}h=x[f+24>>2];c=x[f+12>>2];if((f|0)!=(c|0)){d=x[f+8>>2];x[d+12>>2]=c;x[c+8>>2]=d;break i}e=f+20|0;d=x[e>>2];if(!d){d=x[f+16>>2];if(!d){break j}e=f+16|0}while(1){g=e;c=d;e=c+20|0;d=x[e>>2];if(d){continue}e=c+16|0;d=x[c+16>>2];if(d){continue}break}x[g>>2]=0;break i}x[f+4>>2]=c&-2;x[a+4>>2]=b|1;x[a+b>>2]=b;break g}c=0}if(!h){break h}d=x[f+28>>2];e=(d<<2)+126756|0;k:{if(x[e>>2]==(f|0)){x[e>>2]=c;if(c){break k}i=126456,j=x[31614]&Vua(-2,d),x[i>>2]=j;break h}x[h+(x[h+16>>2]==(f|0)?16:20)>>2]=c;if(!c){break h}}x[c+24>>2]=h;d=x[f+16>>2];if(d){x[c+16>>2]=d;x[d+24>>2]=c}d=x[f+20>>2];if(!d){break h}x[c+20>>2]=d;x[d+24>>2]=c}x[a+4>>2]=b|1;x[a+b>>2]=b;if(x[31618]!=(a|0)){break g}x[31615]=b;return}if(b>>>0<=255){c=(b&-8)+126492|0;d=x[31613];b=1<<(b>>>3);l:{if(!(d&b)){x[31613]=b|d;b=c;break l}b=x[c+8>>2]}x[c+8>>2]=a;x[b+12>>2]=a;x[a+12>>2]=c;x[a+8>>2]=b;return}d=31;if(b>>>0<=16777215){c=G(b>>>8|0);d=((b>>>38-c&1)-(c<<1)|0)+62|0}x[a+28>>2]=d;x[a+16>>2]=0;x[a+20>>2]=0;c=(d<<2)+126756|0;m:{e=x[31614];g=1<<d;n:{if(!(e&g)){x[31614]=e|g;x[c>>2]=a;x[a+24>>2]=c;break n}d=b<<((d|0)!=31?25-(d>>>1|0)|0:0);c=x[c>>2];while(1){e=c;if((x[c+4>>2]&-8)==(b|0)){break m}g=d>>>29|0;d=d<<1;g=c+(g&4)|0;c=x[g+16>>2];if(c){continue}break}x[g+16>>2]=a;x[a+24>>2]=e}x[a+12>>2]=a;x[a+8>>2]=a;return}b=x[e+8>>2];x[b+12>>2]=a;x[e+8>>2]=a;x[a+24>>2]=0;x[a+12>>2]=e;x[a+8>>2]=b}}function _na(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;j=fb-32|0;fb=j;a:{b:{if(ev(a)>>>0<b>>>0){if((b|0)<0){break b}m=Xo(j+20|0);x[31737]=0;O(763,m|0,b|0);b=x[31737];x[31737]=0;if((b|0)==1){break a}rn(j+12|0,x[a>>2]);dr(j+4|0,x[a>>2],x[a+4>>2]);l=fb-48|0;fb=l;e=x[m+4>>2];c=gc(l+40|0,x[j+12>>2],x[j+16>>2]);f=gc(l+32|0,x[j+4>>2],x[j+8>>2]);b=fb-16|0;fb=b;c=gc(b+8|0,x[c>>2],x[c+4>>2]);f=gc(b,x[f>>2],x[f+4>>2]);c=rX(x[c>>2],x[c+4>>2],x[f>>2],x[f+4>>2]);fb=b+16|0;c=c+e|0;x[m+4>>2]=c;c:{d:{if(!e){b=c-1|0;break d}b=c-1|0;if((b^e-1)>>>0<32){break c}}x[x[m>>2]+((c>>>0>=33?b>>>5|0:0)<<2)>>2]=0}c=gc(l+24|0,x[j+12>>2],x[j+16>>2]);g=gc(l+16|0,x[j+4>>2],x[j+8>>2]);b=l+8|0;Dp(b,x[m>>2],e);e=x[c>>2];n=fb-48|0;fb=n;c=x[c+4>>2];e:{if((c|0)==x[b+4>>2]){f=gc(n+40|0,e,c);c=gc(n+32|0,x[g>>2],x[g+4>>2]);b=gc(n+24|0,x[b>>2],x[b+4>>2]);e=fb-16|0;fb=e;g=x[f>>2];d=x[f+4>>2];c=qn(x[c>>2],x[c+4>>2],g,d);x[e+12>>2]=c;f:{if((c|0)<=0){c=x[b>>2];break f}if(d){i=32-d|0;x[e+8>>2]=i;h=c;c=x[ud(e+8|0,e+12|0)>>2];x[e+12>>2]=h-c;h=x[b>>2];d=-1<<d&-1>>>i-c;x[h>>2]=x[h>>2]&(d^-1)|d&x[g>>2];c=c+x[b+4>>2]|0;x[b+4>>2]=c&31;x[b>>2]=h+(c>>>3&536870908);g=x[f>>2]+4|0;x[f>>2]=g;c=x[e+12>>2]}h=g;g=(c|0)/32|0;iD(h,g,x[b>>2]);d=c-(g<<5)|0;x[e+12>>2]=d;g=g<<2;c=g+x[b>>2]|0;x[b>>2]=c;if((d|0)<=0){break f}c=f;f=g+x[f>>2]|0;x[c>>2]=f;c=x[b>>2];g=-1>>>32-d|0;x[c>>2]=x[c>>2]&(g^-1)|g&x[f>>2];x[b+4>>2]=x[e+12>>2]}gc(l,c,x[b+4>>2]);fb=e+16|0;break e}c=gc(n+16|0,e,c);e=gc(n+8|0,x[g>>2],x[g+4>>2]);g=gc(n,x[b>>2],x[b+4>>2]);f=fb-16|0;fb=f;h=x[e>>2];d=x[e+4>>2];b=x[c>>2];e=x[c+4>>2];d=qn(h,d,b,e);x[f+12>>2]=d;g:{if((d|0)<=0){e=x[g+4>>2];c=x[g>>2];break g}h:{if(!e){e=x[g+4>>2];break h}k=32-e|0;x[f+8>>2]=k;i=f+8|0;h=x[ud(i,f+12|0)>>2];x[f+12>>2]=d-h;d=x[g+4>>2];q=x[b>>2];x[f+8>>2]=h;o=32-d|0;x[f+4>>2]=o;b=x[g>>2];r=x[b>>2];i=x[Gb(i,f+4|0)>>2];k=q&(-1<<e&-1>>>k-h);x[b>>2]=(-1<<d&-1>>>o-i^-1)&r|(e>>>0<d>>>0?k<<d-e:k>>>e-d|0);d=d+i|0;e=d&31;x[g+4>>2]=e;d=b+(d>>>3&536870908)|0;x[g>>2]=d;b=h-i|0;if((b|0)>0){x[d>>2]=x[d>>2]&(-1>>>32-b^-1)|k>>>i+x[c+4>>2];x[g+4>>2]=b;e=b}b=x[c>>2]+4|0;x[c>>2]=b;d=x[f+12>>2]}h=32-e|0;i=-1<<e;k=i^-1;while(1){if((d|0)>=32){d=x[g>>2];b=x[b>>2];x[d>>2]=k&x[d>>2]|b<<e;x[g>>2]=d+4;x[d+4>>2]=i&x[d+4>>2]|b>>>h;d=x[f+12>>2]-32|0;x[f+12>>2]=d;b=x[c>>2]+4|0;x[c>>2]=b;continue}break}c=x[g>>2];if((d|0)<=0){break g}k=x[b>>2];x[f+8>>2]=h;o=x[c>>2];b=x[ud(f+12|0,f+8|0)>>2];i=o&(i&-1>>>h-b^-1);h=k&-1>>>32-d;x[c>>2]=i|h<<e;d=b+e|0;e=d&31;x[g+4>>2]=e;c=(d>>>3&536870908)+c|0;x[g>>2]=c;d=x[f+12>>2]-b|0;x[f+12>>2]=d;if((d|0)<=0){break g}x[c>>2]=x[c>>2]&(-1>>>32-d^-1)|h>>>b;e=x[f+12>>2];x[g+4>>2]=e}gc(l,c,e);fb=f+16|0}fb=n+48|0;fb=l+48|0;iC(a,m);tf(m)}fb=j+32|0;return}dd();p()}a=N()|0;tf(m);Q(a|0);p()}function LZ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=fb-128|0;fb=f;i=qg(f+116|0);a:{b:{c:{if(d){x[31737]=0;S(483,a|0,i|0,c|0);c=x[31737];x[31737]=0;if((c|0)!=1){break c}break b}x[31737]=0;S(484,a|0,i|0,c|0);c=x[31737];x[31737]=0;if((c|0)==1){break b}}m=Nb(f+104|0);c=1;while(1){d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{k=c&65535;if(k>>>0<=z[b+480192>>1]){x[31737]=0;w[f+102>>1]=0;j=f+102|0;O(485,a|0,j|0);d=x[31737];x[31737]=0;t:{u:{v:{w:{if((d|0)!=1){e=fb-16|0;fb=e;l=z[j>>1];d=ce(i);h=ec(i);g=fb-16|0;fb=g;while(1){if(d){n=cp(z[d+16>>1],l);h=n?h:d;d=x[(n?d+4|0:d)>>2];continue}break}d=x[vb(g+12|0,h)>>2];fb=g+16|0;x:{if(Ib(d,rg(i))){if(!cp(z[j>>1],z[td(d)>>1])){break x}}d=rg(i)}d=vb(e+12|0,d);fb=e+16|0;j=((k<<2)+b|0)+900380|0;if(!x[j>>2]){break d}d=x[d>>2];if(!Zg(d,Rf(i))){break u}x[31737]=0;h=P(3,f+88|0,td(d)+4|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break t}x[31737]=0;d=P(1,f+76|0,16827)|0;e=x[31737];x[31737]=0;if((e|0)==1){break v}e=lr(h,d);tb(d);if(e){break p}d=x[b+4>>2];x[31737]=0;d=P(486,d|0,h|0)|0;e=x[31737];x[31737]=0;if((e|0)==1){break r}x[x[j>>2]+44>>2]=d;if(!x[x[j>>2]+44>>2]){break w}break e}c=N()|0;break f}x[31737]=0;d=P(1,f- -64|0,13559)|0;e=x[31737];x[31737]=0;y:{z:{A:{if((e|0)!=1){B:{if(!lr(h,d)){x[31737]=0;e=P(1,f+52|0,13764)|0;g=x[31737];x[31737]=0;if((g|0)==1){break A}g=lr(h,e);tb(e);tb(d);if(g){break B}break s}tb(d)}x[31737]=0;d=R(487,h|0)|0;e=x[31737];x[31737]=0;if((e|0)==1){break z}x[f+36>>2]=d;d=x[b+4>>2];e=f+36|0;g=x[qe(f+48|0,e)>>2];x[31737]=0;d=P(488,d|0,g|0)|0;g=x[31737];x[31737]=0;if((g|0)==1){break y}og(e);if(d){break e}break s}c=N()|0;break g}c=N()|0;tb(d);break g}c=N()|0;break g}c=N()|0;og(f+36|0);break g}c=N()|0;break g}d=x[j>>2];if(!d){break d}x[d+44>>2]=0;break d}c=N()|0;break f}Td(m);JZ(i);fb=f+128|0;return}d=wb(x[m>>2]);g=wb(x[m+4>>2]);e=fb-16|0;fb=e;x[e+12>>2]=d;while(1){C:{D:{if(Ib(d,g)){if(!lr(d,h)){break D}d=x[e+12>>2]}fb=e+16|0;break C}d=x[hl(e+12|0)>>2];continue}break}if(Ib(d,wb(x[m+4>>2]))){break p}x[31737]=0;O(489,m|0,h|0);d=x[31737];x[31737]=0;if((d|0)!=1){break q}}c=N()|0;break g}x[31737]=0;d=P(1,f+12|0,17544)|0;e=x[31737];x[31737]=0;if((e|0)==1){break o}x[31737]=0;g=f+24|0;S(490,g|0,d|0,h|0);e=x[31737];x[31737]=0;if((e|0)==1){break n}x[31737]=0;e=P(1,f|0,16403)|0;k=x[31737];x[31737]=0;if((k|0)==1){break m}x[31737]=0;k=f+36|0;S(2,k|0,g|0,e|0);l=x[31737];x[31737]=0;if((l|0)==1){break l}l=x[b+1298472>>2];x[31737]=0;S(386,l|0,2,k|0);l=x[31737];x[31737]=0;if((l|0)==1){break k}tb(k);tb(e);tb(g);tb(d)}x[x[j>>2]+44>>2]=0;break e}c=N()|0;break g}c=N()|0;break h}c=N()|0;break i}c=N()|0;break j}c=N()|0;tb(f+36|0)}tb(e)}tb(f+24|0)}tb(d)}tb(h)}Td(m);break a}tb(h)}c=c+1|0;continue}}c=N()|0}JZ(i);Q(c|0);p()}function O1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,w=0;e=fb-32|0;fb=e;a:{if((d|0)<=0){break a}x[e+8>>2]=d;x[e+20>>2]=b;x[e+16>>2]=214748364;u=e,w=D(x[Gb(e+20|0,e+16|0)>>2],20),x[u+24>>2]=w;vo(c,x[Gb(e+8|0,e+24|0)>>2]);x[e+12>>2]=b;x[e+8>>2]=a;while(1){b:{c:{d:{e:{if((d|0)<=0){break e}g=Jh(a,b,i);h=Jh(a,b,i+4|0);f=Jh(a,b,i+5|0);u=e,w=Jh(a,b,i+6|0)<<8|Jh(a,b,i+7|0),x[u+28>>2]=w;o=h<<8|f;t=i+8|0;f:{g:{switch(g|0){case 0:i=0;if(d>>>0<o>>>0){i=ac(8);x[31737]=0;a=R(189,i|0)|0;b=x[31737];x[31737]=0;if((b|0)!=1){break f}break d}while(1){if((i|0)!=(o|0)){u=e,w=Jh(a,b,i+t|0),v[u+24|0]=w;uo(c,e+24|0);i=i+1|0;continue}break};s=o;break b;case 1:break g;default:break e}}Ai(e+28|0,d);s=x[e+28>>2];q=Jh(a,b,i+10|0);v[e+24|0]=q;uo(c,e+24|0);j=i+11|0;o=o+3&65532;i=s-1|0;h=0;l=0;r=0;n=0;while(1){if((i|0)<=0){break c}f=Og(j,h,1,e+8|0);h:{i:{j:{k:{l:{if((l|0)<=7){if(f){g=h;break i}g=h+1|0;n=8;break l}g=h+1|0;m:{if(!f){m=e+8|0;if(!Og(j,g,1,m)){break i}k=2;n:{o:{f=h+2|0;if(!Og(j,f,1,m)){break o}k=3;f=h+3|0;if(!Og(j,f,1,m)){break o}k=Og(j,f,3,m);g=h+6|0;break n}g=f+1|0}f=4;p:{q:{r:{h=((n<<3)+k|0)-17|0;s:{if((h|0)<0){a=ac(8);x[31737]=0;b=R(189,a|0)|0;c=x[31737];x[31737]=0;if((c|0)!=1){break r}break s}if(h>>>0<56){break p}a=ac(8);x[31737]=0;b=R(189,a|0)|0;c=x[31737];x[31737]=0;if((c|0)!=1){break q}}b=N()|0;jc(a);Q(b|0);p()}da(b|0,24488,163);p()}da(b|0,24488,163);p()}n=y[h+24528|0];if((n|0)!=8){break k}break m}f=4;if((n|0)!=8){break k}}n=8;f=1;if((r|0)>19){break k}}f=0;break j}r=r+8|0}while(1){if(!((f|0)<0|(i|0)<=0)){k=(g|0)/8|0;h=k+j|0;m=Jh(x[e+8>>2],x[e+12>>2],h);q=q-qd((Jh(x[e+8>>2],x[e+12>>2],h+1|0)<<8|m<<16|Jh(x[e+8>>2],x[e+12>>2],h+2|0))<<(g-(k<<3)|0)+8,32-n|0)|0;v[e+24|0]=q;uo(c,e+24|0);f=f-1|0;i=i-1|0;g=g+n|0;continue}break}l=(l|0)==31?31:l+1|0;h=g;break h}t:{u:{v:{f=g+1|0;if(!Og(j,f,1,e+8|0)){h=2;break v}f=g+2|0;if(!Og(j,f,1,e+8|0)){h=4;break v}f=g+3|0;if(!Og(j,f,1,e+8|0)){h=6;break v}f=g+5|0;h=e+8|0;if(!Og(j,g+4|0,1,h)){g=g+8|0;f=Og(j,f,3,h)+8|0;break t}g=g+10|0;h=16;f=Og(j,f,5,e+8|0);break u}g=f+2|0;f=Og(j,f+1|0,1,e+8|0)}f=f+h|0}w:{if(Og(j,g,1,e+8|0)){k=-256;h=12;break w}g=g+1|0;h=Og(j,g,1,e+8|0);k=h?-4352:0;h=h?14:8}m=g+1|0;g=Og(j,m,h,e+8|0);if(f>>>0>=3){l=l-((f|0)!=3)|0;l=((l|0)<=1?1:l)-1|0}k=(g^-1)+k|0;g=Vc(x[c>>2],x[c+4>>2])+k|0;if(g>>>0<k>>>0){h=h+m|0;while(1){if((f|0)<=0|(i|0)<=0){break h}q=y[xb(x[c>>2],g)|0];v[e+24|0]=q;uo(c,e+24|0);i=i-1|0;g=g+1|0;f=f-1|0;continue}}i=ac(8);x[31737]=0;a=R(189,i|0)|0;b=x[31737];x[31737]=0;if((b|0)==1){break d}da(a|0,24488,163);p()}r=r-(r>>3)|0;continue}}da(a|0,24488,163);p()}i=mc(x[c>>2],x[c+4>>2])^1;break a}a=N()|0;jc(i);Q(a|0);p()}x[e+28>>2]=i}d=d-s|0;i=o+t|0;continue}}fb=e+32|0;return i|0}function V1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=fb-144|0;fb=d;xc(b);Rp(a);a:{f=d+108|0;if(!Zw(b,f)){break a}if(!eG(f)){break a}n=x[b+8>>2];b:{if(!cd(b,y[f+16|0]|y[f+17|0]<<8|(y[f+18|0]<<16|y[f+19|0]<<24))){break b}while(1){if((y[f+12|0]|y[f+13|0]<<8|(y[f+14|0]<<16|y[f+15|0]<<24))>>>0<=j>>>0){break b}if(!Mb(x[b>>2],x[b+8>>2],5)){break b}c:{if((y[f+4|0]|y[f+5|0]<<8)>>>0>=64){if((Ri(b)|0)<=0){break c}}g=0;e=1;while(1){l=Zd(b);if(l){m=g>>>0>4;h=m&e;if(!((e^1)&1|m)){h=(Oq(l<<24>>24)&255)==y[g+13181|0]}e=h;g=g+1|0;continue}break}Vb(b,4);i=(g|0)==5&e|i}j=j+1|0;continue}}cd(b,n);if(!(i&1)){break a}if(!Mb(x[b>>2],x[b+8>>2],dG(f))){break a}if(!c){k=1;break a}h=fb-16|0;fb=h;c=d+108|0;cd(b,y[c+16|0]|y[c+17|0]<<8|(y[c+18|0]<<16|y[c+19|0]<<24));j=d+96|0;f=Nb(j);e=y[c+12|0]|y[c+13|0]<<8|(y[c+14|0]<<16|y[c+15|0]<<24);x[31737]=0;O(177,f|0,e|0);e=x[31737];x[31737]=0;d:{e:{f:{if((e|0)!=1){e=0;g:{h:{while(1){if((y[c+12|0]|y[c+13|0]<<8|(y[c+14|0]<<16|y[c+15|0]<<24))>>>0<=e>>>0){break g}g=x[b+8>>2];i=x[b>>2];x[31737]=0;g=U(151,i|0,g|0,5)|0;i=x[31737];x[31737]=0;if((i|0)==1){break f}if(!g){break g}i=y[c+4|0]|y[c+5|0]<<8;x[31737]=0;g=h+4|0;S(178,g|0,b|0,i|0);i=x[31737];x[31737]=0;if((i|0)!=1){x[31737]=0;O(179,f|0,g|0);i=x[31737];x[31737]=0;if((i|0)==1){break h}e=e+1|0;tb(g);continue}break}a=N()|0;break e}a=N()|0;tb(h+4|0);break e}fb=h+16|0;break d}a=N()|0;break e}a=N()|0}Td(f);Q(a|0);p()}x[31737]=0;V(171,d+84|0,b|0,c|0,j|0);c=x[31737];x[31737]=0;i:{if((c|0)!=1){x[31737]=0;P(150,b|0,y[d+132|0]|y[d+133|0]<<8|(y[d+134|0]<<16|y[d+135|0]<<24))|0;c=x[31737];x[31737]=0;j:{if((c|0)!=1){f=d+36|0;k:{l:{m:{n:{while(1){o:{p:{if((y[d+128|0]|y[d+129|0]<<8|(y[d+130|0]<<16|y[d+131|0]<<24))>>>0>k>>>0){c=x[b+8>>2];e=x[b>>2];x[31737]=0;c=U(151,e|0,c|0,8)|0;e=x[31737];x[31737]=0;if((e|0)==1){break p}if(c){break o}}k=mc(x[a>>2],x[a+4>>2])^1;vc(d+84|0);Td(d+96|0);break a}b=N()|0;break j}x[31737]=0;c=d+60|0;aa(172,c|0,b|0,d+108|0,d+84|0,d+96|0);e=x[31737];x[31737]=0;if((e|0)!=1){e=Tp(c);x[31737]=0;c=R(173,x[d+60>>2])|0;h=x[31737];x[31737]=0;if((h|0)==1){break n}if(c){x[31737]=0;c=R(174,d+24|0)|0;h=x[31737];x[31737]=0;if((h|0)==1){break m}e=x[e>>2];q:{if((e|0)<0){break q}g=x[d+96>>2];if(Ud(g,x[d+100>>2])>>>0<=e>>>0){break q}x[31737]=0;h=d+12|0;O(175,h|0,Hd(g,e)|0);e=x[31737];x[31737]=0;if((e|0)==1){break l}Ab(c,h);tb(h)}Xw(f,d+60|0);x[31737]=0;O(176,a|0,c|0);e=x[31737];x[31737]=0;if((e|0)==1){break l}Mp(c)}k=k+1|0;ub(d+60|0);continue}break}b=N()|0;break j}b=N()|0;break k}b=N()|0;break k}b=N()|0;Mp(c)}ub(d+60|0);break j}b=N()|0}vc(d+84|0);break i}b=N()|0}Td(d+96|0);Q(b|0);p()}fb=d+144|0;return k|0}function XP(a){var b=E(0),c=E(0),d=0,e=E(0),f=E(0),g=0,h=0,i=E(0),k=0,m=E(0),p=E(0),s=E(0),t=0,u=0,v=E(0),w=E(0);d=a+4208|0;yB(yb(d,0),B[a+4272>>2]);b=E(B[yb(d,0)>>2]*E(15920));s=Ce(E(10),E(E(E(B[yb(d,2)>>2]+E(-.5))*E(30))/E(40)));c=E(E(E(b+E(80))/E(A[x[a+16>>2]+24620>>2]))*E(6.2831854820251465));b=nQ(c);v=Aq(c);w=b;f=E(E(c*E(E(E(B[yb(d,1)>>2]*E(35))+E(1))*E(.02888113260269165)))/b);m=(l(2,(q(f),j(2))&-2147483648|1056964608),r());c=E(F(f));k=(q(c),j(2));a:{if(k>>>0<=1118925334){b:{c:{d:{e:{f:{g:{h=(q(c),j(2));d=h&2147483647;if(d>>>0>=1100331076){if(d>>>0>2139095040){break c}b=E(-1);if((h|0)<0){break b}if(d>>>0<1118925336){break g}b=E(c*E(17014118346046923e22));break b}if(d>>>0<1051816473){break e}if(d>>>0>1065686417){break g}if((h|0)>=0){d=1;e=E(905800061445916e-20);b=E(c+E(-.6931381225585938));break f}d=-1;e=E(-905800061445916e-20);b=E(c+E(.6931381225585938));break f}b=E(E(c*E(1.4426950216293335))+(l(2,(q(c),j(2))&-2147483648|1056964608),r()));h:{if(E(F(b))<E(2147483648)){d=~~b;break h}d=-2147483648}b=E(d|0);e=E(b*E(905800061445916e-20));b=E(c+E(b*E(-.6931381225585938)))}c=E(b-e);e=E(E(b-c)-e);break d}if(d>>>0<855638016){break c}d=0}b=E(c*E(.5));i=E(c*b);p=E(E(i*E(E(i*E(.0015807170420885086))+E(-.03333321213722229)))+E(1));b=E(E(3)-E(p*b));p=E(i*E(E(p-b)/E(E(6)-E(c*b))));b=E(c-E(E(c*p)-i));if(!d){break b}e=E(E(E(c*E(p-e))-e)-i);i:{switch(d+1|0){case 0:b=E(E(E(c-e)*E(.5))+E(-.5));break b;case 2:b=E(E(e-E(c+E(.5)))*E(-2));if(c<E(-.25)){break b}b=E(c-e);b=E(E(b+b)+E(1));break b;default:break i}}h=d<<23;b=(l(2,h+1065353216|0),r());if(d>>>0>=57){c=E(E(c-e)+E(1));b=E(((d|0)==128?E(E(c+c)*E(17014118346046923e22)):E(c*b))+E(-1));break b}i=(l(2,1065353216-h|0),r());c=E((d>>>0<=22?E(E(E(1)-i)+E(c-e)):E(E(c-E(e+i))+E(1)))*b)}b=c}if(k>>>0<=1065353215){if(k>>>0<964689920){break a}f=E(m*E(E(b+b)-E(E(b*b)/E(b+E(1)))));break a}f=E(m*E(b+E(b/E(b+E(1)))));break a}m=E(E(m+m)*E(1661534994731145e20));b=E(c+E(-162.88958740234375));d=Zy(b)&2047;j:{k:{if(Zy(E(88))>>>0>d>>>0){break k}c=E(0);if(((q(b),j(2))|0)==-8388608){break j}c=E(b+b);if(Zy(E(Infinity))>>>0<=d>>>0){break j}if(b>E(88.72283172607422)){c=DG(0);break j}if(!(b<E(-103.97207641601562))){break k}c=bG(0);break j}g=C[165]*+b;t=C[164];u=g+t;g=g-(u-t);g=(C[166]*g+C[167])*(g*g)+(C[168]*g+1);o(+u);j(1)|0;d=j(0)|0;h=d<<15;d=((d&31)<<3)+1024|0;k=x[d>>2];d=x[d+4>>2]+h|0;l(0,k|0);l(1,(k>>>0<k>>>0?d+1|0:d)|0);c=E(g*+n())}f=E(E(m*c)*E(1661534994731145e20))}c=E(w*f);f=E(c/s);b=E(f+E(1));B[a+4236>>2]=E(E(1)-f)/b;f=E(E(v*E(-2))/b);B[a+4232>>2]=f;c=E(c*s);B[a+4228>>2]=E(E(1)-c)/b;B[a+4224>>2]=f;B[a+4220>>2]=E(c+E(1))/b}function OG(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=fb-144|0;fb=d;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{if((b|0)<=5){h=d+108|0;ox(h,b);x[31737]=0;e=P(1,d+96|0,18418)|0;b=x[31737];x[31737]=0;if((b|0)==1){break E}x[31737]=0;i=d+120|0;S(2,i|0,h|0,e|0);b=x[31737];x[31737]=0;if((b|0)==1){break D}x[31737]=0;f=P(3,d+72|0,c|0)|0;b=x[31737];x[31737]=0;if((b|0)==1){break C}x[31737]=0;g=P(1,d+60|0,20223)|0;b=x[31737];x[31737]=0;if((b|0)==1){break B}x[31737]=0;c=d+84|0;S(4,c|0,f|0,g|0);b=x[31737];x[31737]=0;if((b|0)==1){break A}x[31737]=0;j=d+132|0;S(2,j|0,i|0,c|0);b=x[31737];x[31737]=0;if((b|0)==1){break z}tb(c);tb(g);tb(f);tb(i);tb(e);tb(h);b=x[a>>2];x[31737]=0;O(5,i|0,(b?b:22303)|0);b=x[31737];x[31737]=0;if((b|0)==1){break t}b=x[a+4>>2];x[31737]=0;O(5,h|0,(b?b:22303)|0);b=x[31737];x[31737]=0;if((b|0)==1){break s}a=x[a+8>>2];x[31737]=0;x[d+48>>2]=a;e=d+48|0;O(6,c|0,e|0);a=x[31737];x[31737]=0;if((a|0)==1){break r}x[31737]=0;P(7,499608,18297)|0;a=x[31737];x[31737]=0;if((a|0)==1){break q}x[31737]=0;O(8,e|0,i|0);a=x[31737];x[31737]=0;if((a|0)==1){break p}x[31737]=0;P(9,499608,e|0)|0;a=x[31737];x[31737]=0;if((a|0)==1){break o}x[31737]=0;P(7,499608,17504)|0;a=x[31737];x[31737]=0;if((a|0)==1){break o}x[31737]=0;f=d+36|0;O(8,f|0,c|0);a=x[31737];x[31737]=0;if((a|0)==1){break n}x[31737]=0;P(9,499608,f|0)|0;a=x[31737];x[31737]=0;if((a|0)==1){break m}x[31737]=0;P(7,499608,17502)|0;a=x[31737];x[31737]=0;if((a|0)==1){break m}x[31737]=0;P(7,499608,18418)|0;a=x[31737];x[31737]=0;if((a|0)==1){break m}x[31737]=0;g=d+24|0;O(8,g|0,j|0);a=x[31737];x[31737]=0;if((a|0)==1){break l}x[31737]=0;P(9,499608,g|0)|0;a=x[31737];x[31737]=0;if((a|0)==1){break k}x[31737]=0;P(7,499608,13585)|0;a=x[31737];x[31737]=0;if((a|0)==1){break k}x[31737]=0;b=d+12|0;O(8,b|0,h|0);a=x[31737];x[31737]=0;if((a|0)==1){break j}x[31737]=0;P(9,499608,b|0)|0;a=x[31737];x[31737]=0;if((a|0)==1){break i}x[31737]=0;P(7,499608,13583)|0;a=x[31737];x[31737]=0;if((a|0)==1){break i}x[31737]=0;R(10,499608)|0;a=x[31737];x[31737]=0;if((a|0)==1){break i}tb(b);tb(g);tb(f);tb(e);tb(c);tb(h);tb(i);tb(j)}fb=d+144|0;return}a=N()|0;break u}a=N()|0;break v}a=N()|0;break w}a=N()|0;break x}a=N()|0;break y}a=N()|0;tb(d+84|0)}tb(g)}tb(f)}tb(d+120|0)}tb(e)}tb(d+108|0);break a}a=N()|0;break b}a=N()|0;break c}a=N()|0;break d}a=N()|0;break e}a=N()|0;break e}a=N()|0;break f}a=N()|0;break f}a=N()|0;break g}a=N()|0;break g}a=N()|0;break h}a=N()|0;break h}a=N()|0;tb(d+12|0)}tb(d+24|0)}tb(d+36|0)}tb(d+48|0)}tb(d+84|0)}tb(d+108|0)}tb(d+120|0)}tb(d+132|0)}Q(a|0);p()}function Cpa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=fb-16|0;fb=g;a:{if(!Mb(x[a>>2],x[a+8>>2],2)){Ng(c+484344|0,b,64);break a}m=c+484344|0;n=Kd(Uk(a),1,1024);if(!Ng(m,b,n)){break a}o=z[c+480188>>1];b:while(1){if((k|0)==(n|0)){break a}e=Wb(x[m>>2],b);bf(g+8|0,x[e>>2],x[x[e+48>>2]+12>>2],k);i=0;while(1)if((i|0)==(o|0)){k=k+1|0;continue b}else{e=Wc(x[g+8>>2],i);p=y[e+5|0];l=y[e+3|0];h=g+4|0;sm(h,a);q=$e(h);f=dj(h);j=y[g+4|0];c:{if((j-1&255)>>>0>35){break c}v[e|0]=j+48;j=y[Jc(h)|0];h=j+1|0;v[e+1|0]=h;r=h;h=h&255;if((r|0)!=(h|0)|h>>>0>z[c+480190>>1]){break c}h=ti(c,h);if(!(!y[xb(d,i)|0]|z[h+30>>1]>255)){v[e+4|0]=64;v[e+2|0]=1}h=h+68|0;d:{if(x[yb(h,0)>>2]==1){if(y[xb(d,i)|0]){break d}}if(x[yb(h,0)>>2]){break c}if(y[xb(d,i)|0]){break c}}v[e+1|0]=j+101}e:{f:{switch(y[q|0]-1|0){case 0:if(!y[f|0]){break e}v[e+3|0]=2;v[e+5|0]=y[f|0];break e;case 1:if(!y[f|0]){break e}v[e+3|0]=3;v[e+5|0]=y[f|0];break e;case 9:if(!y[f|0]){break e}v[e+3|0]=1;f=y[f|0];s=e,t=KX(f>>>4|0)<<4|f&15,v[s+5|0]=t;break e;case 10:if(!y[f|0]){break e}v[e+3|0]=1;f=y[f|0];s=e,t=f&240|KX(f&15),v[s+5|0]=t;break e;case 11:if(!y[f|0]){break e}v[e+3|0]=1;v[e+5|0]=y[f|0];break e;case 12:if(!y[f|0]){break e}v[e+3|0]=39;v[g|0]=15;s=e,t=y[Qb(g,f)|0]|16,v[s+5|0]=t;break e;case 29:if(!y[f|0]){break e}v[e+3|0]=38;v[g|0]=15;s=e,t=y[Qb(g,f)|0]|16,v[s+5|0]=t;break e;case 20:if(!y[f|0]){break e}v[e+3|0]=39;v[g|0]=15;s=e,t=y[Qb(g,f)|0]|80,v[s+5|0]=t;break e;case 16:if(!y[f|0]){break e}v[e+3|0]=38;v[g|0]=15;s=e,t=y[Qb(g,f)|0]|80,v[s+5|0]=t;break e;case 14:v[e+3|0]=19;v[e+5|0]=y[f|0]!=0;break e;case 24:v[e+3|0]=12;v[e+5|0]=y[f|0];break e;case 26:_o(e);v[e|0]=255;break e;case 27:if(y[f|0]>31){break e}v[e+3|0]=16;v[e+5|0]=y[f|0];break e;case 30:break f;default:break e}}h=y[f|0];if(h&15){s=e,t=y[xb(d,i)|0]?22:11,v[s+3|0]=t;v[e+5|0]=y[f|0]&15;h=y[f|0]}g:{h:{switch(h>>>4|0){case 4:if((h|0)!=64){break g}case 0:case 1:case 2:case 3:if(y[xb(d,i)|0]){v[e+3|0]=21;v[e+5|0]=y[f|0];break g}v[e+2|0]=1;f=y[f|0];v[e+3|0]=0;v[e+4|0]=f;break g;case 5:v[e+5|0]=y[e+5|0]<<4;break g;case 6:v[g|0]=y[e+5|0];v[g+3|0]=14;s=e,t=y[Qb(g,g+3|0)|0]|240,v[s+5|0]=t;break g;case 7:v[g|0]=y[e+5|0];v[g+3|0]=14;s=e,t=y[Qb(g,g+3|0)|0]<<4|15,v[s+5|0]=t;break g;default:break h}}v[e+3|0]=0}if((y[e+3|0]-21&255)>>>0>1){break e}f=xb(d,i);f=Wc(x[g+8>>2],v[f|0]+i|0);rw(g,y[f+3|0],y[f+5|0],1);if(y[g|0]){h=z[g>>1];v[f+2|0]=h;v[f+4|0]=h>>>8}v[f+3|0]=y[e+3|0];v[f+5|0]=y[e+5|0]}i:{if(!l){break i}f=y[e+3|0];if((f|0)==(l|0)){break i}mm(g,e,f,y[e+5|0],l,p)}i=i+1|0;continue}}}fb=g+16|0}function n9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=fb-336|0;fb=d;e=fb-16|0;fb=e;x[a+4>>2]=0;v[a|0]=0;f=a+40|0;vo(f,32);v[e+15|0]=0;uo(f,e+15|0);fb=e+16|0;e=x[a+36>>2];a:{if(x[(x[x[e>>2]-12>>2]+e|0)+16>>2]){Qh(a,2,16777216);break a}$d(d+72|0,e);e=x[d+84>>2];x[a+16>>2]=x[d+80>>2];x[a+20>>2]=e;x[d+72>>2]=3;f=x[a+36>>2];e=0;while(1){if(A[d+72>>2]>e>>>0){Ki(f,d+e|0);e=e+1|0;continue}break}if(kd(d,24384,3)){Qh(a,2,512);break a}v[d+335|0]=0;Ki(x[a+36>>2],d+335|0);f=d+72|0;Rb(f,0,256);e=y[d+335|0];if(e){Dj(x[a+36>>2],f,e)}f=b;b=yl(d,d+72|0,e);e=Gy(f,b);Eb(b);if(!e){Qh(a,2,4096)}if(vl(y[a|0])){break a}Ki(x[a+36>>2],d+71|0);b=y[d+71|0];e=b&3;w[a+24>>1]=(e|0)==3?4:e;if(wj(b,6)){Pc(d,a+32|0,9);If(d,1)}x[d+64>>2]=0;FK(x[a+36>>2],d- -64|0);e=x[d+64>>2];v[d+63|0]=0;if(e>>>0>=2){Ki(x[a+36>>2],d+71|0);f=-1;if(!y[d+71|0]){Ki(x[a+36>>2],d+63|0);f=-2}Tm(x[a+36>>2],e+f|0)}x[d+48>>2]=0;x[d+52>>2]=0;b:{if(!wj(b,4)){break b}tl(x[a+36>>2],d+48|0);e=x[d+52>>2];f=x[d+48>>2];x[a+64>>2]=f;x[a+68>>2]=e;g=x[c+4>>2];if((g|0)==(e|0)&A[c>>2]>=f>>>0|e>>>0<g>>>0){break b}Qh(a,1,4)}if(wj(b,5)){Ki(x[a+36>>2],d+71|0);Tm(x[a+36>>2],y[d+71|0])}c=y[d+63|0];c:{if(!wj(c,0)){break c}Ki(x[a+36>>2],d+71|0);e=y[d+71|0];e=e&1?-1:e>>>1|0;w[a+24>>1]=e;if(e){break c}Qh(a,1,2)}x[a+8>>2]=0;f=1;if(wj(c,1)){FK(x[a+36>>2],a+8|0)}g=wj(b,2);e=a+32|0;Pc(d,e,6);If(d,g);g=wj(b,3);Pc(d,e,7);If(d,g);g=z[a+24>>1];Pc(d,e,5);If(d,(g|0)!=0);b=wj(b,7);Pc(d,e,8);If(d,b);Pc(d,e,5);d:{if(Hb(x[x[d>>2]>>2],x[d+4>>2])){break d}Pc(d+40|0,e,6);if(Hb(x[x[d+40>>2]>>2],x[d+44>>2])){break d}Pc(d+32|0,e,7);if(Hb(x[x[d+32>>2]>>2],x[d+36>>2])){break d}Pc(d+24|0,e,8);f=Hb(x[x[d+24>>2]>>2],x[d+28>>2])}b=d+16|0;Pc(b,e,11);If(b,f);Pc(d,e,11);if(wj(c,2)){w[d+40>>1]=0;zy(x[a+36>>2],d+40|0);b=x[a+36>>2];f=z[d+40>>1];Pc(d,e,9);Tm(b,f<<Hb(x[x[d>>2]>>2],x[d+4>>2]))}if(wj(c,3)){Tm(x[a+36>>2],5)}tl(x[a+36>>2],d+48|0);c=x[d+52>>2];f=c;b=x[d+48>>2];if(!c&b>>>0>=16001|c){Qh(a,2,8192);break a}x[a+104>>2]=b;if(!b){Qh(a,1,1)}Pc(d,e,11);e:{if(!Hb(x[x[d>>2]>>2],x[d+4>>2])){break e}tl(x[a+36>>2],d+48|0);c=x[d+52>>2];f=c;b=x[d+48>>2];if(uy(b,c)){break e}Qh(a,2,2048);break a}$d(d,x[a+36>>2]);g=x[d+8>>2];h=x[a+16>>2];c=g-h|0;g=x[d+12>>2]-(x[a+20>>2]+(g>>>0<h>>>0)|0)|0;if((g|0)<0){Qh(a,2,16384);break a}x[a+96>>2]=c;x[a+100>>2]=g;Pc(d,e,11);c=x[a+100>>2];g=b;h=x[a+96>>2];b=Hb(x[x[d>>2]>>2],x[d+4>>2]);x[a+72>>2]=b?g:h;x[a+76>>2]=b?f:c;Pc(d,e,11);if(!Hb(x[x[d>>2]>>2],x[d+4>>2])){b=x[a+100>>2]+x[a+20>>2]|0;f=x[a+16>>2];c=f+x[a+96>>2]|0;x[a+80>>2]=c;x[a+84>>2]=c>>>0<f>>>0?b+1|0:b}Pc(d,e,10);If(d,1)}fb=d+336|0}function Nz(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=fb-144|0;fb=f;x[f+136>>2]=c;x[f+140>>2]=d;g=x[b+4>>2];a:{if(!g){h=x[b>>2];break a}h=x[b>>2];i=y[Gl(h,g)|0];if((i|0)==33){e=1}else{if((i|0)!=63){break a}e=0}Sl(f+112|0,h,g,g-1|0);g=x[f+116>>2];h=x[f+112>>2];x[b>>2]=h;x[b+4>>2]=g}j=f+112|0;ge(j);i=x[f+112>>2];k=f+100|0;ge(k);i=Fl(i,x[f+104>>2],b);ge(j);b:{c:{d:{e:{f:{g:{h:{if(x[f+116>>2]==(i|0)){c=qc(f+128|0,22303);a=x[c+4>>2];x[f+8>>2]=x[c>>2];x[f+12>>2]=a;if(Ic(h,g,f+8|0)){g=ac(8);x[31737]=0;O(1012,k|0,f+136|0);a=x[31737];x[31737]=0;if((a|0)==1){break g}x[31737]=0;S(1017,j|0,18282,k|0);a=x[31737];x[31737]=0;if((a|0)==1){break f}pc(g,j);h=0;x[31737]=0;S(98,g|0,48540,1006);a=x[31737];x[31737]=0;if((a|0)!=1){break b}b=N()|0;tb(j);break e}if(!e){break h}g=ac(8);c=x[b>>2];a=x[b+4>>2];x[31737]=0;e=fi(f+76|0,c,a);a=x[31737];x[31737]=0;i:{j:{k:{l:{m:{n:{o:{p:{if((a|0)!=1){x[31737]=0;b=f+88|0;S(1017,b|0,18318,e|0);a=x[31737];x[31737]=0;if((a|0)==1){break p}x[31737]=0;c=f+100|0;O(1019,c|0,b|0);b=x[31737];x[31737]=0;a=1;if((b|0)==1){break o}x[31737]=0;b=f- -64|0;O(1012,b|0,f+136|0);a=x[31737];x[31737]=0;if((a|0)==1){break n}x[31737]=0;d=f+112|0;S(1021,d|0,c|0,b|0);b=x[31737];x[31737]=0;a=1;if((b|0)==1){break m}pc(g,d);x[31737]=0;S(98,g|0,48540,1006);a=x[31737];x[31737]=0;if((a|0)!=1){break b}b=N()|0;tb(d);a=0;break l}b=N()|0;break d}b=N()|0;a=1;break i}b=N()|0;break j}b=N()|0;a=1;break k}b=N()|0}tb(f- -64|0)}tb(f+100|0)}tb(f+88|0)}tb(e);if(a){break d}break c}e=qc(f+56|0,22303);b=x[e+4>>2];x[f+32>>2]=x[e>>2];x[f+36>>2]=b;if(Ic(h,g,f+32|0)){g=ac(8);x[31737]=0;b=f+100|0;O(1012,b|0,f+136|0);a=x[31737];x[31737]=0;q:{r:{if((a|0)!=1){x[31737]=0;c=f+112|0;S(1017,c|0,18282,b|0);a=x[31737];x[31737]=0;if((a|0)==1){break r}pc(g,c);h=0;x[31737]=0;S(98,g|0,48540,1006);a=x[31737];x[31737]=0;if((a|0)!=1){break b}b=N()|0;tb(c);break q}b=N()|0;break d}b=N()|0;h=1}tb(f+100|0);if(h){break d}break c}e=qc(f+48|0,10990);b=x[e+4>>2];x[f+24>>2]=x[e>>2];x[f+28>>2]=b;if(Ic(h,g,f+24|0)){Jz(a,Gc(c,d));break h}e=qc(f+40|0,8643);b=x[e+4>>2];x[f+16>>2]=x[e>>2];x[f+20>>2]=b;if(!Ic(h,g,f+16|0)){break h}b=x[a+32>>2];a=Su(c,d);a=a>>>0>=4?1:a;c=fb-16|0;fb=c;s:{if((yk(y[b+140|0])|0)==(a|0)){b=b+120|0;_t(y[b+20|0]);d=fb-16|0;fb=d;x[d+12>>2]=c+15;e=fb-16|0;fb=e;a=x[19891];x[e+8>>2]=x[19890];x[e+12>>2]=a;a=x[19889];x[e>>2]=x[19888];x[e+4>>2]=a;ib[x[tq(e,yk(y[b+20|0]))>>2]](d+12|0,b);fb=e+16|0;fb=d+16|0;break s}_M(b,a,$M(b))}fb=c+16|0}fb=f+144|0;return}b=N()|0;break d}b=N()|0;h=1}tb(f+100|0);if(!h){break c}}jc(g)}Q(b|0)}p()}function vja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c=fb-32|0;fb=c;a:{b:{if(!Ib(x[b>>2],x[b+4>>2])){break b}l=a+16|0;m=x[b+12>>2];k=z[x[x[b+48>>2]+12>>2]+480188>>1];d=k;e=fb-16|0;fb=e;g=c+20|0;x[g>>2]=0;x[g+4>>2]=0;sc(g+8|0);Rd(e+8|0,x[vb(e+4|0,g)>>2]);c:{d:{if(d){x[31737]=0;O(461,g|0,d|0);f=x[31737];x[31737]=0;if((f|0)==1){break d}h=fb-16|0;fb=h;f=Ir(h+4|0,g,d);d=x[f+4>>2];i=x[f+8>>2];while(1){if((d|0)==(i|0)){hc(f);fb=h+16|0}else{v[d|0]=0;v[d+1|0]=0;v[d+2|0]=0;v[d+3|0]=0;v[d+4|0]=0;v[d+5|0]=0;bh(d);d=d+6|0;x[f+4>>2]=d;continue}break}}d=e+8|0;Qd(d);im(d);fb=e+16|0;break c}a=N()|0;im(e+8|0);Q(a|0);p()}while(1){e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{if(!(x[x[x[a>>2]-12>>2]+l>>2]|j>>>0>=m>>>0)){x[31737]=0;v[c+19|0]=0;P(922,a|0,c+19|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break a}d=v[c+19|0];if(!d){j=j+1|0;continue}v[c+18|0]=0;t:{if((d|0)>=0){break t}x[31737]=0;P(922,a|0,c+18|0)|0;e=x[31737];x[31737]=0;if((e|0)!=1){break t}break a}v[c+17|0]=0;w[c+12>>1]=0;x[c+8>>2]=0;u:{d=d&127;f=(d?d-1|0:0)&65535;i=f>>>0>=k>>>0;v:{w:{if(!i){h=jd(x[b>>2],x[x[b+48>>2]+12>>2],j,f);d=y[c+18|0];if(d&1){break w}e=Wc(x[g>>2],f);break v}h=c+8|0;d=y[c+18|0];if(!(d&1)){break u}}x[31737]=0;P(922,a|0,c+17|0)|0;e=x[31737];x[31737]=0;if((e|0)==1){break a}if(i){break u}e=Wc(x[g>>2],f);v[e|0]=y[c+17|0]}v[h|0]=y[e|0];d=y[c+18|0];if(!(d&2)){break r}break s}if(d&2){break s}break q}Qk(g);break b}x[31737]=0;P(922,a|0,c+17|0)|0;e=x[31737];x[31737]=0;if((e|0)==1){break a}if(i){break q}e=Wc(x[g>>2],f);v[e+1|0]=y[c+17|0]}v[h+1|0]=y[e+1|0];if(d&4){break p}break o}if(!(d&4)){break n}}x[31737]=0;P(922,a|0,c+17|0)|0;e=x[31737];x[31737]=0;if((e|0)==1){break a}if(i){break n}e=Wc(x[g>>2],f);v[e+2|0]=y[c+17|0]}v[h+2|0]=y[e+2|0];if(!(d&8)){break l}break m}if(!(d&8)){break k}}x[31737]=0;P(922,a|0,c+17|0)|0;e=x[31737];x[31737]=0;if((e|0)==1){break a}if(i){break k}e=Wc(x[g>>2],f);v[e+4|0]=y[c+17|0]}v[h+4|0]=y[e+4|0];if(d&16){break j}break i}if(!(d&16)){break h}}x[31737]=0;P(922,a|0,c+17|0)|0;e=x[31737];x[31737]=0;if((e|0)==1){break a}if(i){break h}e=Wc(x[g>>2],f);v[e+3|0]=y[c+17|0]}v[h+3|0]=y[e+3|0];if(!(d&32)){break f}break g}if(!(d&32)){break e}}x[31737]=0;P(922,a|0,c+17|0)|0;e=x[31737];x[31737]=0;if((e|0)==1){break a}if(i){break e}e=Wc(x[g>>2],f);v[e+5|0]=y[c+17|0]}v[h+5|0]=y[e+5|0]}if(!(d&64)){continue}x[31737]=0;P(922,a|0,c+7|0)|0;d=x[31737];x[31737]=0;if((d|0)!=1){x[31737]=0;P(923,a|0,y[c+7|0])|0;d=x[31737];x[31737]=0;if((d|0)!=1){continue}}break}break a}fb=c+32|0;return}a=N()|0;Qk(g);Q(a|0);p()}function Rka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;f=fb-16|0;fb=f;e=fb-16|0;fb=e;d=BB(f+8|0);a:{b:{c:{d:{switch(b-850|0){default:e:{f:{if((b|0)!=437){if((b|0)==737){break f}if((b|0)==775){break e}if((b|0)==1252){break c}g:{h:{if((b|0)!=20127){if((b|0)==28591){break h}if((b|0)==28605){break g}if((b|0)!=65001){break b}b=mf(e+8|0,0);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a}b=mf(e+8|0,1);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a}b=mf(e+8|0,2);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a}b=mf(e+8|0,3);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a}b=mf(e+8|0,4);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a}b=mf(e+8|0,5);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a}b=mf(e+8|0,6);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a;case 0:b=mf(e+8|0,7);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a;case 2:b=mf(e+8|0,8);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a;case 5:b=mf(e+8|0,9);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a;case 7:b=mf(e+8|0,10);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a;case 10:b=mf(e+8|0,11);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a;case 11:b=mf(e+8|0,12);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a;case 12:b=mf(e+8|0,13);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a;case 13:b=mf(e+8|0,14);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a;case 14:b=mf(e+8|0,15);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a;case 15:b=mf(e+8|0,16);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a;case 16:b=mf(e+8|0,17);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a;case 19:b=mf(e+8|0,18);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a;case 1:case 3:case 4:case 6:case 8:case 9:case 17:case 18:case 20:case 21:case 22:case 23:break b;case 24:break d}}b=mf(e+8|0,19);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a}b=mf(e+8|0,20);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a}if(y[d+4|0]){v[d+4|0]=0}}fb=e+16|0;i:{if(Gd(y[f+12|0])){if(!Gd(y[f+12|0])){a=ac(4);x[a>>2]=0;a=Kj(a);x[a>>2]=121484;da(a|0,121520,844);p()}b=fb-32|0;fb=b;j:{k:{l:{m:{e=x[f+8>>2];if(!e){Wf(b+20|0,c);c=0;a=Fb(a);d=y[b+31|0];e=x[b+24>>2];x[31737]=0;O(94,a|0,xh(e,d)|0);d=x[31737];x[31737]=0;if((d|0)!=1){while(1){if(xh(x[b+24>>2],y[b+31|0])>>>0<=c>>>0){break m}d=y[cc(b+20|0,c)|0];x[31737]=0;O(96,a|0,d|0);d=x[31737];x[31737]=0;if((d|0)==1){break k}c=c+1|0;continue}}break k}d=b+8|0;Wf(d,c);x[31737]=0;c=b+20|0;S(11,c|0,e|0,d|0);e=x[31737];x[31737]=0;n:{o:{if((e|0)!=1){x[31737]=0;O(12,a|0,c|0);a=x[31737];x[31737]=0;if((a|0)==1){break o}Ub(c);tb(d);break l}c=N()|0;break n}c=N()|0;Ub(b+20|0)}tb(b+8|0);break j}tb(b+20|0)}fb=b+32|0;break i}c=N()|0;tb(a);tb(b+20|0)}Q(c|0);p()}I0(a,22,c)}fb=f+16|0}function qI(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0,p=0;i=fb-48|0;fb=i;o(+a);e=j(1)|0;d=j(0)|0;a:{b:{h=e&2147483647;c:{if(h>>>0<=1074752122){if((e&1048575)==598523){break c}if(h>>>0<=1073928572){if((e|0)>0|(e|0)>=0){a=a+-1.5707963267341256;c=a+-6077100506506192e-26;C[b>>3]=c;C[b+8>>3]=a-c+-6077100506506192e-26;d=1;break a}a=a+1.5707963267341256;c=a+6077100506506192e-26;C[b>>3]=c;C[b+8>>3]=a-c+6077100506506192e-26;d=-1;break a}if((e|0)>0|(e|0)>=0){a=a+-3.1415926534682512;c=a+-1.2154201013012384e-10;C[b>>3]=c;C[b+8>>3]=a-c+-1.2154201013012384e-10;d=2;break a}a=a+3.1415926534682512;c=a+1.2154201013012384e-10;C[b>>3]=c;C[b+8>>3]=a-c+1.2154201013012384e-10;d=-2;break a}if(h>>>0<=1075594811){if(h>>>0<=1075183036){if((h|0)==1074977148){break c}if((e|0)>0|(e|0)>=0){a=a+-4.712388980202377;c=a+-1.8231301519518578e-10;C[b>>3]=c;C[b+8>>3]=a-c+-1.8231301519518578e-10;d=3;break a}a=a+4.712388980202377;c=a+1.8231301519518578e-10;C[b>>3]=c;C[b+8>>3]=a-c+1.8231301519518578e-10;d=-3;break a}if((h|0)==1075388923){break c}if((e|0)>0|(e|0)>=0){a=a+-6.2831853069365025;c=a+-2.430840202602477e-10;C[b>>3]=c;C[b+8>>3]=a-c+-2.430840202602477e-10;d=4;break a}a=a+6.2831853069365025;c=a+2.430840202602477e-10;C[b>>3]=c;C[b+8>>3]=a-c+2.430840202602477e-10;d=-4;break a}if(h>>>0>1094263290){break b}}f=a*.6366197723675814+6755399441055744+-6755399441055744;c=a+f*-1.5707963267341256;g=f*6077100506506192e-26;p=c-g;e=p<-.7853981633974483;if(F(f)<2147483648){d=~~f}else{d=-2147483648}d:{if(e){d=d-1|0;f=f+-1;g=f*6077100506506192e-26;c=a+f*-1.5707963267341256;break d}if(!(p>.7853981633974483)){break d}d=d+1|0;f=f+1;g=f*6077100506506192e-26;c=a+f*-1.5707963267341256}a=c-g;C[b>>3]=a;o(+a);e=j(1)|0;j(0)|0;k=h>>>20|0;e:{if((k-(e>>>20&2047)|0)<17){break e}g=c;a=f*6077100506303966e-26;c=c-a;g=f*20222662487959506e-37-(g-c-a);a=c-g;C[b>>3]=a;o(+a);e=j(1)|0;j(0)|0;if((k-(e>>>20&2047)|0)<50){break e}g=c;a=f*20222662487111665e-37;c=c-a;g=f*84784276603689e-45-(g-c-a);a=c-g;C[b>>3]=a}C[b+8>>3]=c-a-g;break a}if(h>>>0>=2146435072){a=a-a;C[b>>3]=a;C[b+8>>3]=a;d=0;break a}l(0,d|0);l(1,e&1048575|1096810496);a=+n();d=0;k=1;while(1){m=(i+16|0)+(d<<3)|0;if(F(a)<2147483648){d=~~a}else{d=-2147483648}c=+(d|0);C[m>>3]=c;a=(a-c)*16777216;d=1;m=k;k=0;if(m){continue}break}C[i+32>>3]=a;d=2;while(1){k=d;d=d-1|0;m=i+16|0;if(C[m+(k<<3)>>3]==0){continue}break}d=FL(m,i,(h>>>20|0)-1046|0,k+1|0,1);a=C[i>>3];if((e|0)<0){C[b>>3]=-a;C[b+8>>3]=-C[i+8>>3];d=0-d|0;break a}C[b>>3]=a;C[b+8>>3]=C[i+8>>3]}fb=i+48|0;return d}function gqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=fb-560|0;fb=f;a:{if(!cd(b,1464)){break a}d=f+556|0;if(!nr(b,d)){break a}Bd(a,1);Lb(Lb(dg(a+1074312|0,83),84,1),85,1);b:{if(ne(d,25300)){e=f+32|0;d=tc(e,8430);Ab(a+1298344|0,d);tb(d);d=tc(e,14928);Ab(a+1298356|0,d);tb(d);d=tc(e,14993);Ab(a+1298368|0,d);break b}if(!ne(f+556|0,15623)){break a}e=f+32|0;d=tc(e,8620);Ab(a+1298344|0,d);tb(d);d=tc(e,12356);Ab(a+1298356|0,d);tb(d);d=tc(e,15540);Ab(a+1298368|0,d)}tb(d);r=a+1298404|0,s=x[Fc(e,28)>>2],x[r>>2]=s;e=0;cd(b,0);SZ(b,a+1298308|0,20);w[a+480190>>1]=31;d=1;while(1)if((d|0)==32){if(e>>>0>40){break a}d=f+554|0;Iw(d,b);m=Jc(d);if(y[f+554|0]>128){break a}e=f+32|0;d=fb-16|0;fb=d;c:{if(!Mb(x[b>>2],x[b+8>>2],512)){$X(e);break c}xE(d+8|0,e);rd(d,b,x[d+8>>2],x[d+12>>2])}fb=d+16|0;d=0;e=y[m|0];while(1){n=(d|0)==512;if(!n){g=(f+32|0)+d|0;d=d+1|0;if(e>>>0>=y[g|0]){continue}break a}break}if((c|0)==64){break a}x[a+480260>>2]=56;x[a+480264>>2]=13696;x[a+480204>>2]=125e4;x[a+480196>>2]=6;w[a+480192>>1]=0;w[a+480188>>1]=4;x[a+480228>>2]=64;x[a+480208>>2]=x[a+480208>>2]|18874368;Xh(a,0);xg(Xb(x[a+484360>>2],y[a+484376|0]),y[f+554|0]);l=a+484344|0;Vf(l,y[f+554|0]);g=0;while(1)if(y[f+554|0]<=g>>>0){if(!(c&2)){break a}cd(b,(y[m|0]<<8)+1468|0);d=1;while(1){if((d|0)==32){break a}c=(D(d,104)+a|0)+484380|0;if(x[c>>2]){fg(Xc(f+8|0,8,1,0,0),c,b)}d=d+1|0;continue}}else{r=_b(x[Xb(x[a+484360>>2],y[a+484376|0])>>2],g),s=g,w[r>>1]=s;d:{if(!Ng(l,g&65535,64)){break d}q=g<<2;i=0;e:while(1){if((i|0)==4){r=f,s=wb(x[Wb(x[l>>2],g)>>2]),x[r+24>>2]=s;i=0;while(1){if((i|0)==64){break d}d=0;f:{while(1){if((d&65535)>>>0>=4){g:{v[f+30|0]=o;v[f+31|0]=p;d=h&255;if(d){break g}h=0;break f}}else{e=x[f+24>>2];h:{if((y[e+3|0]&254)!=16){break h}v[e+3|0]=16;h=0;j=y[e+5|0];if(j>>>0<16){break h}h=j>>>4|0;v[e+5|0]=h;k=h;e=j&15;h=(e|0)!=(h|0)&(e|0)!=0;o=h?k:o;p=h?e:p}d=d+1|0;IC(f+24|0);continue}break}ye(Wb(x[l>>2],g),Xe(Ne(f+8|0,16,y[(d+f|0)+29|0]),i));h=h+1|0;h=(h&255)==3?1:h}i=i+1|0;continue}}cd(b,(y[f+32+(i+q)|0]<<8)+1468|0);e=0;d=Wb(x[l>>2],g);d=jd(x[d>>2],x[x[d+48>>2]+12>>2],0,i&65535);while(1)if((e|0)==64){i=i+1|0;continue e}else{k=f+8|0;Y$(k,b,d);j=y[f+8|0];k=y[Jc(k)|0];i:{if(!(!(j|k)|(j-5&255)>>>0<5|(j|0)==14&k>>>0>15)){Bf(d,j,k);break i}v[d+3|0]=0}d=d+24|0;e=e+1|0;continue}}}g=g+1|0;continue}}else{g=f+32|0;LC(b,g);e=UC(g,(D(d,104)+a|0)+484380|0,((d<<5)+a|0)+946304|0,1)+e|0;d=d+1|0;continue}}fb=f+560|0;return n|0}function se(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{b:{c:{switch(b|0){case 1:b=Fb(a);d=y[c+11|0];e=x[c+4>>2];a=0;x[31737]=0;O(115,b|0,Yc(e,d)|0);d=x[31737];x[31737]=0;d:{if((d|0)!=1){e:{while(1){if(Yc(x[c+4>>2],y[c+11|0])>>>0>a>>>0){d=x[Vd(c,a)>>2];x[31737]=0;O(116,b|0,(d>>>0>=128?63:d)<<24>>24);d=x[31737];x[31737]=0;if((d|0)==1){break e}a=a+1|0;continue}break}break d}}break a}return;case 2:b=Fb(a);d=y[c+11|0];e=x[c+4>>2];a=0;x[31737]=0;O(115,b|0,Yc(e,d)|0);d=x[31737];x[31737]=0;f:{if((d|0)!=1){g:{while(1){if(Yc(x[c+4>>2],y[c+11|0])>>>0>a>>>0){d=x[Vd(c,a)>>2];x[31737]=0;O(116,b|0,(d>>>0>=256?63:d)<<24>>24);d=x[31737];x[31737]=0;if((d|0)==1){break g}a=a+1|0;continue}break}break f}}break a}return;case 3:ef(a,c,48976);return;case 4:ef(a,c,5e4);return;case 5:ef(a,c,51024);return;case 6:ef(a,c,52048);return;case 7:ef(a,c,53072);return;case 8:ef(a,c,54096);return;case 9:ef(a,c,55120);return;case 10:ef(a,c,56144);return;case 11:ef(a,c,57168);return;case 12:ef(a,c,58192);return;case 13:ef(a,c,59216);return;case 14:ef(a,c,60240);return;case 15:ef(a,c,61264);return;case 16:ef(a,c,62288);return;case 17:ef(a,c,63312);return;case 18:ef(a,c,64336);return;case 19:ef(a,c,65360);return;case 20:ef(a,c,66384);return;case 21:ef(a,c,67408);return;case 22:ef(a,c,68432);return;case 23:ef(a,c,69456);return;case 24:xx(a,c,70480);return;case 25:xx(a,c,48976);return;case 26:xx(a,c,67408);return;default:a=ac(8);x[31737]=0;b=P(16,a|0,11122)|0;c=x[31737];x[31737]=0;if((c|0)!=1){break b}b=N()|0;jc(a);Q(b|0);p();case 0:break c}}e=fb-16|0;fb=e;f=Fb(a);h:{while(1){i:{j:{k:{if(Yc(x[c+4>>2],y[c+11|0])>>>0>g>>>0){b=x[Vd(c,g)>>2];if(b>>>0>=2097152){x[31737]=0;O(116,f|0,63);a=x[31737];x[31737]=0;if((a|0)!=1){break j}break i}a=0;while(1){if((a|0)==6){b=7;a=6;break k}d=b&63;v[(e+10|0)+a|0]=d;if(b>>>0>=64){a=a+1|0;b=b>>>6|0;continue}break}if(a){b=a+1|0;if((b|0)!=2){break k}a=1;b=2;if((d|0)!=1){break k}a=y[e+10|0]|64}else{a=y[e+10|0]}x[31737]=0;O(116,f|0,a<<24>>24);a=x[31737];x[31737]=0;if((a|0)!=1){break j}break i}fb=e+16|0;break h}i=(2<<a)+255<<7-a;d=b-1|0;j=d+(e+10|0)|0;a=b;while(1){if(!a){break j}l:{if((a|0)==(b|0)){a=y[j|0];x[31737]=0;O(116,f|0,(a|i)<<24>>24);h=x[31737];x[31737]=0;a=d;break l}x[31737]=0;a=a-1|0;O(116,f|0,v[a+(e+10|0)|0]|-128);h=x[31737];x[31737]=0}if((h|0)!=1){continue}break}break i}g=g+1|0;continue}break}a=N()|0;tb(f);Q(a|0);p()}return}da(b|0,125180,17);p()}a=N()|0;tb(b);Q(a|0);p()}function on(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=fb+-64|0;fb=e;h=Nb(a);x[31737]=0;a=R(282,b|0)|0;d=x[31737];x[31737]=0;a:{b:{c:{d:{e:{if((d|0)==1){break e}d=x[b+8>>2];c=x[b>>2];x[31737]=0;d=U(151,c|0,d|0,a|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break e}if(d){break d}x[31737]=0;a=R(203,b|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break e}x[31737]=0;P(184,b|0,a|0)|0;a=x[31737];x[31737]=0;if((a|0)!=1){break c}}a=N()|0;break a}x[31737]=0;c=e+24|0;S(186,c|0,b|0,a|0);b=x[31737];x[31737]=0;f:{g:{h:{if((b|0)!=1){d=ic(e+44|0,c);ub(c);if(a>>>0<10){break g}x[31737]=0;b=R(738,d|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break b}if(!b){break g}x[31737]=0;b=R(282,d|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break b}x[e+20>>2]=b;a=a-10|0;wc(e+20|0,a>>>0>25264513?-1:D(a,170));x[31737]=0;c=x[e+20>>2];O(288,h|0,c|0);a=x[31737];x[31737]=0;if((a|0)!=1){break h}break b}a=N()|0;break a}b=0;i:while(1){f=0;j:{k:{while(1){if(f){break j}a=x[d+8>>2];f=x[d>>2];x[31737]=0;a=P(739,f|0,a|0)|0;f=x[31737];x[31737]=0;l:{m:{n:{o:{if((f|0)!=1){if(a){break j}x[31737]=0;a=R(535,d|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break b}f=1;switch(a|0){case 3:break l;case 2:break m;case 1:break n;case 0:break o;default:continue}}break b}x[31737]=0;a=R(198,d|0)|0;g=x[31737];x[31737]=0;if((g|0)==1){break b}if(a>>>0>c>>>0){continue}g=x[d+8>>2];i=x[d>>2];x[31737]=0;g=U(151,i|0,g|0,a|0)|0;i=x[31737];x[31737]=0;if((i|0)==1){break b}if(!g){continue}re(e+24|0,x[h>>2],x[h+4>>2]);Cr(e+8|0,x[e+24>>2],x[e+28>>2],b,a);x[31737]=0;ao(472,e,d,x[e+8>>2],x[e+12>>2]);f=x[31737];x[31737]=0;if((f|0)!=1){c=c-a|0;b=a+b|0;continue i}break b}x[31737]=0;a=R(198,d|0)|0;g=x[31737];x[31737]=0;if((g|0)==1){break b}g=a<<2;if(g>>>0>c>>>0){continue}x[31737]=0;i=P(740,d|0,e+16|0)|0;j=x[31737];x[31737]=0;if((j|0)==1){break b}if(!i){continue}while(1){if(!(a&255)){break k}f=e+16|0;i=ec(f);ov(f,i,uf(wb(x[h>>2]),b));b=b+4|0;a=a-1|0;continue}}if(c>>>0<8){continue}x[31737]=0;a=e+16|0;g=P(740,d|0,a|0)|0;i=x[31737];x[31737]=0;if((i|0)==1){break b}if(!g){continue}f=ec(a);ov(a,f,uf(wb(x[h>>2]),b));ov(a,f,uf(uf(wb(x[h>>2]),b),4));c=c-8|0;b=b+8|0;continue i}x[31737]=0;a=R(198,d|0)|0;g=x[31737];x[31737]=0;if((g|0)==1){break b}if(a>>>0>c>>>0){continue}break}c=c-a|0;b=a+b|0;continue}c=c-g|0;continue}break}if(!c){break f}Nb(dc(h));break f}x[31737]=0;S(334,d|0,h|0,a|0);a=x[31737];x[31737]=0;if((a|0)==1){break b}}ub(d)}fb=e- -64|0;return}a=N()|0;ub(d)}dc(h);Q(a|0);p()}function uP(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=fb-192|0;fb=d;f=x[b+4>>2];a:{if(!f){break a}e=x[b>>2];g=y[Gl(e,f)|0];if((g|0)==33){c=1}else{if((g|0)!=63){break a}c=0}Sl(d+168|0,e,f,f-1|0);f=x[d+172>>2];e=x[d+168>>2];x[b>>2]=e;x[b+4>>2]=f}e=d+168|0;ge(e);g=x[d+168>>2];ge(d+156|0);g=Fl(g,x[d+160>>2],b);ge(e);b:{c:{d:{e:{if((g|0)==x[d+172>>2]){a=x[b>>2];g=qc(d+184|0,22303);h=x[g+4>>2];x[d>>2]=x[g>>2];x[d+4>>2]=h;if(Ic(a,f,d)){a=ac(8);x[31737]=0;c=P(36,e|0,10498)|0;b=x[31737];x[31737]=0;if((b|0)==1){break d}pc(a,c);x[31737]=0;S(98,a|0,48540,1006);a=x[31737];x[31737]=0;if((a|0)!=1){break b}b=N()|0;tb(c);break c}e=0;if(!c){break e}a=ac(8);c=x[b+4>>2];b=x[b>>2];x[31737]=0;f=fi(d+156|0,b,c);b=x[31737];x[31737]=0;f:{g:{h:{if((b|0)!=1){x[31737]=0;e=d+168|0;S(1017,e|0,18318,f|0);b=x[31737];x[31737]=0;if((b|0)==1){break h}pc(a,e);c=0;x[31737]=0;S(98,a|0,48540,1006);b=x[31737];x[31737]=0;if((b|0)!=1){break b}b=N()|0;tb(e);break g}b=N()|0;break f}b=N()|0;c=1}tb(f);if(!c){break c}}jc(a);break c}if(x[g+4>>2]){a=ac(8);x[31737]=0;c=P(36,d+168|0,11600)|0;b=x[31737];x[31737]=0;if((b|0)!=1){pc(a,c);x[31737]=0;S(98,a|0,48540,1006);a=x[31737];x[31737]=0;if((a|0)!=1){break b}b=N()|0;tb(c);break c}b=N()|0;jc(a);break c}b=x[b>>2];c=qc(d+148|0,22303);e=x[c+4>>2];x[d+72>>2]=x[c>>2];x[d+76>>2]=e;if(Ic(b,f,d+72|0)){a=ac(8);x[31737]=0;c=P(36,d+168|0,10498)|0;b=x[31737];x[31737]=0;if((b|0)!=1){pc(a,c);x[31737]=0;S(98,a|0,48540,1006);a=x[31737];x[31737]=0;if((a|0)!=1){break b}b=N()|0;tb(c);break c}b=N()|0;jc(a);break c}c=qc(d+140|0,7462);e=x[c+4>>2];x[d+64>>2]=x[c>>2];x[d+68>>2]=e;i:{if(!Ic(b,f,d- -64|0)){c=qc(d+132|0,7444);e=x[c+4>>2];x[d+56>>2]=x[c>>2];x[d+60>>2]=e;if(!Ic(b,f,d+56|0)){break i}}e=y[a+60|0]!=0;break e}c=qc(d+124|0,6989);e=x[c+4>>2];x[d+48>>2]=x[c>>2];x[d+52>>2]=e;j:{if(!Ic(b,f,d+48|0)){c=qc(d+116|0,6970);e=x[c+4>>2];x[d+40>>2]=x[c>>2];x[d+44>>2]=e;if(!Ic(b,f,d+40|0)){break j}}e=y[a+61|0]!=0;break e}c=qc(d+108|0,7073);e=x[c+4>>2];x[d+32>>2]=x[c>>2];x[d+36>>2]=e;if(Ic(b,f,d+32|0)){e=y[a+62|0]!=0;break e}c=qc(d+100|0,6064);e=x[c+4>>2];x[d+24>>2]=x[c>>2];x[d+28>>2]=e;if(Ic(b,f,d+24|0)){e=y[a+63|0]!=0;break e}c=qc(d+92|0,7511);e=x[c+4>>2];x[d+16>>2]=x[c>>2];x[d+20>>2]=e;if(Ic(b,f,d+16|0)){e=y[a+64|0]!=0;break e}c=qc(d+84|0,13525);e=x[c+4>>2];x[d+8>>2]=x[c>>2];x[d+12>>2]=e;e=0;if(!Ic(b,f,d+8|0)){break e}e=x[x[a+24>>2]+24668>>2]!=0}fb=d+192|0;return e|0}b=N()|0;jc(a)}Q(b|0)}p()}function yka(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;x[a+24588>>2]=0;x[a+24592>>2]=0;x[a+8>>2]=42080;x[a+4>>2]=0;x[a>>2]=30624;b=a+24596|0;x[b>>2]=0;x[b+4>>2]=0;Xq(a+24604|0);ES(a+24648|0,0);x[a+397448>>2]=0;x[a+397452>>2]=0;b=a+397456|0;x[b>>2]=8;x[b+4>>2]=0;x[b+16>>2]=0;x[b+20>>2]=0;v[b+12|0]=0;x[b+8>>2]=0;w[b+24>>1]=0;Rb(b+28|0,0,40);Rb(b+68|0,0,49824);Rb(b+49892|0,0,32832);v[a+480224|0]=0;w[a+480212>>1]=0;x[a+480204>>2]=0;x[a+480208>>2]=0;x[a+480180>>2]=0;x[a+480184>>2]=0;b=a+480186|0;w[b>>1]=0;w[b+2>>1]=0;w[b+4>>1]=0;w[b+6>>1]=0;x[a+480240>>2]=65536;x[a+480244>>2]=65536;h=Nb(a+480248|0);x[a+480272>>2]=0;c=a+484344|0;b=a+480280|0;while(1){v[b+8|0]=0;x[b>>2]=0;x[b+4>>2]=4194432;kF(b+9|0);b=b+32|0;if((c|0)!=(b|0)){continue}break}f=Nb(c);x[f+12>>2]=a;x[31737]=0;i=P(852,a+484360|0,a|0)|0;b=x[31737];x[31737]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((b|0)!=1){c=a+900380|0;b=a+484380|0;while(1){x[31737]=0;b=R(711,b|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break i}b=b+104|0;if((c|0)!=(b|0)){continue}break}x[31737]=0;R(853,a+901404|0)|0;b=x[31737];x[31737]=0;if((b|0)==1){break h}d=a+906300|0;b=0;while(1){yS(D(b,160)+d|0);b=b+1|0;if((b|0)!=250){continue}break}x[a+946300>>2]=0;e=a+1074304|0;g=a+946304|0;b=g;while(1){b=cv(b)+32|0;if((e|0)!=(b|0)){continue}break}x[a+1074304>>2]=0;x[a+1074308>>2]=0;hs(a+1074312|0);x[31737]=0;X(854);b=x[31737];x[31737]=0;if((b|0)==1){break g}s=a,t=xS(),x[s+1074328>>2]=t;b=a+1074332|0;x[b+12>>2]=1065353216;oS(b,4);x[31737]=0;e=R(855,a+1074376|0)|0;b=x[31737];x[31737]=0;if((b|0)==1){break g}x[31737]=0;j=U(605,a+1298264|0,a|0,255)|0;b=x[31737];x[31737]=0;if((b|0)==1){break f}k=sc(a+1298300|0);l=sc(a+1298304|0);m=Fb(a+1298308|0);n=Fb(a+1298320|0);o=Fb(a+1298332|0);q=DS(a+1298344|0);r=Nb(a+1298412|0);v[a+1298424|0]=0;b=a+1298432|0;x[b>>2]=0;x[b+4>>2]=0;x[b+32>>2]=0;x[b+36>>2]=1072693248;x[b+24>>2]=0;x[b+28>>2]=0;x[b+16>>2]=0;x[b+20>>2]=0;x[b+8>>2]=0;x[b+12>>2]=0;x[a+1298472>>2]=0;Hq(a+12|0);VA(a+8204|0);VA(a+12300|0);b=a+1074408|0;x[b>>2]=4;x[b+4>>2]=16;x[a+480216>>2]=4;x[a+480220>>2]=16;Rb(c,0,1024);wS(g);x[31737]=0;b=R(856,12)|0;c=x[31737];x[31737]=0;if((c|0)==1){break e}x[b>>2]=0;x[b+4>>2]=0;x[b+8>>2]=0;s=a,t=Nb(b),x[s+4>>2]=t;return a|0}b=N()|0;break a}b=N()|0;break b}b=N()|0;break b}b=N()|0;break c}b=N()|0;break d}b=N()|0;CS(r);YA(q);tb(o);tb(n);tb(m);XA(l);WA(k);Pu(j)}jB(e)}BS(d)}_B(i)}tS(f);vc(h);Q(b|0);p()}function Iaa(a,b,c){a=a|0;b=+b;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=fb-160|0;fb=d;x[d+156>>2]=c;a:{b:{c:{if(b>=.8){x[31737]=0;c=ca(1152)|0;e=x[31737];x[31737]=0;d:{e:{f:{if((e|0)!=1){x[d+72>>2]=c;x[31737]=0;c=R(1153,x[d+156>>2])|0;e=x[31737];x[31737]=0;if((e|0)==1){break e}x[d+152>>2]=c;e=x[d+72>>2];yo(e,c);a=Ge(d+132|0,a);x[31737]=0;c=x[a+12>>2];x[d+56>>2]=x[a+8>>2];x[d+60>>2]=c;x[d- -64>>2]=x[a+16>>2];c=x[a+4>>2];x[d+48>>2]=x[a>>2];x[d+52>>2]=c;a=U(1145,e|0,d+48|0,15)|0;c=x[31737];x[31737]=0;if((c|0)==1){break f}if(a){x[31737]=0;W(857,x[d+72>>2]);a=x[31737];x[31737]=0;f=1;if((a|0)==1){break f}}uh(d+152|0);vh(d+72|0);break b}c=T(0)|0;break c}c=T(0)|0;uh(d+152|0);break d}c=T(0)|0}vh(d+72|0);break c}if(b>=.6){x[31737]=0;c=ca(1152)|0;e=x[31737];x[31737]=0;g:{h:{i:{if((e|0)!=1){x[d+72>>2]=c;x[31737]=0;c=R(1153,x[d+156>>2])|0;e=x[31737];x[31737]=0;if((e|0)==1){break h}x[d+152>>2]=c;e=x[d+72>>2];yo(e,c);a=Ge(d+112|0,a);x[31737]=0;c=x[a+12>>2];x[d+32>>2]=x[a+8>>2];x[d+36>>2]=c;x[d+40>>2]=x[a+16>>2];c=x[a+4>>2];x[d+24>>2]=x[a>>2];x[d+28>>2]=c;a=U(1145,e|0,d+24|0,2)|0;c=x[31737];x[31737]=0;if((c|0)==1){break i}if(a){x[31737]=0;W(857,x[d+72>>2]);a=x[31737];x[31737]=0;f=.8;if((a|0)==1){break i}}uh(d+152|0);vh(d+72|0);break b}c=T(0)|0;break c}c=T(0)|0;uh(d+152|0);break g}c=T(0)|0}vh(d+72|0);break c}f=.2;if(b>=.2){x[31737]=0;c=ca(1152)|0;e=x[31737];x[31737]=0;j:{k:{l:{if((e|0)!=1){x[d+72>>2]=c;x[31737]=0;c=R(1153,x[d+156>>2])|0;e=x[31737];x[31737]=0;if((e|0)==1){break k}x[d+152>>2]=c;e=x[d+72>>2];yo(e,c);a=Ge(d+92|0,a);x[31737]=0;c=x[a+12>>2];x[d+8>>2]=x[a+8>>2];x[d+12>>2]=c;x[d+16>>2]=x[a+16>>2];c=x[a+4>>2];x[d>>2]=x[a>>2];x[d+4>>2]=c;a=U(1145,e|0,d|0,64)|0;c=x[31737];x[31737]=0;if((c|0)==1){break l}f=0;if(a){x[31737]=0;W(857,x[d+72>>2]);a=x[31737];x[31737]=0;f=.6;if((a|0)==1){break l}}uh(d+152|0);vh(d+72|0);break b}c=T(0)|0;break c}c=T(0)|0;uh(d+152|0);break j}c=T(0)|0}vh(d+72|0);break c}if(!(b>=.1)){break b}x[31737]=0;c=d+72|0;S(187,c|0,a|0,2048);e=x[31737];x[31737]=0;if((e|0)!=1){e=_e(c);a=x[a>>2];x[31737]=0;g=x[d+72>>2];a=R(155,a|0)|0;h=x[31737];x[31737]=0;m:{if((h|0)==1){break m}x[31737]=0;a=kI(1154,3,0,e,g,a,0);e=x[31737];x[31737]=0;if((e|0)==1){break m}f=C[(a<<3)+79576>>3];Kc(c);break b}c=T(0)|0;Kc(d+72|0);break c}c=T(0)|0}Y(c|0)|0;x[31737]=0;X(26);a=x[31737];x[31737]=0;f=0;if((a|0)==1){break a}}Uc(d+156|0);fb=d+160|0;return+f}a=N()|0;Uc(d+156|0);Q(a|0);p()}function Tna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=fb+-64|0;fb=d;w[d+62>>1]=c;Gf(d+62|0,32);j=Nb(a);x[31737]=0;n=z[d+62>>1];O(539,j|0,n|0);a=x[31737];x[31737]=0;a:{b:{if((a|0)!=1){while(1){c:{d:{if((o&65535)>>>0<n>>>0){f=1;c=z[b+480190>>1];a=c+1|0;w[d+60>>1]=a;if((a&65535)>>>0<4e3){break d}e:{while(1){g=f&65535;if(g>>>0>c>>>0){break e}f:{e=ti(b,g);if(!je(x[e>>2],x[e+20>>2])){if(!Ib(KC(wb(x[j>>2]),wb(x[j+4>>2]),f),wb(x[j+4>>2]))){break f}c=z[b+480190>>1]}f=f+1|0;continue}break}w[d+60>>1]=f;a=1;while(1){c=a&65535;if(c>>>0>z[b+480192>>1]){a=f}else{g:{c=x[((c<<2)+b|0)+900380>>2];if(!c){break g}c=c+236|0;e=xr(c);while(1){if((c|0)==(e|0)){break g}if((g|0)==z[c>>1]){w[c>>1]=0}c=c+2|0;continue}}a=a+1|0;continue}break}}if((a&65535)>>>0<4e3){break d}f=Xo(d+48|0);x[31737]=0;a=P(779,b|0,f|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break b}if(a){x[31737]=0;O(780,b|0,f|0);c=x[31737];x[31737]=0;a=1;if((c|0)==1){break b}while(1){c=a&65535;if(c>>>0<=z[b+480192>>1]){h:{c=x[((c<<2)+b|0)+900380>>2];if(!c){break h}c=c+236|0;g=xr(c);while(1){if((c|0)==(g|0)){break h}e=z[c>>1];i:{if(e>>>0>=A[d+52>>2]){break i}Kb(d+40|0,x[f>>2],e);if(Hb(x[x[d+40>>2]>>2],x[d+44>>2])){break i}w[c>>1]=0}c=c+2|0;continue}}a=a+1|0;continue}break}rn(d+24|0,x[f>>2]);IV(d+32|0,x[d+24>>2],x[d+28>>2],1);dr(d+16|0,x[f>>2],x[d+52>>2]);l=fb-16|0;fb=l;g=d+40|0;e=gc(l,x[d+32>>2],x[d+36>>2]);a=qn(x[d+16>>2],x[d+20>>2],x[d+32>>2],x[d+36>>2]);c=fb-16|0;fb=c;x[c+12>>2]=a;h=x[e+4>>2];j:{if(h){i=32-h|0;x[c+8>>2]=i;m=x[Gb(c+8|0,c+12|0)>>2];k=-1<<h&-1>>>i-m;i=x[e>>2];k=k&(x[i>>2]^-1);if(k){gc(g,i,Rua(k));break j}if((a|0)==(m|0)){IV(g,i,h,a);break j}a=a-m|0;x[c+12>>2]=a;x[e>>2]=i+4}while(1){if(a>>>0>=32){h=x[e>>2];i=x[h>>2];if((i|0)!=-1){gc(g,h,Rua(i^-1));break j}else{x[e>>2]=h+4;a=a-32|0;x[c+12>>2]=a;continue}}break}e=x[e>>2];if(!a){gc(g,e,0);break j}h=(x[e>>2]^-1)&-1>>>32-a;if(!h){gc(g,e,a);break j}gc(g,e,Rua(h))}fb=c+16|0;fb=l+16|0;rn(d+8|0,x[f>>2]);a=qn(x[d+40>>2],x[d+44>>2],x[d+8>>2],x[d+12>>2]);w[d+60>>1]=a;tf(f);if((a&65535)>>>0<4e3){break d}break c}tf(f)}fb=d- -64|0;return}x[31737]=0;O(258,j|0,d+60|0);c=x[31737];x[31737]=0;if((c|0)!=1){if(z[b+480190>>1]>=(a&65535)>>>0){break c}w[b+480190>>1]=a;break c}c=N()|0;break a}o=o+1|0;continue}}c=N()|0;break a}c=N()|0;tf(f)}md(j);Q(c|0);p()}function JS(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;i=fb-48|0;fb=i;d=fb-16|0;fb=d;x[d>>2]=b;x[d+4>>2]=c;g=fb-16|0;fb=g;e=fb-16|0;fb=e;k=x[d>>2];f=x[d+4>>2];j=vb(e+12|0,Tua(k,f,500654080,20));fb=e+16|0;h=fb-16|0;fb=h;e=x[j>>2];j=GS(h+8|0,e);l=x[j>>2];fb=h+16|0;h=x[j+4>>2];if(k>>>0<l>>>0&(h|0)>=(f|0)|(f|0)<(h|0)){h=x[vb(g+12|0,1)>>2];f=fb-16|0;fb=f;e=x[vb(f+12|0,e-h|0)>>2];fb=f+16|0}fb=g+16|0;e=x[vb(d+12|0,e)>>2];fb=d+16|0;f=fb-16|0;fb=f;d=fb-16|0;fb=d;g=e+719468|0;j=(((e|0)>-719469?g:e+573372|0)|0)/146097|0;g=D(j,-146097)+g|0;h=((g>>>0)/36524|0)+g-(((g>>>0)/146096|0)+((g>>>0)/1460|0))|0;k=(h>>>0)/365|0;h=((g-((h>>>0)/1460|0)|0)+((h>>>0)/36500|0)|0)+D(k,-365)|0;l=D(h,5)+2|0;g=(l>>>0)/153|0;j=k+D(j,400)|0;k=g+(l>>>0<1530?3:-9)|0;j=Gw(d+14|0,j+(k>>>0<3)|0);k=pq(d+13|0,k);g=pq(d+12|0,(h-((D(g,153)+2>>>0)/5|0)|0)+1|0);FS(f+12|0,z[j>>1],k,g);fb=d+16|0;d=x[f+12>>2];w[i+44>>1]=d;w[i+46>>1]=d>>>16;fb=f+16|0;d=fb-16|0;fb=d;e=GS(d,e);g=x[e>>2];c=we(d+8|0,b-g|0,c-(x[e+4>>2]+(b>>>0<g>>>0)|0)|0);b=x[c>>2];fb=d+16|0;g=fb-16|0;fb=g;c=x[c+4>>2];d=ZA(g+8|0,0);m=i,n=HS(b,c,x[d>>2],x[d+4>>2]),v[m+8|0]=n;d=fb-16|0;fb=d;e=we(d+8|0,0,0);f=x[e>>2];fb=d+16|0;if(!(HS(b,c,f,x[e+4>>2])^1)){d=fb-16|0;fb=d;c=we(d+8|0,0-b|0,0-(((b|0)!=0)+c|0)|0);b=x[c>>2];fb=d+16|0;c=x[c+4>>2]}d=fb-16|0;fb=d;e=x[vb(d+12|0,Tua(b,c,-694967296,0))>>2];fb=d+16|0;x[i+12>>2]=e;d=fb-16|0;fb=d;f=fb-16|0;fb=f;e=we(f+8|0,Sua(e,e>>31,-694967296,0),hb);h=x[e>>2];e=x[e+4>>2];fb=f+16|0;x[d>>2]=h;x[d+4>>2]=e;e=x[d>>2];b=we(d+8|0,b-e|0,c-(x[d+4>>2]+(b>>>0<e>>>0)|0)|0);c=x[b>>2];e=x[b+4>>2];f=e;fb=d+16|0;b=fb-16|0;fb=b;d=x[vb(b+12|0,Tua(c,e,6e7,0))>>2];fb=b+16|0;x[i+16>>2]=d;b=fb-16|0;fb=b;e=fb-16|0;fb=e;d=we(e+8|0,Sua(d,d>>31,6e7,0),hb);h=x[d>>2];d=x[d+4>>2];fb=e+16|0;x[b>>2]=h;x[b+4>>2]=d;d=x[b>>2];d=we(b+8|0,c-d|0,f-(x[b+4>>2]+(c>>>0<d>>>0)|0)|0);c=x[d>>2];fb=b+16|0;d=x[d+4>>2];e=_A(c,d);x[i+24>>2]=e;f=hb;x[i+28>>2]=f;b=fb-16|0;fb=b;e=Du(b,e,f);f=x[e>>2];c=we(b+8|0,c-f|0,d-(x[e+4>>2]+(c>>>0<f>>>0)|0)|0);d=x[c>>2];fb=b+16|0;m=i,n=AR(d,x[c+4>>2]),x[m+32>>2]=n;x[i+36>>2]=hb;fb=g+16|0;a=IS(a);x[a>>2]=z[i+44>>1]<<16>>16;m=a,n=Pf(y[i+46|0]),x[m+4>>2]=n;m=a,n=Pf(y[i+47|0]),x[m+8>>2]=n;x[a+12>>2]=x[i+12>>2];x[a+16>>2]=x[i+16>>2];b=x[i+28>>2];x[a+24>>2]=x[i+24>>2];x[a+28>>2]=b;fb=i+48|0}function FV(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=fb-32|0;fb=c;e=y[a+13|0];a:{if(e&227|(e&24)==16){break a}e=y[a+8|0];f=y[a+6|0]|y[a+7|0]<<8;v[c+22|0]=0;v[c+26|0]=e;w[c+24>>1]=f;w[c+20>>1]=0;while(1){if((d|0)!=3){e=y[xb(c+24|0,d)|0];h=xb(c+20|0,d),i=e,v[h|0]=i;d=d+1|0;continue}break}e=eg(c+20|0);f=y[a+11|0];g=y[a+9|0]|y[a+10|0]<<8;d=0;v[c+18|0]=0;v[c+26|0]=f;w[c+24>>1]=g;w[c+16>>1]=0;while(1){if((d|0)!=3){f=y[xb(c+24|0,d)|0];h=xb(c+16|0,d),i=f,v[h|0]=i;d=d+1|0;continue}break}d=0;if(eg(c+16|0)>>>0<e>>>0){break a}e=a+6|0;d=a+9|0;f=y[d+2|0];g=y[d|0]|y[d+1|0]<<8;d=0;v[c+22|0]=0;v[c+26|0]=f;w[c+24>>1]=g;w[c+20>>1]=0;while(1){if((d|0)!=3){f=y[xb(c+24|0,d)|0];h=xb(c+20|0,d),i=f,v[h|0]=i;d=d+1|0;continue}break}f=eg(c+20|0);g=y[e+2|0];e=y[e|0]|y[e+1|0]<<8;d=0;v[c+18|0]=0;v[c+26|0]=g;w[c+24>>1]=e;w[c+16>>1]=0;while(1){if((d|0)!=3){e=y[xb(c+24|0,d)|0];h=xb(c+16|0,d),i=e,v[h|0]=i;d=d+1|0;continue}break}e=eg(c+16|0);b:{if(!((b|0)==2|(e|0)==(f|0))){d=0;if((y[a+14|0]|y[a+15|0]<<8)>>>0>=100){break b}break a}if((e|0)==(f|0)|(b|0)!=2){break b}d=0;if((y[a+14|0]|y[a+15|0]<<8)<<16>>16<0){break a}}b=y[a+13|0];e=f-e|0;if(e&1){d=0;if(b&4){break a}}c:{if(b&8){b=y[a+5|0];f=y[a+3|0]|y[a+4|0]<<8;d=0;v[c+22|0]=0;w[c+24>>1]=f;v[c+26|0]=b;w[c+20>>1]=0;while(1){if((d|0)!=3){b=y[xb(c+24|0,d)|0];h=xb(c+20|0,d),i=b,v[h|0]=i;d=d+1|0;continue}break}if(!eg(c+20|0)){break c}}b=y[a+5|0];f=y[a+3|0]|y[a+4|0]<<8;d=0;v[c+22|0]=0;v[c+26|0]=b;w[c+24>>1]=f;w[c+20>>1]=0;while(1){if((d|0)!=3){b=y[xb(c+24|0,d)|0];h=xb(c+20|0,d),i=b,v[h|0]=i;d=d+1|0;continue}break}if(eg(c+20|0)){b=a+3|0;f=y[b+2|0];g=y[b|0]|y[b+1|0]<<8;d=0;v[c+18|0]=0;w[c+24>>1]=g;v[c+26|0]=f;w[c+16>>1]=0;while(1){if((d|0)!=3){f=y[xb(c+24|0,d)|0];h=xb(c+16|0,d),i=f,v[h|0]=i;d=d+1|0;continue}break}if(eg(c+16|0)>>>0>=e>>>0){break c}e=y[a+2|0];a=y[a|0]|y[a+1|0]<<8;d=0;v[c+14|0]=0;w[c+24>>1]=a;v[c+26|0]=e;w[c+12>>1]=0;while(1){if((d|0)!=3){a=y[xb(c+24|0,d)|0];h=xb(c+12|0,d),i=a,v[h|0]=i;d=d+1|0;continue}break}a=eg(c+12|0);e=y[b+2|0];b=y[b|0]|y[b+1|0]<<8;d=0;v[c+10|0]=0;v[c+26|0]=e;w[c+24>>1]=b;w[c+8>>1]=0;while(1){if((d|0)!=3){b=y[xb(c+24|0,d)|0];h=xb(c+8|0,d),i=b,v[h|0]=i;d=d+1|0;continue}break}d=0;if(eg(c+8|0)>>>0<=a>>>0){break a}}d=1;break a}d=0}fb=c+32|0;return d}function E_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;g=fb-80|0;fb=g;a:{b:{c:{d:{e:{f:{g:{if(Ad(x[b+4>>2],y[b+11|0])){Fb(a);break g}k=Nb(g+68|0);x[g+56>>2]=0;x[g+60>>2]=0;h=x[c>>2];x[31737]=0;n=R(38,h|0)|0;h=x[31737];x[31737]=0;if((h|0)==1){break b}h=Jb(b);i=Cb(x[b+4>>2],y[b+11|0]);j=Ok(n);f=fb-16|0;fb=f;x[f+12>>2]=j;x[f+8>>2]=0;j=x[Ye(f+8|0,f+12|0)>>2];fb=f+16|0;x[31737]=0;O(39,k|0,D(i,j+1|0)|0);f=x[31737];x[31737]=0;if((f|0)==1){break c}o=(i<<2)+h|0;i=x[k>>2];m=i+Vc(i,x[k+4>>2])|0;q=(d|0)!=2;h:{while(1){i:{j:{k:{l:{if(!q){while(1){x[g+48>>2]=0;x[g+52>>2]=0;x[31737]=0;f=h+4|0;j=za(40,n|0,g+56|0,h|0,f|0,g+52|0,i|0,m|0,g+48|0)|0;l=x[31737];x[31737]=0;if((l|0)==1){break f}if((j|0)!=1){break l}if((f|0)!=x[g+52>>2]){l=1;break k}else{i=x[g+48>>2];h=f;continue}}}x[g+48>>2]=0;x[g+52>>2]=0;x[31737]=0;j=za(40,n|0,g+56|0,h|0,o|0,g+52|0,i|0,m|0,g+48|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break d}l=1;if((j|0)==1){break k}}l=2;f=x[g+48>>2];if((j|0)!=2|(m|0)!=(f|0)){break j}}h=x[k+4>>2];f=x[k>>2];x[31737]=0;O(39,k|0,Vc(f,h)<<1);h=x[31737];x[31737]=0;if((h|0)==1){break d}h=x[k>>2];f=x[g+48>>2];i=h+(f-i|0)|0;m=Vc(h,x[k+4>>2])+h|0;j=l;break i}m:{n:{o:{p:{q:{switch(d|0){case 0:if(x[g+52>>2]!=(h|0)|(f|0)!=(i|0)|(j|0)!=2){break p}x[31737]=0;v[g+47|0]=1;h=P(41,g+8|0,22304)|0;f=x[31737];x[31737]=0;r:{s:{t:{if((f|0)!=1){x[31737]=0;f=g+20|0;S(42,f|0,h|0,b|0);i=x[31737];x[31737]=0;if((i|0)==1){break t}x[31737]=0;i=g+32|0;aa(43,i|0,f|0,c|0,1,g+47|0);l=x[31737];x[31737]=0;if((l|0)==1){break s}tb(i);Ub(f);Ub(h);if(y[g+47|0]){break o}x[31737]=0;aa(43,a|0,b|0,c|0,2,0);a=x[31737];x[31737]=0;if((a|0)!=1){break h}f=N()|0;break a}f=N()|0;break a}f=N()|0;break r}f=N()|0;Ub(g+20|0)}Ub(h);break a;case 1:break q;default:break p}}v[e|0]=(j|0)!=2|x[g+52>>2]!=(h|0)|(f|0)!=(i|0);Fb(a);break h}if((j|0)==2){break n}break m}f=x[g+48>>2]}x[g+52>>2]=x[g+52>>2]+4;v[f|0]=63;f=x[g+48>>2]+1|0;x[g+48>>2]=f}i=f}h=x[g+52>>2];l=o>>>0>h>>>0;if(l&f>>>0<m>>>0&(j|0)==2|l&(d|0)==2){continue}break}b=x[k>>2];x[31737]=0;U(44,a|0,b|0,f|0)|0;a=x[31737];x[31737]=0;if((a|0)==1){break e}}dc(k)}fb=g+80|0;return}f=N()|0;break a}f=N()|0;break a}f=N()|0;break a}f=N()|0;break a}f=N()|0}dc(k);Q(f|0);p()}function w1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=fb-368|0;fb=e;xc(b);d=fb-16|0;fb=d;g=e+330|0;hF(d+8|0,g);h=x[d+12>>2];lc(d,x[b>>2],x[b+8>>2],x[d+8>>2],x[d+12>>2]);i=x[d+4>>2];if((i|0)==(h|0)){Vb(b,x[d+12>>2])}fb=d+16|0;d=(h|0)==(i|0);if(!d){gF(g)}a:{if(!d){break a}if(!jF(g)){break a}if(!Mb(x[b>>2],x[b+8>>2],Bc(iF(y[e+365|0]),hb))){break a}f=1;if((c|0)==64){break a}Bd(a,2097152);gg(a);Xh(a,1);w[a+480188>>1]=8;x[a+480196>>2]=y[e+362|0];x[a+480204>>2]=D(y[e+363|0],1e4);w[a+480190>>1]=y[e+364|0];d=y[e+367|0];if(d>>>0<y[e+366|0]){af(Xb(x[a+484360>>2],y[a+484376|0]),d)}d=e- -64|0;f=tc(d,6554);Ab(a+1298344|0,f);tb(f);f=tc(d,11164);Ab(a+1298356|0,f);tb(f);n=a+1298404|0,o=x[Fc(d,4)>>2],x[n>>2]=o;Dw(b,d);Vr(Xb(x[a+484360>>2],y[a+484376|0]),d,y[e+366|0],65535,65535);f=1;while(1){i=f&65535;if(i>>>0>z[a+480190>>1]){Vb(b,D(64-y[e+364|0]|0,37));h=a+484344|0;Vf(h,y[e+365|0]);i=c&1;f=0;while(1){b:{c:{if(y[e+365|0]<=f>>>0){if(!(c&2)){break c}c=Xc(e+24|0,8,1,0,0);f=1;while(1){d=f&65535;if(d>>>0>z[a+480190>>1]){break c}fg(c,(D(d,104)+a|0)+484380|0,b);f=f+1|0;continue}}d:{if(i){if(Ng(h,f&65535,64)){break d}}Vb(b,2048);break b}d=Wb(x[h>>2],f);n=e,o=wb(x[d>>2]),x[n+24>>2]=o;j=wb(x[d+4>>2]);while(1){d=x[e+24>>2];if(!Ib(d,j)){break b}g=e+12|0;sm(g,b);l=Jc(g);m=$e(g);g=dj(g);k=y[e+12|0];if((k-1&255)>>>0<=106){v[d|0]=k+13}v[d+1|0]=y[l|0];Bf(d,y[m|0],y[g|0]);vg(e+24|0);continue}}f=1;break a}f=f+1|0;continue}}else{d=e+24|0;fF(b,d);h=fb-16|0;fb=h;g=(D(i,104)+a|0)+484380|0;ld(g,0);v[g+37|0]=y[d+22|0]<<4;v[h+15|0]=y[d+23|0];v[h+14|0]=64;n=g,o=y[Qb(h+15|0,h+14|0)|0]<<2,w[n+30>>1]=o;v[g+36|0]=y[d+24|0];x[g>>2]=y[d+25|0]|y[d+26|0]<<8|(y[d+27|0]<<16|y[d+28|0]<<24);j=y[d+33|0]|y[d+34|0]<<8|(y[d+35|0]<<16|y[d+36|0]<<24);if(!(j>>>0<3|j+(y[d+29|0]|y[d+30|0]<<8|(y[d+31|0]<<16|y[d+32|0]<<24))>>>0>(y[d+25|0]|y[d+26|0]<<8|(y[d+27|0]<<16|y[d+28|0]<<24))>>>0)){w[g+34>>1]=z[g+34>>1]|2;x[g+4>>2]=y[d+29|0]|y[d+30|0]<<8|(y[d+31|0]<<16|y[d+32|0]<<24);x[g+8>>2]=(y[d+33|0]|y[d+34|0]<<8|(y[d+35|0]<<16|y[d+36|0]<<24))+(y[d+29|0]|y[d+30|0]<<8|(y[d+31|0]<<16|y[d+32|0]<<24))}fb=h+16|0;Xk(e,2,d);d=e+12|0;Cc(d,e);zc(((i<<5)+a|0)+946304|0,d);f=f+1|0;tb(d);continue}}}fb=e+368|0;return f|0}function nua(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;m=fb-32|0;fb=m;d=b;b=x[a>>2];b=(pp(d,wb(b))<<1)+b|0;f=x[a+4>>2];a:{b:{if(f>>>0<A[zb(a)>>2]){if((b|0)!=(f|0)){break b}d=fb-16|0;fb=d;a=_h(d+4|0,a,1);hj(x[a+4>>2],y[c|0]|y[c+1|0]<<8);x[a+4>>2]=x[a+4>>2]+2;hc(a);fb=d+16|0;break a}d=zb(a);g=kk(m+12|0,lk(a,Zc(x[a>>2],f)+1|0),b-x[a>>2]>>1,d);x[31737]=0;O(295,g|0,c|0);c=x[31737];x[31737]=0;if((c|0)!=1){h=fb-16|0;fb=h;c=x[g+4>>2];k=zb(a);d=vb(h+12|0,b);f=vb(h+8|0,x[a>>2]);i=vb(h+4|0,x[g+4>>2]);e=x[d>>2];j=x[f>>2];d=fb+-64|0;fb=d;f=x[i>>2];x[d+56>>2]=f;x[d+60>>2]=e;x[d+52>>2]=f;f=Re(d+24|0,k,d+52|0,d+56|0);x[d+16>>2]=x[f+8>>2];i=x[f+4>>2];x[d+8>>2]=x[f>>2];x[d+12>>2]=i;Qe(d+36|0,d+8|0);while(1){if(pd(e,j)){f=oE(x[d+56>>2]);e=Mn(e);hj(f,y[e|0]|y[e+1|0]<<8);e=ij(d+60|0);ij(d+56|0);e=x[e>>2];continue}break}Pe(d+36|0);n=x[d+56>>2];if(!y[d+48|0]){i=fb-16|0;fb=i;e=vb(i+12|0,x[x[d+44>>2]>>2]);l=x[vb(i+8|0,x[x[d+40>>2]>>2])>>2];j=fb-16|0;fb=j;e=x[e>>2];x[j+12>>2]=e;while(1){if(ci(e,l)){f=fb-16|0;fb=f;x[f+12>>2]=e;x[f+12>>2]=x[f+12>>2]+2;fb=f+16|0;oE(x[f+12>>2]);e=x[Md(j+12|0)>>2];continue}break}fb=j+16|0;fb=i+16|0}fb=d- -64|0;x[g+4>>2]=n;f=x[a+4>>2];d=fb-48|0;fb=d;e=x[g+8>>2];x[d+44>>2]=e;x[d+40>>2]=e;e=Re(d+12|0,k,d+40|0,d+44|0);x[d+8>>2]=x[e+8>>2];i=x[e+4>>2];x[d>>2]=x[e>>2];x[d+4>>2]=i;Qe(d+24|0,d);while(1){if((b|0)!=(f|0)){hj(x[d+44>>2],y[b|0]|y[b+1|0]<<8);x[d+44>>2]=x[d+44>>2]+2;b=b+2|0;continue}break}b=d+24|0;Pe(b);e=x[d+44>>2];pE(b);fb=d+48|0;x[g+8>>2]=e;Tb(a,g+4|0);Tb(a+4|0,g+8|0);Tb(zb(a),nc(g));x[g>>2]=x[g+4>>2];fb=h+16|0;b=c;jj(g);break a}a=N()|0;jj(g);Q(a|0);p()}i=fb-16|0;fb=i;e=x[a+4>>2];g=(e-(b+2|0)|0)+b|0;j=_h(i+4|0,a,f-g>>1);h=x[j+4>>2];d=g;while(1){if(d>>>0>=f>>>0){hc(j);h=fb-16|0;fb=h;j=h+8|0;d=e;e=fb-32|0;fb=e;Id(e+24|0,b,g);k=e+16|0;n=x[e+24>>2];g=fb-16|0;fb=g;l=x[e+28>>2];f=l;while(1){if((f|0)!=(n|0)){f=f-2|0;d=h0(d-2|0,f);continue}break}x[g+12>>2]=d;Ac(k,l,g+12|0);fb=g+16|0;d=x[e+16>>2];x[e+12>>2]=x[e+20>>2];Ac(j,d,e+12|0);fb=e+32|0;fb=h+16|0;fb=i+16|0}else{hj(h,y[d|0]|y[d+1|0]<<8);h=h+2|0;x[j+4>>2]=h;d=d+2|0;continue}break}a=((b>>>0<=c>>>0&A[a+4>>2]>c>>>0)<<1)+c|0;c=y[a|0];v[b+1|0]=y[a+1|0];v[b|0]=c}wb(b);fb=m+32|0}function qoa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;k=fb-16|0;fb=k;e=x[b>>2];d=Lg(e,x[b+4>>2]);a:{if(d>>>0<c>>>0){n=fb-32|0;fb=n;d=c-d|0;f=x[zb(b)>>2];e=x[b+4>>2];b:{if(d>>>0<=f-e>>5>>>0){h=fb-16|0;fb=h;e=jC(h+4|0,b,d);d=x[e+4>>2];g=x[e+8>>2];while(1){if((d|0)==(g|0)){hc(e);fb=h+16|0}else{RV(d);d=d+32|0;x[e+4>>2]=d;continue}break}break b}h=zb(b);h=fv(n+12|0,_q(b,Lg(x[b>>2],e)+d|0),Lg(x[b>>2],x[b+4>>2]),h);g=fb-16|0;fb=g;d=SV(g+4|0,h+8|0,d);e=x[d>>2];while(1){if(x[d+4>>2]!=(e|0)){RV(e);e=x[d>>2]+32|0;x[d>>2]=e;continue}break}he(d);fb=g+16|0;l=fb-16|0;fb=l;d=vb(l+12|0,x[b+4>>2]);e=vb(l+8|0,x[b>>2]);f=x[vb(l+4|0,x[h+4>>2])>>2];m=fb-16|0;fb=m;o=m+8|0;g=fb-32|0;fb=g;Id(g+24|0,x[d>>2],x[e>>2]);p=g+16|0;d=x[g+24>>2];q=x[g+28>>2];j=fb-16|0;fb=j;x[j+8>>2]=f;x[j+12>>2]=d;while(1){if(pd(d,q)){d=ln(d);e=ln(x[j+8>>2]);f=y[d+28|0]|y[d+29|0]<<8|(y[d+30|0]<<16|y[d+31|0]<<24);i=y[d+24|0]|y[d+25|0]<<8|(y[d+26|0]<<16|y[d+27|0]<<24);v[e+24|0]=i;v[e+25|0]=i>>>8;v[e+26|0]=i>>>16;v[e+27|0]=i>>>24;v[e+28|0]=f;v[e+29|0]=f>>>8;v[e+30|0]=f>>>16;v[e+31|0]=f>>>24;f=y[d+20|0]|y[d+21|0]<<8|(y[d+22|0]<<16|y[d+23|0]<<24);i=y[d+16|0]|y[d+17|0]<<8|(y[d+18|0]<<16|y[d+19|0]<<24);v[e+16|0]=i;v[e+17|0]=i>>>8;v[e+18|0]=i>>>16;v[e+19|0]=i>>>24;v[e+20|0]=f;v[e+21|0]=f>>>8;v[e+22|0]=f>>>16;v[e+23|0]=f>>>24;f=y[d+12|0]|y[d+13|0]<<8|(y[d+14|0]<<16|y[d+15|0]<<24);i=y[d+8|0]|y[d+9|0]<<8|(y[d+10|0]<<16|y[d+11|0]<<24);v[e+8|0]=i;v[e+9|0]=i>>>8;v[e+10|0]=i>>>16;v[e+11|0]=i>>>24;v[e+12|0]=f;v[e+13|0]=f>>>8;v[e+14|0]=f>>>16;v[e+15|0]=f>>>24;f=y[d+4|0]|y[d+5|0]<<8|(y[d+6|0]<<16|y[d+7|0]<<24);d=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);v[e|0]=d;v[e+1|0]=d>>>8;v[e+2|0]=d>>>16;v[e+3|0]=d>>>24;v[e+4|0]=f;v[e+5|0]=f>>>8;v[e+6|0]=f>>>16;v[e+7|0]=f>>>24;d=Yo(j+12|0);Yo(j+8|0);d=x[d>>2];continue}break}Ac(p,d,j+8|0);fb=j+16|0;d=x[g+16>>2];x[g+12>>2]=x[g+20>>2];Ac(o,d,g+12|0);fb=g+32|0;fb=m+16|0;x[h+4>>2]=x[m+12>>2];Tb(b,h+4|0);Tb(b+4|0,h+8|0);Tb(zb(b),nc(h));x[h>>2]=x[h+4>>2];fb=l+16|0;UV(h)}fb=n+32|0;break a}if(c>>>0<d>>>0){hY(b,e+(c<<5)|0)}}if(Mb(x[a>>2],x[a+8>>2],c<<5)){c=x[b>>2];bc(k+8|0,c,Lg(c,x[b+4>>2])<<5);rd(k,a,x[k+8>>2],x[k+12>>2])}fb=k+16|0}function eba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=fb-144|0;fb=d;i=TM(d+128|0);x[i>>2]=48748;Nb(i+4|0);yo(x[a+24>>2],i);e=x[a+24>>2];f=y[a+62|0];g=y[a+61|0];h=y[a+60|0];b=Ge(d+108|0,b);x[31737]=0;k=x[b+12>>2];x[d+8>>2]=x[b+8>>2];x[d+12>>2]=k;x[d+16>>2]=x[b+16>>2];k=x[b+4>>2];x[d>>2]=x[b>>2];x[d+4>>2]=k;b=h?13:15;b=g?b&14:b;b=U(1145,e|0,d|0,(f?b&3:b)|0)|0;e=x[31737];x[31737]=0;a:{b:{c:{d:{e:{if((e|0)==1){break e}if(!b){b=ac(8);x[31737]=0;c=P(36,d+96|0,12026)|0;a=x[31737];x[31737]=0;if((a|0)!=1){pc(b,c);x[31737]=0;S(98,b|0,48540,1006);a=x[31737];x[31737]=0;if((a|0)!=1){break a}a=N()|0;tb(c);break b}a=N()|0;jc(b);break b}if(!y[a+63|0]){x[31737]=0;O(1146,a|0,a+36|0);b=x[31737];x[31737]=0;if((b|0)==1){break e}}v[a+28|0]=1;yo(x[a+24>>2],x[a+4>>2]);x[31737]=0;O(1147,d+96|0,i|0);b=x[31737];x[31737]=0;if((b|0)==1){break c}m=d,n=wb(x[d+96>>2]),x[m+92>>2]=n;k=a+68|0;l=wb(x[d+100>>2]);f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{while(1){b=x[d+92>>2];if(!Ib(b,l)){b=_i(x[c>>2]);x[d+80>>2]=b;c=Rf(c);while(1){if(!Zg(b,c)){break d}x[31737]=0;e=td(b);b=P(71,d+20|0,e|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break h}x[31737]=0;V(1018,a|0,b|0,e+12|0,0);e=x[31737];x[31737]=0;if((e|0)==1){break g}tb(b);b=x[ah(d+80|0)>>2];continue}}e=x[a+24>>2];f=x[b>>2];x[31737]=0;j=b+4|0;S(1148,e|0,f|0,j|0);e=x[31737];x[31737]=0;if((e|0)!=1){b=x[b>>2];x[31737]=0;e=d+44|0;O(1149,e|0,b|0);b=x[31737];x[31737]=0;if((b|0)==1){break r}x[31737]=0;f=d+56|0;O(1065,f|0,e|0);b=x[31737];x[31737]=0;if((b|0)==1){break q}x[31737]=0;b=P(36,d+32|0,18418)|0;g=x[31737];x[31737]=0;if((g|0)==1){break p}x[31737]=0;g=d+68|0;S(1021,g|0,f|0,b|0);h=x[31737];x[31737]=0;if((h|0)==1){break o}x[31737]=0;h=d+80|0;S(545,h|0,g|0,j|0);j=x[31737];x[31737]=0;if((j|0)==1){break n}x[31737]=0;O(179,k|0,h|0);j=x[31737];x[31737]=0;if((j|0)==1){break m}tb(h);tb(g);tb(b);tb(f);tb(e);Zo(d+92|0);continue}break}a=N()|0;break f}a=N()|0;break f}a=N()|0;break i}a=N()|0;break j}a=N()|0;break k}a=N()|0;break l}a=N()|0;tb(d+80|0)}tb(d+68|0)}tb(b)}tb(d+56|0)}tb(d+44|0);break f}a=N()|0;break f}a=N()|0;tb(b)}tz(d+96|0);break b}a=N()|0;break b}tz(d+96|0);Yt(i);fb=d+144|0;return}a=N()|0}Yt(i);Q(a|0)}p()}function mda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;m=fb-32|0;fb=m;j=rf(m+20|0,1,0);a:{b:{while(1){e=Jb(j);i=e+Cb(x[j+4>>2],y[j+11|0])|0;g=x[b>>2];d=x[b+4>>2];if(!((d|0)>=0|(d|0)>0|(e|0)==(i|0))){v[e|0]=45;e=e+1|0;g=_N(g,d);d=hb}k=m+12|0;c:{d:{switch(c<<31|c-2>>>1){case 4:TN(k,e,i,g,d);break c;case 0:f=64-bu(g|1,d)|0;if((f|0)<=(i-e|0)){i=e+f|0;e=i;while(1){if(!d&g>>>0<17){while(1){e=e-1|0;v[e|0]=y[(g&1)+15526|0];h=!d&g>>>0>1|(d|0)!=0;f=d;d=d>>>1|0;g=(f&1)<<31|g>>>1;if(h){continue}break}}else{e=e-4|0;fn((g<<2&60)+78848|0,4,e);f=d;d=d>>>4|0;g=(f&15)<<28|g>>>4;continue}break}f=0}else{f=61}x[k+4>>2]=f;x[k>>2]=i;break c;case 3:f=(66-bu(g|1,d)>>>0)/3|0;if((f|0)<=(i-e|0)){i=e+f|0;e=i;while(1){if(!d&g>>>0<65){while(1){e=e-1|0;v[e|0]=y[(g&7)+14823|0];h=!d&g>>>0>7|(d|0)!=0;f=d;d=d>>>3|0;g=(f&7)<<29|g>>>3;if(h){continue}break}}else{e=e-2|0;fn((g<<1&126)+78912|0,2,e);f=d;d=d>>>6|0;g=(f&63)<<26|g>>>6;continue}break}f=0}else{f=61}x[k+4>>2]=f;x[k>>2]=i;break c;case 7:f=67-bu(g|1,d)>>>2|0;if((f|0)<=(i-e|0)){i=e+f|0;e=i;while(1){if(!d&g>>>0<257){while(1){e=e-1|0;v[e|0]=y[(g&15)+11181|0];h=!d&g>>>0>15|(d|0)!=0;f=d;d=d>>>4|0;g=(f&15)<<28|g>>>4;if(h){continue}break}}else{e=e-2|0;fn((g<<1&510)+79040|0,2,e);f=d;d=d>>>8|0;g=(f&255)<<24|g>>>8;continue}break}f=0}else{f=61}x[k+4>>2]=f;x[k>>2]=i;break c;default:break d}}f=g;h=d;n=D(c,c);q=D(n,c);r=D(n,n);o=0;e:{while(1){l=o|1;if(!h&c>>>0>f>>>0){break e}l=o|2;if(!h&f>>>0<n>>>0){break e}l=o|3;if(!h&f>>>0<q>>>0){break e}if(!h&f>>>0<r>>>0){l=o+4|0}else{o=o+4|0;f=Uua(f,h,r,0);h=hb;continue}break}}h=l;if((h|0)>(i-e|0)){x[k+4>>2]=61;x[k>>2]=i;break c}q=e+h|0;e=q;while(1){e=e-1|0;h=Uua(g,d,c,0);f=hb;s=e,t=y[(g-Sua(h,f,c,0)|0)+4895|0],v[s|0]=t;n=!d&c>>>0<=g>>>0|(d|0)!=0;g=h;d=f;if(n){continue}break}x[k+4>>2]=0;x[k>>2]=q}if(!x[m+16>>2]){break b}d=qi(Cb(x[j+4>>2],y[j+11|0]));x[31737]=0;O(45,j|0,d|0);d=x[31737];x[31737]=0;if((d|0)!=1){continue}break}break a}c=x[m+12>>2];b=Jb(j);x[31737]=0;O(46,j|0,c-b|0);b=x[31737];x[31737]=0;f:{if((b|0)!=1){x[31737]=0;O(47,a|0,j|0);a=x[31737];x[31737]=0;if((a|0)!=1){break f}break a}break a}tb(j);fb=m+32|0;return}a=N()|0;tb(j);Q(a|0);p()}function Mja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;h=fb-16|0;fb=h;f=x[a+8>>2];e=x[a>>2];x[31737]=0;f=P(623,e|0,f|0)|0;e=x[31737];x[31737]=0;a:{b:{if((e|0)!=1){if(f){break b}x[31737]=0;f=R(198,a|0)|0;e=x[31737];x[31737]=0;c:{if((e|0)==1){break c}x[31737]=0;j=d+484344|0;k=Kd(f+1|0,1,1024);f=U(197,j|0,b|0,k|0)|0;e=x[31737];x[31737]=0;if((e|0)==1){break c}if(!f){break b}d=z[d+480188>>1];if(!d){break b}l=d-1|0;d=0;while(1){if(d>>>0>=k>>>0){break b}f=x[a+8>>2];e=x[a>>2];x[31737]=0;f=U(151,e|0,f|0,1)|0;e=x[31737];x[31737]=0;d:{if((e|0)!=1){if(!f){break b}x[31737]=0;i=R(198,a|0)|0;e=x[31737];x[31737]=0;if((e|0)==1){break a}if(i){break d}d=d+1|0;continue}break a}e=x[j>>2];w[h+14>>1]=i&31;w[h+12>>1]=l;e=Wb(e,b);e=jd(x[e>>2],x[x[e+48>>2]+12>>2],d,z[Nc(h+14|0,h+12|0)>>1]);if(i>>>0<32){continue}e:{if(i<<24>>24>=0){break e}x[31737]=0;g=R(198,a|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break a}v[e+5|0]=g;x[31737]=0;g=R(198,a|0)|0;f=x[31737];x[31737]=0;f:{g:{if((f|0)!=1){if(g>>>0<26){break g}break f}break a}f=y[g+41200|0];v[e+3|0]=f;h:{switch(f-1|0){case 0:if(!y[e+5|0]){break f}break e;case 12:if(y[e+2|0]){break e}v[e+2|0]=1;f=y[e+5|0];v[e+5|0]=0;v[e+3|0]=0;m=e,n=Kd(f,0,64),v[m+4|0]=n;break e;case 5:case 6:case 10:case 23:case 28:f=y[e+5|0]&240;if(!f){break e}v[e+5|0]=f;break e;case 8:f=y[e+5|0];if(f>>>0<=128){m=e,n=Ch(f<<1),v[m+5|0]=n;break e}if((f|0)!=164){break e}v[e+5|0]=145;v[e+3|0]=20;break e;case 13:f=y[e+5|0];v[e+5|0]=D(f>>>4|0,10)+(f&15);break e;case 18:sw(e);break e;case 16:if(y[e+5|0]>31){break e}v[e+3|0]=16;break e;case 27:break h;default:break e}}g=y[e+5|0];f=g&240;i:{if((f|0)==16){f=2}else{if((f|0)!=32){break i}f=3}v[e+3|0]=f}v[e+5|0]=g&15|224;break e}v[e+3|0]=0}j:{k:{if(!(i&64)){break k}x[31737]=0;g=h+10|0;O(199,g|0,a|0);f=x[31737];x[31737]=0;if((f|0)==1){break j}v[e+1|0]=y[h+10|0];g=y[Jc(g)|0];v[e|0]=g;f=255;if((g|0)!=128){f=253;if(g>>>0<129){break k}}v[e|0]=f}if(!(i&32)){continue}v[e+2|0]=1;x[31737]=0;g=R(198,a|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break a}v[e+4|0]=g;if(!c){continue}v[e+4|0]=(g<<6>>>0)/127;continue}break}break a}break a}break a}ub(a);fb=h+16|0;return}b=N()|0;ub(a);Q(b|0);p()}function Wu(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;j=fb-16|0;fb=j;g=x[a+24>>2];h=OB(g,y[a+32|0]);i=x[h>>2];a:{if(Zc(i,x[h+4>>2])>>>0<=b>>>0){break a}if(nU(x[g+484344>>2],x[g+484348>>2],z[_b(i,b)>>1])>>>0<=c>>>0){break a}h=x[a>>2];b:{if(Ud(h,x[a+4>>2])>>>0>b>>>0){if(A[Hd(h,b)+4>>2]>c>>>0){break b}}Qo(a,0);if(Ud(x[a>>2],x[a+4>>2])>>>0<=b>>>0){break a}g=x[a+24>>2]}bc(j,x[d>>2],z[g+480188>>1]);h=j+8|0;l=x[j>>2];d=e?-2046629010:-2078137563;i=e?-1352371636:-873292572;e=x[j+4>>2];while(1){if(!f&(e|0)==(k|0)){x[h>>2]=d;x[h+4>>2]=i}else{g=y[uW(l,k)+841|0];m=g^Sua(d^k,f^i,435,256);g=!g;d=(q=d,r=Sua(m,hb,435,256),s=g,s?q:r);i=g?i:hb;k=k+1|0;f=k?f:f+1|0;continue}break}g=0;d=hn(j,b,c);i=fb-16|0;fb=i;k=a+12|0;e=k;f=dU(z[d>>1],x[d+4>>2],ce(e),ec(e));c:{if(Ib(f,rg(e))){l=z[d>>1];m=x[d+4>>2];d=td(f);if(!Vl(l,m,z[d>>1],x[d+4>>2])){break c}}f=rg(e)}d=x[vb(i+12|0,f)>>2];fb=i+16|0;if(Zg(d,Rf(k))){e=td(d);g=mc(x[e+8>>2],x[e+12>>2])^1}i=x[h>>2]!=-2078137563|x[h+4>>2]!=-873292572;Kb(j,x[Hd(x[a>>2],b)>>2],c);f=1;n=Hb(x[x[j>>2]>>2],x[j+4>>2])^1;e=g|i;if(!(n|e)){break a}d:{e:{f:{g:{if(g){m=td(d);e=wb(x[m+8>>2]);o=wb(x[m+12>>2]);d=x[h>>2];p=x[h+4>>2];l=fb-16|0;fb=l;x[l+12>>2]=e;while(1){h:{if(!Ib(e,o)){break h}if(eo(x[e>>2],x[e+4>>2],d,p)){break h}e=x[Yu(l+12|0)>>2];continue}break}fb=l+16|0;if(Ib(e,wb(x[m+12>>2]))){break a}if(!i){break e}break g}if(i){break g}if(!e){break d}break f}x[a+28>>2]=x[a+28>>2]+1}if(g|n){break e}d=bU(k,hn(j,b,c));i:{if(A[d+4>>2]<A[zb(d)>>2]){e=fb-16|0;fb=e;d=aU(e+4|0,d);_T(x[d+4>>2]);x[d+4>>2]=x[d+4>>2]+8;hc(d);fb=e+16|0;break i}f=fb-32|0;fb=f;e=zb(d);e=ms(f+12|0,ns(d,jh(x[d>>2],x[d+4>>2])+1|0),jh(x[d>>2],x[d+4>>2]),e);_T(x[e+8>>2]);x[e+8>>2]=x[e+8>>2]+8;NB(d,e);ls(e);fb=f+32|0}}d=bU(k,hn(j,b,c));j:{if(A[d+4>>2]<A[zb(d)>>2]){e=fb-16|0;fb=e;d=aU(e+4|0,d);$T(x[d+4>>2],x[h>>2],x[h+4>>2]);x[d+4>>2]=x[d+4>>2]+8;hc(d);fb=e+16|0;break j}f=fb-32|0;fb=f;e=zb(d);e=ms(f+12|0,ns(d,jh(x[d>>2],x[d+4>>2])+1|0),jh(x[d>>2],x[d+4>>2]),e);$T(x[e+8>>2],x[h>>2],x[h+4>>2]);x[e+8>>2]=x[e+8>>2]+8;NB(d,e);ls(e);fb=f+32|0}}Kb(j,x[Hd(x[a>>2],b)>>2],c);If(j,1);f=0}fb=j+16|0;return f|0}function Rla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0;f=fb-48|0;fb=f;y=x[a+16>>2];z=Fg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);b=0;r=x[a+128>>2];if(r){k=x[a+8>>2];g=x[a+12>>2];s=Gg(k,g,r);t=hb;h=x[a+76>>2];hg(x[a>>2],x[a+4>>2],vf(k,g,d),hb);q=hb>>>0>h>>>0?d:0}else{q=0}j=a+112|0;while(1){if((b|0)!=2){g=b<<3;h=g+(f+20|0)|0;g=a+g|0;x[h+4>>2]=x[g+44>>2];x[h+8>>2]=x[g+48>>2];b=b+1|0;continue}break}o=x[a+40>>2];p=x[a+36>>2];b=x[a+4>>2];x[f+8>>2]=x[a>>2];x[f+12>>2]=b;A=x[a+8>>2];B=x[a+12>>2];while(1){if(d){d=d-1|0;g=x[f+12>>2];b=x[f+8>>2];x[f+40>>2]=b;x[f+44>>2]=0;q=q-1|0;h=q;s=h?s:0;t=h?t:0;k=(((g&2147483647)<<1|b>>>31)&-2)+y|0;g=r;a:{b:while(1){c:{if((g|0)<=0){Pb(j,x[a+120>>2],x[a+124>>2]);h=x[a+116>>2];if(!h){break a}b=x[f+40>>2];g=(((x[f+44>>2]&2147483647)<<1|b>>>31)&-2)+k|0;i=0;b=0;break c}b=x[f+40>>2];h=(((x[f+44>>2]&2147483647)<<1|b>>>31)&-2)+k|0;b=0;i=0;while(1)if((b|0)==2){be(j,i>>>3<<16>>16);ae(j,4);Pb(f+40|0,s,t);g=g-1|0;continue b}else{i=(v[b+h|0]<<8)+i|0;b=b+1|0;continue}}break}while(1){if((b|0)!=2){i=(v[b+g|0]<<8)+i|0;b=b+1|0;continue}break}be(j,i>>>3<<16>>16);ae(j,h);x[j>>2]=x[j>>2];x[j+4>>2]=0}b=Eg(j,z);x[f+4>>2]=b;x[f>>2]=b;C=x[a+72>>2];i=x[a+68>>2];E=i>>31;k=x[a+64>>2];F=k>>31;h=x[a+60>>2];G=h>>31;b=0;while(1){if((b|0)!=2){u=(b<<2)+f|0;e=x[u>>2];g=(f+20|0)+(b<<3)|0;H=x[g+8>>2];l=x[g+4>>2];x[g+8>>2]=l;w=e<<8;e=w;e=Sua(e,e>>31,h,G);m=hb;n=e;e=Yb(l,-16777216,16776704);e=Sua(k,F,e,e>>31);l=n+e|0;n=hb+m|0;n=e>>>0>l>>>0?n+1|0:n;e=Yb(H,-16777216,16776704);m=Sua(i,E,e,e>>31);l=m+l|0;e=hb+n|0;e=l>>>0<m>>>0?e+1|0:e;m=l+8388608|0;e=m>>>0<8388608?e+1|0:e;e=Rc(m,e,24);x[g+4>>2]=e-(C&w);x[u>>2]=(e|0)/256;b=b+1|0;continue}break}b=x[a+32>>2];p=x[a+28>>2]+p|0;x[c>>2]=x[c>>2]+D(x[f>>2],p>>12);o=b+o|0;x[c+4>>2]=x[c+4>>2]+D(x[f+4>>2],o>>12);Pb(f+8|0,A,B);c=c+8|0;continue}break}b=x[f+12>>2];x[a>>2]=x[f+8>>2];x[a+4>>2]=b;x[a+40>>2]=o;x[a+20>>2]=p>>12;x[a+36>>2]=p;x[a+24>>2]=o>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+20|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}fb=f+48|0}function Zda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a=Fb(a);x[31737]=0;X(85);c=x[31737];x[31737]=0;a:{b:{if((c|0)==1){c=Ua(48540,125048,125632,0)|0;d=gb;c:{d:{e:{if(($(48540)|0)==(d|0)){c=Y(c|0)|0;x[31737]=0;b=P(991,a|0,b|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break e}x[31737]=0;b=P(991,b|0,18418)|0;d=x[31737];x[31737]=0;if((d|0)==1){break e}x[31737]=0;d=P(991,b|0,18394)|0;b=x[31737];x[31737]=0;if((b|0)==1){break e}b=ib[x[x[c>>2]+8>>2]](c)|0;x[31737]=0;P(991,d|0,(b?b:22303)|0)|0;b=x[31737];x[31737]=0;if((b|0)==1){break e}x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)!=1){break b}b=N()|0;break a}f:{if(($(125048)|0)==(d|0)){c=Y(c|0)|0;x[31737]=0;b=P(991,a|0,b|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break f}x[31737]=0;b=P(991,b|0,18418)|0;d=x[31737];x[31737]=0;if((d|0)==1){break f}x[31737]=0;d=P(991,b|0,18369)|0;b=x[31737];x[31737]=0;if((b|0)==1){break f}b=ib[x[x[c>>2]+8>>2]](c)|0;x[31737]=0;P(991,d|0,(b?b:22303)|0)|0;b=x[31737];x[31737]=0;if((b|0)==1){break f}x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)!=1){break b}b=N()|0;break a}e=$(125632)|0;c=Y(c|0)|0;g:{if((d|0)==(e|0)){x[31737]=0;b=P(991,a|0,b|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break g}x[31737]=0;b=P(991,b|0,18418)|0;d=x[31737];x[31737]=0;if((d|0)==1){break g}x[31737]=0;d=P(991,b|0,18385)|0;b=x[31737];x[31737]=0;if((b|0)==1){break g}b=ib[x[x[c>>2]+8>>2]](c)|0;x[31737]=0;P(991,d|0,(b?b:22303)|0)|0;b=x[31737];x[31737]=0;if((b|0)==1){break g}x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)!=1){break b}b=N()|0;break a}x[31737]=0;b=P(991,a|0,b|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break d}x[31737]=0;b=P(991,b|0,18418)|0;c=x[31737];x[31737]=0;if((c|0)==1){break d}x[31737]=0;P(991,b|0,13836)|0;b=x[31737];x[31737]=0;if((b|0)==1){break d}x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)!=1){break b}b=N()|0;break a}b=N()|0;x[31737]=0;X(26);c=x[31737];x[31737]=0;if((c|0)!=1){break a}break c}b=N()|0;x[31737]=0;X(26);c=x[31737];x[31737]=0;if((c|0)!=1){break a}break c}b=N()|0;x[31737]=0;X(26);c=x[31737];x[31737]=0;if((c|0)==1){break c}break a}b=N()|0;x[31737]=0;X(26);c=x[31737];x[31737]=0;if((c|0)!=1){break a}}T(0)|0;Sb()}p()}return}tb(a);Q(b|0);p()}function a1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=fb-48|0;fb=f;l=f+29|0;m=f+27|0;n=bh(f+42|0);while(1){a:{if(A[a+12>>2]>j>>>0){bf(f+32|0,x[a>>2],x[x[a+48>>2]+12>>2],j);b:while(1){if(!Mb(x[c>>2],x[c+8>>2],1)){break a}e=Zd(c);if((e|0)==255){break a}g=n;k=e<<24>>24;e=k&31;if(e>>>0<z[x[x[a+48>>2]+12>>2]+480188>>1]){g=Wc(x[f+32>>2],e)}d=1;if(!(k&64)){e=Zd(c);i=e<<24>>24;d=255;e=e&127;c:{d:{if((e|0)==1){break d}d=e-1|0;if(b?d>>>0<=120:0){break d}if((e-109&255)>>>0<159|b){break c}d=e+13|0}v[g|0]=d}q=g,r=Zd(c),v[q+1|0]=r;d=(i|0)<0}i=g+3|0;e=g+5|0;while(1){e:{f:{g:{if(d&1){w[f+28>>1]=y[g+4|0]|y[g+5|0]<<8;x[f+24>>2]=y[g|0]|y[g+1|0]<<8|(y[g+2|0]<<16|y[g+3|0]<<24);d=Zd(c);h=d&63;o=d<<24>>24;if(d&64){v[g+4|0]=h;v[g+2|0]=1;break e}d=Zd(c);v[e|0]=d;if(h>>>0<=15){Bf(g,h,d);h:{i:{j:{d=y[g+3|0];switch(d-9|0){case 1:case 2:case 3:break f;case 4:break i;case 0:break j;default:break h}}v[i|0]=9;v[e|0]=D(y[e|0]&15,17);break f}v[g+2|0]=1;v[g+3|0]=0;x[f+20>>2]=y[g+5|0]+1>>>1;x[f+16>>2]=64;q=g,r=x[ud(f+20|0,f+16|0)>>2],v[q+4|0]=r;break f}if((d|0)!=19){break f}if(y[e|0]==128){break g}sw(g);break f}if(h>>>0>44){break f}v[i|0]=y[h+24640|0];k:{switch(h-16|0){case 0:if(d>>>0>1){break g}v[e|0]=d|158;break f;case 1:case 2:v[f+20|0]=15;q=e,r=y[Qb(f+20|0,e)|0]|224,v[q|0]=r;break f;case 5:case 6:x[f+20>>2]=16;x[f+16>>2]=d+1;q=e,r=x[ud(f+20|0,f+16|0)>>2]/2|240,v[q|0]=r;break f;case 14:l:{m:{n:{o:{p:{h=d>>>4|0;switch(h-1|0){case 1:break n;case 0:break o;default:break p}}switch(h-10|0){case 1:break l;case 0:break m;default:break g}}v[i|0]=2;v[e|0]=d|240;break f}v[i|0]=3;v[e|0]=d|240;break f}v[i|0]=11;v[e|0]=(d<<3&120)+8|15;break f}v[i|0]=11;v[e|0]=(d&15)+1>>>1|240;break f;case 12:break k;default:break f}}x[f+20>>2]=d+1>>>1;x[f+16>>2]=64;q=e,r=x[ud(f+20|0,f+16|0)>>2],v[q|0]=r;break f}if((k|0)>=0){continue b}break a}v[i|0]=0}GE(i,e,m,l);d=y[f+27|0];p=xi(d);h=y[i|0];if(p>>>0<=xi(h)>>>0){break e}if(!y[g+2|0]){rw(f+14|0,h,y[g+5|0],1);h=y[f+14|0];v[g+4|0]=y[f+15|0];v[g+2|0]=h}v[i|0]=d;v[e|0]=y[f+29|0]}d=(o|0)<0;continue}}}fb=f+48|0;return}j=j+1|0;continue}}function tga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=E(0),f=0,g=0,h=E(0),i=0,j=0,k=0,l=E(0),m=0,n=0,o=0,p=0,q=0,r=E(0),s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,C=0,D=0,F=E(0),G=E(0),H=E(0),I=0,J=0,K=0,L=0,M=E(0),N=E(0),O=E(0),P=E(0),Q=E(0),R=E(0),S=0,T=0,U=E(0);if(zi(a+44|0)){f=x[a+44>>2];y=Hc(f,0);z=Hc(f,1);f=x[a+56>>2];A=Hc(f,0);C=Hc(f,1);n=x[a+4300>>2];s=x[a+4296>>2];m=s+1|0;k=a+4304|0;f=a+4272|0;t=m+x[yb(f,0)>>2]&4095;o=k+(t<<4)|0;u=m+x[yb(f,1)>>2]&4095;j=((u<<4)+k|0)+4|0;v=m+x[yb(f,2)>>2]&4095;p=((v<<4)+k|0)+8|0;i=x[yb(f,3)>>2];g=x[yb(f,4)>>2]+n|0;w=i+m&4095;D=((w<<4)+k|0)+12|0;q=x[yb(f,5)>>2]+n|0;i=a+4232|0;I=a+69840|0;J=a+78032|0;m=d;while(1){if(m){u=u-1&4095;f=((u<<4)+k|0)+4|0;e=B[f>>2];K=g&1023;g=(K<<3)+I|0;r=B[g>>2];M=B[D>>2];N=B[p>>2];O=B[j>>2];P=B[o>>2];Q=B[z>>2];R=B[y>>2];F=B[yb(i,0)>>2];G=B[g+4>>2];j=yb(i,0);t=t-1&4095;o=(t<<4)+k|0;h=B[o>>2];H=B[j>>2];g=n<<3;j=g+I|0;l=e;e=E(E(e*E(.6180340051651001))+E(r*F));B[j+4>>2]=l+E(e*E(-.6180340051651001));l=h;h=E(E(G*H)+E(h*E(-.6180340051651001)));B[j>>2]=l+E(h*E(.6180340051651001));B[o>>2]=e;B[f>>2]=h;w=w-1&4095;j=(w<<4)+k|0;D=j+12|0;e=B[D>>2];L=q&1023;p=(L<<3)+J|0;r=B[p>>2];F=B[yb(i,1)>>2];G=B[p+4>>2];S=yb(i,1);v=v-1&4095;q=(v<<4)+k|0;p=q+8|0;h=B[p>>2];H=B[S>>2];g=g+J|0;l=e;e=E(E(e*E(.6180340051651001))+E(r*F));B[g+4>>2]=l+E(e*E(-.6180340051651001));l=h;h=E(E(G*H)+E(h*E(-.6180340051651001)));B[g>>2]=l+E(h*E(.6180340051651001));B[q+8>>2]=e;B[j+12>>2]=h;h=e;e=E(R+E(1.0000000031710769e-30));B[A>>2]=h+E(E(e*B[a+4224>>2])+B[o>>2]);h=E(Q+E(1.0000000031710769e-30));B[C>>2]=E(E(h*B[a+4224>>2])+B[f>>2])+B[j+12>>2];g=(s<<4)+k|0;l=e;e=B[a+4228>>2];r=E(l*e);T=g,U=E(r+E(E(B[o>>2]*B[yb(i,2)>>2])+E(P*B[yb(i,3)>>2]))),B[T>>2]=U;e=E(h*e);T=g,U=E(e+E(E(B[f>>2]*B[yb(i,4)>>2])+E(O*B[yb(i,5)>>2]))),B[T+4>>2]=U;T=g,U=E(E(E(B[q+8>>2]*B[yb(i,6)>>2])+E(N*B[yb(i,7)>>2]))-e),B[T+8>>2]=U;T=g,U=E(r+E(E(B[j+12>>2]*B[yb(i,8)>>2])+E(M*B[yb(i,9)>>2]))),B[T+12>>2]=U;m=m-1|0;C=C+4|0;A=A+4|0;z=z+4|0;y=y+4|0;q=L-1|0;g=K-1|0;n=n-1&1023;s=s-1&4095;j=f;continue}else{x[a+4300>>2]=n;x[a+4296>>2]=s;f=a;a=x[a+56>>2];Pi(f,b,c,Hc(a,0),Hc(a,1),d)}break}}}function Sz(a){a=a|0;var b=0,c=0,d=E(0),e=0;Rb(a+4960|0,0,76);v[a+5044|0]=0;x[a+5036>>2]=0;x[a+5040>>2]=0;b=x[a+4292>>2];d=B[a+4268>>2];x[31737]=0;e=a+4504|0;if(d<E(4294967296)&d>=E(0)){c=~~d>>>0}else{c=0}aa(979,e|0,67,5,c|0,b|0);b=x[31737];x[31737]=0;a:{if((b|0)==1){break a}b=x[a+4296>>2];x[31737]=0;aa(979,a+4528|0,62,5,c|0,b|0);b=x[31737];x[31737]=0;if((b|0)==1){break a}b=x[a+4300>>2];x[31737]=0;aa(979,a+4552|0,53,5,c|0,b|0);b=x[31737];x[31737]=0;if((b|0)==1){break a}b=x[a+4304>>2];x[31737]=0;aa(979,a+4576|0,43,5,c|0,b|0);b=x[31737];x[31737]=0;if((b|0)==1){break a}b=x[a+4308>>2];x[31737]=0;aa(979,a+4600|0,32,5,c|0,b|0);b=x[31737];x[31737]=0;if((b|0)==1){break a}b=x[a+4312>>2];x[31737]=0;aa(979,a+4624|0,22,5,c|0,b|0);b=x[31737];x[31737]=0;if((b|0)==1){break a}b=x[a+4316>>2];x[31737]=0;aa(979,a+4648|0,75,5,c|0,b|0);b=x[31737];x[31737]=0;if((b|0)==1){break a}b=x[a+4320>>2];x[31737]=0;aa(979,a+4672|0,69,5,c|0,b|0);b=x[31737];x[31737]=0;if((b|0)==1){break a}b=x[a+4324>>2];x[31737]=0;aa(979,a+4696|0,60,5,c|0,b|0);b=x[31737];x[31737]=0;if((b|0)==1){break a}b=x[a+4328>>2];x[31737]=0;aa(979,a+4720|0,48,5,c|0,b|0);b=x[31737];x[31737]=0;if((b|0)==1){break a}b=x[a+4332>>2];x[31737]=0;aa(979,a+4744|0,36,5,c|0,b|0);b=x[31737];x[31737]=0;if((b|0)==1){break a}b=x[a+4336>>2];x[31737]=0;aa(979,a+4768|0,25,5,c|0,b|0);b=x[31737];x[31737]=0;if((b|0)==1){break a}x[31737]=0;aa(979,a+4792|0,0,0,0,0);b=x[31737];x[31737]=0;if((b|0)==1){break a}b=x[a+4344>>2];x[31737]=0;aa(979,a+4816|0,3,0,c|0,b|0);b=x[31737];x[31737]=0;if((b|0)==1){break a}b=x[a+4348>>2];x[31737]=0;aa(979,a+4840|0,3,0,c|0,b|0);b=x[31737];x[31737]=0;if((b|0)==1){break a}x[31737]=0;aa(979,a+4864|0,407,1,c|0,0);b=x[31737];x[31737]=0;if((b|0)==1){break a}x[31737]=0;aa(979,a+4888|0,400,1,c|0,0);b=x[31737];x[31737]=0;if((b|0)==1){break a}x[31737]=0;aa(979,a+4912|0,10,0,c|0,-1);b=x[31737];x[31737]=0;if((b|0)==1){break a}x[31737]=0;aa(979,a+4936|0,10,0,c|0,-1);c=x[31737];x[31737]=0;if((c|0)==1){break a}v[a+5045|0]=1;return}c=T(125048)|0;if((gb|0)==($(125048)|0)){Y(c|0)|0;v[a+5045|0]=0;Z();return}Q(c|0);p()}function Jha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=E(0),g=E(0),h=E(0),i=0,j=0,k=E(0),l=0,m=0,n=E(0),o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=E(0),w=0,z=0,A=0,C=0,D=0,G=0,H=E(0),I=0,J=0,K=0,L=0,M=0,N=E(0),O=0,P=E(0);a:{if(!x[a+4316>>2]){break a}if(!zi(a+44|0)){break a}D=a+4300|0;G=a+4288|0;I=a+4264|0;J=a+4276|0;e=x[a+44>>2];r=Hc(e,0);s=Hc(e,1);e=x[a+56>>2];t=Hc(e,0);u=Hc(e,1);K=ib[x[x[a>>2]+196>>2]](a)|0;v=E(E(ib[x[x[a>>2]+204>>2]](a))/E(100));H=E(ib[x[x[a>>2]+192>>2]](a));w=ib[x[x[a>>2]+216>>2]](a)|0;L=w&1;o=x[a+4324>>2];l=x[a+4320>>2];m=x[a+4328>>2];j=x[a+4312>>2];M=x[a+4276>>2];p=x[a+4264>>2];z=x[a+4256>>2];A=y[a+4260|0];C=d;while(1){if(C){h=B[s>>2];k=B[r>>2];i=x[a+4316>>2];e=Bo(i,j+z|0);i=Bo(i,j);b:{if(A){O=yb(G,m),P=k,B[O>>2]=P;O=yb(D,m),P=h,B[O>>2]=P;q=yb(p,e);O=yb(p,i),P=E(E(B[q>>2]*v)+k),B[O>>2]=P;g=E(E(B[yb(M,e)>>2]*v)+h);e=J;break b}g=E(E(B[yb(p,e)>>2]*v)+E(E(k+h)*E(.5)));e=I}O=yb(x[e>>2],i),P=g,B[O>>2]=P;c:{if(K){f=B[a+4244>>2];g=E(f+B[a+4236>>2]);B[a+4236>>2]=g;f=E(f+B[a+4240>>2]);B[a+4240>>2]=f;if(g>E(1)){g=E(g+E(-2));B[a+4236>>2]=g}if(f>E(1)){f=E(f+E(-2));B[a+4240>>2]=f}g=E(F(g));g=E(E(g+g)+E(-1));f=E(F(f));f=E(E(f+f)+E(-1));break c}f=B[a+4240>>2];n=B[a+4244>>2];g=E(E(f*n)+B[a+4236>>2]);B[a+4236>>2]=g;f=E(f-E(g*n));B[a+4240>>2]=f}if(A){e=(m+2|0)%3|0;k=B[yb(G,e)>>2];h=B[yb(D,e)>>2]}e=x[a+4316>>2];i=yb(p,Bo(e,j+l|0));q=e;e=j+4096|0;N=B[yb(p,Bo(q,e+l|0))>>2];n=B[i>>2];B[t>>2]=E(E(E(E(E(N-n)*E(E(l&4095)*E(.000244140625)))+n)-k)*H)+k;l=x[(A?4276:4264)+a>>2];i=x[a+4316>>2];q=yb(l,Bo(i,j+o|0));n=B[yb(l,Bo(i,e+o|0))>>2];k=B[q>>2];B[u>>2]=E(E(E(E(E(n-k)*E(E(o&4095)*E(.000244140625)))+k)-h)*H)+h;m=((m|0)<=0?m+3|0:m)-1|0;x[a+4328>>2]=m;j=(((j|0)<=0?x[a+4316>>2]<<12:0)+j|0)-4096|0;x[a+4312>>2]=j;h=L?f:g;f=B[a+4248>>2];h=E(h*f);d:{if(E(F(h))<E(2147483648)){e=~~h;break d}e=-2147483648}o=(w>>>0>1?e:0-e|0)+z|0;x[a+4324>>2]=o;s=s+4|0;r=r+4|0;g=E(g*f);e:{if(E(F(g))<E(2147483648)){e=~~g;break e}e=-2147483648}l=(w>>>0<4?e:0-e|0)+z|0;x[a+4320>>2]=l;C=C-1|0;u=u+4|0;t=t+4|0;continue}else{e=a;a=x[a+56>>2];Pi(e,b,c,Hc(a,0),Hc(a,1),d)}break}}}function Qla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0;f=fb-48|0;fb=f;y=x[a+16>>2];z=Fg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);b=0;q=x[a+128>>2];if(q){j=x[a+8>>2];g=x[a+12>>2];r=Gg(j,g,q);s=hb;h=x[a+76>>2];hg(x[a>>2],x[a+4>>2],vf(j,g,d),hb);p=hb>>>0>h>>>0?d:0}else{p=0}i=a+112|0;while(1){if((b|0)!=2){g=b<<3;h=g+(f+20|0)|0;g=a+g|0;x[h+4>>2]=x[g+44>>2];x[h+8>>2]=x[g+48>>2];b=b+1|0;continue}break}n=x[a+40>>2];o=x[a+36>>2];b=x[a+4>>2];x[f+8>>2]=x[a>>2];x[f+12>>2]=b;A=x[a+8>>2];B=x[a+12>>2];a:while(1){if(d){d=d-1|0;g=x[f+12>>2];b=x[f+8>>2];x[f+40>>2]=b;x[f+44>>2]=0;p=p-1|0;h=p;r=h?r:0;s=h?s:0;j=((((g&2147483647)<<1|b>>>31)&2147483646)<<1)+y|0;b=q;while(1)if((b|0)<=0){Pb(i,x[a+120>>2],x[a+124>>2]);h=x[a+116>>2];if(h){b=x[f+40>>2];b=((((x[f+44>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+j|0;be(i,(w[b>>1]+w[b+2>>1]|0)/8<<16>>16);ae(i,h);x[i>>2]=x[i>>2];x[i+4>>2]=0}b=Eg(i,z);x[f+4>>2]=b;x[f>>2]=b;C=x[a+72>>2];t=x[a+68>>2];E=t>>31;j=x[a+64>>2];F=j>>31;h=x[a+60>>2];G=h>>31;b=0;while(1){if((b|0)!=2){u=(b<<2)+f|0;e=x[u>>2];g=(f+20|0)+(b<<3)|0;H=x[g+8>>2];k=x[g+4>>2];x[g+8>>2]=k;v=e<<8;e=v;e=Sua(e,e>>31,h,G);l=hb;m=e;e=Yb(k,-16777216,16776704);e=Sua(j,F,e,e>>31);k=m+e|0;m=hb+l|0;m=e>>>0>k>>>0?m+1|0:m;e=Yb(H,-16777216,16776704);l=Sua(t,E,e,e>>31);k=l+k|0;e=hb+m|0;e=k>>>0<l>>>0?e+1|0:e;l=k+8388608|0;e=l>>>0<8388608?e+1|0:e;e=Rc(l,e,24);x[g+4>>2]=e-(C&v);x[u>>2]=(e|0)/256;b=b+1|0;continue}break}b=x[a+32>>2];o=x[a+28>>2]+o|0;x[c>>2]=x[c>>2]+D(x[f>>2],o>>12);n=b+n|0;x[c+4>>2]=x[c+4>>2]+D(x[f+4>>2],n>>12);Pb(f+8|0,A,B);c=c+8|0;continue a}else{g=x[f+40>>2];g=((((x[f+44>>2]&2147483647)<<1|g>>>31)&2147483646)<<1)+j|0;be(i,(w[g>>1]+w[g+2>>1]|0)/8<<16>>16);ae(i,4);Pb(f+40|0,r,s);b=b-1|0;continue}}break}b=x[f+12>>2];x[a>>2]=x[f+8>>2];x[a+4>>2]=b;x[a+40>>2]=n;x[a+20>>2]=o>>12;x[a+36>>2]=o;x[a+24>>2]=n>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+20|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}fb=f+48|0}function uma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0;f=fb-48|0;fb=f;g=x[a+8>>2];r=g;h=x[a+12>>2];m=h;a:{b:{c:{d:{if((h|0)<=1&g>>>0<=805306368|(h|0)<=0){g=h;if((g|0)>-2){e=1}else{e=(g|0)>=-2&r>>>0>=3489660928}if(e){break c}if((m|0)==-2&r>>>0>2147483647|(m|0)==-1){break d}break b}if((m|0)==1&r>>>0>2147483648|m>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}y=b;z=x[a+16>>2];b=0;while(1){if((b|0)!=2){g=b<<3;h=g+(f+28|0)|0;g=a+g|0;x[h+4>>2]=x[g+44>>2];x[h+8>>2]=x[g+48>>2];b=b+1|0;continue}break}n=x[a+40>>2];o=x[a+36>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;A=x[a+32>>2];B=x[a+28>>2];C=x[a+72>>2];v=x[a+68>>2];E=v>>31;h=x[a+64>>2];F=h>>31;g=x[a+60>>2];G=g>>31;while(1){if(d){b=x[f+16>>2];H=((((x[f+20>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+z|0;b=(b>>>16&65520)+y|0;l=w[b+14>>1];s=w[b+12>>1];u=w[b+10>>1];i=w[b+8>>1];t=w[b+6>>1];k=w[b+4>>1];e=w[b+2>>1];b=w[b>>1];p=0;q=0;while(1){if((q|0)!=2){j=H+(q<<1)|0;x[(f+8|0)+(q<<2)>>2]=(((((((D(w[j-8>>1],e)+D(w[j-12>>1],b)|0)+D(w[j-4>>1],k)|0)+D(w[j>>1],t)|0)+D(w[j+4>>1],i)|0)+D(w[j+8>>1],u)|0)+D(s,w[j+12>>1])|0)+D(l,w[j+16>>1])|0)/32768;q=q+1|0;continue}break}while(1){if((p|0)!=2){s=(f+8|0)+(p<<2)|0;e=x[s>>2];b=(f+28|0)+(p<<3)|0;u=x[b+8>>2];i=x[b+4>>2];x[b+8>>2]=i;t=e<<8;e=t;e=Sua(e,e>>31,g,G);k=hb;j=e;e=Yb(i,-16777216,16776704);e=Sua(h,F,e,e>>31);i=j+e|0;l=hb+k|0;l=e>>>0>i>>>0?l+1|0:l;e=Yb(u,-16777216,16776704);k=Sua(v,E,e,e>>31);i=k+i|0;e=hb+l|0;e=i>>>0<k>>>0?e+1|0:e;k=i+8388608|0;e=k>>>0<8388608?e+1|0:e;e=Rc(k,e,24);x[b+4>>2]=e-(t&C);x[s>>2]=(e|0)/256;p=p+1|0;continue}break}o=o+B|0;x[c>>2]=x[c>>2]+D(x[f+8>>2],o>>12);n=n+A|0;x[c+4>>2]=x[c+4>>2]+D(x[f+12>>2],n>>12);Pb(f+16|0,r,m);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;x[a+40>>2]=n;x[a+20>>2]=o>>12;x[a+36>>2]=o;x[a+24>>2]=n>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+28|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}fb=f+48|0}function pR(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;j=fb-128|0;fb=j;a:{b:{c:{if(!kn(f,g,h,i,0,0,0,0)){break c}k=i&65535;n=i>>>16&32767;d:{e:{if((n|0)!=32767){l=4;if(n){break e}l=f|h|(g|k)?3:2;break d}l=!(f|h|(g|k))}}s=e>>>16|0;o=s&32767;if((o|0)==32767){break c}if(l){break b}}Wd(j+16|0,b,c,d,e,f,g,h,i);b=x[j+16>>2];d=x[j+20>>2];e=x[j+24>>2];c=x[j+28>>2];VR(j,b,d,e,c,b,d,e,c);d=x[j+8>>2];e=x[j+12>>2];h=x[j>>2];i=x[j+4>>2];break a}l=d;p=e&2147483647;k=p;n=h;m=i&2147483647;if((kn(b,c,l,k,f,g,h,m)|0)<=0){if(kn(b,c,l,k,f,g,h,m)){h=b;i=c;break a}Wd(j+112|0,b,c,d,e,0,0,0,0);d=x[j+120>>2];e=x[j+124>>2];h=x[j+112>>2];i=x[j+116>>2];break a}q=i>>>16&32767;if(o){i=c;h=b}else{Wd(j+96|0,b,c,l,p,0,0,0,1081540608);l=x[j+104>>2];h=x[j+108>>2];p=h;o=(h>>>16|0)-120|0;i=x[j+100>>2];h=x[j+96>>2]}if(!q){Wd(j+80|0,f,g,n,m,0,0,0,1081540608);n=x[j+88>>2];f=x[j+92>>2];m=f;q=(f>>>16|0)-120|0;g=x[j+84>>2];f=x[j+80>>2]}r=n;t=m&65535|65536;p=p&65535|65536;if((o|0)>(q|0)){while(1){m=l-r|0;k=(g|0)==(i|0)&f>>>0>h>>>0|g>>>0>i>>>0;n=m-k|0;k=(p-((l>>>0<r>>>0)+t|0)|0)-(k>>>0>m>>>0)|0;f:{if((k|0)>=0|(k|0)>0){l=h;h=h-f|0;i=i-((f>>>0>l>>>0)+g|0)|0;if(!(h|n|(i|k))){Wd(j+32|0,b,c,d,e,0,0,0,0);d=x[j+40>>2];e=x[j+44>>2];h=x[j+32>>2];i=x[j+36>>2];break a}k=k<<1|n>>>31;l=n<<1|i>>>31;break f}k=p<<1|l>>>31;l=l<<1|i>>>31}p=k;k=i<<1|h>>>31;h=h<<1;i=k;o=o-1|0;if((o|0)>(q|0)){continue}break}o=q}m=l-r|0;k=(g|0)==(i|0)&f>>>0>h>>>0|g>>>0>i>>>0;n=m-k|0;k=(p-((l>>>0<r>>>0)+t|0)|0)-(k>>>0>m>>>0)|0;m=k;g:{if((k|0)<0){n=l;m=p;break g}l=h;h=h-f|0;i=i-((f>>>0>l>>>0)+g|0)|0;if(h|n|(i|m)){break g}Wd(j+48|0,b,c,d,e,0,0,0,0);d=x[j+56>>2];e=x[j+60>>2];h=x[j+48>>2];i=x[j+52>>2];break a}if((m|0)==65535|m>>>0<65535){while(1){b=i>>>31|0;o=o-1|0;p=i<<1|h>>>31;h=h<<1;i=p;c=b;b=m<<1|n>>>31;n=c|n<<1;m=b;if(b>>>0<65536){continue}break}}b=s&32768;if((o|0)<=0){Wd(j- -64|0,h,i,n,m&65535|(b|o+120)<<16,0,0,0,1065811968);d=x[j+72>>2];e=x[j+76>>2];h=x[j+64>>2];i=x[j+68>>2];break a}d=n;e=m&65535|(b|o)<<16}x[a>>2]=h;x[a+4>>2]=i;x[a+8>>2]=d;x[a+12>>2]=e;fb=j+128|0}function Vla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0;f=fb-48|0;fb=f;u=x[a+16>>2];w=Fg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);b=0;p=x[a+128>>2];if(p){k=x[a+8>>2];g=x[a+12>>2];q=Gg(k,g,p);r=hb;h=x[a+76>>2];hg(x[a>>2],x[a+4>>2],vf(k,g,d),hb);o=hb>>>0>h>>>0?d:0}else{o=0}j=a+112|0;while(1){if((b|0)!=2){g=b<<3;h=g+(f+20|0)|0;g=a+g|0;x[h+4>>2]=x[g+44>>2];x[h+8>>2]=x[g+48>>2];b=b+1|0;continue}break}y=x[a+24>>2];z=x[a+20>>2];b=x[a+4>>2];x[f+8>>2]=x[a>>2];x[f+12>>2]=b;A=x[a+8>>2];B=x[a+12>>2];while(1){if(d){d=d-1|0;g=x[f+12>>2];b=x[f+8>>2];x[f+40>>2]=b;x[f+44>>2]=0;o=o-1|0;h=o;q=h?q:0;r=h?r:0;k=(((g&2147483647)<<1|b>>>31)&-2)+u|0;g=p;a:{b:while(1){c:{if((g|0)<=0){Pb(j,x[a+120>>2],x[a+124>>2]);h=x[a+116>>2];if(!h){break a}b=x[f+40>>2];g=(((x[f+44>>2]&2147483647)<<1|b>>>31)&-2)+k|0;i=0;b=0;break c}b=x[f+40>>2];h=(((x[f+44>>2]&2147483647)<<1|b>>>31)&-2)+k|0;b=0;i=0;while(1)if((b|0)==2){be(j,i>>>3<<16>>16);ae(j,4);Pb(f+40|0,q,r);g=g-1|0;continue b}else{i=(v[b+h|0]<<8)+i|0;b=b+1|0;continue}}break}while(1){if((b|0)!=2){i=(v[b+g|0]<<8)+i|0;b=b+1|0;continue}break}be(j,i>>>3<<16>>16);ae(j,h);x[j>>2]=x[j>>2];x[j+4>>2]=0}b=Eg(j,w);x[f+4>>2]=b;x[f>>2]=b;C=x[a+72>>2];i=x[a+68>>2];E=i>>31;k=x[a+64>>2];F=k>>31;h=x[a+60>>2];G=h>>31;b=0;while(1){if((b|0)!=2){s=(b<<2)+f|0;e=x[s>>2];g=(f+20|0)+(b<<3)|0;H=x[g+8>>2];l=x[g+4>>2];x[g+8>>2]=l;t=e<<8;e=t;e=Sua(e,e>>31,h,G);m=hb;n=e;e=Yb(l,-16777216,16776704);e=Sua(k,F,e,e>>31);l=n+e|0;n=hb+m|0;n=e>>>0>l>>>0?n+1|0:n;e=Yb(H,-16777216,16776704);m=Sua(i,E,e,e>>31);l=m+l|0;e=hb+n|0;e=l>>>0<m>>>0?e+1|0:e;m=l+8388608|0;e=m>>>0<8388608?e+1|0:e;e=Rc(m,e,24);x[g+4>>2]=e-(C&t);x[s>>2]=(e|0)/256;b=b+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[f>>2],z);x[c+4>>2]=x[c+4>>2]+D(x[f+4>>2],y);Pb(f+8|0,A,B);c=c+8|0;continue}break}b=x[f+12>>2];x[a>>2]=x[f+8>>2];x[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+20|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}fb=f+48|0}function Tqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=fb-16|0;fb=f;a:{b:{if(!c){break b}n=f,o=Zd(a),v[n+8|0]=o;uo(b,f+8|0);j=c-1|0;while(1){e=1;if(!j){break a}c:{c=g<<1&254;d:{if(!c){if(!Af(a,f+8|0)){break b}d=y[f+8|0]<<1|1;c=d&255;if(d>>>0<256){break d}break c}if((g&65535)>>>0>127){break c}}d=f+8|0;if(!Af(a,d)){break b}f$(b,d);j=j-1|0;g=c;continue}e=1;while(1){e:{f:{g:{g=c<<1&254;if(g){c=(c&65535)>>>0>127}else{if(!Af(a,f+8|0)){break g}c=y[f+8|0]<<1|1;g=c&255;c=c>>>0>255}e=kr(e,1)+c|0;c=g<<1&254;if(c){break f}if(!Af(a,f+8|0)){break g}d=y[f+8|0]<<1|1;c=d&255;if(d>>>0>255){continue}break e}c=0;break e}if(g>>>0>127){continue}}break}h:{if((e|0)<=2){h=0;d=e-2|0;break h}if(!Af(a,f+8|0)){break b}d=kr(e-3|0,8)|y[f+8|0];h=((d|0)>1279?2:1)+((d|0)>31999)|0;l=d^-1;d=0}e=c<<1&254;if(e){c=c>>>0>127}else{if(!Af(a,f+8|0)){break b}c=y[f+8|0]<<1|1;e=c&255;c=c>>>0>255}i=kr(d,1);g=e<<1&254;if(g){d=e>>>0>127}else{if(!Af(a,f+8|0)){break b}d=y[f+8|0]<<1|1;g=d&255;d=d>>>0>255}e=1;c=kr(c+i|0,1)+d|0;if(!c){while(1){i:{j:{k:{c=g<<1&254;if(c){d=(g&65535)>>>0>127}else{if(!Af(a,f+8|0)){break k}d=y[f+8|0]<<1|1;c=d&255;d=d>>>0>255}e=kr(e,1)+d|0;g=c<<1&254;if(g){break j}if(!Af(a,f+8|0)){break k}c=y[f+8|0]<<1|1;g=c&255;if(c>>>0>255){continue}break i}g=0;break i}if(c>>>0>127){continue}}break}c=e+2|0}d=c+h|0;e=0;if(d>>>0>j>>>0|(d|0)<=0|(l|0)>=0){break a}c=x[b+4>>2];e=0;if((0-Vc(x[b>>2],c)|0)>(l|0)){break a}c=vb(f+12|0,wb(c));v[f+8|0]=0;i=f+8|0;m=fb-32|0;fb=m;e=x[c>>2];c=x[b>>2];h=Fk(e,wb(c))+c|0;c=x[zb(b)>>2];k=x[b+4>>2];l:{if(d>>>0<=c-k>>>0){c=d;e=k-h|0;if(c>>>0>e>>>0){Fp(b,c-e|0,i);c=e;if(!c){break l}}i$(b,h,k,d+h|0);Vh(h,c,i+(h>>>0<=i>>>0?i>>>0<A[b+4>>2]?d:0:0)|0);break l}c=zb(b);c=un(m+12|0,bm(b,Vc(x[b>>2],k)+d|0),h-x[b>>2]|0,c);sZ(c,d,i);h=h$(b,c,h);tn(c)}wb(h);fb=m+32|0;n=f,o=uf(YC(wb(x[b+4>>2]),d),l),x[n+8>>2]=o;n=f,o=YC(wb(x[b+4>>2]),d),x[n+4>>2]=o;c=d;while(1){e=y[yY(f+8|0)|0];n=yY(f+4|0),o=e,v[n|0]=o;e=c>>>0>1;c=c-1|0;if(e){continue}break}j=j-d|0;continue}}e=0}fb=f+16|0;return e|0}
function tP(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=fb-112|0;fb=d;f=x[b+4>>2];a:{if(!f){break a}e=x[b>>2];h=y[Gl(e,f)|0];if((h|0)==33){c=1}else{if((h|0)!=63){break a}c=0}Sl(d+88|0,e,f,f-1|0);f=x[d+92>>2];e=x[d+88>>2];x[b>>2]=e;x[b+4>>2]=f}e=d+88|0;ge(e);h=x[d+88>>2];ge(d+76|0);h=Fl(h,x[d+80>>2],b);ge(e);b:{c:{d:{e:{if((h|0)==x[d+92>>2]){a=x[b>>2];h=qc(d+104|0,22303);i=x[h+4>>2];x[d>>2]=x[h>>2];x[d+4>>2]=i;if(Ic(a,f,d)){a=ac(8);x[31737]=0;c=P(36,e|0,10498)|0;b=x[31737];x[31737]=0;if((b|0)==1){break d}pc(a,c);x[31737]=0;S(98,a|0,48540,1006);a=x[31737];x[31737]=0;if((a|0)!=1){break b}b=N()|0;tb(c);break c}g=0;if(!c){break e}c=ac(8);a=x[b+4>>2];b=x[b>>2];x[31737]=0;f=fi(d+76|0,b,a);a=x[31737];x[31737]=0;f:{g:{h:{if((a|0)!=1){x[31737]=0;e=d+88|0;S(1017,e|0,18318,f|0);a=x[31737];x[31737]=0;if((a|0)==1){break h}pc(c,e);a=0;x[31737]=0;S(98,c|0,48540,1006);b=x[31737];x[31737]=0;if((b|0)!=1){break b}b=N()|0;tb(e);break g}b=N()|0;break f}b=N()|0;a=1}tb(f);if(!a){break c}}jc(c);break c}if(x[h+4>>2]!=2){a=ac(8);x[31737]=0;c=P(36,d+88|0,11600)|0;b=x[31737];x[31737]=0;if((b|0)!=1){pc(a,c);x[31737]=0;S(98,a|0,48540,1006);a=x[31737];x[31737]=0;if((a|0)!=1){break b}b=N()|0;tb(c);break c}b=N()|0;jc(a);break c}b=x[b>>2];c=qc(d+68|0,22303);e=x[c+4>>2];x[d+32>>2]=x[c>>2];x[d+36>>2]=e;if(Ic(b,f,d+32|0)){a=ac(8);x[31737]=0;c=P(36,d+88|0,10498)|0;b=x[31737];x[31737]=0;if((b|0)!=1){pc(a,c);x[31737]=0;S(98,a|0,48540,1006);a=x[31737];x[31737]=0;if((a|0)!=1){break b}b=N()|0;tb(c);break c}b=N()|0;jc(a);break c}c=qc(d+60|0,7759);e=x[c+4>>2];x[d+24>>2]=x[c>>2];x[d+28>>2]=e;if(Ic(b,f,d+24|0)){g=1;if(!Gd(y[a+28|0])){break e}g=65536/+A[x[a+24>>2]+480244>>2];break e}c=qc(d+52|0,7811);e=x[c+4>>2];x[d+16>>2]=x[c>>2];x[d+20>>2]=e;if(Ic(b,f,d+16|0)){g=1;if(!Gd(y[a+28|0])){break e}g=+A[x[a+24>>2]+480240>>2]*152587890625e-16;break e}c=qc(d+44|0,7829);e=x[c+4>>2];x[d+8>>2]=x[c>>2];x[d+12>>2]=e;g=0;if(!Ic(b,f,d+8|0)){break e}g=+A[x[a+24>>2]+480236>>2]*152587890625e-16}fb=d+112|0;return+g}b=N()|0;jc(a)}Q(b|0)}p()}function vma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0;f=fb-48|0;fb=f;g=x[a+8>>2];r=g;h=x[a+12>>2];m=h;a:{b:{c:{d:{if((h|0)<=1&g>>>0<=805306368|(h|0)<=0){g=h;if((g|0)>-2){e=1}else{e=(g|0)>=-2&r>>>0>=3489660928}if(e){break c}if((m|0)==-2&r>>>0>2147483647|(m|0)==-1){break d}break b}if((m|0)==1&r>>>0>2147483648|m>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}z=b;A=x[a+16>>2];b=0;while(1){if((b|0)!=2){g=b<<3;h=g+(f+28|0)|0;g=a+g|0;x[h+4>>2]=x[g+44>>2];x[h+8>>2]=x[g+48>>2];b=b+1|0;continue}break}n=x[a+40>>2];o=x[a+36>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;B=x[a+32>>2];C=x[a+28>>2];E=x[a+72>>2];y=x[a+68>>2];F=y>>31;h=x[a+64>>2];G=h>>31;g=x[a+60>>2];H=g>>31;while(1){if(d){b=x[f+16>>2];I=(((x[f+20>>2]&2147483647)<<1|b>>>31)&-2)+A|0;b=(b>>>16&65520)+z|0;l=w[b+14>>1];s=w[b+12>>1];u=w[b+10>>1];i=w[b+8>>1];t=w[b+6>>1];k=w[b+4>>1];e=w[b+2>>1];b=w[b>>1];p=0;q=0;while(1){if((q|0)!=2){j=q+I|0;x[(f+8|0)+(q<<2)>>2]=(((((((D(v[j-4|0],e)+D(v[j-6|0],b)|0)+D(v[j-2|0],k)|0)+D(v[j|0],t)|0)+D(v[j+2|0],i)|0)+D(v[j+4|0],u)|0)+D(s,v[j+6|0])|0)+D(l,v[j+8|0])<<8)/32768;q=q+1|0;continue}break}while(1){if((p|0)!=2){s=(f+8|0)+(p<<2)|0;e=x[s>>2];b=(f+28|0)+(p<<3)|0;u=x[b+8>>2];i=x[b+4>>2];x[b+8>>2]=i;t=e<<8;e=t;e=Sua(e,e>>31,g,H);k=hb;j=e;e=Yb(i,-16777216,16776704);e=Sua(h,G,e,e>>31);i=j+e|0;l=hb+k|0;l=e>>>0>i>>>0?l+1|0:l;e=Yb(u,-16777216,16776704);k=Sua(y,F,e,e>>31);i=k+i|0;e=hb+l|0;e=i>>>0<k>>>0?e+1|0:e;k=i+8388608|0;e=k>>>0<8388608?e+1|0:e;e=Rc(k,e,24);x[b+4>>2]=e-(t&E);x[s>>2]=(e|0)/256;p=p+1|0;continue}break}o=o+C|0;x[c>>2]=x[c>>2]+D(x[f+8>>2],o>>12);n=n+B|0;x[c+4>>2]=x[c+4>>2]+D(x[f+12>>2],n>>12);Pb(f+16|0,r,m);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;x[a+40>>2]=n;x[a+20>>2]=o>>12;x[a+36>>2]=o;x[a+24>>2]=n>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+28|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}fb=f+48|0}function qpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;if(x[a+4>>2]!=x[zb(a)>>2]){e=fb-16|0;fb=e;c=e+4|0;x[c>>2]=a;a=x[a+4>>2];x[c+4>>2]=a;x[c+8>>2]=a+56;a=x[c+4>>2];x[31737]=0;O(684,a|0,b|0);a=x[31737];x[31737]=0;a:{if((a|0)!=1){x[c+4>>2]=x[c+4>>2]+56;hc(c);fb=e+16|0;break a}a=N()|0;hc(c);Q(a|0);p()}return}k=fb-32|0;fb=k;i=zb(a);c=k+12|0;d=xv(x[a>>2],x[a+4>>2])+1|0;h=fb-16|0;fb=h;x[h+12>>2]=d;f=fb-16|0;fb=f;x[f+12>>2]=76695844;x[f+8>>2]=2147483647;e=x[Gb(f+12|0,f+8|0)>>2];fb=f+16|0;b:{if(e>>>0>=d>>>0){d=xX(a);if(d>>>0<e>>>1>>>0){x[h+8>>2]=d<<1;e=x[ad(h+8|0,h+12|0)>>2]}fb=h+16|0;break b}dd();p()}f=xv(x[a>>2],x[a+4>>2]);h=fb-16|0;fb=h;Kg(c+12|0,i);c:{if(!e){i=0;e=0;break c}if(e>>>0>=76695845){Zj();p()}d=Ec(D(e,56));x[h+12>>2]=e;x[h+8>>2]=d;i=x[h+12>>2];e=x[h+8>>2]}x[c>>2]=e;d=e+D(f,56)|0;x[c+8>>2]=d;x[c+4>>2]=d;l=nc(c),m=e+D(i,56)|0,x[l>>2]=m;fb=h+16|0;e=x[c+8>>2];x[31737]=0;O(684,e|0,b|0);b=x[31737];x[31737]=0;d:{if((b|0)!=1){x[c+8>>2]=x[c+8>>2]+56;h=fb-16|0;fb=h;f=zb(a);d=vb(h+12|0,x[a+4>>2]);e=vb(h+8|0,x[a>>2]);b=vb(h+4|0,x[c+4>>2]);i=x[d>>2];e=x[e>>2];g=fb+-64|0;fb=g;b=x[b>>2];x[g+56>>2]=b;x[g+60>>2]=i;x[g+52>>2]=b;d=Re(g+24|0,f,g+52|0,g+56|0);x[g+16>>2]=x[d+8>>2];b=x[d+4>>2];x[g+8>>2]=x[d>>2];x[g+12>>2]=b;Qe(g+36|0,g+8|0);while(1){if(pd(i,e)){b=uX(x[g+56>>2]);f=yX(i);d=_l(b,f);_l(d+12|0,f+12|0);AC(d+24|0,f+24|0);w[d+52>>1]=z[f+52>>1];b=x[f+48>>2];x[d+44>>2]=x[f+44>>2];x[d+48>>2]=b;b=x[f+40>>2];x[d+36>>2]=x[f+36>>2];x[d+40>>2]=b;b=vX(g+60|0);vX(g+56|0);i=x[b>>2];continue}break}Pe(g+36|0);d=x[g+56>>2];if(!y[g+48|0]){i=fb-16|0;fb=i;b=vb(i+12|0,x[x[g+44>>2]>>2]);e=x[vb(i+8|0,x[x[g+40>>2]>>2])>>2];f=fb-16|0;fb=f;b=x[b>>2];x[f+12>>2]=b;while(1){if(ci(b,e)){j=fb-16|0;fb=j;x[j+12>>2]=b;x[j+12>>2]=x[j+12>>2]+56;fb=j+16|0;er(uX(x[j+12>>2]));b=f+12|0;x[b>>2]=x[b>>2]+56;b=x[b>>2];continue}break}fb=f+16|0;fb=i+16|0}fb=g- -64|0;x[c+4>>2]=d;Tb(a,c+4|0);Tb(a+4|0,c+8|0);Tb(zb(a),nc(c));x[c>>2]=x[c+4>>2];fb=h+16|0;wX(c);fb=k+32|0;break d}a=N()|0;wX(c);Q(a|0);p()}}function woa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=fb-112|0;fb=d;a:{b:{c:{d:{switch(y[a|0]-23|0){case 0:e=v[a+1|0];i=d,j=FD(c,+y[a+2|0]*1e4/240),v[i+12|0]=j;x[d+88>>2]=127;x[d+76>>2]=(D(y[a+3|0],127)>>>0)/185;i=d,j=x[ud(d+88|0,d+76|0)>>2],v[i+111|0]=j;e:{switch(((e>>>0)%5|0)-1|0){case 0:a=d+76|0;mw(a,15681);x[31737]=0;c=d- -64|0;O(560,c|0,d+12|0);e=x[31737];x[31737]=0;f:{g:{h:{i:{if((e|0)!=1){x[31737]=0;e=d+52|0;O(560,e|0,d+111|0);f=x[31737];x[31737]=0;if((f|0)==1){break i}x[31737]=0;f=d+88|0;V(561,f|0,a|0,c|0,e|0);g=x[31737];x[31737]=0;if((g|0)==1){break h}ee(d+100|0,f);qf(b,x[d+100>>2],x[d+104>>2]);tb(f);tb(e);tb(c);Eb(a);break b}a=N()|0;break f}a=N()|0;break g}a=N()|0;tb(d+52|0)}tb(d- -64|0)}break c;case 1:a=d+76|0;mw(a,15628);x[31737]=0;c=d- -64|0;O(560,c|0,d+12|0);e=x[31737];x[31737]=0;j:{k:{l:{m:{if((e|0)!=1){x[31737]=0;e=d+52|0;O(560,e|0,d+111|0);f=x[31737];x[31737]=0;if((f|0)==1){break m}x[31737]=0;f=d+88|0;V(561,f|0,a|0,c|0,e|0);g=x[31737];x[31737]=0;if((g|0)==1){break l}ee(d+44|0,f);qf(b,x[d+44>>2],x[d+48>>2]);tb(f);tb(e);tb(c);Eb(a);break b}a=N()|0;break j}a=N()|0;break k}a=N()|0;tb(d+52|0)}tb(d- -64|0)}break c;default:break e}}a=qc(d+36|0,15708);qf(b,x[a>>2],x[a+4>>2]);break b;case 1:break d;default:break a}}c=v[a+1|0];v[d+111|0]=(c|0)<5?c:0;c=v[a+2|0];v[d+35|0]=(c|0)<0?127:c;a=v[a+3|0];v[d+34|0]=(a|0)<0?127:a;a=fb-16|0;fb=a;c=d+76|0;e=Dc(a+4|0,4048);_c(c,e);tb(e);fb=a+16|0;x[31737]=0;a=d- -64|0;O(560,a|0,d+111|0);e=x[31737];x[31737]=0;n:{o:{p:{q:{r:{s:{if((e|0)!=1){x[31737]=0;e=d+52|0;O(560,e|0,d+35|0);f=x[31737];x[31737]=0;if((f|0)==1){break s}x[31737]=0;f=d+12|0;O(560,f|0,d+34|0);g=x[31737];x[31737]=0;if((g|0)==1){break r}x[31737]=0;g=d+88|0;aa(742,g|0,c|0,a|0,e|0,f|0);h=x[31737];x[31737]=0;if((h|0)==1){break q}ee(d+24|0,g);qf(b,x[d+24>>2],x[d+28>>2]);tb(g);tb(f);tb(e);tb(a);Eb(c);break b}a=N()|0;break n}a=N()|0;break o}a=N()|0;break p}a=N()|0;tb(d+12|0)}tb(d+52|0)}tb(d- -64|0)}}Eb(d+76|0);Q(a|0);p()}e=1}fb=d+112|0;return e|0}function ye(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=fb-16|0;fb=h;e=x[a>>2];a:{if(mc(e,x[a+4>>2])){break a}f=x[b+4>>2];if(f>>>0>=A[a+12>>2]){break a}i=z[b+8>>1];j=x[x[a+48>>2]+12>>2];c=z[j+480188>>1];if(i>>>0>=c>>>0&(i|0)!=65535){break a}d=c-1|0;c=(i|0)==65535;l=c?d:i;c=c?0:i;e=jd(e,j,f,c);g=y[b+12|0];k=g&4;b:{c:{if(g&2){break c}i=y[b+10|0];f=e;d=c;while(1){if((d&65535)>>>0>(l&65535)>>>0){break c}d:{if(!k){if((i|0)!=y[f+3|0]){break d}break b}if((i|0)==y[f+2|0]){break b}}f=f+6|0;d=d+1|0;continue}}i=l&65535;d=e;f=c;while(1){if(i>>>0>=(f&65535)>>>0){e:{if(!k){if(y[d+3|0]){break e}v[d+3|0]=y[b+10|0];v[d+5|0]=y[b+11|0];break b}if(y[d+2|0]){break e}v[d+2|0]=y[b+10|0];v[d+4|0]=y[b+11|0];break b}d=d+6|0;f=f+1|0;continue}break}f:{if(!(g&1)){break f}d=x[j+480180>>2]&2;g:{h:{i:{if(!k){while(1){if((c&65535)>>>0<=(l&65535)>>>0){j:{k:{switch(y[e+3|0]-9|0){case 4:if(!Wv(x[x[j+8>>2]+88>>2],1)){break j}d=1;v[e+2|0]=1;v[e+4|0]=y[e+5|0];v[e+3|0]=y[b+10|0];v[e+5|0]=y[b+11|0];break a;case 0:break k;default:break j}}l:{if(d){f=y[e+5|0];if(f>>>0>128){break j}v[e+2|0]=2;v[e+3|0]=y[b+10|0];a=1;break l}v[e+2|0]=2;v[e+3|0]=y[b+10|0];f=y[e+5|0];a=2}v[e+4|0]=a+(f&255)>>>a;v[e+5|0]=y[b+11|0];break b}e=e+6|0;c=c+1|0;continue}break}if(!k){break i}}f=y[b+11|0];c=13;m:{switch(y[b+10|0]-1|0){case 1:c=9;f=yi(f<<(d?1:2));break;case 0:break m;default:break g}}v[b+11|0]=f;v[b+10|0]=c;g=g&254;break h}v[h+15|0]=0;v[h+14|0]=0;e=b;c=y[b+10|0];n:{if(!(!d|(c|0)!=9)){c=y[b+11|0];if(c>>>0>128){break g}d=2;c=c>>>1|0;break n}f=h+12|0;rw(f,c,y[b+11|0],1);c=h+4|0;VD(c,h+15|0,h+14|0);UD(c,f);g=y[b+12|0];d=y[h+15|0];if(!d){break g}c=y[h+14|0]}v[e+11|0]=c;v[b+10|0]=d;g=g&254}v[b+12|0]=g}d=1;if(g&1){break f}v[b+12|0]=g^4;if(ye(a,b)){break a}}d=0;o:{p:{switch(x[b>>2]-1|0){case 0:c=x[b+4>>2]+1|0;if(c>>>0>=A[a+12>>2]){break a}x[b+4>>2]=c;break o;case 1:break p;default:break a}}c=x[b+4>>2];if(!c){break a}x[b+4>>2]=c-1}v[b+12|0]=y[b+12|0]|1;d=ye(a,b);break a}d=1}fb=h+16|0;return d}function xU(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0;c=fb-176|0;fb=c;i=1;p=2;d=x[a+12>>2];q=1<<d;m=q;a:while(1){if(d>>>0>=p>>>0){m=m>>>2|0;v=D(i,3);w=i<<1;h=0;b:while(1){if((h|0)==(m|0)){p=p+2|0;i=i<<2;d=x[a+12>>2];continue a}d=x[a>>2];e=Xd(d,h<<1);JR(c+160|0,C[e>>3],C[e+8>>3]);d=Xd(d,h);JR(c+144|0,C[d>>3],C[d+8>>3]);Si(c+128|0,C[c+144>>3],C[c+152>>3],C[c+160>>3],C[c+168>>3]);d=h<<p;e=i+d|0;y=d>>>0>e>>>0?d:e;while(1)if((d|0)==(y|0)){h=h+1|0;continue b}else{f=x[b>>2];e=Xd(f,d);g=e+8|0;j=x[g+4>>2];x[c+120>>2]=x[g>>2];x[c+124>>2]=j;g=x[e+4>>2];x[c+112>>2]=x[e>>2];x[c+116>>2]=g;k=d+i|0;g=Xd(f,k);n=C[g+8>>3];o=C[g>>3];r=d+w|0;g=Xd(f,r);j=x[g+12>>2];x[c+104>>2]=x[g+8>>2];x[c+108>>2]=j;j=x[g+4>>2];x[c+96>>2]=x[g>>2];x[c+100>>2]=j;s=d+v|0;f=Xd(f,s);t=C[f+8>>3];u=C[f>>3];g=c+80|0;f=c+112|0;Kl(g,f,o,n);j=c- -64|0;Fj(j,f,o,n);l=c+96|0;Kl(c+48|0,l,u,t);f=c+16|0;Fj(f,l,u,t);Si(c+32|0,0,1,C[c+16>>3],C[c+24>>3]);Kl(f,g,C[c+48>>3],C[c+56>>3]);l=x[c+28>>2];x[e+8>>2]=x[c+24>>2];x[e+12>>2]=l;l=x[c+20>>2];x[e>>2]=x[c+16>>2];x[e+4>>2]=l;Kl(c,j,C[c+32>>3],C[c+40>>3]);Si(f,C[c+160>>3],C[c+168>>3],C[c>>3],C[c+8>>3]);e=Xd(x[b>>2],k);k=x[c+28>>2];x[e+8>>2]=x[c+24>>2];x[e+12>>2]=k;k=x[c+20>>2];x[e>>2]=x[c+16>>2];x[e+4>>2]=k;Fj(c,g,C[c+48>>3],C[c+56>>3]);Si(f,C[c+144>>3],C[c+152>>3],C[c>>3],C[c+8>>3]);e=Xd(x[b>>2],r);g=x[c+28>>2];x[e+8>>2]=x[c+24>>2];x[e+12>>2]=g;g=x[c+20>>2];x[e>>2]=x[c+16>>2];x[e+4>>2]=g;Fj(c,j,C[c+32>>3],C[c+40>>3]);Si(f,C[c+128>>3],C[c+136>>3],C[c>>3],C[c+8>>3]);e=Xd(x[b>>2],s);f=x[c+28>>2];x[e+8>>2]=x[c+24>>2];x[e+12>>2]=f;f=x[c+20>>2];x[e>>2]=x[c+16>>2];x[e+4>>2]=f;d=d+1|0;continue}}}break}c:{if(!(d&1)){break c}i=q>>>1|0;d=0;while(1){if((d|0)==(i|0)){break c}h=x[b>>2];a=Xd(h,d+i|0);m=Xd(h,d);n=C[a>>3];o=C[a+8>>3];Fj(c+160|0,m,n,o);h=x[c+172>>2];x[a+8>>2]=x[c+168>>2];x[a+12>>2]=h;h=x[c+164>>2];x[a>>2]=x[c+160>>2];x[a+4>>2]=h;xA(Xd(x[b>>2],d),n,o);d=d+1|0;continue}}fb=c+176|0}function _7(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;j=fb-16|0;fb=j;k=Ny(x[g>>2]);o=sy(x[g>>2]);rh(j+4|0,o);x[f>>2]=d;a:{b:{c:{i=a;g=y[i|0];switch(g-43|0){case 0:case 2:break c;default:break b}}x[31737]=0;g=P(1228,k|0,g<<24>>24)|0;i=x[31737];x[31737]=0;if((i|0)==1){break a}i=x[f>>2];x[f>>2]=i+4;x[i>>2]=g;i=a+1|0}d:{g=i;if(!((c-g|0)<=1|y[g|0]!=48|(y[g+1|0]|32)!=120)){x[31737]=0;i=P(1228,k|0,48)|0;h=x[31737];x[31737]=0;if((h|0)==1){break a}h=x[f>>2];x[f>>2]=h+4;x[h>>2]=i;i=v[g+1|0];x[31737]=0;i=P(1228,k|0,i|0)|0;h=x[31737];x[31737]=0;if((h|0)==1){break a}h=x[f>>2];x[f>>2]=h+4;x[h>>2]=i;i=g+2|0;g=i;while(1){if(c>>>0<=g>>>0){break d}h=v[g|0];Od();if(!TK(h)){break d}g=g+1|0;continue}}while(1){if(c>>>0<=g>>>0){break d}h=v[g|0];Od();if(!Oh(h)){break d}g=g+1|0;continue}}e:{if(Ad(x[j+8>>2],y[j+15|0])){h=x[f>>2];x[31737]=0;V(1222,k|0,i|0,g|0,h|0);h=x[31737];x[31737]=0;if((h|0)==1){break a}x[f>>2]=x[f>>2]+(g-i<<2);break e}Hm(i,g);x[31737]=0;r=R(1220,o|0)|0;h=x[31737];x[31737]=0;if((h|0)==1){break a}h=i;while(1){if(g>>>0<=h>>>0){jt((i-a<<2)+d|0,x[f>>2]);break e}f:{if(v[cc(j+4|0,l)|0]<=0){break f}if(v[cc(j+4|0,l)|0]!=(m|0)){break f}m=x[f>>2];x[f>>2]=m+4;x[m>>2]=r;l=(Cb(x[j+8>>2],y[j+15|0])-1>>>0>l>>>0)+l|0;m=0}q=v[h|0];x[31737]=0;q=P(1228,k|0,q|0)|0;n=x[31737];x[31737]=0;if((n|0)!=1){n=x[f>>2];x[f>>2]=n+4;x[n>>2]=q;h=h+1|0;m=m+1|0;continue}break}break a}g:{while(1){if(c>>>0>g>>>0){i=y[g|0];if((i|0)==46){x[31737]=0;i=R(1223,o|0)|0;h=x[31737];x[31737]=0;if((h|0)==1){break a}l=x[f>>2];h=l+4|0;x[f>>2]=h;x[l>>2]=i;g=g+1|0;break g}x[31737]=0;i=P(1228,k|0,i<<24>>24)|0;h=x[31737];x[31737]=0;if((h|0)==1){break a}h=x[f>>2];x[f>>2]=h+4;x[h>>2]=i;g=g+1|0;continue}break}h=x[f>>2]}x[31737]=0;V(1222,k|0,g|0,c|0,h|0);i=x[31737];x[31737]=0;if((i|0)==1){break a}i=f;f=x[f>>2]+(c-g<<2)|0;x[i>>2]=f;x[e>>2]=(b|0)==(c|0)?f:(b-a<<2)+d|0;tb(j+4|0);fb=j+16|0;return}a=N()|0;tb(j+4|0);Q(a|0);p()}function Ula(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0;f=fb-48|0;fb=f;u=x[a+16>>2];v=Fg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);b=0;o=x[a+128>>2];if(o){j=x[a+8>>2];g=x[a+12>>2];p=Gg(j,g,o);q=hb;h=x[a+76>>2];hg(x[a>>2],x[a+4>>2],vf(j,g,d),hb);n=hb>>>0>h>>>0?d:0}else{n=0}i=a+112|0;while(1){if((b|0)!=2){g=b<<3;h=g+(f+20|0)|0;g=a+g|0;x[h+4>>2]=x[g+44>>2];x[h+8>>2]=x[g+48>>2];b=b+1|0;continue}break}y=x[a+24>>2];z=x[a+20>>2];b=x[a+4>>2];x[f+8>>2]=x[a>>2];x[f+12>>2]=b;A=x[a+8>>2];B=x[a+12>>2];a:while(1){if(d){d=d-1|0;g=x[f+12>>2];b=x[f+8>>2];x[f+40>>2]=b;x[f+44>>2]=0;n=n-1|0;h=n;p=h?p:0;q=h?q:0;j=((((g&2147483647)<<1|b>>>31)&2147483646)<<1)+u|0;b=o;while(1)if((b|0)<=0){Pb(i,x[a+120>>2],x[a+124>>2]);h=x[a+116>>2];if(h){b=x[f+40>>2];b=((((x[f+44>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+j|0;be(i,(w[b>>1]+w[b+2>>1]|0)/8<<16>>16);ae(i,h);x[i>>2]=x[i>>2];x[i+4>>2]=0}b=Eg(i,v);x[f+4>>2]=b;x[f>>2]=b;C=x[a+72>>2];r=x[a+68>>2];E=r>>31;j=x[a+64>>2];F=j>>31;h=x[a+60>>2];G=h>>31;b=0;while(1){if((b|0)!=2){s=(b<<2)+f|0;e=x[s>>2];g=(f+20|0)+(b<<3)|0;H=x[g+8>>2];k=x[g+4>>2];x[g+8>>2]=k;t=e<<8;e=t;e=Sua(e,e>>31,h,G);l=hb;m=e;e=Yb(k,-16777216,16776704);e=Sua(j,F,e,e>>31);k=m+e|0;m=hb+l|0;m=e>>>0>k>>>0?m+1|0:m;e=Yb(H,-16777216,16776704);l=Sua(r,E,e,e>>31);k=l+k|0;e=hb+m|0;e=k>>>0<l>>>0?e+1|0:e;l=k+8388608|0;e=l>>>0<8388608?e+1|0:e;e=Rc(l,e,24);x[g+4>>2]=e-(C&t);x[s>>2]=(e|0)/256;b=b+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[f>>2],z);x[c+4>>2]=x[c+4>>2]+D(y,x[f+4>>2]);Pb(f+8|0,A,B);c=c+8|0;continue a}else{g=x[f+40>>2];g=((((x[f+44>>2]&2147483647)<<1|g>>>31)&2147483646)<<1)+j|0;be(i,(w[g>>1]+w[g+2>>1]|0)/8<<16>>16);ae(i,4);Pb(f+40|0,p,q);b=b-1|0;continue}}break}b=x[f+12>>2];x[a>>2]=x[f+8>>2];x[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+20|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}fb=f+48|0}function Pi(a,b,c,d,e,f){var g=0,h=0,i=0,j=E(0),k=E(0),l=0,m=0,n=E(0),o=E(0),p=E(0),q=0,r=E(0);m=ib[x[x[a>>2]+140>>2]](a)|0;g=x[a+20>>2];h=m?h:y[g+25|0];j=B[g+144>>2];k=E(1);if(!(ib[x[x[a>>2]+140>>2]](a)|0)){k=B[x[a+20>>2]+144>>2]}j=E(E(1)-j);a:{if((ib[x[x[a>>2]+156>>2]](a)|0)<=0){break a}if(!BQ(y[x[a+20>>2]+24|0])){break a}j=E(E(j+j)+E(-1));k=E(-j)}n=B[a+4196>>2];k=E(k*n);j=E(j*n);g=0;l=x[a+44>>2];m=Hc(l,0);l=Hc(l,1);b:{c:{d:{e:{f:{g:{h:{h=h&255;switch(h|0){case 0:break h;case 5:break c;case 4:break d;case 3:break e;case 2:break f;case 1:break g;default:break b}}while(1){if((f|0)==(h|0)){break b}g=h<<2;i=g+b|0;B[i>>2]=B[i>>2]+E(E(B[d+g>>2]*j)+E(k*B[g+m>>2]));i=c+g|0;B[i>>2]=B[i>>2]+E(E(B[e+g>>2]*j)+E(k*B[g+l>>2]));h=h+1|0;continue}}while(1){if((f|0)==(g|0)){break b}h=g<<2;i=h+b|0;B[i>>2]=B[i>>2]+E(B[h+m>>2]-E(B[d+h>>2]*j));i=c+h|0;B[i>>2]=B[i>>2]+E(B[h+l>>2]-E(B[e+h>>2]*j));g=g+1|0;continue}}while(1){if((f|0)==(g|0)){break b}h=g<<2;i=h+b|0;B[i>>2]=B[i>>2]+E(B[d+h>>2]-E(B[h+m>>2]*k));i=c+h|0;B[i>>2]=B[i>>2]+E(B[e+h>>2]-E(B[h+l>>2]*k));g=g+1|0;continue}}while(1){if((f|0)==(g|0)){break b}h=g<<2;i=h+b|0;B[i>>2]=B[i>>2]-E(B[d+h>>2]-E(B[h+m>>2]*j));i=c+h|0;B[i>>2]=B[i>>2]-E(B[e+h>>2]-E(B[h+l>>2]*j));g=g+1|0;continue}}while(1){if((f|0)==(g|0)){break b}h=g<<2;i=h+b|0;k=B[i>>2];q=i;r=k;n=B[h+m>>2];i=c+h|0;o=B[i>>2];p=B[h+l>>2];k=E(E(E(E(k+n)+o)+p)*E(.5));B[q>>2]=r-E(E(k+E(k-E(B[d+h>>2]*j)))-n);B[i>>2]=o-E(E(k+E(k-E(B[e+h>>2]*j)))-p);g=g+1|0;continue}}g=BQ(y[x[a+20>>2]+24|0]);j=g?E(j*E(.5)):j;k=g?E(k*E(.5)):k;h=0;while(1){if((f|0)==(h|0)){break b}g=h<<2;i=g+b|0;n=E(B[d+g>>2]-B[g+m>>2]);o=E(B[g+l>>2]-B[e+g>>2]);B[i>>2]=B[i>>2]+E(E(j*n)+E(k*o));g=c+g|0;B[g>>2]=B[g>>2]+E(E(k*n)+E(j*o));h=h+1|0;continue}}i:{if(!((y[x[a+20>>2]+24|0]&4)>>>2|0)){break i}if(ib[x[x[a>>2]+140>>2]](a)|0){break i}g=0;while(1){if((f|0)==(g|0)){break i}a=g<<2;d=a+b|0;B[d>>2]=B[a+m>>2]+B[d>>2];d=a+c|0;B[d>>2]=B[a+l>>2]+B[d>>2];g=g+1|0;continue}}}function DK(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;e=x[b>>2];a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{if(!d){break l}g=x[d>>2];if(!g){break l}if(!a){d=c;break j}x[d>>2]=0;d=c;break k}m:{if(!x[x[124243]>>2]){if(!a){break m}if(!c){break a}g=c;while(1){d=v[e|0];if(d){x[a>>2]=d&57343;a=a+4|0;e=e+1|0;g=g-1|0;if(g){continue}break a}break}x[a>>2]=0;x[b>>2]=0;return c-g|0}d=c;if(!a){break i}break g}return Cf(e)}f=1;break g}f=0;break h}f=1}while(1){if(!f){f=y[e|0]>>>3|0;if((f-16|f+(g>>26))>>>0>7){break f}f=e+1|0;n:{if(!(g&33554432)){break n}if((y[f|0]&192)!=128){e=e-1|0;break d}f=e+2|0;if(!(g&524288)){break n}if((y[f|0]&192)!=128){e=e-1|0;break d}f=e+3|0}e=f;d=d-1|0;f=1;continue}while(1){g=y[e|0];o:{if(e&3|g-1>>>0>126){break o}g=x[e>>2];if((g|g-16843009)&-2139062144){break o}while(1){d=d-4|0;g=x[e+4>>2];e=e+4|0;if(!((g-16843009|g)&-2139062144)){continue}break}}f=g&255;if(f-1>>>0<=126){d=d-1|0;e=e+1|0;continue}break}f=f-194|0;if(f>>>0>50){break e}e=e+1|0;g=x[(f<<2)+111568>>2];f=0;continue}}while(1){if(!f){if(!d){break a}while(1){p:{f=y[e|0];h=f-1|0;q:{r:{if(h>>>0>126){g=f;break r}if(e&3|d>>>0<5){break q}s:{while(1){g=x[e>>2];if((g|g-16843009)&-2139062144){break s}x[a>>2]=g&255;x[a+4>>2]=y[e+1|0];x[a+8>>2]=y[e+2|0];x[a+12>>2]=y[e+3|0];a=a+16|0;e=e+4|0;d=d-4|0;if(d>>>0>4){continue}break}g=y[e|0]}f=g&255;h=f-1|0}if(h>>>0>126){break p}}x[a>>2]=f;a=a+4|0;e=e+1|0;d=d-1|0;if(d){continue}break a}break}f=f-194|0;if(f>>>0>50){break e}e=e+1|0;g=x[(f<<2)+111568>>2];f=1;continue}i=y[e|0];f=i>>>3|0;if((f-16|f+(g>>26))>>>0>7){break f}t:{u:{h=e+1|0;f=i-128|g<<6;v:{if((f|0)>=0){break v}i=y[h|0]-128|0;if(i>>>0>63){break u}h=e+2|0;f=i|f<<6;if((f|0)>=0){break v}h=y[h|0]-128|0;if(h>>>0>63){break u}f=h|f<<6;h=e+3|0}e=h;x[a>>2]=f;d=d-1|0;a=a+4|0;break t}x[31612]=25;e=e-1|0;break c}f=0;continue}}e=e-1|0;if(g){break d}g=y[e|0]}if(g&255){break d}if(a){x[a>>2]=0;x[b>>2]=0}return c-d|0}x[31612]=25;if(!a){break b}}x[b>>2]=e}return-1}x[b>>2]=e;return c}function Ura(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=E(0),i=0,j=E(0);e=fb-96|0;fb=e;d=fb-16|0;fb=d;c=b+16|0;oZ(d+8|0,c);g=x[d+12>>2];lc(d,x[a>>2],x[a+8>>2],x[d+8>>2],x[d+12>>2]);f=x[d+4>>2];if((f|0)==(g|0)){Vb(a,x[d+12>>2])}fb=d+16|0;if((f|0)!=(g|0)){Rb(c,0,128)}v[b+79|0]=0;v[b+143|0]=0;x[b+152>>2]=-2147483648;x[b+156>>2]=-2147483648;d=e+56|0;fe(d,a,Pg(a));g=ic(e+76|0,d);ub(d);x[31737]=0;c=R(203,g|0)|0;f=x[31737];x[31737]=0;a:{b:{if((f|0)==1){break b}x[31737]=0;O(288,b+4|0,c|0);c=x[31737];x[31737]=0;if((c|0)==1){break b}re(e+48|0,x[b+4>>2],x[b+8>>2]);x[31737]=0;ao(472,d,g,x[e+48>>2],x[e+52>>2]);c=x[31737];x[31737]=0;if((c|0)!=1){x[31737]=0;f=R(152,a|0)|0;c=x[31737];x[31737]=0;c:{if((c|0)==1){break c}x[31737]=0;c=e+28|0;S(186,c|0,a|0,f|0);a=x[31737];x[31737]=0;if((a|0)==1){break c}d=ic(d,c);ub(c);a=x[d>>2];x[31737]=0;a=R(173,a|0)|0;c=x[31737];x[31737]=0;d:{if((c|0)!=1){e:{f:{g:{if(!a){break g}while(1){a=x[d+8>>2];c=x[d>>2];x[31737]=0;a=U(151,c|0,a|0,5)|0;c=x[31737];x[31737]=0;if((c|0)==1){break f}if(!a){break g}x[31737]=0;P(473,d|0,e+24|0)|0;a=x[31737];x[31737]=0;h:{if((a|0)!=1){a=4;c=y[e+24|0]|y[e+25|0]<<8|(y[e+26|0]<<16|y[e+27|0]<<24);if((c|0)==1414682436|(c|0)==1196380752){break h}x[31737]=0;a=R(152,d|0)|0;c=x[31737];x[31737]=0;if((c|0)!=1){break h}a=N()|0;break d}a=N()|0;break d}x[31737]=0;f=e+4|0;S(186,f|0,d|0,a|0);a=x[31737];x[31737]=0;i:{j:{if((a|0)!=1){c=ic(e+28|0,f);ub(f);if((y[e+24|0]|y[e+25|0]<<8|(y[e+26|0]<<16|y[e+27|0]<<24))!=1414682436){break j}x[31737]=0;h=E(xa(474,c|0));a=x[31737];x[31737]=0;if((a|0)==1){break e}i=b,j=Pd(h,E(0)),B[i+144>>2]=j;break i}a=N()|0;break d}if((y[e+24|0]|y[e+25|0]<<8|(y[e+26|0]<<16|y[e+27|0]<<24))!=1196380752){break i}x[31737]=0;a=R(152,c|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break e}x[b+148>>2]=a}ub(c);continue}}ub(d);ub(g);fb=e+96|0;return}a=N()|0;break d}a=N()|0;ub(c);break d}a=N()|0}ub(d);break a}a=N()|0;break a}a=N()|0;break a}a=N()|0}ub(g);Q(a|0);p()}function yma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0;f=fb-48|0;fb=f;g=x[a+8>>2];p=g;h=x[a+12>>2];m=h;a:{b:{c:{d:{if((h|0)<=1&g>>>0<=805306368|(h|0)<=0){g=h;if((g|0)>-2){e=1}else{e=(g|0)>=-2&p>>>0>=3489660928}if(e){break c}if((m|0)==-2&p>>>0>2147483647|(m|0)==-1){break d}break b}if((m|0)==1&p>>>0>2147483648|m>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}u=b;v=x[a+16>>2];b=0;while(1){if((b|0)!=2){g=b<<3;h=g+(f+28|0)|0;g=a+g|0;x[h+4>>2]=x[g+44>>2];x[h+8>>2]=x[g+48>>2];b=b+1|0;continue}break}y=x[a+24>>2];z=x[a+20>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;A=x[a+72>>2];t=x[a+68>>2];B=t>>31;h=x[a+64>>2];C=h>>31;g=x[a+60>>2];E=g>>31;while(1){if(d){b=x[f+16>>2];F=((((x[f+20>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+v|0;b=(b>>>16&65520)+u|0;l=w[b+14>>1];q=w[b+12>>1];s=w[b+10>>1];i=w[b+8>>1];r=w[b+6>>1];k=w[b+4>>1];e=w[b+2>>1];b=w[b>>1];n=0;o=0;while(1){if((o|0)!=2){j=F+(o<<1)|0;x[(f+8|0)+(o<<2)>>2]=(((((((D(w[j-8>>1],e)+D(w[j-12>>1],b)|0)+D(w[j-4>>1],k)|0)+D(w[j>>1],r)|0)+D(w[j+4>>1],i)|0)+D(w[j+8>>1],s)|0)+D(q,w[j+12>>1])|0)+D(l,w[j+16>>1])|0)/32768;o=o+1|0;continue}break}while(1){if((n|0)!=2){q=(f+8|0)+(n<<2)|0;e=x[q>>2];b=(f+28|0)+(n<<3)|0;s=x[b+8>>2];i=x[b+4>>2];x[b+8>>2]=i;r=e<<8;e=r;e=Sua(e,e>>31,g,E);k=hb;j=e;e=Yb(i,-16777216,16776704);e=Sua(h,C,e,e>>31);i=j+e|0;l=hb+k|0;l=e>>>0>i>>>0?l+1|0:l;e=Yb(s,-16777216,16776704);k=Sua(t,B,e,e>>31);i=k+i|0;e=hb+l|0;e=i>>>0<k>>>0?e+1|0:e;k=i+8388608|0;e=k>>>0<8388608?e+1|0:e;e=Rc(k,e,24);x[b+4>>2]=e-(r&A);x[q>>2]=(e|0)/256;n=n+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[f+8>>2],z);x[c+4>>2]=x[c+4>>2]+D(x[f+12>>2],y);Pb(f+16|0,p,m);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+28|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}fb=f+48|0}function i8(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;j=fb-16|0;fb=j;k=Bw(x[g>>2]);o=Ay(x[g>>2]);rh(j+4|0,o);x[f>>2]=d;a:{b:{c:{h=a;g=y[h|0];switch(g-43|0){case 0:case 2:break c;default:break b}}x[31737]=0;g=P(29,k|0,g<<24>>24)|0;h=x[31737];x[31737]=0;if((h|0)==1){break a}h=x[f>>2];x[f>>2]=h+1;v[h|0]=g;h=a+1|0}d:{g=h;if(!((c-g|0)<=1|y[g|0]!=48|(y[g+1|0]|32)!=120)){x[31737]=0;h=P(29,k|0,48)|0;i=x[31737];x[31737]=0;if((i|0)==1){break a}i=x[f>>2];x[f>>2]=i+1;v[i|0]=h;h=v[g+1|0];x[31737]=0;h=P(29,k|0,h|0)|0;i=x[31737];x[31737]=0;if((i|0)==1){break a}i=x[f>>2];x[f>>2]=i+1;v[i|0]=h;h=g+2|0;g=h;while(1){if(c>>>0<=g>>>0){break d}i=v[g|0];Od();if(!TK(i)){break d}g=g+1|0;continue}}while(1){if(c>>>0<=g>>>0){break d}i=v[g|0];Od();if(!Oh(i)){break d}g=g+1|0;continue}}e:{if(Ad(x[j+8>>2],y[j+15|0])){i=x[f>>2];x[31737]=0;V(1209,k|0,h|0,g|0,i|0);i=x[31737];x[31737]=0;if((i|0)==1){break a}x[f>>2]=x[f>>2]+(g-h|0);break e}Hm(h,g);x[31737]=0;r=R(1207,o|0)|0;i=x[31737];x[31737]=0;if((i|0)==1){break a}i=h;while(1){if(g>>>0<=i>>>0){Hm((h-a|0)+d|0,x[f>>2]);break e}f:{if(v[cc(j+4|0,m)|0]<=0){break f}if(v[cc(j+4|0,m)|0]!=(l|0)){break f}l=x[f>>2];x[f>>2]=l+1;v[l|0]=r;m=(Cb(x[j+8>>2],y[j+15|0])-1>>>0>m>>>0)+m|0;l=0}q=v[i|0];x[31737]=0;q=P(29,k|0,q|0)|0;n=x[31737];x[31737]=0;if((n|0)!=1){n=x[f>>2];x[f>>2]=n+1;v[n|0]=q;i=i+1|0;l=l+1|0;continue}break}break a}while(1){g:{if(c>>>0>g>>>0){h=y[g|0];if((h|0)!=46){break g}x[31737]=0;h=R(1210,o|0)|0;i=x[31737];x[31737]=0;if((i|0)==1){break a}i=x[f>>2];x[f>>2]=i+1;v[i|0]=h;g=g+1|0}h=x[f>>2];x[31737]=0;V(1209,k|0,g|0,c|0,h|0);h=x[31737];x[31737]=0;if((h|0)==1){break a}h=f;f=x[f>>2]+(c-g|0)|0;x[h>>2]=f;x[e>>2]=(b|0)==(c|0)?f:(b-a|0)+d|0;tb(j+4|0);fb=j+16|0;return}x[31737]=0;h=P(29,k|0,h<<24>>24)|0;i=x[31737];x[31737]=0;if((i|0)==1){break a}i=x[f>>2];x[f>>2]=i+1;v[i|0]=h;g=g+1|0;continue}}a=N()|0;tb(j+4|0);Q(a|0);p()}function Nfa(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0;j=fb-80|0;fb=j;a:{b:{c:{k=ir(1,32);d:{e:{if(!k){a=An(ac(4));x[31737]=0;S(98,a|0,125048,34);a=x[31737];x[31737]=0;if((a|0)!=1){break a}i=T(0)|0;break e}x[k+12>>2]=f;x[k+8>>2]=e;x[k+4>>2]=d;f=c?c:983;x[k>>2]=f;c=qg(j+68|0);f:{g:{h:{if(!i){break h}while(1){e=x[i>>2];if(!e){break h}l=x[i+4>>2];i:{if(l){x[31737]=0;e=P(36,j+56|0,e|0)|0;m=x[31737];x[31737]=0;j:{if((m|0)!=1){x[31737]=0;m=P(994,c|0,e|0)|0;n=x[31737];x[31737]=0;if((n|0)==1){break j}x[31737]=0;O(273,m|0,l|0);l=x[31737];x[31737]=0;if((l|0)==1){break j}break i}i=T(0)|0;break f}i=T(0)|0;tb(e);break f}x[31737]=0;e=P(36,j+44|0,e|0)|0;l=x[31737];x[31737]=0;if((l|0)==1){break g}gu(c,e)}tb(e);i=i+8|0;continue}}e=x[a+8>>2];i=x[a+4>>2];l=x[a>>2];x[31737]=0;a=R(856,104)|0;m=x[31737];x[31737]=0;k:{l:{m:{if((m|0)!=1){x[j+40>>2]=e;x[j+36>>2]=i;x[j+32>>2]=l;x[j+28>>2]=b;x[31737]=0;b=P(995,f|0,d|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break m}x[j+20>>2]=b;d=j+20|0;b=x[qe(j+24|0,d)>>2];e=x[j+40>>2];x[j+8>>2]=x[j+36>>2];x[j+12>>2]=e;x[31737]=0;e=x[j+32>>2];x[j>>2]=x[j+28>>2];x[j+4>>2]=e;b=ba(1025,a|0,j|0,b|0,c|0)|0;e=x[31737];x[31737]=0;if((e|0)!=1){break k}i=T(0)|0;Uc(d);break l}i=T(0)|0;break f}i=T(0)|0}Db(a);break f}x[k+28>>2]=b;Uc(j+20|0);x[k+24>>2]=b+8;Tl(c);break d}i=T(0)|0}Tl(c);Y(i|0)|0;x[31737]=0;V(989,11356,k|0,g|0,h|0);a=x[31737];x[31737]=0;if((a|0)!=1){x[31737]=0;X(26);a=x[31737];x[31737]=0;if((a|0)!=1){a=x[k+28>>2];if(a){ib[x[x[a>>2]+4>>2]](a)}x[k+24>>2]=0;x[k+28>>2]=0;a=x[k+20>>2];if(a){Db(a);x[k+20>>2]=0}Db(k);k=0;break d}i=T(0)|0;break e}i=T(0)|0;x[31737]=0;X(26);a=x[31737];x[31737]=0;if((a|0)==1){break b}}Y(i|0)|0;k=0;x[31737]=0;V(989,11356,0,g|0,h|0);a=x[31737];x[31737]=0;if((a|0)==1){break c}Z()}fb=j+80|0;return k|0}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)==1){break b}Q(a|0);p()}T(0)|0;Sb()}p()}function Y1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;d=fb-112|0;fb=d;xc(b);Rp(a);f=d+104|0;a:{if(!Bi(b,f)){break a}if(!iG(f)){break a}b:{if(!c){break b}if(!Mb(x[b>>2],x[b+8>>2],4)){break a}px(a);q=d,r=nx(),x[q+84>>2]=r;c=d+84|0;mx(lj(x[a+4>>2])+32|0,c);rs(c);l=x[lj(x[a+4>>2])+32>>2];c=Kh(x[b>>2]);if(c&1){break a}e=c-4|0;cd(b,e);f=fb-16|0;fb=f;c=f+13|0;ax(c,b);i=y[xb(c,0)|0];j=y[xb(c,1)|0];c=xb(c,2);fb=f+16|0;i=y[c|0]|(j<<8|i<<16);if(!i){break a}x[31737]=0;O(39,l|0,i|0);c=x[31737];x[31737]=0;c:{if((c|0)==1){b=T(125048)|0;if((gb|0)!=($(125048)|0)){break c}Y(b|0)|0;Z();break a}cd(b,4);k=d+84|0;hG(k,b,e);Rn(d- -64|0,k);lf(d+76|0,x[d+64>>2],x[d+68>>2]);c=x[d+80>>2];j=x[l>>2];e=fb-32|0;fb=e;b=x[d+76>>2];q=e,r=y[xb(b,0)|0],v[q+28|0]=r;q=e,r=y[xb(b,1)|0],v[q+29|0]=r;q=e,r=y[xb(b,2)|0],v[q+30|0]=r;q=e,r=y[xb(b,3)|0],v[q+31|0]=r;f=hs(e+12|0);c=b+c|0;x[f+12>>2]=c-4;x[f+8>>2]=b;ok(f,y[c-1|0]);m=j-1|0;c=i;d:while(1){e:{f:{g:{if(!c){break g}if(ok(f,1)){break f}b=1;while(1){g=ok(f,2);b=g+b|0;if((g|0)==3){continue}break}x[e+8>>2]=b;wc(e+8|0,c);b=0;g=x[e+8>>2];while(1)if((b|0)==(g|0)){if(!c){break g}break f}else{c=c-1|0;q=j+c|0,r=ok(f,8),v[q|0]=r;b=b+1|0;continue}}fb=e+32|0;break e}g=ok(f,2);b=g+2|0;x[e+8>>2]=b;h:{if((g|0)==3){i:{if(!ok(f,1)){b=5;g=7;break i}g=y[xb(e+28|0,3)|0]}g=ok(f,g);while(1){h=ok(f,3);b=h+b|0;if((h|0)==7){continue}break}x[e+8>>2]=b;break h}g=ok(f,y[xb(e+28|0,g)|0])}wc(e+8|0,c);b=0;n=x[e+8>>2];while(1){if((b|0)==(n|0)){continue d}o=c+m|0;h=c+g|0;if(i>>>0>h>>>0){h=y[j+h|0]}else{h=0}v[o|0]=h;b=b+1|0;c=c-1|0;continue}}break}re(d+24|0,x[l>>2],x[l+4>>2]);lf(d+32|0,x[d+24>>2],x[d+28>>2]);b=Nd(d+16|0);x[31737]=0;c=x[b+4>>2];x[d+8>>2]=x[b>>2];x[d+12>>2]=c;b=jg(161,d+44|0,x[d+32>>2],x[d+36>>2],d+8|0);c=x[31737];x[31737]=0;if((c|0)!=1){hd(lj(x[a+4>>2])+12|0,b);ub(b);Kc(k);break b}b=N()|0;Kc(d+84|0)}Q(b|0);p()}k=1}fb=d+112|0;return k|0}function zma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0;f=fb-48|0;fb=f;g=x[a+8>>2];p=g;h=x[a+12>>2];m=h;a:{b:{c:{d:{if((h|0)<=1&g>>>0<=805306368|(h|0)<=0){g=h;if((g|0)>-2){e=1}else{e=(g|0)>=-2&p>>>0>=3489660928}if(e){break c}if((m|0)==-2&p>>>0>2147483647|(m|0)==-1){break d}break b}if((m|0)==1&p>>>0>2147483648|m>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}u=b;y=x[a+16>>2];b=0;while(1){if((b|0)!=2){g=b<<3;h=g+(f+28|0)|0;g=a+g|0;x[h+4>>2]=x[g+44>>2];x[h+8>>2]=x[g+48>>2];b=b+1|0;continue}break}z=x[a+24>>2];A=x[a+20>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;B=x[a+72>>2];t=x[a+68>>2];C=t>>31;h=x[a+64>>2];E=h>>31;g=x[a+60>>2];F=g>>31;while(1){if(d){b=x[f+16>>2];G=(((x[f+20>>2]&2147483647)<<1|b>>>31)&-2)+y|0;b=(b>>>16&65520)+u|0;l=w[b+14>>1];q=w[b+12>>1];s=w[b+10>>1];i=w[b+8>>1];r=w[b+6>>1];k=w[b+4>>1];e=w[b+2>>1];b=w[b>>1];n=0;o=0;while(1){if((o|0)!=2){j=o+G|0;x[(f+8|0)+(o<<2)>>2]=(((((((D(v[j-4|0],e)+D(v[j-6|0],b)|0)+D(v[j-2|0],k)|0)+D(v[j|0],r)|0)+D(v[j+2|0],i)|0)+D(v[j+4|0],s)|0)+D(q,v[j+6|0])|0)+D(l,v[j+8|0])<<8)/32768;o=o+1|0;continue}break}while(1){if((n|0)!=2){q=(f+8|0)+(n<<2)|0;e=x[q>>2];b=(f+28|0)+(n<<3)|0;s=x[b+8>>2];i=x[b+4>>2];x[b+8>>2]=i;r=e<<8;e=r;e=Sua(e,e>>31,g,F);k=hb;j=e;e=Yb(i,-16777216,16776704);e=Sua(h,E,e,e>>31);i=j+e|0;l=hb+k|0;l=e>>>0>i>>>0?l+1|0:l;e=Yb(s,-16777216,16776704);k=Sua(t,C,e,e>>31);i=k+i|0;e=hb+l|0;e=i>>>0<k>>>0?e+1|0:e;k=i+8388608|0;e=k>>>0<8388608?e+1|0:e;e=Rc(k,e,24);x[b+4>>2]=e-(r&B);x[q>>2]=(e|0)/256;n=n+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[f+8>>2],A);x[c+4>>2]=x[c+4>>2]+D(x[f+12>>2],z);Pb(f+16|0,p,m);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+28|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}fb=f+48|0}function Nv(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if(!a){return Ed(b)}if(b>>>0>=4294967232){x[31612]=48;return 0}f=b>>>0<11?16:b+11&-8;e=a-8|0;i=x[e+4>>2];d=i&-8;a:{if(!(i&3)){if(f>>>0<256){break a}if(d>>>0>=f+4>>>0){c=e;if(d-f>>>0<=x[31733]<<1>>>0){break a}}c=0;break a}g=d+e|0;b:{if(d>>>0>=f>>>0){c=d-f|0;if(c>>>0<16){break b}x[e+4>>2]=i&1|f|2;d=e+f|0;x[d+4>>2]=c|3;x[g+4>>2]=x[g+4>>2]|1;Ev(d,c);break b}if(x[31619]==(g|0)){d=d+x[31616]|0;if(d>>>0<=f>>>0){break a}x[e+4>>2]=i&1|f|2;c=e+f|0;d=d-f|0;x[c+4>>2]=d|1;x[31616]=d;x[31619]=c;break b}if(x[31618]==(g|0)){d=d+x[31615]|0;if(d>>>0<f>>>0){break a}c=d-f|0;c:{if(c>>>0>=16){x[e+4>>2]=i&1|f|2;h=e+f|0;x[h+4>>2]=c|1;d=d+e|0;x[d>>2]=c;x[d+4>>2]=x[d+4>>2]&-2;break c}x[e+4>>2]=d|i&1|2;c=d+e|0;x[c+4>>2]=x[c+4>>2]|1;c=0}x[31618]=h;x[31615]=c;break b}h=x[g+4>>2];if(h&2){break a}j=d+(h&-8)|0;if(j>>>0<f>>>0){break a}l=j-f|0;d:{if(h>>>0<=255){c=x[g+12>>2];d=x[g+8>>2];if((c|0)==(d|0)){n=126452,o=x[31613]&Vua(-2,h>>>3|0),x[n>>2]=o;break d}x[d+12>>2]=c;x[c+8>>2]=d;break d}k=x[g+24>>2];d=x[g+12>>2];e:{if((g|0)!=(d|0)){c=x[g+8>>2];x[c+12>>2]=d;x[d+8>>2]=c;break e}f:{c=g+20|0;h=x[c>>2];if(!h){h=x[g+16>>2];if(!h){break f}c=g+16|0}while(1){m=c;d=h;c=d+20|0;h=x[c>>2];if(h){continue}c=d+16|0;h=x[d+16>>2];if(h){continue}break}x[m>>2]=0;break e}d=0}if(!k){break d}c=x[g+28>>2];h=(c<<2)+126756|0;g:{if(x[h>>2]==(g|0)){x[h>>2]=d;if(d){break g}n=126456,o=x[31614]&Vua(-2,c),x[n>>2]=o;break d}x[(x[k+16>>2]==(g|0)?16:20)+k>>2]=d;if(!d){break d}}x[d+24>>2]=k;c=x[g+16>>2];if(c){x[d+16>>2]=c;x[c+24>>2]=d}c=x[g+20>>2];if(!c){break d}x[d+20>>2]=c;x[c+24>>2]=d}if(l>>>0<=15){x[e+4>>2]=i&1|j|2;c=e+j|0;x[c+4>>2]=x[c+4>>2]|1;break b}x[e+4>>2]=i&1|f|2;c=e+f|0;x[c+4>>2]=l|3;d=e+j|0;x[d+4>>2]=x[d+4>>2]|1;Ev(c,l)}c=e}if(c){return c+8|0}c=Ed(b);if(!c){return 0}e=x[a-4>>2];e=(e&3?-4:-8)+(e&-8)|0;yc(c,a,b>>>0>e>>>0?e:b);Db(a);return c}function yP(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0;j=fb-80|0;fb=j;a:{b:{c:{d:{e:{f:{k=ir(1,28);if(!k){a=An(ac(4));x[31737]=0;S(98,a|0,125048,34);a=x[31737];x[31737]=0;if((a|0)!=1){break a}break f}x[k+12>>2]=f;x[k+8>>2]=e;x[k+4>>2]=d;f=c?c:983;x[k>>2]=f;c=qg(j+68|0);g:{h:{i:{if(!i){break i}while(1){e=x[i>>2];if(!e){break i}l=x[i+4>>2];j:{if(l){x[31737]=0;e=P(36,j+56|0,e|0)|0;m=x[31737];x[31737]=0;k:{if((m|0)!=1){x[31737]=0;m=P(994,c|0,e|0)|0;n=x[31737];x[31737]=0;if((n|0)==1){break k}x[31737]=0;O(273,m|0,l|0);l=x[31737];x[31737]=0;if((l|0)==1){break k}break j}i=T(0)|0;break g}i=T(0)|0;tb(e);break g}x[31737]=0;e=P(36,j+44|0,e|0)|0;l=x[31737];x[31737]=0;if((l|0)==1){break h}gu(c,e)}tb(e);i=i+8|0;continue}}e=x[a+8>>2];i=x[a+4>>2];l=x[a>>2];x[31737]=0;a=R(856,80)|0;m=x[31737];x[31737]=0;l:{m:{n:{if((m|0)!=1){x[j+40>>2]=e;x[j+36>>2]=i;x[j+32>>2]=l;x[j+28>>2]=b;x[31737]=0;b=P(995,f|0,d|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break n}x[j+20>>2]=b;b=j+20|0;d=x[qe(j+24|0,b)>>2];e=x[j+40>>2];x[j+8>>2]=x[j+36>>2];x[j+12>>2]=e;x[31737]=0;e=x[j+32>>2];x[j>>2]=x[j+28>>2];x[j+4>>2]=e;d=ba(996,a|0,j|0,d|0,c|0)|0;e=x[31737];x[31737]=0;if((e|0)!=1){break l}i=T(0)|0;Uc(b);break m}i=T(0)|0;break g}i=T(0)|0}Db(a);break g}x[k+24>>2]=d;Uc(j+20|0);Tl(c);i=k;break d}i=T(0)|0}Tl(c);Y(i|0)|0;x[31737]=0;V(989,15286,k|0,g|0,h|0);a=x[31737];x[31737]=0;if((a|0)!=1){x[31737]=0;X(26);a=x[31737];x[31737]=0;if((a|0)==1){break f}a=x[k+24>>2];if(a){Db(zq(a))}i=0;x[k+24>>2]=0;a=x[k+20>>2];if(a){Db(a);x[k+20>>2]=0}Db(k);break d}i=T(0)|0;x[31737]=0;X(26);a=x[31737];x[31737]=0;if((a|0)!=1){break e}break b}i=T(0)|0}Y(i|0)|0;i=0;x[31737]=0;V(989,15286,0,g|0,h|0);a=x[31737];x[31737]=0;if((a|0)==1){break c}Z()}fb=j+80|0;return i|0}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)==1){break b}Q(a|0);p()}T(0)|0;Sb()}p()}function Nu(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=D(c,872)+b|0;g=e+704|0;x[g>>2]=x[g>>2]|524288;a:{b:{if(!(y[a+480208|0]&8)){if(Ob(a+1074312|0,15)|x[a+480180>>2]==268435456){break b}break a}if(x[a+480180>>2]!=268435456){break a}}f=D(c,872)+b|0;d=d?d:y[(D(c,872)+b|0)+1427|0];v[f+1427|0]=d;v[f+1428|0]=d}if(d){w[(D(c,872)+b|0)+1384>>1]=d}c:{h=e+616|0;i=x[h+656>>2];if(Rj(i)){d=D(c,872)+b|0;a=z[d+1384>>1];if(!a){break c}e=0;f=x[b+16>>2];e=f?x[d+1472>>2]:e;k=+(f>>>0)+1;j=0-a|0;d=a;h=D(c,872)+b|0;f=h+1324|0;a=x[f>>2];k=k*+(((a|0)<0?j:d)|0)/+A[b+40>>2];d:{if(F(k)<2147483648){d=~~k;break d}d=-2147483648}h=h+1472|0;x[h>>2]=d;if(y[g+2|0]&16){d=D(x[x[i+44>>2]+36>>2]+1|0,d);x[h>>2]=d}d=d-e|0;g=d>>31;e=a>>31;if((e^a)-e>>>0<=(d^g)-g>>>0){if(!a){break c}b=D(c,872)+b|0;c=b+1468|0;x[c>>2]=a+x[c>>2];x[f>>2]=0;a=b+1467|0;v[a|0]=y[a|0]|64;return 0}b=D(c,872)+b|0;c=b+1468|0;x[c>>2]=d+x[c>>2];x[f>>2]=a-d;a=b+1467|0;v[a|0]=y[a|0]|64;break c}f=a+1074312|0;e:{if(!(!Ob(f,118)|!(y[g+1|0]&2))){d=0;if(Sc(y[(D(c,872)+b|0)+1404|0])){break e}}g=1;i=D(c,872)+b|0;e=i+1467|0;f:{if(!(v[e|0]&1)){break f}d=x[a+480180>>2];if(d&524352){break f}if(x[b+40>>2]==1){if(Ob(f,6)){break f}d=x[a+480180>>2]}g=0;if((d|0)!=8){break f}g=(y[a+480208|0]&2)>>>1|0}j=x[a+480180>>2];d=z[i+1384>>1];if(!((j|0)!=268435456|d>>>0<240)){g=v[e|0]&1;d=d-240|0}d=d<<((j|0)==64?1:2);i=D(c,872)+b|0;b=i+1316|0;g:{if(!x[b>>2]){break g}c=i+1324|0;if(!(x[c>>2]!=0&g)){break g}j=Gj(a)?d:0-d|0;l=x[b>>2];m=x[c>>2];if(!(!(y[e|0]&16)&(l|0)>=(m|0))){Ck(a,h,b,j,1);c=x[c>>2];if((c|0)>=x[b>>2]){break g}x[b>>2]=c;break g}if((l|0)<=(m|0)){break g}Ck(a,h,b,0-j|0,1);h=x[b>>2];c=x[c>>2];h:{if((h|0)<(c|0)){x[b>>2]=c;break h}if((c|0)!=(h|0)){break g}}if(!Ob(f,112)){break g}v[e|0]=y[e|0]|16}c=x[b>>2];b=i+1324|0;i:{if((c|0)!=x[b>>2]){break i}if(!Ob(f,25)&x[a+480180>>2]!=1){break i}x[b>>2]=0}d=g?d:0}return d}return 0}function ooa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;j=fb-16|0;fb=j;e=x[b>>2];d=Ik(e,x[b+4>>2]);a:{if(d>>>0<c>>>0){n=fb-32|0;fb=n;e=c-d|0;d=x[zb(b)>>2];f=x[b+4>>2];b:{if(e>>>0<=d-f>>4>>>0){f=fb-16|0;fb=f;e=gv(f+4|0,b,e);d=x[e+4>>2];g=x[e+8>>2];while(1){if((d|0)==(g|0)){hc(e);fb=f+16|0}else{Jr(d);d=d+16|0;x[e+4>>2]=d;continue}break}break b}d=zb(b);f=YV(n+12|0,ZV(b,Ik(x[b>>2],f)+e|0),Ik(x[b>>2],x[b+4>>2]),d);g=fb-16|0;fb=g;h=x[f+8>>2];d=g+4|0;x[d+8>>2]=f+8;x[d>>2]=h;x[d+4>>2]=h+(e<<4);e=x[d>>2];while(1){if(x[d+4>>2]!=(e|0)){Jr(e);e=x[d>>2]+16|0;x[d>>2]=e;continue}break}he(d);fb=g+16|0;k=fb-16|0;fb=k;d=vb(k+12|0,x[b+4>>2]);e=vb(k+8|0,x[b>>2]);i=x[vb(k+4|0,x[f+4>>2])>>2];l=fb-16|0;fb=l;o=l+8|0;g=fb-32|0;fb=g;Id(g+24|0,x[d>>2],x[e>>2]);p=g+16|0;d=x[g+24>>2];q=x[g+28>>2];h=fb-16|0;fb=h;x[h+8>>2]=i;x[h+12>>2]=d;while(1){if(pd(d,q)){e=kC(d);d=kC(x[h+8>>2]);i=y[e+12|0]|y[e+13|0]<<8|(y[e+14|0]<<16|y[e+15|0]<<24);m=y[e+8|0]|y[e+9|0]<<8|(y[e+10|0]<<16|y[e+11|0]<<24);v[d+8|0]=m;v[d+9|0]=m>>>8;v[d+10|0]=m>>>16;v[d+11|0]=m>>>24;v[d+12|0]=i;v[d+13|0]=i>>>8;v[d+14|0]=i>>>16;v[d+15|0]=i>>>24;i=y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24);e=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);v[d|0]=e;v[d+1|0]=e>>>8;v[d+2|0]=e>>>16;v[d+3|0]=e>>>24;v[d+4|0]=i;v[d+5|0]=i>>>8;v[d+6|0]=i>>>16;v[d+7|0]=i>>>24;d=$q(h+12|0);$q(h+8|0);d=x[d>>2];continue}break}Ac(p,d,h+8|0);fb=h+16|0;d=x[g+16>>2];x[g+12>>2]=x[g+20>>2];Ac(o,d,g+12|0);fb=g+32|0;fb=l+16|0;x[f+4>>2]=x[l+12>>2];Tb(b,f+4|0);Tb(b+4|0,f+8|0);Tb(zb(b),nc(f));x[f>>2]=x[f+4>>2];fb=k+16|0;d=x[f+4>>2];e=x[f+8>>2];while(1){if((d|0)!=(e|0)){e=e-16|0;x[f+8>>2]=e;continue}break}d=x[f>>2];if(d){ys(f);Db(d)}}fb=n+32|0;break a}if(c>>>0<d>>>0){_V(b,e+(c<<4)|0)}}if(Mb(x[a>>2],x[a+8>>2],c<<4)){c=x[b>>2];bc(j+8|0,c,Ik(c,x[b+4>>2])<<4);rd(j,a,x[j+8>>2],x[j+12>>2])}fb=j+16|0}function Ala(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;j=fb-16|0;fb=j;c=Hf(a,c);$d(j,x[a+36>>2]);a:{if(!c){Pc(j,a+32|0,5);f=0;if(Hb(x[x[j>>2]>>2],x[j+4>>2])){break a}}f=fb-240|0;fb=f;h=Pm(f+128|0,x[a+36>>2]);x[31737]=0;g=P(462,f+116|0,26216)|0;e=x[31737];x[31737]=0;b:{c:{d:{e:{if((e|0)!=1){x[31737]=0;x[f+96>>2]=20054022;x[f+100>>2]=0;S(463,h|0,g|0,f+96|0);e=x[31737];x[31737]=0;if((e|0)==1){break e}Eb(g);if(!vl(y[h|0])){break d}break b}a=N()|0;break c}a=N()|0;Eb(g);break c}v[f+115|0]=0;x[31737]=0;g=P(462,f+96|0,5505)|0;e=x[31737];x[31737]=0;f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{if((e|0)!=1){x[31737]=0;S(464,h|0,f+115|0,g|0);e=x[31737];x[31737]=0;if((e|0)==1){break p}Eb(g);g=Fb(f+84|0);x[31737]=0;e=P(462,f+72|0,10110)|0;i=x[31737];x[31737]=0;if((i|0)==1){break o}x[31737]=0;S(789,h|0,g|0,e|0);i=x[31737];x[31737]=0;if((i|0)==1){break n}Eb(e);x[31737]=0;e=f+60|0;S(259,e|0,(y[f+115|0]?0:d)|0,g|0);d=x[31737];x[31737]=0;if((d|0)==1){break m}tp(b,e);tb(e);w[f+58>>1]=0;x[31737]=0;d=P(462,f+44|0,10799)|0;e=x[31737];x[31737]=0;if((e|0)==1){break g}x[31737]=0;e=f+58|0;U(492,h|0,e|0,d|0)|0;i=x[31737];x[31737]=0;if((i|0)==1){break l}Eb(d);Gf(e,4e3);x[31737]=0;d=P(462,f+32|0,13557)|0;e=x[31737];x[31737]=0;if((e|0)==1){break k}i=z[f+58>>1];e=x[vb(f+28|0,i)>>2];x[31737]=0;V(790,h|0,b|0,d|0,e|0);e=x[31737];x[31737]=0;if((e|0)==1){break j}Eb(d);w[f+26>>1]=65535;x[31737]=0;d=P(462,f+12|0,8980)|0;e=x[31737];x[31737]=0;if((e|0)==1){break i}x[31737]=0;k=U(492,h|0,f+26|0,d|0)|0;e=x[31737];x[31737]=0;if((e|0)==1){break h}e=z[f+26>>1];Eb(d);if(e>>>0<i>>>0&k){af(b,e)}tb(g);break b}a=N()|0;break c}a=N()|0;Eb(g);break c}a=N()|0;break f}a=N()|0;Eb(e);break f}a=N()|0;break f}a=N()|0;Eb(d);break f}a=N()|0;break f}a=N()|0;Eb(d);break f}a=N()|0;break f}a=N()|0;Eb(d);break f}a=N()|0}tb(g)}Ah(h);Q(a|0);p()}Ah(h);fb=f+240|0;f=c}ff(a,f);fb=j+16|0}function Eta(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0;d=fb-1104|0;fb=d;x[d+1100>>2]=c;i=aE(d+40|0,b);r=Gr(i);f=Nb(a);x[31737]=0;a=R(203,b|0)|0;c=x[31737];x[31737]=0;a:{if((c|0)!=1){x[d+12>>2]=a;x[d+36>>2]=85899345;a=d+12|0;t=d,u=D(x[Gb(a,d+36|0)>>2],50),x[t+24>>2]=u;c=d+24|0;e=x[Gb(d+1100|0,c)>>2];x[31737]=0;O(329,f|0,e|0);e=x[31737];x[31737]=0;if((e|0)!=1){x[31737]=0;h=R(341,c|0)|0;c=x[31737];x[31737]=0;if((c|0)!=1){x[31737]=0;g=P(342,a|0,8192)|0;a=x[31737];x[31737]=0;b:{if((a|0)!=1){a=x[h>>2];c=0;while(1){if((c|0)!=256){e=yb(a,c);v[e+2|0]=c;w[e>>1]=8192;c=c+1|0;continue}break}m=9;c:{d:while(1){e=0;n=257;while(1){s=m&255;e:{while(1){j=n&65535;while(1){x[31737]=0;o=P(159,i|0,s|0)|0;a=x[31737];x[31737]=0;if((a|0)==1){break c}k=o&65535;if((k|0)==257|j>>>0<k>>>0){break e}if(Vc(x[f>>2],x[f+4>>2])>>>0>=A[d+1100>>2]){break e}if((k|0)==256){m=9;continue d}c=j>>>0>k>>>0?o:e;a=x[h>>2];l=8192;while(1){c=c&65535;a=yb(a,c);l=l-1|0;q=l&65535;t=xb(x[g>>2],q),u=y[a+2|0],v[t|0]=u;a=x[h>>2];c=z[yb(a,c)>>1];if(c>>>0<8192){continue}break}a=vb(d+8|0,wb(x[f+4>>2]));c=uf(wb(x[g>>2]),q);l=wb(x[g+4>>2]);a=x[a>>2];x[31737]=0;V(330,f|0,a|0,c|0,l|0);a=x[31737];x[31737]=0;if((a|0)==1){break c}f:{if((j|0)!=(k|0)){break f}a=x[g>>2];x[31737]=0;O(343,f|0,xb(a,q)|0);a=x[31737];x[31737]=0;if((a|0)!=1){break f}break c}if(j>>>0>=8192){e=o;continue}if(Vc(x[f>>2],x[f+4>>2])>>>0>=A[d+1100>>2]){continue}break}a=y[xb(x[g>>2],q)|0];c=yb(x[h>>2],j);w[c>>1]=e;v[c+2|0]=a;a=n+1|0;n=8192;e=o;c=a&65535;if((c|0)==8192){continue}break}m=((c|0)==1<<s)+m|0;n=a;continue}break}break}a=Gr(i);x[31737]=0;P(150,b|0,((a-r|0)+3&-4)+r|0)|0;a=x[31737];x[31737]=0;if((a|0)==1){break c}dc(g);vc(h);ub(i);fb=d+1104|0;return}c=N()|0;dc(g);break b}c=N()|0}vc(h);break a}c=N()|0;break a}c=N()|0;break a}c=N()|0}dc(f);ub(i);Q(c|0);p()}function yU(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0;c=fb-176|0;fb=c;e=x[a+12>>2];j=1<<e;a:{if(!(e&1)){h=j>>>2|0;l=1;break a}l=j>>>1|0;e=0;while(1){if((e|0)==(l|0)){h=j>>>3|0;l=2;e=x[a+12>>2]}else{i=x[b>>2];h=Xd(i,e+l|0);d=Xd(i,e);o=C[h>>3];p=C[h+8>>3];Fj(c+160|0,d,o,p);i=x[c+172>>2];x[h+8>>2]=x[c+168>>2];x[h+12>>2]=i;i=x[c+164>>2];x[h>>2]=x[c+160>>2];x[h+4>>2]=i;xA(Xd(x[b>>2],e),o,p);e=e+1|0;continue}break}}i=e&-2;b:while(1){if(i){w=D(h,3);y=h<<1;j=0;c:while(1){if((j|0)==(l|0)){i=i-2|0;h=h>>>2|0;l=l<<2;continue b}d=x[a>>2];e=Xd(d,j<<1);d=Xd(d,j);o=C[d>>3];p=C[d+8>>3];r=C[e>>3];s=C[e+8>>3];Si(c+160|0,o,p,r,s);e=j<<i;d=h+e|0;z=d>>>0<e>>>0?e:d;while(1)if((e|0)==(z|0)){j=j+1|0;continue c}else{f=x[b>>2];d=Xd(f,e);g=x[d+12>>2];x[c+152>>2]=x[d+8>>2];x[c+156>>2]=g;g=x[d+4>>2];x[c+144>>2]=x[d>>2];x[c+148>>2]=g;g=c+128|0;t=e+h|0;k=Xd(f,t);Si(g,r,s,C[k>>3],C[k+8>>3]);u=e+y|0;k=Xd(f,u);Si(c+112|0,o,p,C[k>>3],C[k+8>>3]);m=C[c+160>>3];n=C[c+168>>3];v=e+w|0;f=Xd(f,v);Si(c+96|0,m,n,C[f>>3],C[f+8>>3]);k=c+80|0;f=c+144|0;m=C[c+112>>3];n=C[c+120>>3];Kl(k,f,m,n);q=c- -64|0;Fj(q,f,m,n);m=C[c+96>>3];n=C[c+104>>3];Kl(c+48|0,g,m,n);f=c+16|0;Wl(f,-0,-1);Fj(c,g,m,n);Si(c+32|0,C[c+16>>3],C[c+24>>3],C[c>>3],C[c+8>>3]);Kl(f,k,C[c+48>>3],C[c+56>>3]);g=x[c+28>>2];x[d+8>>2]=x[c+24>>2];x[d+12>>2]=g;g=x[c+20>>2];x[d>>2]=x[c+16>>2];x[d+4>>2]=g;Fj(f,k,C[c+48>>3],C[c+56>>3]);d=Xd(x[b>>2],t);g=x[c+28>>2];x[d+8>>2]=x[c+24>>2];x[d+12>>2]=g;g=x[c+20>>2];x[d>>2]=x[c+16>>2];x[d+4>>2]=g;Kl(f,q,C[c+32>>3],C[c+40>>3]);d=Xd(x[b>>2],u);g=x[c+28>>2];x[d+8>>2]=x[c+24>>2];x[d+12>>2]=g;g=x[c+20>>2];x[d>>2]=x[c+16>>2];x[d+4>>2]=g;Fj(f,q,C[c+32>>3],C[c+40>>3]);d=Xd(x[b>>2],v);f=x[c+28>>2];x[d+8>>2]=x[c+24>>2];x[d+12>>2]=f;f=x[c+20>>2];x[d>>2]=x[c+16>>2];x[d+4>>2]=f;e=e+1|0;continue}}}break}fb=c+176|0}function PO(a,b,c){a=a|0;b=E(b);c=c|0;var d=0,e=E(0),f=E(0),g=E(0),h=E(0),i=E(0),k=E(0),m=0,n=0,o=0;d=fb-16|0;fb=d;a:{b:{c:{d:{switch(c-1|0){case 0:a=(q(b),j(2));e:{f:{g:{if((a|0)<=8388607){e=E(E(-1)/E(b*b));if(!((q(b),j(2))&2147483647)){break e}e=E(E(b-b)/E(0));if((a|0)<0){break e}a=(q(E(b*E(33554432))),j(2));c=-152;break g}if(a>>>0>2139095039){break f}c=-127;b=E(0);if((a|0)==1065353216){break f}}a=a+4913933|0;k=E((a>>>23|0)+c|0);b=E((l(2,(a&8388607)+1060439283|0),r())+E(-1));f=E(b*E(b*E(.5)));g=E(b/E(b+E(2)));h=E(g*g);i=E(h*h);e=b;b=(l(2,(q(E(b-f)),j(2))&-4096),r());f=E(E(g*E(f+E(E(h*E(E(i*E(.2849878668785095))+E(.6666666269302368)))+E(i*E(E(i*E(.24279078841209412))+E(.40000972151756287))))))+E(E(e-b)-f));b=E(E(k*E(.3010292053222656))+E(E(b*E(.434326171875))+E(E(f*E(.434326171875))+E(E(k*E(7.903415166765626e-7))+E(E(f+b)*E(-3168997136526741e-20))))))}e=b}b=E(e*E(2e3));if(!(E(F(b))<E(2147483648))){break c}a=~~b;break b;case 1:a=(D(x[a+24604>>2],100)|0)/128|0;break b;case 2:c=fb-16|0;fb=c;h:{i:{j:{k:{a=y[a+24648|0];if(a>>>0>=6){a=ac(8);x[31737]=0;c=P(36,c+4|0,5123)|0;d=x[31737];x[31737]=0;if((d|0)==1){break k}pc(a,c);x[31737]=0;S(98,a|0,48540,1006);a=x[31737];x[31737]=0;if((a|0)!=1){break i}d=N()|0;tb(c);break j}fb=c+16|0;a=x[(a<<2)+79592>>2];break h}d=N()|0;jc(a)}Q(d|0)}p()}break b;case 3:x[d+4>>2]=0;m=x[a+24640>>2];c=fb-80|0;fb=c;a=x[a+24636>>2];x[c+40>>2]=a;x[c>>2]=m;n=c+40|0;o=x[Ye(n,c)>>2];l:{if((a|0)==x[Xq(n)+32>>2]){a=-1;if(x[Xq(c)+36>>2]==(m|0)){break l}}a=0;if((o|0)<=0){break l}a=(o+500>>>0)/1e3|0}x[d+4>>2]=a;fb=c+80|0;a=x[d+4>>2];break b;default:break d}}c=ac(8);x[31737]=0;d=P(36,d+4|0,10401)|0;a=x[31737];x[31737]=0;m:{if((a|0)!=1){pc(c,d);x[31737]=0;S(98,c|0,48540,1006);a=x[31737];x[31737]=0;if((a|0)!=1){break a}a=N()|0;tb(d);break m}a=N()|0;jc(c)}Q(a|0);p()}a=-2147483648}fb=d+16|0;return a|0}p()}function sP(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=fb-96|0;fb=d;g=x[b+4>>2];a:{if(!g){break a}e=x[b>>2];f=y[Gl(e,g)|0];if((f|0)==33){c=1}else{if((f|0)!=63){break a}c=0}Sl(d+72|0,e,g,g-1|0);g=x[d+76>>2];e=x[d+72>>2];x[b>>2]=e;x[b+4>>2]=g}e=d+72|0;ge(e);f=x[d+72>>2];ge(d+60|0);f=Fl(f,x[d+64>>2],b);ge(e);b:{c:{d:{e:{if((f|0)==x[d+76>>2]){a=x[b>>2];f=qc(d+88|0,22303);h=x[f+4>>2];x[d>>2]=x[f>>2];x[d+4>>2]=h;if(Ic(a,g,d)){a=ac(8);x[31737]=0;c=P(36,e|0,10498)|0;b=x[31737];x[31737]=0;if((b|0)==1){break d}pc(a,c);x[31737]=0;S(98,a|0,48540,1006);a=x[31737];x[31737]=0;if((a|0)!=1){break b}b=N()|0;tb(c);break c}e=0;f=0;if(!c){break e}a=ac(8);c=x[b+4>>2];b=x[b>>2];x[31737]=0;e=fi(d+60|0,b,c);b=x[31737];x[31737]=0;f:{g:{h:{if((b|0)!=1){x[31737]=0;g=d+72|0;S(1017,g|0,18318,e|0);b=x[31737];x[31737]=0;if((b|0)==1){break h}pc(a,g);c=0;x[31737]=0;S(98,a|0,48540,1006);b=x[31737];x[31737]=0;if((b|0)!=1){break b}b=N()|0;tb(g);break g}b=N()|0;break f}b=N()|0;c=1}tb(e);if(!c){break c}}jc(a);break c}if(x[f+4>>2]!=1){a=ac(8);x[31737]=0;c=P(36,d+72|0,11600)|0;b=x[31737];x[31737]=0;if((b|0)!=1){pc(a,c);x[31737]=0;S(98,a|0,48540,1006);a=x[31737];x[31737]=0;if((a|0)!=1){break b}b=N()|0;tb(c);break c}b=N()|0;jc(a);break c}b=x[b>>2];c=qc(d+52|0,22303);e=x[c+4>>2];x[d+24>>2]=x[c>>2];x[d+28>>2]=e;if(Ic(b,g,d+24|0)){a=ac(8);x[31737]=0;c=P(36,d+72|0,10498)|0;b=x[31737];x[31737]=0;if((b|0)!=1){pc(a,c);x[31737]=0;S(98,a|0,48540,1006);a=x[31737];x[31737]=0;if((a|0)!=1){break b}b=N()|0;tb(c);break c}b=N()|0;jc(a);break c}c=qc(d+44|0,10990);e=x[c+4>>2];x[d+16>>2]=x[c>>2];x[d+20>>2]=e;if(Ic(b,g,d+16|0)){e=x[a+8>>2];f=e>>31;break e}c=qc(d+36|0,8643);e=x[c+4>>2];x[d+8>>2]=x[c>>2];x[d+12>>2]=e;e=0;f=0;if(!Ic(b,g,d+8|0)){break e}e=yk(y[x[a+32>>2]+140|0]);f=0}fb=d+96|0;hb=f;return e|0}b=N()|0;jc(a)}Q(b|0)}p()}function rP(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=fb-96|0;fb=e;f=x[c+4>>2];a:{if(!f){g=x[c>>2];break a}g=x[c>>2];h=y[Gl(g,f)|0];if((h|0)==33){d=1}else{if((h|0)!=63){break a}d=0}Sl(e+72|0,g,f,f-1|0);f=x[e+76>>2];g=x[e+72>>2];x[c>>2]=g;x[c+4>>2]=f}i=e+72|0;ge(i);h=x[e+72>>2];ge(e+60|0);h=Fl(h,x[e+64>>2],c);ge(i);b:{c:{d:{e:{if(x[e+76>>2]==(h|0)){h=qc(e+88|0,22303);b=x[h+4>>2];x[e>>2]=x[h>>2];x[e+4>>2]=b;if(Ic(g,f,e)){c=ac(8);x[31737]=0;b=P(36,i|0,10498)|0;a=x[31737];x[31737]=0;if((a|0)==1){break d}pc(c,b);x[31737]=0;S(98,c|0,48540,1006);a=x[31737];x[31737]=0;if((a|0)!=1){break b}f=N()|0;tb(b);break c}if(d){g=ac(8);b=x[c>>2];a=x[c+4>>2];x[31737]=0;d=fi(e+60|0,b,a);a=x[31737];x[31737]=0;f:{g:{h:{if((a|0)!=1){x[31737]=0;b=e+72|0;S(1017,b|0,18318,d|0);a=x[31737];x[31737]=0;if((a|0)==1){break h}pc(g,b);c=0;x[31737]=0;S(98,g|0,48540,1006);a=x[31737];x[31737]=0;if((a|0)!=1){break b}f=N()|0;tb(b);break g}f=N()|0;break f}f=N()|0;c=1}tb(d);if(!c){break c}}jc(g);break c}Fb(a);break e}d=qc(e+52|0,22303);c=x[d+4>>2];x[e+24>>2]=x[d>>2];x[e+28>>2]=c;if(Ic(g,f,e+24|0)){c=ac(8);x[31737]=0;b=P(36,e+72|0,10498)|0;a=x[31737];x[31737]=0;if((a|0)!=1){pc(c,b);x[31737]=0;S(98,c|0,48540,1006);a=x[31737];x[31737]=0;if((a|0)!=1){break b}f=N()|0;tb(b);break c}f=N()|0;jc(c);break c}d=qc(e+44|0,12437);c=x[d+4>>2];x[e+16>>2]=x[d>>2];x[e+20>>2]=c;if(Ic(g,f,e+16|0)){i:{switch(x[b+52>>2]){case 0:Dc(a,5601);break e;case 1:Dc(a,11301);break e;case 2:Dc(a,9222);break e;default:break i}}Fb(a);break e}d=qc(e+36|0,11538);c=x[d+4>>2];x[e+8>>2]=x[d>>2];x[e+12>>2]=c;if(Ic(g,f,e+8|0)){j:{switch(x[b+56>>2]){case 0:Dc(a,15670);break e;case 1:Dc(a,15675);break e;case 2:Dc(a,12711);break e;case 3:Dc(a,9286);break e;default:break j}}Fb(a);break e}Fb(a)}fb=e+96|0;return}f=N()|0;jc(c)}Q(f|0)}p()}function s7(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;a=fb-1056|0;fb=a;x[a+16>>2]=f;x[a+20>>2]=g;x[a+24>>2]=h;x[a+28>>2]=i;k=a+944|0;x[a+940>>2]=k;j=Fy(k,100,11198,a+16|0);x[a+48>>2]=1199;l=a+48|0;o=Be(a+520|0,0,l);x[a+48>>2]=1199;l=Be(a+512|0,0,l);a:{b:{c:{d:{if(j>>>0<100){h=a+528|0;break d}j=Od();x[a>>2]=f;x[a+4>>2]=g;x[a+8>>2]=h;x[a+12>>2]=i;j=rj(a+940|0,j,11198,a);if((j|0)!=-1){k=x[a+940>>2];Se(o,k);Se(l,Ed(j<<2));h=x[l>>2];if(!Mj(h)){break d}}x[31737]=0;X(1200);a=x[31737];x[31737]=0;if((a|0)!=1){break a}j=N()|0;break c}bd(a+508|0,x[d+28>>2]);x[31737]=0;r=R(1211,x[a+508>>2])|0;f=x[31737];x[31737]=0;e:{f:{g:{h:{i:{j:{if((f|0)==1){break j}x[31737]=0;V(1222,r|0,k|0,j+k|0,h|0);f=x[31737];x[31737]=0;if((f|0)==1){break j}q=(j|0)>0?y[x[a+940>>2]]==45:q;i=Fb(a+484|0);f=Fb(a+472|0);g=Fb(a+460|0);x[31737]=0;ka(1250,c|0,q|0,x[a+508>>2],a+504|0,a+500|0,a+496|0,i|0,f|0,g|0,a+456|0);c=x[31737];x[31737]=0;if((c|0)==1){break i}x[a+36>>2]=1199;c=Be(a+40|0,0,a+36|0);k=a+48|0;n=x[a+456>>2];k:{if((n|0)<(j|0)){m=((Cb(x[g+4>>2],y[g+11|0])+(j-n<<1)|0)+Cb(x[f+4>>2],y[f+11|0])|0)+1|0;break k}m=(Cb(x[g+4>>2],y[g+11|0])+Cb(x[f+4>>2],y[f+11|0])|0)+2|0}m=m+n|0;if(m>>>0<101){break h}Se(c,Ed(m<<2));k=x[c>>2];if(k){break h}x[31737]=0;X(1200);b=x[31737];x[31737]=0;if((b|0)!=1){break a}break g}j=N()|0;break e}j=N()|0;break f}m=x[d+4>>2];x[31737]=0;ma(1251,k|0,a+36|0,a+32|0,m|0,h|0,(j<<2)+h|0,r|0,q|0,a+504|0,x[a+500>>2],x[a+496>>2],i|0,f|0,g|0,n|0);h=x[31737];x[31737]=0;if((h|0)!=1){x[31737]=0;b=ea(1231,b|0,k|0,x[a+36>>2],x[a+32>>2],d|0,e|0)|0;d=x[31737];x[31737]=0;if((d|0)!=1){break b}}}j=N()|0;Lc(c)}Ub(g);Ub(f);tb(i)}Zb(a+508|0)}Lc(l);Lc(o);Q(j|0);p()}Lc(c);Ub(g);Ub(f);tb(i);Zb(a+508|0);Lc(l);Lc(o);fb=a+1056|0;return b|0}p()}function $fa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=fb-96|0;fb=d;f=1;g=x[c+4>>2];h=y[c+11|0];a:{if(Ad(g,h)){break a}e=y[wz(c)|0];if((e|0)!=33){if((e|0)!=63){break a}f=0}e=d+84|0;tx(e,c,0,Yc(g,h)-1|0);Ab(c,e);tb(e)}e=d+84|0;ge(e);g=x[d+84>>2];ge(d+72|0);g=bN(g,x[d+76>>2],c);ge(e);b:{c:{d:{e:{f:{if((g|0)==x[d+88>>2]){if(Ld(c,22303)){a=ac(8);x[31737]=0;b=P(36,e|0,10498)|0;c=x[31737];x[31737]=0;if((c|0)==1){break d}pc(a,b);x[31737]=0;S(98,a|0,48540,1006);a=x[31737];x[31737]=0;if((a|0)!=1){break b}c=N()|0;tb(b);break c}if(!f){break f}a=ac(8);x[31737]=0;b=d+84|0;S(1008,b|0,18318,c|0);c=x[31737];x[31737]=0;if((c|0)!=1){pc(a,b);x[31737]=0;S(98,a|0,48540,1006);a=x[31737];x[31737]=0;if((a|0)!=1){break b}c=N()|0;tb(b);break c}c=N()|0;jc(a);break c}e=Fb(d+84|0);g:{h:{i:{j:{switch(x[g+4>>2]){case 0:ee(d- -64|0,c);x[31737]=0;c=x[d+68>>2];x[d+8>>2]=x[d+64>>2];x[d+12>>2]=c;b=U(1009,b|0,d+8|0,f|0)|0;c=x[31737];x[31737]=0;if((c|0)!=1){x[31737]=0;v[d+72|0]=b;O(1010,a|0,d+72|0);a=x[31737];x[31737]=0;if((a|0)!=1){break g}}break i;case 1:ee(d+56|0,c);x[31737]=0;c=x[d+60>>2];x[d+16>>2]=x[d+56>>2];x[d+20>>2]=c;b=lI(b,d+16|0,f);c=hb;f=x[31737];x[31737]=0;if((f|0)!=1){x[31737]=0;x[d+72>>2]=b;x[d+76>>2]=c;O(1012,a|0,d+72|0);a=x[31737];x[31737]=0;if((a|0)!=1){break g}}break i;case 2:ee(d+48|0,c);x[31737]=0;c=x[d+52>>2];x[d+24>>2]=x[d+48>>2];x[d+28>>2]=c;i=+oa(1013,b|0,d+24|0,f|0);b=x[31737];x[31737]=0;if((b|0)!=1){x[31737]=0;C[d+72>>3]=i;O(1014,a|0,d+72|0);a=x[31737];x[31737]=0;if((a|0)!=1){break g}}break i;case 3:break j;default:break h}}ee(d+40|0,c);x[31737]=0;c=x[d+44>>2];x[d+32>>2]=x[d+40>>2];x[d+36>>2]=c;V(1015,a|0,b|0,d+32|0,f|0);a=x[31737];x[31737]=0;if((a|0)!=1){break g}}c=N()|0;tb(e);break c}_c(a,e)}tb(e);break e}Fb(a)}fb=d+96|0;return}c=N()|0;jc(a)}Q(c|0)}p()}function kra(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=x[a>>2];b=Jv(e,x[a+4>>2]);if(b>>>0<=63){h=fb-32|0;fb=h;g=64-b|0;b=x[zb(a)>>2];c=x[a+4>>2];a:{if(g>>>0<=(b-c|0)/33>>>0){e=fb-16|0;fb=e;b=e+4|0;x[b>>2]=a;a=x[a+4>>2];x[b+4>>2]=a;x[b+8>>2]=a+D(g,33);c=x[b+4>>2];a=x[b+8>>2];while(1){if((a|0)==(c|0)){hc(b);fb=e+16|0}else{ZY(c);c=c+33|0;x[b+4>>2]=c;continue}break}break a}i=zb(a);e=h+12|0;f=Jv(x[a>>2],c)+g|0;c=fb-16|0;fb=c;x[c+12>>2]=f;d=fb-16|0;fb=d;x[d+12>>2]=130150524;x[d+8>>2]=2147483647;b=x[Gb(d+12|0,d+8|0)>>2];fb=d+16|0;b:{if(b>>>0>=f>>>0){d=bZ(a);if(d>>>0<b>>>1>>>0){x[c+8>>2]=d<<1;b=x[ad(c+8|0,c+12|0)>>2]}fb=c+16|0;break b}dd();p()}f=Jv(x[a>>2],x[a+4>>2]);d=fb-16|0;fb=d;Kg(e+12|0,i);c:{if(!b){c=0;b=0;break c}if(b>>>0>=130150525){Zj();p()}c=Ec(D(b,33));x[d+12>>2]=b;x[d+8>>2]=c;c=x[d+12>>2];b=x[d+8>>2]}x[e>>2]=b;f=b+D(f,33)|0;x[e+8>>2]=f;x[e+4>>2]=f;l=nc(e),m=b+D(c,33)|0,x[l>>2]=m;fb=d+16|0;d=fb-16|0;fb=d;c=x[e+8>>2];b=d+4|0;x[b+8>>2]=e+8;x[b>>2]=c;x[b+4>>2]=c+D(g,33);c=x[b>>2];while(1){if(x[b+4>>2]!=(c|0)){ZY(c);c=x[b>>2]+33|0;x[b>>2]=c;continue}break}he(b);fb=d+16|0;g=fb-16|0;fb=g;b=vb(g+12|0,x[a+4>>2]);d=vb(g+8|0,x[a>>2]);i=x[vb(g+4|0,x[e+4>>2])>>2];f=fb-16|0;fb=f;c=fb-32|0;fb=c;Id(c+24|0,x[b>>2],x[d>>2]);j=c+16|0;b=x[c+24>>2];k=x[c+28>>2];d=fb-16|0;fb=d;x[d+8>>2]=i;x[d+12>>2]=b;while(1){if(pd(b,k)){b=$Y(b);yc($Y(x[d+8>>2]),b,33);b=_Y(d+12|0);_Y(d+8|0);b=x[b>>2];continue}break}Ac(j,b,d+8|0);fb=d+16|0;b=x[c+16>>2];x[c+12>>2]=x[c+20>>2];Ac(f+8|0,b,c+12|0);fb=c+32|0;fb=f+16|0;x[e+4>>2]=x[f+12>>2];Tb(a,e+4|0);Tb(a+4|0,e+8|0);Tb(zb(a),nc(e));x[e>>2]=x[e+4>>2];fb=g+16|0;b=x[e+4>>2];a=x[e+8>>2];while(1){if((a|0)!=(b|0)){a=a-33|0;x[e+8>>2]=a;continue}break}a=x[e>>2];if(a){nc(e);Db(a)}}fb=h+32|0;return}if((b|0)!=64){aZ(a,e+2112|0)}}function ema(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0;f=fb-48|0;fb=f;v=x[a+16>>2];while(1){if((g|0)!=2){j=g<<3;m=j+(f+28|0)|0;j=a+j|0;x[m+4>>2]=x[j+44>>2];x[m+8>>2]=x[j+48>>2];g=g+1|0;continue}break}n=x[a+40>>2];o=x[a+36>>2];j=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=j;y=b+24|0;z=x[a+32>>2];A=x[a+28>>2];B=x[a+72>>2];t=x[a+68>>2];C=t>>31;u=x[a+64>>2];E=u>>31;m=x[a+60>>2];F=m>>31;j=x[a+8>>2];G=x[a+12>>2];while(1){if(d){b=x[f+16>>2];H=((((x[f+20>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+v|0;b=(((b>>>16|0)+4&131064)<<1)+y|0;l=w[b+14>>1];q=w[b+12>>1];s=w[b+10>>1];h=w[b+8>>1];r=w[b+6>>1];k=w[b+4>>1];e=w[b+2>>1];b=w[b>>1];g=0;p=0;while(1){if((p|0)!=2){i=H+(p<<1)|0;x[(f+8|0)+(p<<2)>>2]=(((((D(w[i+8>>1],s)+D(w[i+4>>1],h)|0)+D(q,w[i+12>>1])|0)+D(l,w[i+16>>1])|0)/2|0)+((((D(w[i-8>>1],e)+D(w[i-12>>1],b)|0)+D(w[i-4>>1],k)|0)+D(w[i>>1],r)|0)/2|0)|0)/16384;p=p+1|0;continue}break}while(1){if((g|0)!=2){q=(f+8|0)+(g<<2)|0;e=x[q>>2];b=(f+28|0)+(g<<3)|0;s=x[b+8>>2];h=x[b+4>>2];x[b+8>>2]=h;r=e<<8;e=r;e=Sua(e,e>>31,m,F);k=hb;i=e;e=Yb(h,-16777216,16776704);e=Sua(u,E,e,e>>31);h=i+e|0;l=hb+k|0;l=e>>>0>h>>>0?l+1|0:l;e=Yb(s,-16777216,16776704);k=Sua(t,C,e,e>>31);h=k+h|0;e=hb+l|0;e=h>>>0<k>>>0?e+1|0:e;k=h+8388608|0;e=k>>>0<8388608?e+1|0:e;e=Rc(k,e,24);x[b+4>>2]=e-(r&B);x[q>>2]=(e|0)/256;g=g+1|0;continue}break}o=o+A|0;x[c>>2]=x[c>>2]+D(x[f+8>>2],o>>12);n=n+z|0;x[c+4>>2]=x[c+4>>2]+D(x[f+12>>2],n>>12);Pb(f+16|0,j,G);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;x[a+40>>2]=n;x[a+20>>2]=o>>12;x[a+36>>2]=o;x[a+24>>2]=n>>12;g=0;while(1){if((g|0)!=2){b=g<<3;c=b+a|0;b=b+(f+28|0)|0;x[c+44>>2]=x[b+4>>2];x[c+48>>2]=x[b+8>>2];g=g+1|0;continue}break}fb=f+48|0}function zW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c=x[a>>2];e=Th(c,x[a+4>>2]);if(e>>>0<b>>>0){h=fb-32|0;fb=h;g=b-e|0;b=x[zb(a)>>2];c=x[a+4>>2];a:{if(g>>>0<=b-c>>8>>>0){e=fb-16|0;fb=e;b=e+4|0;x[b>>2]=a;a=x[a+4>>2];x[b+4>>2]=a;x[b+8>>2]=a+(g<<8);a=x[b+4>>2];c=x[b+8>>2];while(1){if((a|0)==(c|0)){hc(b);fb=e+16|0}else{aW(a);a=a+256|0;x[b+4>>2]=a;continue}break}break a}i=zb(a);e=h+12|0;f=Th(x[a>>2],c)+g|0;c=fb-16|0;fb=c;x[c+12>>2]=f;d=fb-16|0;fb=d;x[d+12>>2]=16777215;x[d+8>>2]=2147483647;b=x[Gb(d+12|0,d+8|0)>>2];fb=d+16|0;b:{if(b>>>0>=f>>>0){d=lC(a);if(d>>>0<b>>>1>>>0){x[c+8>>2]=d<<1;b=x[ad(c+8|0,c+12|0)>>2]}fb=c+16|0;break b}dd();p()}f=Th(x[a>>2],x[a+4>>2]);d=fb-16|0;fb=d;Kg(e+12|0,i);c:{if(!b){c=0;b=0;break c}if(b>>>0>=16777216){Zj();p()}c=Ec(b<<8);x[d+12>>2]=b;x[d+8>>2]=c;c=x[d+8>>2];b=x[d+12>>2]}x[e>>2]=c;f=c+(f<<8)|0;x[e+8>>2]=f;x[e+4>>2]=f;l=nc(e),m=c+(b<<8)|0,x[l>>2]=m;fb=d+16|0;d=fb-16|0;fb=d;b=x[e+8>>2];c=d+4|0;x[c+8>>2]=e+8;x[c>>2]=b;x[c+4>>2]=b+(g<<8);b=x[c>>2];while(1){if(x[c+4>>2]!=(b|0)){aW(b);b=x[c>>2]+256|0;x[c>>2]=b;continue}break}he(c);fb=d+16|0;g=fb-16|0;fb=g;c=vb(g+12|0,x[a+4>>2]);d=vb(g+8|0,x[a>>2]);i=x[vb(g+4|0,x[e+4>>2])>>2];f=fb-16|0;fb=f;b=fb-32|0;fb=b;Id(b+24|0,x[c>>2],x[d>>2]);j=b+16|0;d=x[b+24>>2];k=x[b+28>>2];c=fb-16|0;fb=c;x[c+8>>2]=i;x[c+12>>2]=d;while(1){if(pd(d,k)){d=cW(d);yc(cW(x[c+8>>2]),d,256);d=bW(c+12|0);bW(c+8|0);d=x[d>>2];continue}break}Ac(j,d,c+8|0);fb=c+16|0;c=x[b+16>>2];x[b+12>>2]=x[b+20>>2];Ac(f+8|0,c,b+12|0);fb=b+32|0;fb=f+16|0;x[e+4>>2]=x[f+12>>2];Tb(a,e+4|0);Tb(a+4|0,e+8|0);Tb(zb(a),nc(e));x[e>>2]=x[e+4>>2];fb=g+16|0;b=x[e+4>>2];a=x[e+8>>2];while(1){if((a|0)!=(b|0)){a=a-256|0;x[e+8>>2]=a;continue}break}a=x[e>>2];if(a){nc(e);Db(a)}}fb=h+32|0;return}if(b>>>0<e>>>0){dW(a,c+(b<<8)|0)}}function w7(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;a=fb-448|0;fb=a;x[a+16>>2]=f;x[a+20>>2]=g;x[a+24>>2]=h;x[a+28>>2]=i;k=a+336|0;x[a+332>>2]=k;j=Fy(k,100,11198,a+16|0);x[a+48>>2]=1199;l=a+48|0;o=Be(a+216|0,0,l);x[a+48>>2]=1199;l=Be(a+208|0,0,l);a:{b:{c:{d:{if(j>>>0<100){h=a+224|0;break d}j=Od();x[a>>2]=f;x[a+4>>2]=g;x[a+8>>2]=h;x[a+12>>2]=i;j=rj(a+332|0,j,11198,a);if((j|0)!=-1){k=x[a+332>>2];Se(o,k);Se(l,Ed(j));h=x[l>>2];if(!Mj(h)){break d}}x[31737]=0;X(1200);a=x[31737];x[31737]=0;if((a|0)!=1){break a}j=N()|0;break c}bd(a+204|0,x[d+28>>2]);x[31737]=0;r=R(28,x[a+204>>2])|0;f=x[31737];x[31737]=0;e:{f:{g:{h:{i:{j:{if((f|0)==1){break j}x[31737]=0;V(1209,r|0,k|0,j+k|0,h|0);f=x[31737];x[31737]=0;if((f|0)==1){break j}q=(j|0)>0?y[x[a+332>>2]]==45:q;i=Fb(a+184|0);f=Fb(a+172|0);g=Fb(a+160|0);x[31737]=0;ka(1248,c|0,q|0,x[a+204>>2],a+200|0,a+199|0,a+198|0,i|0,f|0,g|0,a+156|0);c=x[31737];x[31737]=0;if((c|0)==1){break i}x[a+36>>2]=1199;c=Be(a+40|0,0,a+36|0);k=a+48|0;n=x[a+156>>2];k:{if((n|0)<(j|0)){m=((Cb(x[g+4>>2],y[g+11|0])+(j-n<<1)|0)+Cb(x[f+4>>2],y[f+11|0])|0)+1|0;break k}m=(Cb(x[g+4>>2],y[g+11|0])+Cb(x[f+4>>2],y[f+11|0])|0)+2|0}m=m+n|0;if(m>>>0<101){break h}Se(c,Ed(m));k=x[c>>2];if(k){break h}x[31737]=0;X(1200);b=x[31737];x[31737]=0;if((b|0)!=1){break a}break g}j=N()|0;break e}j=N()|0;break f}m=x[d+4>>2];x[31737]=0;ma(1249,k|0,a+36|0,a+32|0,m|0,h|0,h+j|0,r|0,q|0,a+200|0,v[a+199|0],v[a+198|0],i|0,f|0,g|0,n|0);h=x[31737];x[31737]=0;if((h|0)!=1){x[31737]=0;b=ea(23,b|0,k|0,x[a+36>>2],x[a+32>>2],d|0,e|0)|0;d=x[31737];x[31737]=0;if((d|0)!=1){break b}}}j=N()|0;Lc(c)}tb(g);tb(f);tb(i)}Zb(a+204|0)}Lc(l);Lc(o);Q(j|0);p()}Lc(c);tb(g);tb(f);tb(i);Zb(a+204|0);Lc(l);Lc(o);fb=a+448|0;return b|0}p()}function fma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0;f=fb-48|0;fb=f;y=x[a+16>>2];while(1){if((g|0)!=2){j=g<<3;m=j+(f+28|0)|0;j=a+j|0;x[m+4>>2]=x[j+44>>2];x[m+8>>2]=x[j+48>>2];g=g+1|0;continue}break}n=x[a+40>>2];o=x[a+36>>2];j=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=j;z=b+24|0;A=x[a+32>>2];B=x[a+28>>2];C=x[a+72>>2];t=x[a+68>>2];E=t>>31;u=x[a+64>>2];F=u>>31;m=x[a+60>>2];G=m>>31;j=x[a+8>>2];H=x[a+12>>2];while(1){if(d){b=x[f+16>>2];I=(((x[f+20>>2]&2147483647)<<1|b>>>31)&-2)+y|0;b=(((b>>>16|0)+4&131064)<<1)+z|0;l=w[b+14>>1];q=w[b+12>>1];s=w[b+10>>1];h=w[b+8>>1];r=w[b+6>>1];k=w[b+4>>1];e=w[b+2>>1];b=w[b>>1];g=0;p=0;while(1){if((p|0)!=2){i=p+I|0;x[(f+8|0)+(p<<2)>>2]=((((D(v[i+4|0],s)+D(v[i+2|0],h)|0)+D(q,v[i+6|0])|0)+D(l,v[i+8|0])<<8>>1)+(((D(v[i-4|0],e)+D(v[i-6|0],b)|0)+D(v[i-2|0],k)|0)+D(v[i|0],r)<<8>>1)|0)/16384;p=p+1|0;continue}break}while(1){if((g|0)!=2){q=(f+8|0)+(g<<2)|0;e=x[q>>2];b=(f+28|0)+(g<<3)|0;s=x[b+8>>2];h=x[b+4>>2];x[b+8>>2]=h;r=e<<8;e=r;e=Sua(e,e>>31,m,G);k=hb;i=e;e=Yb(h,-16777216,16776704);e=Sua(u,F,e,e>>31);h=i+e|0;l=hb+k|0;l=e>>>0>h>>>0?l+1|0:l;e=Yb(s,-16777216,16776704);k=Sua(t,E,e,e>>31);h=k+h|0;e=hb+l|0;e=h>>>0<k>>>0?e+1|0:e;k=h+8388608|0;e=k>>>0<8388608?e+1|0:e;e=Rc(k,e,24);x[b+4>>2]=e-(r&C);x[q>>2]=(e|0)/256;g=g+1|0;continue}break}o=o+B|0;x[c>>2]=x[c>>2]+D(x[f+8>>2],o>>12);n=n+A|0;x[c+4>>2]=x[c+4>>2]+D(x[f+12>>2],n>>12);Pb(f+16|0,j,H);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;x[a+40>>2]=n;x[a+20>>2]=o>>12;x[a+36>>2]=o;x[a+24>>2]=n>>12;g=0;while(1){if((g|0)!=2){b=g<<3;c=b+a|0;b=b+(f+28|0)|0;x[c+44>>2]=x[b+4>>2];x[c+48>>2]=x[b+8>>2];g=g+1|0;continue}break}fb=f+48|0}function Lfa(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0;k=fb-48|0;fb=k;a:{b:{c:{j=ir(1,32);d:{e:{if(!j){a=An(ac(4));x[31737]=0;S(98,a|0,125048,34);a=x[31737];x[31737]=0;if((a|0)!=1){break a}i=T(0)|0;break e}x[j+12>>2]=f;x[j+8>>2]=e;x[j+4>>2]=d;f=c?c:983;x[j>>2]=f;c=qg(k+36|0);f:{g:{h:{if(!i){break h}while(1){e=x[i>>2];if(!e){break h}l=x[i+4>>2];i:{if(l){x[31737]=0;e=P(36,k+24|0,e|0)|0;m=x[31737];x[31737]=0;j:{if((m|0)!=1){x[31737]=0;m=P(994,c|0,e|0)|0;n=x[31737];x[31737]=0;if((n|0)==1){break j}x[31737]=0;O(273,m|0,l|0);l=x[31737];x[31737]=0;if((l|0)==1){break j}break i}i=T(0)|0;break f}i=T(0)|0;tb(e);break f}x[31737]=0;e=P(36,k+12|0,e|0)|0;l=x[31737];x[31737]=0;if((l|0)==1){break g}gu(c,e)}tb(e);i=i+8|0;continue}}x[31737]=0;e=R(856,104)|0;i=x[31737];x[31737]=0;k:{l:{m:{if((i|0)!=1){x[31737]=0;d=P(995,f|0,d|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break m}x[k+4>>2]=d;d=k+4|0;f=x[qe(k+8|0,d)>>2];x[31737]=0;a=ha(1026,e|0,a|0,b|0,f|0,c|0)|0;b=x[31737];x[31737]=0;if((b|0)!=1){break k}i=T(0)|0;Uc(d);break l}i=T(0)|0;break f}i=T(0)|0}Db(e);break f}x[j+28>>2]=a;Uc(k+4|0);x[j+24>>2]=a+8;Tl(c);break d}i=T(0)|0}Tl(c);Y(i|0)|0;x[31737]=0;V(989,4973,j|0,g|0,h|0);a=x[31737];x[31737]=0;if((a|0)!=1){x[31737]=0;X(26);a=x[31737];x[31737]=0;if((a|0)!=1){a=x[j+28>>2];if(a){ib[x[x[a>>2]+4>>2]](a)}x[j+24>>2]=0;x[j+28>>2]=0;a=x[j+20>>2];if(a){Db(a);x[j+20>>2]=0}Db(j);j=0;break d}i=T(0)|0;break e}i=T(0)|0;x[31737]=0;X(26);a=x[31737];x[31737]=0;if((a|0)==1){break b}}Y(i|0)|0;j=0;x[31737]=0;V(989,4973,0,g|0,h|0);a=x[31737];x[31737]=0;if((a|0)==1){break c}Z()}fb=k+48|0;return j|0}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)==1){break b}Q(a|0);p()}T(0)|0;Sb()}p()}function k7(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;q=fb-16|0;fb=q;i=c;while(1){a:{if((d|0)==(i|0)){i=d;break a}if(!y[i|0]){break a}i=i+1|0;continue}break}x[h>>2]=f;x[e>>2]=c;while(1){b:{c:{d:{if((c|0)==(d|0)|(f|0)==(g|0)){break d}k=x[b+4>>2];x[q+8>>2]=x[b>>2];x[q+12>>2]=k;r=fb-16|0;fb=r;u=Nh(r+12|0,x[a+8>>2]);o=i-c|0;l=0;n=fb-1040|0;fb=n;k=x[e>>2];x[n+12>>2]=k;p=f?f:n+16|0;m=f?g-f>>2:256;e:{f:{g:{if(!(!k|!m)){while(1){j=o>>>2|0;if(!(o>>>0>131|j>>>0>=m>>>0)){j=k;break f}s=DK(p,n+12|0,j>>>0<m>>>0?j:m,b);j=x[n+12>>2];if((s|0)==-1){m=0;l=-1;break g}t=(n+16|0)!=(p|0)?s:0;m=m-t|0;p=(t<<2)+p|0;o=j?(k+o|0)-j|0:0;l=l+s|0;if(!j){break g}k=j;if(m){continue}break g}}j=k}if(!j){break e}}if(!m|!o){break e}k=l;while(1){h:{l=xt(p,j,o,b);i:{if(l+2>>>0<=2){j:{switch(l+1|0){case 1:x[n+12>>2]=0;break i;case 0:break e;default:break j}}x[b>>2]=0;break i}j=x[n+12>>2]+l|0;x[n+12>>2]=j;k=k+1|0;m=m-1|0;if(m){break h}}l=k;break e}p=p+4|0;o=o-l|0;l=k;if(o){continue}break}}if(f){x[e>>2]=x[n+12>>2]}fb=n+1040|0;Mh(u);fb=r+16|0;k:{l:{m:{n:{if((l|0)==-1){while(1){o:{x[h>>2]=f;if(x[e>>2]==(c|0)){break o}g=1;p:{q:{r:{b=ey(f,c,i-c|0,q+8|0,x[a+8>>2]);switch(b+2|0){case 0:break l;case 2:break p;case 1:break r;default:break q}}x[e>>2]=c;break n}g=b}c=c+g|0;f=x[h>>2]+4|0;continue}break}x[e>>2]=c;break d}f=x[h>>2]+(l<<2)|0;x[h>>2]=f;if((f|0)==(g|0)){break k}c=x[e>>2];if((d|0)==(i|0)){i=d;continue}if(!ey(f,c,1,b,x[a+8>>2])){break m}}a=2;break c}x[h>>2]=x[h>>2]+4;c=x[e>>2]+1|0;x[e>>2]=c;i=c;while(1){if((d|0)==(i|0)){i=d;break b}if(!y[i|0]){break b}i=i+1|0;continue}}x[e>>2]=c;a=1;break c}c=x[e>>2]}a=(c|0)!=(d|0)}fb=q+16|0;return a|0}f=x[h>>2];continue}}function XR(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=fb-16|0;fb=f;e=D(b,872)+a|0;j=e+1074992|0;a:{b:{i=x[e+1075080>>2];if(i&131072){e=x[a+480180>>2];i=1;c:{d:{e:{h=x[a+480208>>2];if(h&4096){if(!(e&16777248)){break e}i=!(h&4)}if((e|0)!=64){break d}break b}if((e|0)==64){break b}h=a+480180|0;i=0;break c}h=a+480180|0;if(!i){break c}Kb(f+8|0,a+1074312|0,21);if(!Hb(x[x[f+8>>2]>>2],x[f+12>>2])){break c}e=D(b,872)+a|0;g=e+1075811|0;v[g|0]=y[g|0]+(y[e+1075815|0]<<2)}g=D(b,872)+a|0;k=g+1075814|0;l=g+1075811|0;e=IA(a,y[k|0],y[l|0]);f:{if(Rj(x[j+656>>2])){B[d>>2]=B[d>>2]+E(E(E(D(y[g+1075816|0],e)|0)*E(.05000000074505806))/E(7680));c=g+1075843|0;d=y[c|0];v[c|0]=d&159|64;if(x[a+1074416>>2]!=(x[a+1074392>>2]+1|0)){break f}v[c|0]=d|96;break f}d=x[a+480208>>2];if((d&2101248)==2101248){break a}g=x[h>>2];if(d&4096?g&67633152:0){break a}if(g&5){e=(y[k|0]&3)==1?0-e|0:e}k=a+1074312|0;Kb(f+8|0,k,21);g=x[a+480208>>2];g:{if(Hb(x[x[f+8>>2]>>2],x[f+12>>2])){d=g&4;e=d?e:0-e|0;d=d?5:6;break g}d=5;h:{if(g&131072){break h}h=x[h>>2];d=8;if((h|0)==1024){break h}d=7;if(h&524304){break h}d=h&16777248?g&4?6:7:6}Kb(f+8|0,k,80);if(!Hb(x[x[f+8>>2]>>2],x[f+12>>2])){break g}d=y[(D(b,872)+a|0)+1075783|0]==26?d+2|0:d}d=0-((D(y[(D(b,872)+a|0)+1075816|0],e)|0)/(1<<d)|0)|0;Ck(a,j,c,d,0);e=x[j+656>>2];c=Iq(a,x[j+88>>2],e);if(!c){break f}ib[x[x[c>>2]+92>>2]](c,d,(e?v[e+33|0]:2)<<24>>24,b)}if(!i){break a}Kb(f+8|0,a+1074312|0,21);if(Hb(x[x[f+8>>2]>>2],x[f+12>>2])){break a}v[l|0]=y[l|0]+y[(D(b,872)+a|0)+1075815|0];break a}if(!(y[e+1075662|0]&2)){break a}a=Iq(a,i,x[j+656>>2]);if(!a){break a}ib[x[x[a>>2]+92>>2]](a,0,0,b);break a}a=D(b,872)+a|0;b=a+1075811|0;d=y[b|0];if(d&1){x[c>>2]=x[c>>2]+D(y[a+1075816|0],167)}v[b|0]=d+1}fb=f+16|0}function WX(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=fb-16|0;fb=f;v[a|0]=0;c=y[b|0];if(c){v[a|0]=c>>>0>96?-1:c+12|0}v[a+1|0]=y[b+1|0];c=y[b+2|0];a:{b:{if((c-16&255)>>>0<=128){v[a+2|0]=1;c=c+496>>>1|0;break b}c:{switch((c+96&240)>>>4|0){case 0:v[a+2|0]=4;c=c&15;break b;case 1:v[a+2|0]=3;c=c&15;break b;case 2:v[a+2|0]=6;c=c&15;break b;case 3:break c;default:break a}}v[a+2|0]=5;c=c&15}v[a+4|0]=c}c=y[b+6|0];d=y[b+5|0];e=y[b+4|0];d:{if(!(c|(d|e))){break d}e:{f:{g:{h:{i:{j:{switch(e|0){default:k:{switch(e-29|0){case 7:break f;case 5:break g;case 3:break h;case 0:break i;case 1:case 2:case 4:case 6:break d;default:break k}}if((e|0)==128){break e}if((e|0)!=157){break d}v[a+2|0]=15;v[a+3|0]=20;v[a+4|0]=c>>>3;v[f+15|0]=15;h=a,i=y[Qb(b+5|0,f+15|0)|0]|208,v[h+5|0]=i;break d;case 0:Bf(a,c,d);g=y[b+6|0]==15;break d;case 1:v[a+3|0]=2;h=a,i=Ch(c<<4|(d&240)>>>4),v[h+5|0]=i;break d;case 2:v[a+3|0]=3;h=a,i=Ch(c<<4|(d&240)>>>4),v[h+5|0]=i;break d;case 3:v[a+3|0]=4;h=a,i=Ch(c<<4|(d&240)>>>4),v[h+5|0]=i;break d;case 4:v[a+3|0]=5;v[a+5|0]=c&240|(d&240)>>>4;break d;case 8:if(d){v[a+5|0]=d;v[a+3|0]=9;break d}if((c-1&255)>>>0>1){break d}v[a+5|0]=145;v[a+3|0]=20;break d;case 12:v[a+3|0]=13;v[a+5|0]=c>>>1;break d;case 15:if(c){v[a+5|0]=c;v[a+3|0]=17;break d}v[a+3|0]=16;v[a+5|0]=d&15;break d;case 16:break j;case 5:case 6:case 7:case 9:case 10:case 11:case 13:case 14:break d}}xD(a,c,d,1);g=(y[a+3|0]&254)==16;break d}v[a+5|0]=d;v[a+3|0]=18;break d}v[a+3|0]=31;v[a+5|0]=c>>>1;break d}v[a+3|0]=31;v[a+5|0]=c>>>1&120;break d}v[a+5|0]=159;v[a+3|0]=20;break d}v[a+3|0]=21;v[a+5|0]=c>>>2}b=y[b+3|0];l:{if(!b){break l}if(!y[a+3|0]){v[a+5|0]=b;v[a+3|0]=9;break l}if(y[a+2|0]){break l}v[a+2|0]=2;v[a+4|0]=b>>>2}fb=f+16|0;return g}function xP(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0;k=fb-48|0;fb=k;a:{b:{c:{d:{e:{f:{j=ir(1,28);if(!j){a=An(ac(4));x[31737]=0;S(98,a|0,125048,34);a=x[31737];x[31737]=0;if((a|0)!=1){break a}break f}x[j+12>>2]=f;x[j+8>>2]=e;x[j+4>>2]=d;f=c?c:983;x[j>>2]=f;c=qg(k+36|0);g:{h:{i:{if(!i){break i}while(1){e=x[i>>2];if(!e){break i}l=x[i+4>>2];j:{if(l){x[31737]=0;e=P(36,k+24|0,e|0)|0;m=x[31737];x[31737]=0;k:{if((m|0)!=1){x[31737]=0;m=P(994,c|0,e|0)|0;n=x[31737];x[31737]=0;if((n|0)==1){break k}x[31737]=0;O(273,m|0,l|0);l=x[31737];x[31737]=0;if((l|0)==1){break k}break j}i=T(0)|0;break g}i=T(0)|0;tb(e);break g}x[31737]=0;e=P(36,k+12|0,e|0)|0;l=x[31737];x[31737]=0;if((l|0)==1){break h}gu(c,e)}tb(e);i=i+8|0;continue}}x[31737]=0;e=R(856,80)|0;i=x[31737];x[31737]=0;l:{m:{n:{if((i|0)!=1){x[31737]=0;d=P(995,f|0,d|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break n}x[k+4>>2]=d;d=k+4|0;f=x[qe(k+8|0,d)>>2];x[31737]=0;a=ha(1e3,e|0,a|0,b|0,f|0,c|0)|0;b=x[31737];x[31737]=0;if((b|0)!=1){break l}i=T(0)|0;Uc(d);break m}i=T(0)|0;break g}i=T(0)|0}Db(e);break g}x[j+24>>2]=a;Uc(k+4|0);Tl(c);i=j;break d}i=T(0)|0}Tl(c);Y(i|0)|0;x[31737]=0;V(989,15185,j|0,g|0,h|0);a=x[31737];x[31737]=0;if((a|0)!=1){x[31737]=0;X(26);a=x[31737];x[31737]=0;if((a|0)==1){break f}a=x[j+24>>2];if(a){Db(zq(a))}i=0;x[j+24>>2]=0;a=x[j+20>>2];if(a){Db(a);x[j+20>>2]=0}Db(j);break d}i=T(0)|0;x[31737]=0;X(26);a=x[31737];x[31737]=0;if((a|0)!=1){break e}break b}i=T(0)|0}Y(i|0)|0;i=0;x[31737]=0;V(989,15185,0,g|0,h|0);a=x[31737];x[31737]=0;if((a|0)==1){break c}Z()}fb=k+48|0;return i|0}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)==1){break b}Q(a|0);p()}T(0)|0;Sb()}p()}function sX(a,b,c,d,e,f){var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;l=fb-16|0;fb=l;g=x[b>>2];h=x[b+4>>2];a:{if((h|0)==(f|0)){j=gc(l+8|0,e,f);b=fb-16|0;fb=b;c=qn(c,d,g,f);x[b+12>>2]=c;e=x[j>>2];b:{if((c|0)<=0){break b}if(f){d=32-f|0;x[b+8>>2]=d;h=c;c=x[ud(b+8|0,b+12|0)>>2];x[b+12>>2]=h-c;d=-1<<f&-1>>>d-c;x[e>>2]=x[e>>2]&(d^-1)|d&x[g>>2];c=c+x[j+4>>2]|0;x[j+4>>2]=c&31;e=(c>>>3&536870908)+e|0;x[j>>2]=e;g=g+4|0;c=x[b+12>>2]}d=(c|0)/32|0;iD(g,d,e);c=c-(d<<5)|0;x[b+12>>2]=c;d=d<<2;e=d+x[j>>2]|0;x[j>>2]=e;if((c|0)<=0){break b}c=-1>>>32-c|0;x[e>>2]=x[e>>2]&(c^-1)|c&x[d+g>>2];x[j+4>>2]=x[b+12>>2]}gc(a,e,x[j+4>>2]);fb=b+16|0;break a}j=a;i=gc(l,e,f);f=fb-16|0;fb=f;e=qn(c,d,g,h);x[f+12>>2]=e;c:{if((e|0)<=0){a=x[i+4>>2];b=x[i>>2];break c}d:{if(!h){a=x[i+4>>2];break d}k=32-h|0;x[f+8>>2]=k;c=f+8|0;b=x[ud(c,f+12|0)>>2];x[f+12>>2]=e-b;a=x[i+4>>2];e=x[g>>2];x[f+8>>2]=b;m=32-a|0;x[f+4>>2]=m;d=x[i>>2];n=x[d>>2];c=x[Gb(c,f+4|0)>>2];e=e&(-1<<h&-1>>>k-b);x[d>>2]=(-1<<a&-1>>>m-c^-1)&n|(a>>>0>h>>>0?e<<a-h:e>>>h-a|0);k=a+c|0;a=k&31;x[i+4>>2]=a;d=d+(k>>>3&536870908)|0;x[i>>2]=d;b=b-c|0;if((b|0)>0){x[d>>2]=x[d>>2]&(-1>>>32-b^-1)|e>>>c+h;x[i+4>>2]=b;a=b}g=g+4|0;e=x[f+12>>2]}c=32-a|0;d=-1<<a;h=d^-1;while(1){if((e|0)>=32){b=x[i>>2];e=x[g>>2];x[b>>2]=h&x[b>>2]|e<<a;x[i>>2]=b+4;x[b+4>>2]=d&x[b+4>>2]|e>>>c;e=x[f+12>>2]-32|0;x[f+12>>2]=e;g=g+4|0;continue}break}b=x[i>>2];if((e|0)<=0){break c}g=x[g>>2];x[f+8>>2]=c;k=x[b>>2];h=c;c=x[ud(f+12|0,f+8|0)>>2];e=g&-1>>>32-e;x[b>>2]=k&(d&-1>>>h-c^-1)|e<<a;d=a+c|0;a=d&31;x[i+4>>2]=a;b=(d>>>3&536870908)+b|0;x[i>>2]=b;d=x[f+12>>2]-c|0;x[f+12>>2]=d;if((d|0)<=0){break c}x[b>>2]=x[b>>2]&(-1>>>32-d^-1)|e>>>c;a=x[f+12>>2];x[i+4>>2]=a}gc(j,b,a);fb=f+16|0}fb=l+16|0}function Dg(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0;i=x[a+8>>2]+(D(z[a+14>>1],(y[a+80|0]?c:0)+b|0)>>>1|0)|0;x[a+8>>2]=i;g=y[a+79|0]?z[x[a>>2]+3836>>1]:g;c=z[a+20>>1];h=z[a+22>>1];k=z[a+70>>1];a:{b:{c:{d:{switch(x[a+16>>2]){case 1:b=z[x[a>>2]+3832>>1];f=c+(b&z[a+46>>1]?0:z[a+26>>1]?z[a+48>>1]>>>z[x[a+52>>2]+((b>>>z[a+44>>1]&7)<<1)>>1]|0:0)|0;w[a+20>>1]=f;b=2;j=z[a+28>>1];if((j|0)<=f<<16>>16){break c}break b;case 2:if(y[a+78|0]){break b}case 3:b=0;f=z[x[a>>2]+3832>>1];f=c+(f&z[a+58>>1]?0:z[a+30>>1]?z[a+60>>1]>>>z[x[a+64>>2]+((f>>>z[a+56>>1]&7)<<1)>>1]|0:0)|0;w[a+20>>1]=f;if(f<<16>>16<511){break b}x[a+16>>2]=-1;w[a+20>>1]=511;x[a+72>>2]=0;break a;default:b=0;x[a+72>>2]=0;break a;case 0:break d}}b=1;f=z[x[a>>2]+3832>>1];f=c+(f&z[a+34>>1]?0:z[a+24>>1]?D((c^-1)<<16>>16,z[a+36>>1]>>>z[x[a+40>>2]+((f>>>z[a+32>>1]&7)<<1)>>1]|0)>>>3|0:0)|0;w[a+20>>1]=f;if(f<<16>>16>0){break b}}x[a+16>>2]=b;w[a+20>>1]=j}h=((c+h|0)+k|0)+g<<3;if(e){d=(w[a+74>>1]+w[a+72>>1]>>e)+d|0}d=(i>>>10|0)+d|0;c=d&255;b=d&65535;e:{f:{switch(z[a+12>>1]){case 0:g=(b&512)>>>9|0;b=z[((b&256?c^255:c)<<1)+26816>>1];break e;case 1:g=0;b=z[((b&512?0:b&256?c^255:c)<<1)+26816>>1];break e;case 2:g=0;b=z[((b&256?c^255:c)<<1)+26816>>1];break e;case 3:g=0;b=z[((b&256?0:c)<<1)+26816>>1];break e;case 4:g=0;if(b&512){b=0}else{g=(d&256)>>>8|0;b=(c<<1^b<<24>>31)&254}b=z[(b<<1)+26816>>1];break e;case 5:g=0;if(b&512){b=0}else{c=c<<1&254;b=b&128?c^255:c}b=z[(b<<1)+26816>>1];break e;case 6:g=(d&512)>>>9|0;b=0;break e;default:break f}}c=d<<3&4088;g=(b&512)>>>9|0;b=g?c^4088:c}w[a+74>>1]=z[a+72>>1];c=a;a=b+h&65535;a=a>>>0>=8191?8191:a;b=0-(g&1)^z[((a&255)<<1)+26304>>1]+1024>>>(a>>>8)<<1;w[c+72>>1]=b}return b<<16>>16}function RS(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;c=fb-16|0;fb=c;d=a+1074376|0;e=D(b,872);a:{if(x[(d+e|0)+704>>2]&67109888){break a}f=a+e|0;g=x[f+1075648>>2];if(!Ij(g)|y[g+15|0]&2){break a}d=vm(a,d,b,2,1)-1|0;if((d&255)>>>0>249){break a}h=x[vd(a+906300|0,d)>>2];if(!h){break a}d=f;j=d+1075780|0;e=y[j|0];b:{if(y[d+1075782|0]==1){v[c+8|0]=64;d=y[Qb(d+1075784|0,c+8|0)|0];break b}f=y[d+1075783|0];if((f|0)!=46){d=255;if((f|0)!=13){break b}v[c+8|0]=64;d=y[Qb((D(b,872)+a|0)+1075785|0,c+8|0)|0];break b}d=y[(D(b,872)+a|0)+1075785|0]+3>>>2|0}i=a+1074312|0;Kb(c+8|0,i,2);if(Hb(x[x[c+8>>2]>>2],x[c+12>>2])){if(e){if(Sc(e)){e=y[xb(g+108|0,e-1|0)|0]}bn(a,b,e&255,z[(D(b,872)+a|0)+1075680>>1]);break a}if((d|0)==255){break a}ib[x[x[h>>2]+76>>2]](h,39,d,b);break a}k=x[g+4>>2];c:{if(!e){break c}f=y[g+35|0]?k<<2:x[(D(b,872)+a|0)+1075680>>2];l=w[(D(b,872)+a|0)+1075768>>1];Kb(c+8|0,i,28);m=c,n=f+(Hb(x[x[c+8>>2]>>2],x[c+12>>2])?l<<2:l)|0,x[m+4>>2]=n;Fe(c+4|0,0,256);f=e;if(Sc(e)){f=y[xb(g+108|0,e-1|0)|0]}Kb(c+8|0,i,117);if(!Hb(x[x[c+8>>2]>>2],x[c+12>>2])){if(Ql(y[j+2|0],y[j+3|0])){break c}}bn(a,b,f&255,z[c+4>>1])}a=y[g+35|0];Kb(c+8|0,i,101);a=(a|0)==1;f=(d|0)!=255;if(!Hb(x[x[c+8>>2]>>2],x[c+12>>2])){e=Sc(e)}if(((e?a:f)|0)!=1){break a}d:{switch(y[g+36|0]){case 1:a=x[h+20>>2];if((d|0)!=255){Hu(a,E(E(E(d<<1)/E(-127))+E(1)));break a}Hu(a,E(E(E(k<<1>>>0)/E(-127))+E(1)));break a;case 0:break d;default:break a}}if((d|0)!=255){v[c+8|0]=127;v[c+4|0]=d<<1;n=h,o=7,p=y[Qb(c+8|0,c+4|0)|0],q=b,m=x[x[h>>2]+76>>2],ib[m](n|0,o|0,p|0,q|0);break a}x[c+8>>2]=127;x[c+4>>2]=k<<1;q=h,p=7,o=y[Gb(c+8|0,c+4|0)|0],n=b,m=x[x[h>>2]+76>>2],ib[m](q|0,p|0,o|0,n|0)}fb=c+16|0}function ima(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0;f=fb-48|0;fb=f;t=x[a+16>>2];while(1){if((g|0)!=2){j=g<<3;m=j+(f+28|0)|0;j=a+j|0;x[m+4>>2]=x[j+44>>2];x[m+8>>2]=x[j+48>>2];g=g+1|0;continue}break}u=x[a+24>>2];v=x[a+20>>2];j=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=j;y=b+24|0;z=x[a+72>>2];r=x[a+68>>2];A=r>>31;s=x[a+64>>2];B=s>>31;m=x[a+60>>2];C=m>>31;j=x[a+8>>2];E=x[a+12>>2];while(1){if(d){b=x[f+16>>2];F=((((x[f+20>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+t|0;b=(((b>>>16|0)+4&131064)<<1)+y|0;l=w[b+14>>1];o=w[b+12>>1];q=w[b+10>>1];h=w[b+8>>1];p=w[b+6>>1];k=w[b+4>>1];e=w[b+2>>1];b=w[b>>1];g=0;n=0;while(1){if((n|0)!=2){i=F+(n<<1)|0;x[(f+8|0)+(n<<2)>>2]=(((((D(w[i+8>>1],q)+D(w[i+4>>1],h)|0)+D(o,w[i+12>>1])|0)+D(l,w[i+16>>1])|0)/2|0)+((((D(w[i-8>>1],e)+D(w[i-12>>1],b)|0)+D(w[i-4>>1],k)|0)+D(w[i>>1],p)|0)/2|0)|0)/16384;n=n+1|0;continue}break}while(1){if((g|0)!=2){o=(f+8|0)+(g<<2)|0;e=x[o>>2];b=(f+28|0)+(g<<3)|0;q=x[b+8>>2];h=x[b+4>>2];x[b+8>>2]=h;p=e<<8;e=p;e=Sua(e,e>>31,m,C);k=hb;i=e;e=Yb(h,-16777216,16776704);e=Sua(s,B,e,e>>31);h=i+e|0;l=hb+k|0;l=e>>>0>h>>>0?l+1|0:l;e=Yb(q,-16777216,16776704);k=Sua(r,A,e,e>>31);h=k+h|0;e=hb+l|0;e=h>>>0<k>>>0?e+1|0:e;k=h+8388608|0;e=k>>>0<8388608?e+1|0:e;e=Rc(k,e,24);x[b+4>>2]=e-(p&z);x[o>>2]=(e|0)/256;g=g+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[f+8>>2],v);x[c+4>>2]=x[c+4>>2]+D(u,x[f+12>>2]);Pb(f+16|0,j,E);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;g=0;while(1){if((g|0)!=2){b=g<<3;c=b+a|0;b=b+(f+28|0)|0;x[c+44>>2]=x[b+4>>2];x[c+48>>2]=x[b+8>>2];g=g+1|0;continue}break}fb=f+48|0}function mt(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;i=fb-128|0;fb=i;x[i+124>>2]=b;k=lt(c,d);x[i+4>>2]=1199;n=kt(i+8|0,i+4|0);j=i+16|0;a:{b:{if(k>>>0>=101){j=Ed(k);if(!j){x[31737]=0;X(1200);a=x[31737];x[31737]=0;if((a|0)!=1){break a}break b}Se(n,j)}h=j;b=c;c:{d:{while(1){if((b|0)==(d|0)){e:while(1){f:{x[31737]=0;h=P(1201,a|0,i+124|0)|0;b=x[31737];x[31737]=0;if((b|0)==1){break f}if((!k|h)==1){x[31737]=0;b=P(1201,a|0,i+124|0)|0;a=x[31737];x[31737]=0;if((a|0)==1){break c}if(!b){break d}x[f>>2]=x[f>>2]|2;break d}b=x[a>>2];x[31737]=0;b=R(1202,b|0)|0;h=x[31737];x[31737]=0;g:{if((h|0)!=1){if(g){break g}x[31737]=0;b=P(1203,e|0,b|0)|0;h=x[31737];x[31737]=0;if((h|0)!=1){break g}}break b}l=o+1|0;r=0;s=b&255;h=j;b=c;while(1){if((b|0)==(d|0)){o=l;if(!r){continue e}x[31737]=0;R(1204,a|0)|0;b=x[31737];x[31737]=0;if((b|0)!=1){h=j;b=c;if(k+m>>>0<2){continue e}while(1){if((b|0)==(d|0)){continue e}h:{if(y[h|0]!=2){break h}if((Cb(x[b+4>>2],y[b+11|0])|0)==(o|0)){break h}v[h|0]=0;m=m-1|0}h=h+1|0;b=b+12|0;continue}}break b}i:{if(y[h|0]!=1){break i}q=v[cc(b,o)|0];j:{if(g){break j}x[31737]=0;q=P(1203,e|0,q<<24>>24)|0;t=x[31737];x[31737]=0;if((t|0)!=1){break j}break b}k:{if((q&255)==(s|0)){r=1;if((Cb(x[b+4>>2],y[b+11|0])|0)!=(l|0)){break i}v[h|0]=2;m=m+1|0;break k}v[h|0]=0}k=k-1|0}h=h+1|0;b=b+12|0;continue}}break}}else{l=Ad(x[b+4>>2],y[b+11|0]);v[h|0]=l?2:1;m=m+l|0;k=k-l|0;h=h+1|0;b=b+12|0;continue}break}break b}l:{m:{while(1){if((c|0)==(d|0)){break m}if(y[j|0]!=2){j=j+1|0;c=c+12|0;continue}break}d=c;break l}x[f>>2]=x[f>>2]|4}Lc(n);fb=i+128|0;return d|0}}a=N()|0;Lc(n);Q(a|0)}p()}function it(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;i=fb-128|0;fb=i;x[i+124>>2]=b;k=lt(c,d);x[i+4>>2]=1199;n=kt(i+8|0,i+4|0);j=i+16|0;a:{b:{if(k>>>0>=101){j=Ed(k);if(!j){x[31737]=0;X(1200);a=x[31737];x[31737]=0;if((a|0)!=1){break a}break b}Se(n,j)}h=j;b=c;c:{d:{while(1){if((b|0)==(d|0)){e:while(1){f:{x[31737]=0;h=P(1216,a|0,i+124|0)|0;b=x[31737];x[31737]=0;if((b|0)==1){break f}if((!k|h)==1){x[31737]=0;b=P(1216,a|0,i+124|0)|0;a=x[31737];x[31737]=0;if((a|0)==1){break c}if(!b){break d}x[f>>2]=x[f>>2]|2;break d}b=x[a>>2];x[31737]=0;o=R(1217,b|0)|0;b=x[31737];x[31737]=0;g:{if((b|0)!=1){if(g){break g}x[31737]=0;o=P(1218,e|0,o|0)|0;b=x[31737];x[31737]=0;if((b|0)!=1){break g}}break b}l=q+1|0;s=0;h=j;b=c;while(1){if((b|0)==(d|0)){q=l;if(!s){continue e}x[31737]=0;R(1219,a|0)|0;b=x[31737];x[31737]=0;if((b|0)!=1){h=j;b=c;if(k+m>>>0<2){continue e}while(1){if((b|0)==(d|0)){continue e}h:{if(y[h|0]!=2){break h}if((Cb(x[b+4>>2],y[b+11|0])|0)==(q|0)){break h}v[h|0]=0;m=m-1|0}h=h+1|0;b=b+12|0;continue}}break b}i:{if(y[h|0]!=1){break i}r=x[Vd(b,q)>>2];j:{if(g){break j}x[31737]=0;r=P(1218,e|0,r|0)|0;t=x[31737];x[31737]=0;if((t|0)!=1){break j}break b}k:{if((o|0)==(r|0)){s=1;if((Cb(x[b+4>>2],y[b+11|0])|0)!=(l|0)){break i}v[h|0]=2;m=m+1|0;break k}v[h|0]=0}k=k-1|0}h=h+1|0;b=b+12|0;continue}}break}}else{l=Ad(x[b+4>>2],y[b+11|0]);v[h|0]=l?2:1;m=m+l|0;k=k-l|0;h=h+1|0;b=b+12|0;continue}break}break b}l:{m:{while(1){if((c|0)==(d|0)){break m}if(y[j|0]!=2){j=j+1|0;c=c+12|0;continue}break}d=c;break l}x[f>>2]=x[f>>2]|4}Lc(n);fb=i+128|0;return d|0}}a=N()|0;Lc(n);Q(a|0)}p()}function Wna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;h=fb-48|0;fb=h;k=c+484344|0;Vf(k,y[b+70|0]|y[b+71|0]<<8);a:{b:{while(1){if((y[b+70|0]|y[b+71|0]<<8)>>>0<=j>>>0){break b}f=x[a+8>>2];e=Pg(a);Vb(a,1);c:{if((y[b+58|0]|y[b+59|0]<<8)==258){c=Zd(a)+1|0;break c}c=hh(a)}d=hh(a);cd(a,e+f|0);e=h+8|0;fe(e,a,d);f=ic(h+28|0,e);ub(e);x[31737]=0;c=U(197,k|0,j&65535,(c?c>>>0>=1024?1024:c:64)|0)|0;e=x[31737];x[31737]=0;if((e|0)!=1){d:{if(!(c&(d|0)!=0)){break d}c=Wb(x[k>>2],j);m=h,n=wb(x[c>>2]),x[m+8>>2]=n;l=wb(x[c+4>>2]);while(1){c=x[h+8>>2];if(!Ib(c,l)){break d}x[31737]=0;d=R(198,f|0)|0;e=x[31737];x[31737]=0;e:{f:{g:{if((e|0)!=1){e=d<<24>>24;if((e|0)>=0){break g}if(e&1){x[31737]=0;d=R(198,f|0)|0;i=x[31737];x[31737]=0;if((i|0)==1){break a}v[c|0]=d}d=e&255;if(e&2){break f}break e}break a}v[c|0]=e;d=255}x[31737]=0;e=R(198,f|0)|0;i=x[31737];x[31737]=0;if((i|0)==1){break a}v[c+1|0]=e}i=0;e=0;if(d&4){x[31737]=0;e=R(198,f|0)|0;g=x[31737];x[31737]=0;if((g|0)==1){break a}}if(d&8){x[31737]=0;i=R(198,f|0)|0;g=x[31737];x[31737]=0;if((g|0)==1){break a}}if(d&16){x[31737]=0;d=R(198,f|0)|0;g=x[31737];x[31737]=0;if((g|0)==1){break a}v[c+5|0]=d}h:{i:{d=y[c|0];if(!d){break i}g=255;if((d|0)==97){break h}if(d>>>0>96){break i}g=d+12|0;break h}g=0}v[c|0]=g;d=y[c+5|0];j:{if((d|i)&255){Bf(c,i,d);break j}v[c+3|0]=0}if(y[c+1|0]==255){v[c+1|0]=0}d=e-16|0;k:{if((d&255)>>>0<=64){v[c+4|0]=d;v[c+2|0]=1;break k}if(e>>>0<96){break k}d=e&15;v[c+4|0]=d;e=e-96>>>4|0;v[c+2|0]=y[e+25550|0];if((e|0)!=6){break k}v[c+4|0]=d<<2}vg(h+8|0);continue}}ub(f);j=j+1|0;continue}break}break a}fb=h+48|0;return}a=N()|0;ub(f);Q(a|0);p()}function jma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0;f=fb-48|0;fb=f;t=x[a+16>>2];while(1){if((g|0)!=2){j=g<<3;m=j+(f+28|0)|0;j=a+j|0;x[m+4>>2]=x[j+44>>2];x[m+8>>2]=x[j+48>>2];g=g+1|0;continue}break}u=x[a+24>>2];y=x[a+20>>2];j=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=j;z=b+24|0;A=x[a+72>>2];r=x[a+68>>2];B=r>>31;s=x[a+64>>2];C=s>>31;m=x[a+60>>2];E=m>>31;j=x[a+8>>2];F=x[a+12>>2];while(1){if(d){b=x[f+16>>2];G=(((x[f+20>>2]&2147483647)<<1|b>>>31)&-2)+t|0;b=(((b>>>16|0)+4&131064)<<1)+z|0;l=w[b+14>>1];o=w[b+12>>1];q=w[b+10>>1];h=w[b+8>>1];p=w[b+6>>1];k=w[b+4>>1];e=w[b+2>>1];b=w[b>>1];g=0;n=0;while(1){if((n|0)!=2){i=n+G|0;x[(f+8|0)+(n<<2)>>2]=((((D(v[i+4|0],q)+D(v[i+2|0],h)|0)+D(o,v[i+6|0])|0)+D(l,v[i+8|0])<<8>>1)+(((D(v[i-4|0],e)+D(v[i-6|0],b)|0)+D(v[i-2|0],k)|0)+D(v[i|0],p)<<8>>1)|0)/16384;n=n+1|0;continue}break}while(1){if((g|0)!=2){o=(f+8|0)+(g<<2)|0;e=x[o>>2];b=(f+28|0)+(g<<3)|0;q=x[b+8>>2];h=x[b+4>>2];x[b+8>>2]=h;p=e<<8;e=p;e=Sua(e,e>>31,m,E);k=hb;i=e;e=Yb(h,-16777216,16776704);e=Sua(s,C,e,e>>31);h=i+e|0;l=hb+k|0;l=e>>>0>h>>>0?l+1|0:l;e=Yb(q,-16777216,16776704);k=Sua(r,B,e,e>>31);h=k+h|0;e=hb+l|0;e=h>>>0<k>>>0?e+1|0:e;k=h+8388608|0;e=k>>>0<8388608?e+1|0:e;e=Rc(k,e,24);x[b+4>>2]=e-(p&A);x[o>>2]=(e|0)/256;g=g+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[f+8>>2],y);x[c+4>>2]=x[c+4>>2]+D(u,x[f+12>>2]);Pb(f+16|0,j,F);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;g=0;while(1){if((g|0)!=2){b=g<<3;c=b+a|0;b=b+(f+28|0)|0;x[c+44>>2]=x[b+4>>2];x[c+48>>2]=x[b+8>>2];g=g+1|0;continue}break}fb=f+48|0}function S4(a){a=a|0;var b=0,c=0,d=0;a=a+12|0;d=a+508|0;c=Cb(x[a+512>>2],y[a+519|0]);while(1){a:{if((b|0)==(c|0)){b=c;break a}if(x[Vd(d,b)>>2]==37){break a}b=b+1|0;continue}break}b:{c:{d:{e:{f:{a=x[Vd(d,b+1|0)>>2];if((a|0)!=121){if((a|0)==100){break f}if((a|0)==109){break e}if((a|0)!=89){break c}}b=b+2|0;a=b>>>0<c>>>0?c:b;while(1){g:{if(b>>>0<c>>>0){if(x[Vd(d,b)>>2]!=37){break g}a=b}if((a|0)==(c|0)){break c}b=x[Vd(d,a+1|0)>>2];if((b|0)==100){break d}if((b|0)!=109){break c}b=a+2|0;a=b>>>0<c>>>0?c:b;while(1){h:{if(b>>>0<c>>>0){if(x[Vd(d,b)>>2]!=37){break h}a=b}if((a|0)==(c|0)){break c}b=3;if(x[Vd(d,a+1|0)>>2]!=100){break c}break b}b=b+1|0;continue}}b=b+1|0;continue}}b=b+2|0;a=b>>>0<c>>>0?c:b;while(1){i:{if(b>>>0<c>>>0){if(x[Vd(d,b)>>2]!=37){break i}a=b}if((a|0)==(c|0)){break c}if(x[Vd(d,a+1|0)>>2]!=109){break c}b=a+2|0;a=b>>>0<c>>>0?c:b;while(1){j:{if(b>>>0<c>>>0){if(x[Vd(d,b)>>2]!=37){break j}a=b}if((a|0)==(c|0)){break c}b=1;a=a+1|0;if(x[Vd(d,a)>>2]==121){break b}if(x[Vd(d,a)>>2]==89){break b}break c}b=b+1|0;continue}}b=b+1|0;continue}}b=b+2|0;a=b>>>0<c>>>0?c:b;while(1){k:{if(b>>>0<c>>>0){if(x[Vd(d,b)>>2]!=37){break k}a=b}if((a|0)==(c|0)){break c}if(x[Vd(d,a+1|0)>>2]!=100){break c}b=a+2|0;a=b>>>0<c>>>0?c:b;while(1){l:{if(b>>>0<c>>>0){if(x[Vd(d,b)>>2]!=37){break l}a=b}if((a|0)==(c|0)){break c}b=2;a=a+1|0;if(x[Vd(d,a)>>2]==121){break b}if(x[Vd(d,a)>>2]!=89){break c}break b}b=b+1|0;continue}}b=b+1|0;continue}}b=a+2|0;a=b>>>0<c>>>0?c:b;while(1){m:{if(b>>>0<c>>>0){if(x[Vd(d,b)>>2]!=37){break m}a=b}if((a|0)==(c|0)){break c}b=4;if(x[Vd(d,a+1|0)>>2]!=109){break c}break b}b=b+1|0;continue}}b=0}return b|0}function Kma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0;f=fb-48|0;fb=f;t=x[a+16>>2];b=0;while(1){if((b|0)!=2){g=b<<3;o=g+(f+28|0)|0;g=a+g|0;x[o+4>>2]=x[g+44>>2];x[o+8>>2]=x[g+48>>2];b=b+1|0;continue}break}m=x[a+40>>2];n=x[a+36>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;u=x[a+32>>2];v=x[a+28>>2];y=x[a+72>>2];q=x[a+68>>2];z=q>>31;r=x[a+64>>2];A=r>>31;s=x[a+60>>2];B=s>>31;o=x[a+8>>2];C=x[a+12>>2];while(1){if(d){b=x[f+16>>2];h=((((x[f+20>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+t|0;b=b>>>21&2040;p=w[b+38198>>1];i=w[b+38196>>1];e=w[b+38194>>1];g=w[b+38192>>1];b=0;j=0;while(1){if((j|0)!=2){k=h+(j<<1)|0;x[(f+8|0)+(j<<2)>>2]=(((D(w[k>>1],e)+D(w[k-4>>1],g)|0)+D(i,w[k+4>>1])|0)+D(p,w[k+8>>1])|0)/16384;j=j+1|0;continue}break}while(1){if((b|0)!=2){j=(f+8|0)+(b<<2)|0;e=x[j>>2];g=(f+28|0)+(b<<3)|0;k=x[g+8>>2];h=x[g+4>>2];x[g+8>>2]=h;p=e<<8;e=p;e=Sua(e,e>>31,s,B);i=hb;l=e;e=Yb(h,-16777216,16776704);e=Sua(r,A,e,e>>31);h=l+e|0;l=hb+i|0;l=e>>>0>h>>>0?l+1|0:l;e=Yb(k,-16777216,16776704);i=Sua(q,z,e,e>>31);h=i+h|0;e=hb+l|0;e=h>>>0<i>>>0?e+1|0:e;i=h+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Rc(i,e,24);x[g+4>>2]=e-(p&y);x[j>>2]=(e|0)/256;b=b+1|0;continue}break}n=n+v|0;x[c>>2]=x[c>>2]+D(x[f+8>>2],n>>12);m=m+u|0;x[c+4>>2]=x[c+4>>2]+D(x[f+12>>2],m>>12);Pb(f+16|0,o,C);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;x[a+40>>2]=m;x[a+20>>2]=n>>12;x[a+36>>2]=n;x[a+24>>2]=m>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+28|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}fb=f+48|0}function xja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;c=fb-192|0;fb=c;e=Pm(c+80|0,a);x[31737]=0;d=P(462,c+68|0,42319)|0;a=x[31737];x[31737]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if((a|0)!=1){x[31737]=0;x[c+56>>2]=20054022;x[c+60>>2]=0;a=c+56|0;S(463,e|0,d|0,a|0);f=x[31737];x[31737]=0;if((f|0)==1){break n}Eb(d);if(vl(y[e|0])){break e}x[31737]=0;d=P(462,a|0,13450)|0;a=x[31737];x[31737]=0;if((a|0)==1){break m}x[31737]=0;V(494,e|0,b|0,d|0,918);a=x[31737];x[31737]=0;if((a|0)==1){break l}Eb(d);x[c+52>>2]=0;x[c+48>>2]=0;x[31737]=0;d=P(462,c+36|0,16796)|0;a=x[31737];x[31737]=0;if((a|0)==1){break k}x[31737]=0;S(919,e|0,c+52|0,d|0);a=x[31737];x[31737]=0;if((a|0)==1){break j}Eb(d);x[31737]=0;d=P(462,c+24|0,16786)|0;a=x[31737];x[31737]=0;if((a|0)==1){break i}x[31737]=0;S(919,e|0,c+48|0,d|0);a=x[31737];x[31737]=0;if((a|0)==1){break h}Eb(d);a=x[c+52>>2];d=x[c+48>>2];o:{if(!a|d>>>0<a>>>0){break o}f=x[x[x[x[b+48>>2]+12>>2]+8>>2]+40>>2];if(f>>>0<a>>>0|d>>>0>f>>>0){break o}x[b+20>>2]=d;x[b+16>>2]=a}d=Nb(c+12|0);x[31737]=0;f=P(462,c|0,14194)|0;a=x[31737];x[31737]=0;if((a|0)==1){break d}x[31737]=0;S(920,e|0,d|0,f|0);a=x[31737];x[31737]=0;if((a|0)==1){break g}Eb(f);if(mc(x[d>>2],x[d+4>>2])){break f}a=x[b+16>>2];x[31737]=0;O(870,d|0,a|0);a=x[31737];x[31737]=0;if((a|0)!=1){break f}break c}a=N()|0;break a}a=N()|0;Eb(d);break a}a=N()|0;break a}a=N()|0;Eb(d);break a}a=N()|0;break a}a=N()|0;Eb(d);break a}a=N()|0;break a}a=N()|0;Eb(d);break a}a=N()|0;Eb(f);break b}x[31737]=0;O(921,b|0,d|0);a=x[31737];x[31737]=0;if((a|0)==1){break c}vc(d)}Ah(e);fb=c+192|0;return}a=N()|0;break b}a=N()|0}vc(d)}Ah(e);Q(a|0);p()}function Jra(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;g=fb-16|0;fb=g;j=Hf(a,c);$d(g,x[a+36>>2]);k=a;a:{if(!j){Pc(g,a+32|0,5);c=0;if(Hb(x[x[g>>2]>>2],x[g+4>>2])){break a}}e=fb-192|0;fb=e;f=Pm(e+80|0,x[a+36>>2]);x[31737]=0;a=P(462,e+68|0,26223)|0;c=x[31737];x[31737]=0;b:{c:{d:{e:{if((c|0)!=1){x[31737]=0;x[e+8>>2]=20054022;x[e+12>>2]=0;S(463,f|0,a|0,e+8|0);c=x[31737];x[31737]=0;if((c|0)==1){break e}Eb(a);if(!vl(y[f|0])){break d}break b}c=N()|0;break c}c=N()|0;Eb(a);break c}v[e+67|0]=0;v[e+66|0]=0;x[31737]=0;a=P(462,e+52|0,10110)|0;c=x[31737];x[31737]=0;f:{g:{h:{i:{if((c|0)!=1){x[31737]=0;c=e+67|0;S(504,f|0,c|0,a|0);h=x[31737];x[31737]=0;if((h|0)==1){break i}Eb(a);if(!y[e+67|0]){break b}Qf(c,50);x[31737]=0;a=P(462,e+40|0,13304)|0;c=x[31737];x[31737]=0;if((c|0)==1){break f}x[31737]=0;S(504,f|0,e+66|0,a|0);c=x[31737];x[31737]=0;if((c|0)==1){break g}Eb(a);a=x[b>>2];c=Nj(a,x[b+4>>2]);h=y[e+67|0];if(c>>>0<h>>>0){a=$B(e+8|0,x[b+12>>2]);x[31737]=0;S(505,b|0,h|0,a|0);c=x[31737];x[31737]=0;if((c|0)==1){break h}Ek(a);a=x[b>>2]}l=z[Tj(a,0)+28>>1];c=0;j:{while(1){a=c&255;if(a>>>0>=h>>>0){a=y[e+66|0];o=b,q=Nj(x[b>>2],x[b+4>>2])>>>0>a>>>0?a:0,v[o+16|0]=q;break b}af(Tj(x[b>>2],a),l);m=x[b>>2];x[31737]=0;i=e+8|0;O(506,i|0,c|0);n=x[31737];x[31737]=0;if((n|0)!=1){x[31737]=0;V(507,f|0,Tj(m,a)|0,i|0,d|0);a=x[31737];x[31737]=0;if((a|0)==1){break j}c=c+1|0;Eb(i);continue}break}c=N()|0;break c}c=N()|0;Eb(e+8|0);break c}c=N()|0;break c}c=N()|0;Eb(a);break c}c=N()|0;Ek(a);break c}c=N()|0;Eb(a);break c}c=N()|0}Ah(f);Q(c|0);p()}Ah(f);fb=e+192|0;c=j}ff(k,c);fb=g+16|0}function x4(a){a=a|0;var b=0,c=0,d=0;a=a+12|0;d=a+508|0;c=Cb(x[a+512>>2],y[a+519|0]);while(1){a:{if((b|0)==(c|0)){b=c;break a}if(y[cc(d,b)|0]==37){break a}b=b+1|0;continue}break}b:{c:{d:{e:{f:{a=v[cc(d,b+1|0)|0];if((a|0)!=121){if((a|0)==100){break f}if((a|0)==109){break e}if((a|0)!=89){break c}}b=b+2|0;a=b>>>0<c>>>0?c:b;while(1){g:{if(b>>>0<c>>>0){if(y[cc(d,b)|0]!=37){break g}a=b}if((a|0)==(c|0)){break c}b=v[cc(d,a+1|0)|0];if((b|0)==100){break d}if((b|0)!=109){break c}b=a+2|0;a=b>>>0<c>>>0?c:b;while(1){h:{if(b>>>0<c>>>0){if(y[cc(d,b)|0]!=37){break h}a=b}if((a|0)==(c|0)){break c}b=3;if(y[cc(d,a+1|0)|0]!=100){break c}break b}b=b+1|0;continue}}b=b+1|0;continue}}b=b+2|0;a=b>>>0<c>>>0?c:b;while(1){i:{if(b>>>0<c>>>0){if(y[cc(d,b)|0]!=37){break i}a=b}if((a|0)==(c|0)){break c}if(y[cc(d,a+1|0)|0]!=109){break c}b=a+2|0;a=b>>>0<c>>>0?c:b;while(1){j:{if(b>>>0<c>>>0){if(y[cc(d,b)|0]!=37){break j}a=b}if((a|0)==(c|0)){break c}b=1;a=a+1|0;if(y[cc(d,a)|0]==121){break b}if(y[cc(d,a)|0]==89){break b}break c}b=b+1|0;continue}}b=b+1|0;continue}}b=b+2|0;a=b>>>0<c>>>0?c:b;while(1){k:{if(b>>>0<c>>>0){if(y[cc(d,b)|0]!=37){break k}a=b}if((a|0)==(c|0)){break c}if(y[cc(d,a+1|0)|0]!=100){break c}b=a+2|0;a=b>>>0<c>>>0?c:b;while(1){l:{if(b>>>0<c>>>0){if(y[cc(d,b)|0]!=37){break l}a=b}if((a|0)==(c|0)){break c}b=2;a=a+1|0;if(y[cc(d,a)|0]==121){break b}if(y[cc(d,a)|0]!=89){break c}break b}b=b+1|0;continue}}b=b+1|0;continue}}b=a+2|0;a=b>>>0<c>>>0?c:b;while(1){m:{if(b>>>0<c>>>0){if(y[cc(d,b)|0]!=37){break m}a=b}if((a|0)==(c|0)){break c}b=4;if(y[cc(d,a+1|0)|0]!=109){break c}break b}b=b+1|0;continue}}b=0}return b|0}function Lma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0,A=0,B=0,C=0,E=0;f=fb-48|0;fb=f;t=x[a+16>>2];b=0;while(1){if((b|0)!=2){g=b<<3;o=g+(f+28|0)|0;g=a+g|0;x[o+4>>2]=x[g+44>>2];x[o+8>>2]=x[g+48>>2];b=b+1|0;continue}break}m=x[a+40>>2];n=x[a+36>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;u=x[a+32>>2];y=x[a+28>>2];z=x[a+72>>2];q=x[a+68>>2];A=q>>31;r=x[a+64>>2];B=r>>31;s=x[a+60>>2];C=s>>31;o=x[a+8>>2];E=x[a+12>>2];while(1){if(d){b=x[f+16>>2];h=(((x[f+20>>2]&2147483647)<<1|b>>>31)&-2)+t|0;b=b>>>21&2040;p=w[b+38198>>1];i=w[b+38196>>1];e=w[b+38194>>1];g=w[b+38192>>1];b=0;j=0;while(1){if((j|0)!=2){k=h+j|0;x[(f+8|0)+(j<<2)>>2]=(((D(v[k|0],e)+D(v[k-2|0],g)|0)+D(i,v[k+2|0])|0)+D(p,v[k+4|0])<<8)/16384;j=j+1|0;continue}break}while(1){if((b|0)!=2){j=(f+8|0)+(b<<2)|0;e=x[j>>2];g=(f+28|0)+(b<<3)|0;k=x[g+8>>2];h=x[g+4>>2];x[g+8>>2]=h;p=e<<8;e=p;e=Sua(e,e>>31,s,C);i=hb;l=e;e=Yb(h,-16777216,16776704);e=Sua(r,B,e,e>>31);h=l+e|0;l=hb+i|0;l=e>>>0>h>>>0?l+1|0:l;e=Yb(k,-16777216,16776704);i=Sua(q,A,e,e>>31);h=i+h|0;e=hb+l|0;e=h>>>0<i>>>0?e+1|0:e;i=h+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Rc(i,e,24);x[g+4>>2]=e-(p&z);x[j>>2]=(e|0)/256;b=b+1|0;continue}break}n=n+y|0;x[c>>2]=x[c>>2]+D(x[f+8>>2],n>>12);m=m+u|0;x[c+4>>2]=x[c+4>>2]+D(x[f+12>>2],m>>12);Pb(f+16|0,o,E);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;x[a+40>>2]=m;x[a+20>>2]=n>>12;x[a+36>>2]=n;x[a+24>>2]=m>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+28|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}fb=f+48|0}function rw(a,b,c,d){var e=0,f=0;e=fb-16|0;fb=e;v[e+15|0]=c;a:{b:{c:{d:{e:{switch(b-2|0){case 11:v[e+14|0]=64;de(a,1,Qb(e+15|0,e+14|0));break a;case 0:if(!(c&3|c>>>0>223?d:1)){break b}v[e+14|0]=c>>>2;de(a,12,e+14|0);break a;case 1:if(!(c&3|c>>>0>223?d:1)){break b}v[e+14|0]=c>>>2;de(a,13,e+14|0);break a;case 2:if(c>>>0>=240){v[e+14|0]=9;de(a,11,e+14|0);break a}b=0;while(1){if((b|0)==10){break b}f=y[b+42256|0];f:{if(d){if(c>>>0>f>>>0){break f}break d}if((c|0)==(f|0)){break d}}b=b+1|0;continue};case 3:g:{if(d){v[e+14|0]=c&15;v[e+13|0]=9;c=y[Qb(e+14|0,e+13|0)|0];break g}if(c>>>0>15|(c&14)>>>0>9){break b}}v[e+14|0]=c&15;de(a,8,e+14|0);break a;case 24:h:{if(d){v[e+15|0]=0;break h}if(c){break b}}de(a,8,e+15|0);break a;case 7:v[e+15|0]=(c|0)==255?64:c>>>2|0;de(a,2,e+15|0);break a;case 9:if(!c){break b}b=c&15;if(!b){v[e+14|0]=c>>>4;de(a,3,e+14|0);break a}d=c&240;if(!d){de(a,4,e+15|0);break a}if((b|0)==15){v[e+14|0]=c>>>4;de(a,5,e+14|0);break a}if((d|0)!=240){break b}v[e+14|0]=c&15;de(a,6,e+14|0);break a;case 18:if((c&240)!=128){break b}v[e+14|0]=c<<2&60|2;de(a,2,e+14|0);break a;case 17:i:{switch((c>>>4|0)-8|0){case 0:v[e+14|0]=c<<2&60|2;de(a,2,e+14|0);break a;case 2:v[e+14|0]=c&15;de(a,5,e+14|0);break a;case 3:break i;default:break b}}v[e+14|0]=c&15;de(a,6,e+14|0);break a;case 4:case 5:case 6:case 8:case 10:case 12:case 13:case 14:case 15:case 16:case 19:case 20:case 21:case 22:case 23:break b;default:break e}}if((b|0)==46){break c}break b}v[e+14|0]=b;de(a,11,e+14|0);break a}if(d?0:c&3){break b}v[e+14|0]=c+3>>>2;de(a,1,e+14|0);break a}v[e+14|0]=0;de(a,0,e+14|0)}fb=e+16|0}function nV(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{b:{d=b;e=x[b>>2];if(e){if(!x[b+4>>2]){break b}g=x[b+4>>2];c:{if(!g){while(1){g=Uh(d);d=x[d+8>>2];if(!g){continue}break}break c}d=h_(g)}e=x[d>>2];if(e){break b}}e=x[d+4>>2];if(e){break b}e=0;g=1;break a}x[e+8>>2]=x[d+8>>2];g=0}d:{e:{if(Uh(d)){c=x[d+8>>2];x[c>>2]=e;if((a|0)==(d|0)){a=e;c=0;break d}c=c+4|0;break e}c=x[d+8>>2];x[c+4>>2]=e}c=x[c>>2]}h=!y[d+12|0];if((b|0)!=(d|0)){f=x[b+8>>2];x[d+8>>2]=f;i=f+(Uh(b)?0:4)|0,j=d,x[i>>2]=j;f=x[b>>2];x[d>>2]=f;Dn(f,d);f=x[b+4>>2];x[d+4>>2]=f;if(f){Dn(f,d)}v[d+12|0]=y[b+12|0];a=(a|0)==(b|0)?d:a}if(!(h|!a)){if(g){while(1){b=y[c+12|0];f:{g:{if(!Uh(c)){if(!b){v[c+12|0]=1;b=x[c+8>>2];v[b+12|0]=0;sr(b);b=x[c>>2];a=(b|0)==(a|0)?c:a;c=x[b+4>>2]}b=x[c>>2];h:{if(!(y[b+12|0]?0:b)){b=x[c+4>>2];if(y[b+12|0]?0:b){break h}v[c+12|0]=0;i:{b=x[c+8>>2];if((b|0)!=(a|0)){if(y[b+12|0]){break i}a=b}v[a+12|0]=1;return}if(!Uh(b)){break g}b=x[b+8>>2]+4|0;break f}a=x[c+4>>2];if(y[a+12|0]?0:a){break h}v[b+12|0]=1;v[c+12|0]=0;qr(c);c=x[c+8>>2]}a=x[c+8>>2];v[c+12|0]=y[a+12|0];v[a+12|0]=1;v[x[c+4>>2]+12|0]=1;sr(a);return}if(!b){v[c+12|0]=1;b=x[c+8>>2];v[b+12|0]=0;qr(b);b=x[c+4>>2];a=(b|0)==(a|0)?c:a;c=x[b>>2]}d=x[c>>2];j:{if(y[d+12|0]?0:d){break j}b=x[c+4>>2];if(!(y[b+12|0]?0:b)){v[c+12|0]=0;b=x[c+8>>2];if(!((a|0)!=(b|0)?y[b+12|0]:0)){v[b+12|0]=1;return}if(Uh(b)){b=x[b+8>>2]+4|0;break f}b=x[b+8>>2];break f}if(y[d+12|0]?0:d){break j}v[b+12|0]=1;v[c+12|0]=0;sr(c);c=x[c+8>>2];d=x[c>>2]}a=x[c+8>>2];v[c+12|0]=y[a+12|0];v[a+12|0]=1;v[d+12|0]=1;qr(a);return}b=x[b+8>>2]}c=x[b>>2];continue}}v[e+12|0]=1}}function C7(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0;a=fb-624|0;fb=a;x[a+616>>2]=c;x[a+620>>2]=b;x[a+16>>2]=1232;b=a+16|0;h=Be(a+200|0,a+208|0,b);i=a+192|0;bd(i,x[e+28>>2]);x[31737]=0;j=R(1211,x[a+192>>2])|0;k=x[31737];x[31737]=0;a:{b:{c:{d:{e:{f:{g:{if((k|0)!=1){v[a+191|0]=0;e=x[e+4>>2];x[31737]=0;c=na(1241,a+620|0,c|0,d|0,i|0,e|0,f|0,a+191|0,j|0,h|0,a+196|0,a+608|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break d}if(!c){break e}c=y[14699]|y[14700]<<8|(y[14701]<<16|y[14702]<<24);v[a+183|0]=c;v[a+184|0]=c>>>8;v[a+185|0]=c>>>16;v[a+186|0]=c>>>24;c=y[14696]|y[14697]<<8|(y[14698]<<16|y[14699]<<24);x[a+176>>2]=y[14692]|y[14693]<<8|(y[14694]<<16|y[14695]<<24);x[a+180>>2]=c;x[31737]=0;V(1222,j|0,a+176|0,a+186|0,a+128|0);c=x[31737];x[31737]=0;if((c|0)==1){break g}x[a+4>>2]=1199;d=Be(a+8|0,0,a+4|0);e=b;b=x[a+196>>2];c=b-x[h>>2]|0;if((c|0)<393){break f}Se(d,Ed((c>>2)+2|0));e=x[d>>2];if(e){break f}x[31737]=0;X(1200);b=x[31737];x[31737]=0;if((b|0)==1){break c}break a}c=N()|0;break b}c=N()|0;break b}if(y[a+191|0]){v[e|0]=45;e=e+1|0}c=x[h>>2];while(1){if(b>>>0<=c>>>0){v[e|0]=0;x[a>>2]=g;if((MK(a+16|0,a)|0)!=1){x[31737]=0;W(1234,8e3);b=x[31737];x[31737]=0;if((b|0)!=1){break a}break c}Lc(d)}else{b=a+128|0;l=e,m=y[(a+176|0)+(ry(b,b+40|0,x[c>>2])-b>>2)|0],v[l|0]=m;e=e+1|0;c=c+4|0;b=x[a+196>>2];continue}break}}x[31737]=0;b=P(1216,a+620|0,a+616|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break d}if(b){x[f>>2]=x[f>>2]|2}b=x[a+620>>2];Zb(a+192|0);Lc(h);fb=a+624|0;return b|0}c=N()|0;break b}c=N()|0;Lc(d)}Zb(a+192|0);Lc(h);Q(c|0);p()}p()}function J7(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0;a=fb-272|0;fb=a;x[a+264>>2]=c;x[a+268>>2]=b;x[a+16>>2]=1232;b=a+16|0;h=Be(a+152|0,a+160|0,b);j=a+144|0;bd(j,x[e+28>>2]);x[31737]=0;i=R(28,x[a+144>>2])|0;k=x[31737];x[31737]=0;a:{b:{c:{d:{e:{f:{g:{if((k|0)!=1){v[a+143|0]=0;e=x[e+4>>2];x[31737]=0;c=na(1233,a+268|0,c|0,d|0,j|0,e|0,f|0,a+143|0,i|0,h|0,a+148|0,a+260|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break d}if(!c){break e}c=y[14699]|y[14700]<<8|(y[14701]<<16|y[14702]<<24);v[a+135|0]=c;v[a+136|0]=c>>>8;v[a+137|0]=c>>>16;v[a+138|0]=c>>>24;c=y[14696]|y[14697]<<8|(y[14698]<<16|y[14699]<<24);x[a+128>>2]=y[14692]|y[14693]<<8|(y[14694]<<16|y[14695]<<24);x[a+132>>2]=c;x[31737]=0;V(1209,i|0,a+128|0,a+138|0,a+118|0);c=x[31737];x[31737]=0;if((c|0)==1){break g}x[a+4>>2]=1199;d=Be(a+8|0,0,a+4|0);e=b;b=x[a+148>>2];c=b-x[h>>2]|0;if((c|0)<99){break f}Se(d,Ed(c+2|0));e=x[d>>2];if(e){break f}x[31737]=0;X(1200);b=x[31737];x[31737]=0;if((b|0)==1){break c}break a}c=N()|0;break b}c=N()|0;break b}if(y[a+143|0]){v[e|0]=45;e=e+1|0}c=x[h>>2];while(1){if(b>>>0<=c>>>0){v[e|0]=0;x[a>>2]=g;if((MK(a+16|0,a)|0)!=1){x[31737]=0;W(1234,8e3);b=x[31737];x[31737]=0;if((b|0)!=1){break a}break c}Lc(d)}else{b=a+118|0;i=r_(b);l=e,m=y[((Li(b,i,y[c|0])-a|0)+a|0)+10|0],v[l|0]=m;e=e+1|0;c=c+1|0;b=x[a+148>>2];continue}break}}x[31737]=0;b=P(1201,a+268|0,a+264|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break d}if(b){x[f>>2]=x[f>>2]|2}b=x[a+268>>2];Zb(a+144|0);Lc(h);fb=a+272|0;return b|0}c=N()|0;break b}c=N()|0;Lc(d)}Zb(a+144|0);Lc(h);Q(c|0);p()}p()}function TQ(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;l=fb-16|0;fb=l;a:{if((b|0)==(c|0)){break a}x[l+12>>2]=-1953789045;aA(b,c,l+12|0);c=c-b>>2;x[l+8>>2]=c;i=oc(x[a>>2],x[a+4>>2]);j=i+1|0;x[l+4>>2]=j;m=x[ad(l+4|0,l+8|0)>>2];d=11;b:{if(c>>>0>622){break b}d=7;if(c>>>0>67){break b}d=5;if(c>>>0>38){break b}d=3;if(c>>>0>6){break b}d=c-1>>>1|0}e=c-d>>>1|0;h=(e<<2)+b|0;g=x[h>>2];f=D(pu(g^(x[b>>2]^x[((c<<2)+b|0)-4>>2])),1664525);x[h>>2]=f+g;h=d+e|0;d=(h<<2)+b|0;g=d;k=x[d>>2];d=f+i|0;x[g>>2]=k+d;x[b>>2]=d;g=j>>>0<=1?1:j;d=c-1|0;e=(e>>>0)%(c>>>0)|0;f=(h>>>0)%(c>>>0)|0;k=x[a>>2];i=1;a=0;while(1)if((i|0)==(g|0)){while(1)if(j>>>0>=m>>>0){j=c+m|0;i=j>>>0<m>>>0?m:j;while(1){if((i|0)==(m|0)){break a}d=d+1|0;d=(c|0)!=(d|0)?d:0;e=e+1|0;e=(c|0)!=(e|0)?e:0;g=(e<<2)+b|0;k=x[g>>2];a=a+1|0;a=(a|0)!=(c|0)?a:0;h=(a<<2)+b|0;j=D(pu(x[(d<<2)+b>>2]+(k+x[h>>2]|0)|0),1566083941);x[g>>2]=j^k;f=f+1|0;f=(c|0)!=(f|0)?f:0;g=(f<<2)+b|0;j=j-a|0;x[g>>2]=j^x[g>>2];x[h>>2]=j;m=m+1|0;continue}}else{e=e+1|0;e=(c|0)!=(e|0)?e:0;g=(e<<2)+b|0;k=x[g>>2];a=a+1|0;a=(a|0)!=(c|0)?a:0;h=(a<<2)+b|0;d=d+1|0;d=(c|0)!=(d|0)?d:0;i=D(pu(k^(x[h>>2]^x[(d<<2)+b>>2])),1664525);x[g>>2]=i+k;f=f+1|0;f=(c|0)!=(f|0)?f:0;g=(f<<2)+b|0;i=a+i|0;x[g>>2]=i+x[g>>2];x[h>>2]=i;j=j+1|0;continue}}else{e=e+1|0;e=(c|0)!=(e|0)?e:0;n=(e<<2)+b|0;o=x[n>>2];a=a+1|0;a=(a|0)!=(c|0)?a:0;p=(a<<2)+b|0;d=d+1|0;d=(c|0)!=(d|0)?d:0;h=D(pu(o^(x[p>>2]^x[(d<<2)+b>>2])),1664525);x[n>>2]=h+o;h=x[yb(k,i-1|0)>>2]+(a+h|0)|0;f=f+1|0;f=(c|0)!=(f|0)?f:0;n=(f<<2)+b|0;x[n>>2]=h+x[n>>2];x[p>>2]=h;i=i+1|0;continue}}fb=l+16|0}function oja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=x[a>>2];d=pm(e,x[a+4>>2]);if(d>>>0<b>>>0){i=fb-32|0;fb=i;a:{b:{h=b-d|0;b=x[zb(a)>>2];e=x[a+4>>2];c:{if(h>>>0<=(b-e|0)/52>>>0){oA(a,h,c);break c}f=zb(a);d=nR(a,pm(x[a>>2],e)+h|0);g=pm(x[a>>2],x[a+4>>2]);e=fb-16|0;fb=e;b=i+12|0;Kg(b+12|0,f);d:{if(!d){f=0;d=0;break d}mR(e+8|0,d);f=x[e+12>>2];d=x[e+8>>2]}x[b>>2]=d;g=d+D(g,52)|0;x[b+8>>2]=g;x[b+4>>2]=g;l=nc(b),m=d+D(f,52)|0,x[l>>2]=m;fb=e+16|0;x[31737]=0;S(928,b|0,h|0,c|0);c=x[31737];x[31737]=0;if((c|0)==1){break b}h=fb-16|0;fb=h;e=zb(a);c=vb(h+12|0,x[a+4>>2]);d=vb(h+8|0,x[a>>2]);f=vb(h+4|0,x[b+4>>2]);c=x[c>>2];g=x[d>>2];d=fb+-64|0;fb=d;f=x[f>>2];x[d+56>>2]=f;x[d+60>>2]=c;x[d+52>>2]=f;e=Re(d+24|0,e,d+52|0,d+56|0);x[d+16>>2]=x[e+8>>2];f=x[e+4>>2];x[d+8>>2]=x[e>>2];x[d+12>>2]=f;Qe(d+36|0,d+8|0);while(1){if(pd(c,g)){c=c-52|0;e=_l(iR(x[d+56>>2]),c);x[e+20>>2]=x[c+20>>2];f=x[c+16>>2];x[e+12>>2]=x[c+12>>2];x[e+16>>2]=f;CW(e+24|0,c+24|0);_c(e+36|0,c+36|0);x[e+48>>2]=x[c+48>>2];c=kR(d+60|0);kR(d+56|0);c=x[c>>2];continue}break}Pe(d+36|0);j=x[d+56>>2];if(!y[d+48|0]){f=fb-16|0;fb=f;c=vb(f+12|0,x[x[d+44>>2]>>2]);k=x[vb(f+8|0,x[x[d+40>>2]>>2])>>2];g=fb-16|0;fb=g;c=x[c>>2];x[g+12>>2]=c;while(1){if(ci(c,k)){e=fb-16|0;fb=e;x[e+12>>2]=c;x[e+12>>2]=x[e+12>>2]+52;fb=e+16|0;Bk(iR(x[e+12>>2]));c=x[am(g+12|0)>>2];continue}break}fb=g+16|0;fb=f+16|0}fb=d- -64|0;x[b+4>>2]=j;Tb(a,b+4|0);Tb(a+4|0,b+8|0);Tb(zb(a),nc(b));x[b>>2]=x[b+4>>2];fb=h+16|0;lR(b)}fb=i+32|0;break a}a=N()|0;lR(b);Q(a|0);p()}return}if(b>>>0<d>>>0){qR(a,e+D(b,52)|0)}}function q7(a,b,c,d,e,f,g,h,i,j,k,l,m,n,o){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,u=0,w=0,z=0,A=0,B=0,C=0;x[c>>2]=a;w=d&512;z=h<<2;while(1){if((u|0)==4){if(Cb(x[n+4>>2],y[n+11|0])>>>0>1){B=c,C=HJ(Jk(zd(n),1),sl(n),x[c>>2]),x[B>>2]=C}d=d&176;if((d|0)!=16){if((d|0)==32){a=x[c>>2]}x[b>>2]=a}}else{a:{b:{switch(v[i+u|0]){case 0:x[b>>2]=x[c>>2];break a;case 1:x[b>>2]=x[c>>2];h=At(g,32);p=x[c>>2];x[c>>2]=p+4;x[p>>2]=h;break a;case 3:if(Ad(x[n+4>>2],y[n+11|0])){break a}h=x[Vd(n,0)>>2];p=x[c>>2];x[c>>2]=p+4;x[p>>2]=h;break a;case 2:if(Ad(x[m+4>>2],y[m+11|0])|!w){break a}B=c,C=HJ(zd(m),sl(m),x[c>>2]),x[B>>2]=C;break a;case 4:break b;default:break a}}A=x[c>>2];e=e+z|0;h=e;while(1){c:{if(f>>>0<=h>>>0){break c}if(!yj(g,64,x[h>>2])){break c}h=h+4|0;continue}break}if((o|0)>0){p=x[c>>2];q=o;while(1){if(!(!q|e>>>0>=h>>>0)){q=q-1|0;h=h-4|0;s=x[h>>2];r=p+4|0;x[c>>2]=r;x[p>>2]=s;p=r;continue}break}d:{if(!q){s=0;break d}s=At(g,48);p=x[c>>2]}while(1){r=p+4|0;if((q|0)>0){x[p>>2]=s;q=q-1|0;p=r;continue}break}x[c>>2]=r;x[p>>2]=j}e:{if((e|0)==(h|0)){p=At(g,48);q=x[c>>2];h=q+4|0;x[c>>2]=h;x[q>>2]=p;break e}s=-1;if(!Ad(x[l+4>>2],y[l+11|0])){s=v[cc(l,0)|0]}q=0;t=0;while(1){if((e|0)!=(h|0)){r=x[c>>2];f:{if((q|0)!=(s|0)){p=r;r=q;break f}p=r+4|0;x[c>>2]=p;x[r>>2]=k;r=0;t=t+1|0;if(Cb(x[l+4>>2],y[l+11|0])>>>0<=t>>>0){s=q;break f}s=-1;if(y[cc(l,t)|0]==127){break f}s=v[cc(l,t)|0]}h=h-4|0;q=x[h>>2];x[c>>2]=p+4;x[p>>2]=q;q=r+1|0;continue}break}h=x[c>>2]}jt(A,h)}u=u+1|0;continue}break}}function oe(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{b:{c:{switch(b|0){case 1:b=Fb(a);d=y[c+11|0];e=x[c+4>>2];a=0;x[31737]=0;O(53,b|0,Yc(e,d)|0);d=x[31737];x[31737]=0;d:{if((d|0)!=1){e:{while(1){if(Yc(x[c+4>>2],y[c+11|0])>>>0>a>>>0){d=v[cc(c,a)|0];x[31737]=0;O(35,b|0,((d|0)<0?65533:d&255)|0);d=x[31737];x[31737]=0;if((d|0)==1){break e}a=a+1|0;continue}break}break d}}break a}return;case 2:b=Fb(a);d=y[c+11|0];e=x[c+4>>2];a=0;x[31737]=0;O(53,b|0,Yc(e,d)|0);d=x[31737];x[31737]=0;f:{if((d|0)!=1){while(1){if(Yc(x[c+4>>2],y[c+11|0])>>>0<=a>>>0){break f}d=y[cc(c,a)|0];x[31737]=0;O(35,b|0,d|0);d=x[31737];x[31737]=0;if((d|0)!=1){a=a+1|0;continue}break}}break a}return;case 3:hf(a,c,48976);return;case 4:hf(a,c,5e4);return;case 5:hf(a,c,51024);return;case 6:hf(a,c,52048);return;case 7:hf(a,c,53072);return;case 8:hf(a,c,54096);return;case 9:hf(a,c,55120);return;case 10:hf(a,c,56144);return;case 11:hf(a,c,57168);return;case 12:hf(a,c,58192);return;case 13:hf(a,c,59216);return;case 14:hf(a,c,60240);return;case 15:hf(a,c,61264);return;case 16:hf(a,c,62288);return;case 17:hf(a,c,63312);return;case 18:hf(a,c,64336);return;case 19:hf(a,c,65360);return;case 20:hf(a,c,66384);return;case 21:hf(a,c,67408);return;case 22:hf(a,c,68432);return;case 23:hf(a,c,69456);return;case 24:kB(a,c,70480);return;case 25:kB(a,c,48976);return;case 26:kB(a,c,67408);return;default:a=ac(8);x[31737]=0;b=P(16,a|0,11122)|0;c=x[31737];x[31737]=0;if((c|0)!=1){break b}b=N()|0;jc(a);Q(b|0);p();case 0:break c}}K_(a,c);return}da(b|0,125180,17);p()}a=N()|0;Ub(b);Q(a|0);p()}function wka(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=fb-32|0;fb=c;a:{b:{c:{d:{e:{f:{if(Dd(x[a+24>>2])){break f}i=Yc(x[a+8>>2],y[a+15|0]);f=fb-16|0;fb=f;h=f+8|0;x[h>>2]=-1;x[h+4>>2]=-1;x[31737]=0;g=jI(65);d=x[31737];x[31737]=0;b=hb;if((d|0)==1){T(0)|0;Sb();p()}e=fb-16|0;fb=e;d=we(e+8|0,Sua(g,b,1e3,0),hb);b=x[d>>2];fb=e+16|0;j=f,k=vA(b,x[d+4>>2]),x[j>>2]=k;x[f+4>>2]=hb;e=DR(h,f,zb(f));x[31737]=0;g=jI(66);d=x[31737];x[31737]=0;b=hb;if((d|0)==1){T(0)|0;Sb();p()}h=a+24|0;j=f,k=vA(AR(g,b),hb),x[j>>2]=k;x[f+4>>2]=hb;b=DR(e,f,zb(f));g=x[b>>2];b=x[b+4>>2];fb=f+16|0;if(i){e=Nb(c+20|0);x[31737]=0;x[c+8>>2]=b;d=c+8|0;O(59,e|0,d|0);b=x[31737];x[31737]=0;if((b|0)==1){break c}x[31737]=0;x[c+8>>2]=g;O(59,e|0,d|0);b=x[31737];x[31737]=0;if((b|0)==1){break d}d=a+4|0;g=0;g:{while(1){if(Yc(x[a+8>>2],y[a+15|0])>>>0<=g>>>0){b=wb(x[e>>2]);a=wb(x[e+4>>2]);x[31737]=0;d=U(60,c+8|0,b|0,a|0)|0;a=x[31737];x[31737]=0;if((a|0)!=1){break g}a=N()|0;break b}b=y[cc(d,g)|0];x[31737]=0;x[c+8>>2]=b;O(59,e|0,c+8|0);b=x[31737];x[31737]=0;if((b|0)!=1){g=g+1|0;continue}break}a=N()|0;break b}x[31737]=0;b=R(61,d|0)|0;a=x[31737];x[31737]=0;if((a|0)!=1){x[c+4>>2]=b;a=c+4|0;BA(h,a);Nl(a);an(d);vc(e);break f}a=N()|0;an(d);break b}hb=g;x[c+8>>2]=b;x[c+12>>2]=hb;b=Nb(c+20|0);x[31737]=0;S(64,b|0,c+8|0,c+16|0);a=x[31737];x[31737]=0;if((a|0)==1){a=N()|0;vc(b);Q(a|0);p()}x[31737]=0;d=R(61,b|0)|0;a=x[31737];x[31737]=0;if((a|0)==1){break e}x[c+4>>2]=d;a=c+4|0;BA(h,a);Nl(a);an(b)}fb=c+32|0;return}a=N()|0;an(b);break a}a=N()|0;break b}a=N()|0}vc(e)}Q(a|0);p()}function $ma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0;f=fb-48|0;fb=f;s=x[a+16>>2];b=0;while(1){if((b|0)!=2){g=b<<3;n=g+(f+28|0)|0;g=a+g|0;x[n+4>>2]=x[g+44>>2];x[n+8>>2]=x[g+48>>2];b=b+1|0;continue}break}k=x[a+40>>2];l=x[a+36>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;t=x[a+32>>2];u=x[a+28>>2];v=x[a+72>>2];o=x[a+68>>2];y=o>>31;p=x[a+64>>2];z=p>>31;q=x[a+60>>2];A=q>>31;n=x[a+8>>2];B=x[a+12>>2];while(1){if(d){g=x[f+16>>2];i=g>>>18|0;e=((((x[f+20>>2]&2147483647)<<1|g>>>31)&2147483646)<<1)+s|0;b=0;h=0;while(1){if((h|0)!=2){g=e+(h<<1)|0;m=w[g>>1];x[(f+8|0)+(h<<2)>>2]=m+((D(i,w[g+4>>1]-m|0)|0)/16384|0);h=h+1|0;continue}break}while(1){if((b|0)!=2){r=(f+8|0)+(b<<2)|0;e=x[r>>2];g=(f+28|0)+(b<<3)|0;C=x[g+8>>2];h=x[g+4>>2];x[g+8>>2]=h;m=e<<8;e=m;e=Sua(e,e>>31,q,A);i=hb;j=e;e=Yb(h,-16777216,16776704);e=Sua(p,z,e,e>>31);h=j+e|0;j=hb+i|0;j=e>>>0>h>>>0?j+1|0:j;e=Yb(C,-16777216,16776704);i=Sua(o,y,e,e>>31);h=i+h|0;e=hb+j|0;e=h>>>0<i>>>0?e+1|0:e;i=h+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Rc(i,e,24);x[g+4>>2]=e-(m&v);x[r>>2]=(e|0)/256;b=b+1|0;continue}break}l=l+u|0;x[c>>2]=x[c>>2]+D(x[f+8>>2],l>>12);k=k+t|0;x[c+4>>2]=x[c+4>>2]+D(x[f+12>>2],k>>12);Pb(f+16|0,n,B);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;x[a+40>>2]=k;x[a+20>>2]=l>>12;x[a+36>>2]=l;x[a+24>>2]=k>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+28|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}fb=f+48|0}function HH(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;d=fb-432|0;fb=d;a:{f=Ts(d+428|0,b);e=x[f>>2];b:{if(!Dd(e)){x[31737]=0;b=P(36,d+416|0,b|0)|0;a=x[31737];x[31737]=0;c:{d:{e:{if((a|0)!=1){x[31737]=0;a=d+16|0;S(1017,a|0,17727,b|0);c=x[31737];x[31737]=0;if((c|0)==1){break e}x[31737]=0;W(1325,a|0);a=x[31737];x[31737]=0;if((a|0)==1){break d}break a}a=N()|0;break b}a=N()|0;break c}a=N()|0;tb(d+16|0)}tb(b);break b}iq(e);if(!eq(a+8|0,22303,x[f>>2])){x[a+8>>2]=2147483647}if(!eq(a+12|0,22303,x[f>>2])){x[a+12>>2]=2147483647}x[31737]=0;O(273,a+16|0,22303);b=x[31737];x[31737]=0;f:{g:{if((b|0)!=1){x[d+8>>2]=0;x[d+12>>2]=0;x[d+4>>2]=22303;e=Gi(d+16|0,d+4|0,100,d+8|0,x[f>>2]);if((e|0)==-1){x[31737]=0;W(1234,12677);a=x[31737];x[31737]=0;if((a|0)!=1){break a}a=N()|0;break b}x[31737]=0;b=d+16|0;e=U(1332,a+28|0,b|0,b+(e<<2)|0)|0;g=x[31737];x[31737]=0;if((g|0)==1){break f}x[a+64>>2]=0;x[d+4>>2]=22303;x[d+8>>2]=0;x[d+12>>2]=0;h:{g=d+4|0;i=d+8|0;h=Gi(b,g,100,i,x[f>>2]);if((h|0)!=-1){x[31737]=0;U(1332,a+40|0,b|0,b+(h<<2)|0)|0;h=x[31737];x[31737]=0;if((h|0)==1){break f}x[d+4>>2]=22303;x[d+8>>2]=0;x[d+12>>2]=0;b=Gi(b,g,100,i,x[f>>2]);if((b|0)!=-1){break h}}x[31737]=0;W(1234,12677);a=x[31737];x[31737]=0;if((a|0)!=1){break a}break f}x[31737]=0;g=d+16|0;U(1332,a+52|0,g|0,g+(b<<2)|0)|0;b=x[31737];x[31737]=0;if((b|0)==1){break f}x[31737]=0;b=P(1333,d+416|0,e|0)|0;e=x[31737];x[31737]=0;if((e|0)!=1){break g}a=N()|0;break b}a=N()|0;break b}hi(a+68|0,c);hi(a+72|0,c);Ub(b);nl(f);fb=d+432|0;return}a=N()|0}nl(f);Q(a|0);p()}p()}function pna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0;f=fb-48|0;fb=f;t=x[a+16>>2];n=mg(1,2);b=hb;u=b;Pb(a,n,b);b=0;while(1){if((b|0)!=2){g=b<<3;m=g+(f+28|0)|0;g=a+g|0;x[m+4>>2]=x[g+44>>2];x[m+8>>2]=x[g+48>>2];b=b+1|0;continue}break}k=x[a+40>>2];l=x[a+36>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;v=x[a+32>>2];y=x[a+28>>2];z=x[a+72>>2];o=x[a+68>>2];A=o>>31;p=x[a+64>>2];B=p>>31;q=x[a+60>>2];C=q>>31;m=x[a+8>>2];E=x[a+12>>2];while(1){if(d){d=d-1|0;b=x[f+16>>2];g=((((x[f+20>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+t|0;b=0;e=0;while(1){if((e|0)!=2){x[(f+8|0)+(e<<2)>>2]=w[g+(e<<1)>>1];e=e+1|0;continue}break}while(1){if((b|0)!=2){r=(f+8|0)+(b<<2)|0;e=x[r>>2];g=(f+28|0)+(b<<3)|0;F=x[g+8>>2];h=x[g+4>>2];x[g+8>>2]=h;s=e<<8;e=s;e=Sua(e,e>>31,q,C);i=hb;j=e;e=Yb(h,-16777216,16776704);e=Sua(p,B,e,e>>31);h=j+e|0;j=hb+i|0;j=e>>>0>h>>>0?j+1|0:j;e=Yb(F,-16777216,16776704);i=Sua(o,A,e,e>>31);h=i+h|0;e=hb+j|0;e=h>>>0<i>>>0?e+1|0:e;i=h+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Rc(i,e,24);x[g+4>>2]=e-(z&s);x[r>>2]=(e|0)/256;b=b+1|0;continue}break}l=l+y|0;x[c>>2]=x[c>>2]+D(x[f+8>>2],l>>12);k=k+v|0;x[c+4>>2]=x[c+4>>2]+D(x[f+12>>2],k>>12);Pb(f+16|0,m,E);c=c+8|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;x[a+40>>2]=k;x[a+20>>2]=l>>12;x[a+36>>2]=l;x[a+24>>2]=k>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+28|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}Hg(a,n,u);fb=f+48|0}function wma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0;h=fb-16|0;fb=h;f=x[a+8>>2];l=f;e=x[a+12>>2];i=e;a:{b:{c:{d:{if((e|0)<=1&f>>>0<=805306368|(e|0)<=0){f=e;if((e|0)>-2){f=1}else{f=(f|0)>=-2&l>>>0>=3489660928}if(f){break c}if((i|0)==-2&l>>>0>2147483647|(i|0)==-1){break d}break b}if((i|0)==1&l>>>0>2147483648|i>>>0>1){break b}}p=b+196648|0;break a}p=b+131112|0;break a}p=b+262184|0}t=x[a+16>>2];e=x[a+48>>2];j=x[a+40>>2];k=x[a+36>>2];b=x[a+44>>2];f=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=f;u=x[a+32>>2];v=x[a+28>>2];y=x[a+72>>2];q=x[a+68>>2];z=q>>31;r=x[a+64>>2];A=r>>31;s=x[a+60>>2];B=s>>31;while(1){f=b;if(d){b=Yb(b,-16777216,16776704);m=Sua(r,A,b,b>>31);n=hb;b=x[h+8>>2];g=(x[h+12>>2]<<1)+t|0;b=(b>>>16&65520)+p|0;g=(((((((D(w[g-4>>1],w[b+2>>1])+D(w[g-6>>1],w[b>>1])|0)+D(w[g-2>>1],w[b+4>>1])|0)+D(w[g>>1],w[b+6>>1])|0)+D(w[g+2>>1],w[b+8>>1])|0)+D(w[g+4>>1],w[b+10>>1])|0)+D(w[g+6>>1],w[b+12>>1])|0)+D(w[g+8>>1],w[b+14>>1])|0)/32768<<8;b=g;b=Sua(b,b>>31,s,B);m=b+m|0;o=hb+n|0;o=b>>>0>m>>>0?o+1|0:o;b=Yb(e,-16777216,16776704);e=Sua(q,z,b,b>>31);n=e+m|0;b=hb+o|0;b=e>>>0>n>>>0?b+1|0:b;e=n+8388608|0;b=e>>>0<8388608?b+1|0:b;e=Rc(e,b,24);b=(e|0)/256|0;k=k+v|0;x[c>>2]=D(b,k>>12)+x[c>>2];j=j+u|0;x[c+4>>2]=x[c+4>>2]+D(b,j>>12);Pb(h+8|0,l,i);b=e-(g&y)|0;c=c+8|0;d=d-1|0;e=f;continue}break}b=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=b;x[a+40>>2]=j;x[a+20>>2]=k>>12;x[a+36>>2]=k;x[a+48>>2]=e;x[a+44>>2]=f;x[a+24>>2]=j>>12;fb=h+16|0}function ana(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0,A=0,B=0,C=0;f=fb-48|0;fb=f;s=x[a+16>>2];b=0;while(1){if((b|0)!=2){g=b<<3;n=g+(f+28|0)|0;g=a+g|0;x[n+4>>2]=x[g+44>>2];x[n+8>>2]=x[g+48>>2];b=b+1|0;continue}break}k=x[a+40>>2];l=x[a+36>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;t=x[a+32>>2];u=x[a+28>>2];w=x[a+72>>2];o=x[a+68>>2];y=o>>31;p=x[a+64>>2];z=p>>31;q=x[a+60>>2];A=q>>31;n=x[a+8>>2];B=x[a+12>>2];while(1){if(d){g=x[f+16>>2];i=g>>>10&4194048;e=(((x[f+20>>2]&2147483647)<<1|g>>>31)&-2)+s|0;b=0;h=0;while(1){if((h|0)!=2){g=e+h|0;m=v[g|0];x[(f+8|0)+(h<<2)>>2]=((D(i,v[g+2|0]-m|0)|0)/16384|0)+(m<<8);h=h+1|0;continue}break}while(1){if((b|0)!=2){r=(f+8|0)+(b<<2)|0;e=x[r>>2];g=(f+28|0)+(b<<3)|0;C=x[g+8>>2];h=x[g+4>>2];x[g+8>>2]=h;m=e<<8;e=m;e=Sua(e,e>>31,q,A);i=hb;j=e;e=Yb(h,-16777216,16776704);e=Sua(p,z,e,e>>31);h=j+e|0;j=hb+i|0;j=e>>>0>h>>>0?j+1|0:j;e=Yb(C,-16777216,16776704);i=Sua(o,y,e,e>>31);h=i+h|0;e=hb+j|0;e=h>>>0<i>>>0?e+1|0:e;i=h+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Rc(i,e,24);x[g+4>>2]=e-(m&w);x[r>>2]=(e|0)/256;b=b+1|0;continue}break}l=l+u|0;x[c>>2]=x[c>>2]+D(x[f+8>>2],l>>12);k=k+t|0;x[c+4>>2]=x[c+4>>2]+D(x[f+12>>2],k>>12);Pb(f+16|0,n,B);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;x[a+40>>2]=k;x[a+20>>2]=l>>12;x[a+36>>2]=l;x[a+24>>2]=k>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+28|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}fb=f+48|0}function rla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0;g=fb-32|0;fb=g;e=AU(g+20|0,1<<x[b+12>>2]);f=x[e>>2];while(1){d=x[a>>2];if(jh(d,x[a+4>>2])>>>0>c>>>0){d=Ue(d,c);zU(Xd(f,c),C[d>>3]);c=c+1|0;continue}break}yU(b,e);c=wb(x[e>>2]);x[g>>2]=c;p=wb(x[e+4>>2]);while(1){if(Ib(c,p)){k=fb-32|0;fb=k;m=F(C[c+8>>3]);h=F(C[c>>3]);o(+h);n=j(1)|0;f=j(0)|0;o(+m);l=j(1)|0;d=j(0)|0;l=(l|0)==(n|0)&d>>>0>f>>>0|l>>>0>n>>>0;i=l?h:m;o(+i);d=j(1)|0;f=j(0)|0;n=d>>>20|0;a:{if((n|0)==2047){break a}h=l?m:h;b:{if(!(d|f)){break b}o(+h);d=j(1)|0;j(0)|0;d=d>>>20|0;if((d|0)==2047){break b}if((d-n|0)>=65){i=h+i;break a}c:{if(d>>>0>=1534){i=i*190109156629516e-225;h=h*190109156629516e-225;m=5.260135901548374e210;break c}m=1;if(n>>>0>572){break c}i=i*5.260135901548374e210;h=h*5.260135901548374e210;m=190109156629516e-225}KL(k+24|0,k+16|0,h);KL(k+8|0,k,i);i=m*M(C[k>>3]+C[k+16>>3]+C[k+8>>3]+C[k+24>>3]);break a}i=h}fb=k+32|0;zU(c,sq(i));c=x[Zo(g)>>2];continue}break}xU(b,e);wU(e);l=x[e>>2];f=Ik(l,x[e+4>>2])>>>1|0;d=f>>>0<=1?1:f;c=1;while(1){if((c|0)!=(d|0)){PB(Xd(l,c),2);PB(Xd(l,c+f|0),0);c=c+1|0;continue}break}yU(b,e);c=wb(x[e>>2]);x[g+16>>2]=c;f=wb(x[e+4>>2]);while(1){if(Ib(c,f)){vU(g,C[c>>3],C[c+8>>3]);d=x[g+12>>2];x[c+8>>2]=x[g+8>>2];x[c+12>>2]=d;d=x[g+4>>2];x[c>>2]=x[g>>2];x[c+4>>2]=d;c=x[Zo(g+16|0)>>2];continue}break}xU(b,e);wU(e);f=x[a>>2];d=jh(f,x[a+4>>2]);b=x[e>>2];c=0;while(1){if((c|0)==(d|0)){pn(e);fb=g+32|0}else{a=Xd(b,c);q=Ue(f,c),r=C[a>>3],C[q>>3]=r;c=c+1|0;continue}break}}function Nq(a,b,c,d){var e=E(0),f=E(0),g=E(0),h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=E(0),p=0;h=fb-16|0;fb=h;x[h+12>>2]=w[b+780>>1]+y[b+837|0];x[h+8>>2]=w[b+782>>1]+(y[b+838|0]&127);Fe(h+12|0,0,127);Fe(h+8|0,0,127);k=a+1074312|0;j=Ob(k,1);i=x[h+8>>2];l=x[h+12>>2];if(!j){v[b+838|0]=i;v[b+837|0]=l;x[b+780>>2]=0}m=D(d+256|0,l);j=(m|0)/256|0;a:{if(!(i|!Ob(k,36)|(m|0)<65024)){j=-1;if(!(y[b+851|0]&2)){break a}x[b+88>>2]=x[b+88>>2]&-32769;break a}x[b+88>>2]=x[b+88>>2]|32768;e=Ce(E(10),E(E(0-i|0)*E(.00937500037252903)));i=fb-16|0;fb=i;g=E(D(d+256|0,l)>>>0);b:{if(x[a+480180>>2]!=33554432){f=E(110);g=E(E(g/(y[a+480209|0]&128?E(10240):E(12288)))+E(.25));break b}f=E(125);g=E(E(g*E(6))/E(65024))}n=i,o=E(Ce(E(2),g)*f),B[n+12>>2]=o;d=i+12|0;NT(d,E(120),E(2e4));yB(d,E(E(A[a+24620>>2])*E(.5)));fb=i+16|0;g=E(B[i+12>>2]*E(6.2831854820251465));c:{if(!(!Ob(k,36)|y[a+480209|0]&128)){f=E(E(A[a+24620>>2])/g);g=E(E(E(e*f)+e)+E(-1));e=E(f*f);break c}f=E(e+e);e=E(g/E(A[a+24620>>2]));B[h+4>>2]=E(E(1)-f)*e;yB(h+4|0,E(2));g=E(E(f-B[h+4>>2])/e);e=E(E(1)/E(e*e))}f=E(e+E(g+E(1)));g=E(E(e+E(e+g))/f);e=E(E(-e)/f);f=E(E(1)/f);d:{if(y[b+845|0]==1){n=b,p=Rl(E(E(E(1)-f)*E(16777216))),x[n+60>>2]=p;n=b,p=Rl(E(g*E(16777216))),x[n+64>>2]=p;n=b,p=Rl(E(e*E(16777216))),x[n+68>>2]=p;a=-1;break d}d=Rl(E(f*E(16777216)));x[b+60>>2]=d;n=b,p=Rl(E(g*E(16777216))),x[n+64>>2]=p;n=b,p=Rl(E(e*E(16777216))),x[n+68>>2]=p;a=0;if(d){break d}x[b+60>>2]=1}x[b+72>>2]=a;if(!c){break a}x[b+44>>2]=0;x[b+48>>2]=0;x[b+52>>2]=0;x[b+56>>2]=0}fb=h+16|0;return j}function u7(a,b,c,d,e,f,g,h,i,j,k,l,m,n,o){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,u=0,w=0,z=0,A=0,B=0,C=0;x[c>>2]=a;z=d&512;while(1){if((u|0)==4){if(Cb(x[n+4>>2],y[n+11|0])>>>0>1){B=c,C=Br(uf(zd(n),1),Df(n),x[c>>2]),x[B>>2]=C}d=d&176;if((d|0)!=16){if((d|0)==32){a=x[c>>2]}x[b>>2]=a}}else{a:{b:{switch(v[i+u|0]){case 0:x[b>>2]=x[c>>2];break a;case 1:x[b>>2]=x[c>>2];p=rm(g,32);q=x[c>>2];x[c>>2]=q+1;v[q|0]=p;break a;case 3:if(Ad(x[n+4>>2],y[n+11|0])){break a}p=y[cc(n,0)|0];q=x[c>>2];x[c>>2]=q+1;v[q|0]=p;break a;case 2:if(Ad(x[m+4>>2],y[m+11|0])|!z){break a}B=c,C=Br(zd(m),Df(m),x[c>>2]),x[B>>2]=C;break a;case 4:break b;default:break a}}p=x[g+8>>2];A=x[c>>2];e=e+h|0;r=e;while(1){c:{if(f>>>0<=r>>>0){break c}if(!Jf(p,64,v[r|0])){break c}r=r+1|0;continue}break}p=o;if((p|0)>0){while(1){if(!(!p|e>>>0>=r>>>0)){p=p-1|0;r=r-1|0;q=y[r|0];s=x[c>>2];x[c>>2]=s+1;v[s|0]=q;continue}break}if(p){q=rm(g,48)}else{q=0}while(1){s=x[c>>2];x[c>>2]=s+1;if((p|0)>0){v[s|0]=q;p=p-1|0;continue}break}v[s|0]=j}d:{if((e|0)==(r|0)){p=rm(g,48);q=x[c>>2];x[c>>2]=q+1;v[q|0]=p;break d}q=-1;if(!Ad(x[l+4>>2],y[l+11|0])){q=v[cc(l,0)|0]}p=0;t=0;while(1){if((e|0)==(r|0)){break d}e:{if((p|0)!=(q|0)){s=p;break e}q=x[c>>2];x[c>>2]=q+1;v[q|0]=k;s=0;t=t+1|0;if(Cb(x[l+4>>2],y[l+11|0])>>>0<=t>>>0){q=p;break e}q=-1;if(y[cc(l,t)|0]==127){break e}q=v[cc(l,t)|0]}r=r-1|0;p=y[r|0];w=x[c>>2];x[c>>2]=w+1;v[w|0]=p;p=s+1|0;continue}}Hm(A,x[c>>2])}u=u+1|0;continue}break}}function yoa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=fb-16|0;fb=f;k=f,l=Xj(b),x[k+4>>2]=l;e=fb-16|0;fb=e;h=a;c=ce(a);a:{if(c){g=ec(a);while(1){a=c;c=a+14|0;if(jv(b,c)){g=a;c=x[a>>2];if(c){continue}break a}if(!jv(c,b)){break a}g=a+4|0;c=x[a+4>>2];if(c){continue}break}break a}a=ec(h);g=a}x[e+12>>2]=a;b=x[g>>2];if(!b){i=fb-16|0;fb=i;a=ec(h);j=Bh(e,Ec(48),Mg(i+8|0,a));a=x[j>>2];b=x[f+4>>2];c=y[b+4|0]|y[b+5|0]<<8|(y[b+6|0]<<16|y[b+7|0]<<24);d=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);v[a+14|0]=d;v[a+15|0]=d>>>8;v[a+16|0]=d>>>16;v[a+17|0]=d>>>24;v[a+18|0]=c;v[a+19|0]=c>>>8;v[a+20|0]=c>>>16;v[a+21|0]=c>>>24;c=y[b+28|0]|y[b+29|0]<<8|(y[b+30|0]<<16|y[b+31|0]<<24);d=y[b+24|0]|y[b+25|0]<<8|(y[b+26|0]<<16|y[b+27|0]<<24);v[a+38|0]=d;v[a+39|0]=d>>>8;v[a+40|0]=d>>>16;v[a+41|0]=d>>>24;v[a+42|0]=c;v[a+43|0]=c>>>8;v[a+44|0]=c>>>16;v[a+45|0]=c>>>24;c=y[b+20|0]|y[b+21|0]<<8|(y[b+22|0]<<16|y[b+23|0]<<24);d=y[b+16|0]|y[b+17|0]<<8|(y[b+18|0]<<16|y[b+19|0]<<24);v[a+30|0]=d;v[a+31|0]=d>>>8;v[a+32|0]=d>>>16;v[a+33|0]=d>>>24;v[a+34|0]=c;v[a+35|0]=c>>>8;v[a+36|0]=c>>>16;v[a+37|0]=c>>>24;c=y[b+12|0]|y[b+13|0]<<8|(y[b+14|0]<<16|y[b+15|0]<<24);b=y[b+8|0]|y[b+9|0]<<8|(y[b+10|0]<<16|y[b+11|0]<<24);v[a+22|0]=b;v[a+23|0]=b>>>8;v[a+24|0]=b>>>16;v[a+25|0]=b>>>24;v[a+26|0]=c;v[a+27|0]=c>>>8;v[a+28|0]=c>>>16;v[a+29|0]=c>>>24;w[a+46>>1]=0;k=ec(j),l=1,v[k+4|0]=l;fb=i+16|0;$g(h,x[e+12>>2],g,x[e>>2]);b=me(e);dm(e);d=1}_g(f+8|0,x[vb(e,b)>>2],d);fb=e+16|0;a=hp(x[f+8>>2]);fb=f+16|0;return a+32|0}function xma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0,A=0,B=0;h=fb-16|0;fb=h;g=x[a+8>>2];l=g;e=x[a+12>>2];i=e;a:{b:{c:{d:{if((e|0)<=1&g>>>0<=805306368|(e|0)<=0){g=e;if((e|0)>-2){g=1}else{g=(g|0)>=-2&l>>>0>=3489660928}if(g){break c}if((i|0)==-2&l>>>0>2147483647|(i|0)==-1){break d}break b}if((i|0)==1&l>>>0>2147483648|i>>>0>1){break b}}n=b+196648|0;break a}n=b+131112|0;break a}n=b+262184|0}s=x[a+16>>2];b=x[a+48>>2];j=x[a+40>>2];k=x[a+36>>2];e=x[a+44>>2];g=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=g;t=x[a+32>>2];u=x[a+28>>2];y=x[a+72>>2];o=x[a+68>>2];z=o>>31;p=x[a+64>>2];A=p>>31;q=x[a+60>>2];B=q>>31;while(1){g=e;if(d){e=Yb(e,-16777216,16776704);f=Sua(p,A,e,e>>31);e=hb;b=Yb(b,-16777216,16776704);b=Sua(o,z,b,b>>31);f=b+f|0;e=hb+e|0;e=b>>>0>f>>>0?e+1|0:e;b=x[h+8>>2];m=f;f=x[h+12>>2]+s|0;b=(b>>>16&65520)+n|0;r=(((((((D(v[f-2|0],w[b+2>>1])+D(v[f-3|0],w[b>>1])|0)+D(v[f-1|0],w[b+4>>1])|0)+D(v[f|0],w[b+6>>1])|0)+D(v[f+1|0],w[b+8>>1])|0)+D(v[f+2|0],w[b+10>>1])|0)+D(v[f+3|0],w[b+12>>1])|0)+D(v[f+4|0],w[b+14>>1])<<8)/32768<<8;b=r;f=Sua(b,b>>31,q,B);m=m+f|0;b=hb+e|0;b=f>>>0>m>>>0?b+1|0:b;e=m+8388608|0;b=e>>>0<8388608?b+1|0:b;e=Rc(e,b,24);b=(e|0)/256|0;k=k+u|0;x[c>>2]=D(b,k>>12)+x[c>>2];j=j+t|0;x[c+4>>2]=x[c+4>>2]+D(j>>12,b);Pb(h+8|0,l,i);e=e-(y&r)|0;c=c+8|0;d=d-1|0;b=g;continue}break}c=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=c;x[a+40>>2]=j;x[a+20>>2]=k>>12;x[a+36>>2]=k;x[a+48>>2]=b;x[a+44>>2]=g;x[a+24>>2]=j>>12;fb=h+16|0}function U4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=fb-576|0;fb=c;Rb(c+532|0,0,44);x[c+24>>2]=0;x[c+28>>2]=0;while(1){a:{if((d|0)==7){d=0;while(1){b:{if((d|0)==12){x[c+540>>2]=1;d=c+432|0;fa(d|0,100,9278,c+532|0,x[a>>2])|0;x[c+24>>2]=0;x[c+28>>2]=0;x[c+20>>2]=d;e=Gi(c+32|0,c+20|0,100,c+24|0,x[a>>2]);if((e|0)!=-1){break b}break a}x[c+548>>2]=d;e=c+432|0;g=c+532|0;fa(e|0,100,14339,g|0,x[a>>2])|0;x[c+24>>2]=0;x[c+28>>2]=0;x[c+8>>2]=e;f=c+32|0;h=c+8|0;i=c+24|0;j=Gi(f,h,100,i,x[a>>2]);if(j+1>>>0<=1){break a}k=D(d,12)+a|0;Gm(k+172|0,f,f+(j<<2)|0);fa(e|0,100,13349,g|0,x[a>>2])|0;x[c+24>>2]=0;x[c+28>>2]=0;x[c+8>>2]=e;e=Gi(f,h,100,i,x[a>>2]);if(e+1>>>0<=1){break a}Gm(k+316|0,f,(e<<2)+f|0);d=d+1|0;continue}break}d=c+32|0;Gm(a+460|0,d,d+(e<<2)|0);x[c+540>>2]=13;e=c+432|0;fa(e|0,100,9278,c+532|0,x[a>>2])|0;x[c+24>>2]=0;x[c+28>>2]=0;x[c+20>>2]=e;e=Gi(d,c+20|0,100,c+24|0,x[a>>2]);if((e|0)!=-1){Gm(a+472|0,d,(e<<2)+d|0);d=c+8|0;Ws(d,a,99,b);oh(a+484|0,d);Ub(d);Ws(d,a,114,b);oh(a+496|0,d);Ub(d);Ws(d,a,120,b);oh(a+508|0,d);Ub(c+8|0);Ws(d,a,88,b);oh(a+520|0,d);Ub(c+8|0);fb=c+576|0;return}break a}x[c+556>>2]=d;e=c+432|0;g=c+532|0;fa(e|0,100,14352,g|0,x[a>>2])|0;x[c+24>>2]=0;x[c+28>>2]=0;x[c+8>>2]=e;f=c+32|0;h=c+8|0;i=c+24|0;j=Gi(f,h,100,i,x[a>>2]);if(j+1>>>0>1){k=D(d,12)+a|0;Gm(k+4|0,f,f+(j<<2)|0);fa(e|0,100,13556,g|0,x[a>>2])|0;x[c+24>>2]=0;x[c+28>>2]=0;x[c+8>>2]=e;e=Gi(f,h,100,i,x[a>>2]);if(e+1>>>0<=1){break a}Gm(k+88|0,f,(e<<2)+f|0);d=d+1|0;continue}}break}io(12677);p()}function Oma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0;f=fb-48|0;fb=f;r=x[a+16>>2];b=0;while(1){if((b|0)!=2){g=b<<3;m=g+(f+28|0)|0;g=a+g|0;x[m+4>>2]=x[g+44>>2];x[m+8>>2]=x[g+48>>2];b=b+1|0;continue}break}s=x[a+24>>2];t=x[a+20>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;u=x[a+72>>2];o=x[a+68>>2];v=o>>31;p=x[a+64>>2];y=p>>31;q=x[a+60>>2];z=q>>31;m=x[a+8>>2];A=x[a+12>>2];while(1){if(d){b=x[f+16>>2];h=((((x[f+20>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+r|0;b=b>>>21&2040;n=w[b+38198>>1];i=w[b+38196>>1];e=w[b+38194>>1];g=w[b+38192>>1];b=0;j=0;while(1){if((j|0)!=2){k=h+(j<<1)|0;x[(f+8|0)+(j<<2)>>2]=(((D(w[k>>1],e)+D(w[k-4>>1],g)|0)+D(i,w[k+4>>1])|0)+D(n,w[k+8>>1])|0)/16384;j=j+1|0;continue}break}while(1){if((b|0)!=2){j=(f+8|0)+(b<<2)|0;e=x[j>>2];g=(f+28|0)+(b<<3)|0;k=x[g+8>>2];h=x[g+4>>2];x[g+8>>2]=h;n=e<<8;e=n;e=Sua(e,e>>31,q,z);i=hb;l=e;e=Yb(h,-16777216,16776704);e=Sua(p,y,e,e>>31);h=l+e|0;l=hb+i|0;l=e>>>0>h>>>0?l+1|0:l;e=Yb(k,-16777216,16776704);i=Sua(o,v,e,e>>31);h=i+h|0;e=hb+l|0;e=h>>>0<i>>>0?e+1|0:e;i=h+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Rc(i,e,24);x[g+4>>2]=e-(n&u);x[j>>2]=(e|0)/256;b=b+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[f+8>>2],t);x[c+4>>2]=x[c+4>>2]+D(x[f+12>>2],s);Pb(f+16|0,m,A);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+28|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}fb=f+48|0}function T1(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=fb-48|0;fb=f;g=Ri(b)^-1;a:{if(oc(x[d>>2],x[d+4>>2])>>>0<=g>>>0){xu(a);break a}Ri(b);if((y[c+4|0]|y[c+5|0]<<8)>>>0>=60){Vb(b,4)}j=f,k=Ri(b),x[j+44>>2]=k;Vb(b,4);h=Ri(b);i=Ri(b);if(!((h|0)>0&(i|0)>36)){xu(a);break a}if(!Ld(Hd(x[e>>2],x[yb(x[d>>2],g)>>2]),13181)){xu(a);break a}e=f+4|0;vF(e,b,i,h);d=ic(f+24|0,e);ub(e);b=x[d>>2];x[31737]=0;b=R(173,b|0)|0;e=x[31737];x[31737]=0;b:{if((e|0)==1){break b}c:{d:{if(!b){x[31737]=0;R(183,a|0)|0;a=x[31737];x[31737]=0;if((a|0)!=1){break d}break b}b=y[c+4|0]|y[c+5|0]<<8;if(b>>>0<=39){x[31737]=0;P(184,d|0,8)|0;b=x[31737];x[31737]=0;if((b|0)==1){break b}b=y[c+4|0]|y[c+5|0]<<8}if((b&65535)>>>0<=59){x[31737]=0;P(184,d|0,16)|0;b=x[31737];x[31737]=0;if((b|0)==1){break b}}x[31737]=0;R(185,d|0)|0;b=x[31737];x[31737]=0;if((b|0)==1){break b}e:{f:{b=y[c+4|0]|y[c+5|0]<<8;g:{if(b>>>0>=120){x[31737]=0;R(185,d|0)|0;c=x[31737];x[31737]=0;b=8;break g}h:{if(b>>>0>=100){x[31737]=0;P(184,d|0,4)|0;b=x[31737];x[31737]=0;if((b|0)==1){break b}break h}if(b>>>0<62){break f}}x[31737]=0;R(185,d|0)|0;c=x[31737];x[31737]=0;b=4}if((c|0)==1){break b}x[31737]=0;P(184,d|0,b|0)|0;break e}x[31737]=0;R(185,d|0)|0}b=x[31737];x[31737]=0;if((b|0)==1){break b}x[31737]=0;c=R(185,d|0)|0;b=x[31737];x[31737]=0;if((b|0)==1){break c}x[31737]=0;b=f+4|0;S(186,b|0,d|0,c|0);c=x[31737];x[31737]=0;if((c|0)==1){break c}j=ic(a,b),k=x[f+44>>2],x[j+20>>2]=k;ub(b)}ub(d);break a}}a=N()|0;ub(d);Q(a|0);p()}fb=f+48|0}function qna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0;f=fb-48|0;fb=f;t=x[a+16>>2];n=mg(1,2);b=hb;u=b;Pb(a,n,b);b=0;while(1){if((b|0)!=2){g=b<<3;m=g+(f+28|0)|0;g=a+g|0;x[m+4>>2]=x[g+44>>2];x[m+8>>2]=x[g+48>>2];b=b+1|0;continue}break}k=x[a+40>>2];l=x[a+36>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;w=x[a+32>>2];y=x[a+28>>2];z=x[a+72>>2];o=x[a+68>>2];A=o>>31;p=x[a+64>>2];B=p>>31;q=x[a+60>>2];C=q>>31;m=x[a+8>>2];E=x[a+12>>2];while(1){if(d){d=d-1|0;b=x[f+16>>2];g=(((x[f+20>>2]&2147483647)<<1|b>>>31)&-2)+t|0;b=0;e=0;while(1){if((e|0)!=2){x[(f+8|0)+(e<<2)>>2]=v[e+g|0]<<8;e=e+1|0;continue}break}while(1){if((b|0)!=2){r=(f+8|0)+(b<<2)|0;e=x[r>>2];g=(f+28|0)+(b<<3)|0;F=x[g+8>>2];h=x[g+4>>2];x[g+8>>2]=h;s=e<<8;e=s;e=Sua(e,e>>31,q,C);i=hb;j=e;e=Yb(h,-16777216,16776704);e=Sua(p,B,e,e>>31);h=j+e|0;j=hb+i|0;j=e>>>0>h>>>0?j+1|0:j;e=Yb(F,-16777216,16776704);i=Sua(o,A,e,e>>31);h=i+h|0;e=hb+j|0;e=h>>>0<i>>>0?e+1|0:e;i=h+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Rc(i,e,24);x[g+4>>2]=e-(z&s);x[r>>2]=(e|0)/256;b=b+1|0;continue}break}l=l+y|0;x[c>>2]=x[c>>2]+D(x[f+8>>2],l>>12);k=k+w|0;x[c+4>>2]=x[c+4>>2]+D(x[f+12>>2],k>>12);Pb(f+16|0,m,E);c=c+8|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;x[a+40>>2]=k;x[a+20>>2]=l>>12;x[a+36>>2]=l;x[a+24>>2]=k>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+28|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}Hg(a,n,u);fb=f+48|0}function hQ(a){var b=E(0),c=E(0),d=0,e=0,f=0,g=0,h=0,i=0,k=E(0),l=0,m=E(0);d=fb-16|0;fb=d;f=a+4208|0;c=Tz(B[yb(f,2)>>2]);b=E(A[x[a+16>>2]+24620>>2]);B[d+12>>2]=c/b;x[d+8>>2]=1056964608;c=Aq(E(B[Xm(d+12|0,d+8|0)>>2]*E(6.2831854820251465)));c=E(M(E(E(E(c+c)+E(3))/E(5))));B[a+4236>>2]=c;B[a+4240>>2]=M(E(E(1)-E(c*c)));c=E(E(B[yb(f,1)>>2]*E(29))+E(2));a:{if(c<E(4294967296)&c>=E(0)){i=~~c>>>0;break a}i=0}v[a+4272|0]=i;e=i;while(1){if(e&255){g=g+1|0;e=(e&254)>>>1|0;continue}break}v[a+4273|0]=g;k=Ce(E(10),E(E(E(B[a+4208>>2]*E(60))+E(-60))/E(20)));l=d,m=E(Tz(B[yb(f,3)>>2])/b),B[l+12>>2]=m;x[d+8>>2]=1056964608;c=B[Xm(d+12|0,d+8|0)>>2];l=d,m=E(Tz(B[yb(f,4)>>2])/b),B[l+12>>2]=m;x[d+8>>2]=1056964608;b=E(E(B[Xm(d+12|0,d+8|0)>>2]*E(6.2831854820251465))*E(.5));g=fb-16|0;fb=g;f=(q(b),j(2));e=f&2147483647;b:{if(e>>>0<=1061752794){if(e>>>0<964689920){break b}b=po(+b,0);break b}if(e>>>0<=1081824209){h=+b;if(e>>>0<=1075235811){b=po(((f|0)<0?1.5707963267948966:-1.5707963267948966)+h,1);break b}b=po(((f|0)<0?3.141592653589793:-3.141592653589793)+h,0);break b}if(e>>>0<=1088565717){h=+b;if(e>>>0<=1085271519){b=po(((f|0)<0?4.71238898038469:-4.71238898038469)+h,1);break b}b=po(((f|0)<0?6.283185307179586:-6.283185307179586)+h,0);break b}if(e>>>0>=2139095040){b=E(b-b);break b}e=Wy(b,g+8|0);b=po(C[g+8>>3],e&1)}fb=g+16|0;b=E(E(E(1)-b)/E(b+E(1)));B[a+4268>>2]=b;c=Aq(E(c*E(6.2831854820251465)));B[a+4264>>2]=-c;B[a+4260>>2]=E(E(k*E(M(E(E(1)-E(c*c)))))*E(M(E(E(1)-E(b*b)))))*B[(i<<2)+44112>>2];fb=d+16|0}function yh(a,b,c,d,e){var f=0,g=0,h=0;if(!b){c=fb-16|0;fb=c;a:{if((d|0)==189){v[a+3843|0]=e>>>7;v[a+3844|0]=e>>>6&1;break a}b=d&224;if(!b){if((d|0)!=260){break a}b=0;d=1;while(1){if((b|0)==6){break a}f=D(b>>>0<3?b:b+6|0,44)+a|0;g=f+148|0;f=f+16|0;h=d&e;b:{if(h){So(f,g);break b}So(f,0)}v[g+40|0]=!h;b=b+1|0;d=d<<1&510;continue}}if(b-160>>>0<=32){b=d&15;if(b>>>0>8){break a}a=D(d&256?b+9|0:b,44)+a|0;x[c+8>>2]=a+16;b=x[a+52>>2];x[c+12>>2]=b;g=b?2:1;c:{b=d&240;if((b|0)!=160){if((b|0)==192){break c}if((b|0)!=176){break a}f=e&3;h=e>>>2&7;b=0;d=(e&32)!=0;while(1){if((b|0)==(g|0)){break a}a=x[(c+8|0)+(b<<2)>>2];PU(x[a>>2],d);PU(x[a+4>>2],d);w[a+22>>1]=h;UB(a);RU(a);v[a+21|0]=f;UB(a);RU(a);b=b+1|0;continue}}b=0;while(1){if((b|0)==(g|0)){break a}a=x[(c+8|0)+(b<<2)>>2];w[a+20>>1]=z[a+20>>1]&768|e&255;UB(a);b=b+1|0;continue}}v[a+58|0]=(e&32)>>>5;v[a+57|0]=(e&16)>>>4;b=e>>>1&7;w[a+46>>1]=b?9-b|0:0;w[a+48>>1]=e&1;break a}if((b|0)!=224&b>>>0>=129|-4144960>>>d&1){break a}f=a;a=v[(d&31)+27408|0];a=(f+D(d&256?a+18|0:a,84)|0)+808|0;d:{switch(b-32>>>5|0){case 0:v[a+79|0]=e>>>7;v[a+80|0]=(e&64)>>>6;v[a+78|0]=(e&32)>>>5;v[a+77|0]=(e&16)>>>4;To(a);w[a+14>>1]=z[((e&15)<<1)+27440>>1];break a;case 1:w[a+68>>1]=y[(e>>>6|0)+22288|0];QU(a);w[a+22>>1]=(e&63)<<2;break a;case 2:w[a+24>>1]=e>>>4;To(a);w[a+26>>1]=e&15;To(a);break a;case 3:b=e>>>4|0;w[a+28>>1]=b>>>0>=15?496:b<<4;w[a+30>>1]=e&15;To(a);break a;case 6:break d;default:break a}}w[a+12>>1]=e&7}fb=c+16|0;return}ib[x[x[b>>2]>>2]](b,c,d,e)}function zu(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=fb-128|0;fb=f;a:{b:{c:{d:{e:{f:{g:{if(!c){break g}d=x[c+4>>2];if(!d&A[c>>2]>=A[b+4>>2]|d){break g}a=ac(8);x[31737]=0;b=P(51,a|0,22303)|0;c=x[31737];x[31737]=0;if((c|0)!=1){break f}b=N()|0;jc(a);break a}if(!x[b>>2]){a=ac(8);x[31737]=0;b=R(859,a|0)|0;c=x[31737];x[31737]=0;if((c|0)!=1){break e}b=N()|0;jc(a);break a}d=x[b>>2];j=x[b+4>>2];b=fb-16|0;fb=b;lf(b+8|0,d,j);h=x[b+8>>2];g=f+108|0;EG(g,h,x[b+12>>2]);x[g+12>>2]=0;fb=b+16|0;h:{i:{if(a&2){b=Qn(f+88|0,g);x[31737]=0;b=R(860,b|0)|0;e=x[31737];x[31737]=0;d=1;if((e|0)==1){break h}if((b|0)==1){break i}d=Qn(f+68|0,g);x[31737]=0;e=R(861,d|0)|0;h=x[31737];x[31737]=0;d=1;if((h|0)==1){break d}if((e|0)==1){break i}d=Qn(f+48|0,g);x[31737]=0;h=P(862,d|0,c|0)|0;i=x[31737];x[31737]=0;d=1;if((i|0)==1){break c}if((h|0)==1){break i}d=Qn(f+28|0,g);x[31737]=0;i=P(863,d|0,c|0)|0;k=x[31737];x[31737]=0;d=1;if((k|0)==1){break b}if((i|0)==1){break i}e=0-((b|0)==-1|(e|0)==-1|(h|0)==-1|(i|0)==-1)|0}j:{if(!(a&1)){break j}b=29968;while(1){if((b|0)==30544){break j}a=x[b>>2];if(a){d=Qn(f+8|0,g);x[31737]=0;a=P(a|0,d|0,c|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){b=N()|0;break a}d=1;if((a|0)==1){break i}e=(a|0)==-1?-1:e}b=b+12|0;continue}}a=j;if(c){d=0;if((e|0)!=-1){break i}d=Bc(x[c>>2],x[c+4>>2])>>>0>a>>>0?-1:0;break i}d=0;if((e|0)!=-1){break i}d=a>>>0>2047?1:-1}fb=f+128|0;return d}b=N()|0;break a}da(b|0,125340,17);p()}da(b|0,125236,17);p()}b=N()|0;break a}b=N()|0;break a}b=N()|0}Q(b|0);p()}function Pma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0,A=0,B=0;f=fb-48|0;fb=f;r=x[a+16>>2];b=0;while(1){if((b|0)!=2){g=b<<3;m=g+(f+28|0)|0;g=a+g|0;x[m+4>>2]=x[g+44>>2];x[m+8>>2]=x[g+48>>2];b=b+1|0;continue}break}s=x[a+24>>2];t=x[a+20>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;u=x[a+72>>2];o=x[a+68>>2];y=o>>31;p=x[a+64>>2];z=p>>31;q=x[a+60>>2];A=q>>31;m=x[a+8>>2];B=x[a+12>>2];while(1){if(d){b=x[f+16>>2];h=(((x[f+20>>2]&2147483647)<<1|b>>>31)&-2)+r|0;b=b>>>21&2040;n=w[b+38198>>1];i=w[b+38196>>1];e=w[b+38194>>1];g=w[b+38192>>1];b=0;j=0;while(1){if((j|0)!=2){k=h+j|0;x[(f+8|0)+(j<<2)>>2]=(((D(v[k|0],e)+D(v[k-2|0],g)|0)+D(i,v[k+2|0])|0)+D(n,v[k+4|0])<<8)/16384;j=j+1|0;continue}break}while(1){if((b|0)!=2){j=(f+8|0)+(b<<2)|0;e=x[j>>2];g=(f+28|0)+(b<<3)|0;k=x[g+8>>2];h=x[g+4>>2];x[g+8>>2]=h;n=e<<8;e=n;e=Sua(e,e>>31,q,A);i=hb;l=e;e=Yb(h,-16777216,16776704);e=Sua(p,z,e,e>>31);h=l+e|0;l=hb+i|0;l=e>>>0>h>>>0?l+1|0:l;e=Yb(k,-16777216,16776704);i=Sua(o,y,e,e>>31);h=i+h|0;e=hb+l|0;e=h>>>0<i>>>0?e+1|0:e;i=h+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Rc(i,e,24);x[g+4>>2]=e-(n&u);x[j>>2]=(e|0)/256;b=b+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[f+8>>2],t);x[c+4>>2]=x[c+4>>2]+D(x[f+12>>2],s);Pb(f+16|0,m,B);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+28|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}fb=f+48|0}function Iz(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=E(0);e=fb-48|0;fb=e;a:{b:{c:{d:{e:{switch(b-1|0){case 1:b=(c<<7)/100|0;d=x[a+24>>2];if((b|0)==x[d+24604>>2]){break d}a=e+8|0;yc(a,d+24604|0,40);x[e+8>>2]=b;LA(d,a);break d;case 2:f=x[a+24>>2];d=f+24664|0;b=x[d+4>>2];x[e+24>>2]=x[d>>2];x[e+28>>2]=b;d=f+24656|0;b=x[d+4>>2];x[e+16>>2]=x[d>>2];x[e+20>>2]=b;b=x[f+24652>>2];x[e+8>>2]=x[f+24648>>2];x[e+12>>2]=b;d=fb-16|0;fb=d;b=3;f:{g:{h:{if(!c|(c|0)>7){break h}b=2;if((c|0)>2){break h}b=1;if((c|0)==2){break h}b=0;if((c|0)>0){break h}c=ac(8);x[31737]=0;b=P(36,d+4|0,10846)|0;a=x[31737];x[31737]=0;i:{if((a|0)!=1){pc(c,b);x[31737]=0;S(98,c|0,48540,1006);a=x[31737];x[31737]=0;if((a|0)!=1){break g}a=N()|0;tb(b);break i}a=N()|0;jc(c)}Q(a|0);p()}fb=d+16|0;break f}p()}v[e+8|0]=b;b=e+8|0;a=x[a+24>>2];if(!xz(b,a+24648|0)){break d}JA(a,b);break d;case 3:f=e+8|0;d=x[a+24>>2];yc(f,d+24604|0,40);b=fb-48|0;fb=b;j:{if((c|0)==-1){$t(f,x[Xq(b+8|0)+32>>2]);So(f,x[Xq(b+8|0)+36>>2]);break j}if((c|0)<=0){$t(f,0);So(f,0);break j}a=D(c,1e3);$t(f,a);So(f,a)}fb=b+48|0;if(x[d+24636>>2]==x[e+40>>2]&x[d+24640>>2]==x[e+44>>2]){break d}LA(d,e+8|0);break d;default:d=ac(8);x[31737]=0;c=P(36,e+8|0,10401)|0;a=x[31737];x[31737]=0;if((a|0)==1){break c}pc(d,c);x[31737]=0;S(98,d|0,48540,1006);a=x[31737];x[31737]=0;if((a|0)!=1){break a}b=N()|0;tb(c);break b;case 0:break e}}g=a,h=Ce(E(10),E(E(E(c|0)*E(.0010000000474974513))*E(.5))),B[g+48>>2]=h}fb=e+48|0;return}b=N()|0;jc(d)}Q(b|0)}p()}function Ck(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0;i=fb-16|0;fb=i;a:{if(!d){break a}g=x[c>>2];if(!g){break a}b:{c:{d:{e:{f=x[a+480180>>2];if((f|0)!=512){if((f|0)!=64){break e}f=D(d,20)+g|0;break d}f=((D(d,36318)|0)/1024|0)+g|0;break d}f:{g:{if(y[a+480208|0]&16){if((f|0)==4){break g}f=d>>31;x[i+12>>2]=(f^d)-f;wc(i+12|0,1020);h=x[i+12>>2];f=c;h:{if((d|0)>0){if(h>>>0<=15){h=x[(h<<2)+(Ob(a+1074312|0,7)?35488:35552)>>2];break h}h=x[(h&-4)+(Ob(a+1074312|0,7)?35616:36640)>>2];break h}if(h>>>0<=15){h=x[(h<<2)+(Ob(a+1074312|0,7)?35552:35488)>>2];break h}h=x[(h&-4)+(Ob(a+1074312|0,7)?36640:35616)>>2]}j=Sua(h,h>>31,g,g>>31);h=hb;j=j+32768|0;h=j>>>0<32768?h+1|0:h;k=f;f=Gc(Tua(j,h,65536,0),hb);x[k>>2]=f;if((g|0)!=(f|0)){break c}f=Ob(a+1074312|0,7);g=x[c>>2];if(!((d|0)>0^f)){f=2147483647;d=1;if((g|0)==2147483647){break c}break f}d=-1;if((g|0)>=2){break f}f=g;break c}f=Ob(a+1074312|0,7);g=x[c>>2];if(!f){break g}if((d|0)<0){f=Sua(g,0,14317456,0);h=hb;g=Sua(g,0,0-d|0,0);d=hb;g=g+14317456|0;d=g>>>0<14317456?d+1|0:d;f=$S(Uua(f,h,g,d),hb);break d}d=Sua(g,g>>31,d,0);f=hb;if((f|0)>=0&d>>>0>=14317456|(f|0)>0){if(e){x[c>>2]=2147483647;break a}x[c>>2]=0;x[b+696>>2]=0;x[b+88>>2]=x[b+88>>2]|2101248;break a}d=$S(Uua(Sua(g,0,14317456,0),hb,14317456-d|0,0-(f+(d>>>0>14317456)|0)|0),hb);x[c>>2]=d;if((d|0)<=0){break b}break a}f=g-d|0;break d}f=d+g|0}x[c>>2]=f}if((f|0)>0){break a}}x[c>>2]=1;if(x[a+480180>>2]!=2|e){break a}x[b+696>>2]=0;x[b+88>>2]=x[b+88>>2]|2101248}fb=i+16|0}function Y0(){var a=0,b=0,c=0;if(!y[500128]){a=fb-16|0;fb=a;Nt(499776);x[124956]=-1;x[124954]=499832;x[124952]=126136;x[124944]=94684;v[499828]=0;b=a+12|0;bd(b,x[124945]);c=x[x[124944]+8>>2];x[31737]=0;O(c|0,499776,b|0);c=x[31737];x[31737]=0;a:{if((c|0)!=1){Zb(b);fb=a+16|0;break a}b=N()|0;Zb(a+12|0);no(499776);Q(b|0);p()}Qt(499104);x[124776]=94816;x[124774]=94796;x[124775]=0;so(499104,499776);aL(499840,126280,499888);Iy(499272,499840);aL(499896,125984,499944);Iy(499440,499896);Iy(499608,x[x[x[124860]-12>>2]+499464>>2]);$K(x[x[124774]-12>>2]+499096|0);YK(x[x[124860]-12>>2]+499440|0);$K(x[x[124860]-12>>2]+499440|0);a=fb-16|0;fb=a;kL(499952);x[125e3]=-1;x[124998]=500008;x[124996]=126136;x[124988]=95076;v[500004]=0;b=a+12|0;bd(b,x[124989]);c=x[x[124988]+8>>2];x[31737]=0;O(c|0,499952,b|0);c=x[31737];x[31737]=0;b:{if((c|0)!=1){Zb(b);fb=a+16|0;break b}b=N()|0;Zb(a+12|0);Ct(499952);Q(b|0);p()}XK(499192);x[124798]=95208;x[124796]=95188;x[124797]=0;so(499192,499952);_K(500016,126280,500064);Hy(499356,500016);_K(500072,125984,500120);Hy(499524,500072);Hy(499692,x[x[x[124881]-12>>2]+499548>>2]);ZK(x[x[124796]-12>>2]+499184|0);YK(x[x[124881]-12>>2]+499524|0);ZK(x[x[124881]-12>>2]+499524|0);v[500128]=1}a=fb-16|0;fb=a;c:{if(bb(a+12|0,a+8|0)|0){break c}b=Ed((x[a+12>>2]<<2)+4|0);x[125034]=b;if(!b){break c}b=Ed(x[a+8>>2]);if(b){c=x[125034];x[c+(x[a+12>>2]<<2)>>2]=0;if(!(ab(c|0,b|0)|0)){break c}}x[125034]=0}fb=a+16|0;x[124225]=42;x[124243]=500228}function RB(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;a:{e=255;b:{c:{g=a+62|0;d=y[xb(g,b)|0];if((d|0)==255){break c}if(v[xb(g,b)|0]>=0){break b}f=a+26|0;d=d&127;if(z[_b(f,d)>>1]!=65535){if(z[_b(f,d)>>1]!=(b|0)){break c}}j=_b(f,d),k=b,w[j>>1]=k;j=xb(g,b),k=d,v[j|0]=k;break b}i=a+8|0;f=a+26|0;d=0;h=255;d:{while(1){if((d|0)==18){break d}if(z[_b(f,d)>>1]!=65535){if(!(y[xb(i,d)|0]&32)){h=v[xb(g,z[_b(f,d)>>1])|0]<0?d:h;e=d}d=d+1|0;continue}break}j=_b(f,d),k=b,w[j>>1]=k;j=xb(g,b),k=d,v[j|0]=k;break b}if((e&255)!=255){d=(h&255)==255?e:h;e=d&255;j=xb(g,z[_b(f,e)>>1]),k=255,v[j|0]=k;j=_b(f,e),k=b,w[j>>1]=k;j=xb(g,b),k=d,v[j|0]=k}d=Xl(a,b)}g=d&255;if((g|0)==255){break a}if(Mj(x[a>>2])){break a}e=Hd(a+318|0,g);d=y[c+8|0]|y[c+9|0]<<8|(y[c+10|0]<<16|y[c+11|0]<<24);v[e+8|0]=d;v[e+9|0]=d>>>8;v[e+10|0]=d>>>16;v[e+11|0]=d>>>24;d=y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24);f=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);v[e|0]=f;v[e+1|0]=f>>>8;v[e+2|0]=f>>>16;v[e+3|0]=f>>>24;v[e+4|0]=d;v[e+5|0]=d>>>8;v[e+6|0]=d>>>16;v[e+7|0]=d>>>24;f=LU(g);h=f+3|0;d=0;while(1){if((d|0)==2){yh(x[a>>2],x[a+4>>2],b,bv(g)|192,y[xb(c,10)|0])}else{e=d?h:f;yh(x[a>>2],x[a+4>>2],b,(e|32)&65535,y[xb(c,d)|0]);yh(x[a>>2],x[a+4>>2],b,(e|64)&65535,y[xb(c,d+2|0)|0]);yh(x[a>>2],x[a+4>>2],b,(e|96)&65535,y[xb(c,d+4|0)|0]);yh(x[a>>2],x[a+4>>2],b,(e|128)&65535,y[xb(c,d+6|0)|0]);yh(x[a>>2],x[a+4>>2],b,(e|224)&65535,y[xb(c,d+8|0)|0]);d=d+1|0;continue}break}}}function r8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;d=x[d+28>>2];a=fb-384|0;fb=a;x[a+376>>2]=c;x[a+380>>2]=b;qy(a+220|0,d,a+240|0,a+236|0,a+232|0);d=Fb(a+208|0);b=Mc(d);x[31737]=0;O(46,d|0,b|0);b=x[31737];x[31737]=0;a:{b:{c:{if((b|0)!=1){c=cc(d,0);x[a+204>>2]=c;x[a+28>>2]=a+32;x[a+24>>2]=0;v[a+23|0]=1;v[a+22|0]=69;h=x[a+232>>2];i=x[a+236>>2];while(1){d:{x[31737]=0;b=P(1216,a+380|0,a+376|0)|0;g=x[31737];x[31737]=0;if((g|0)==1){break d}if(b){break c}g=x[a+204>>2];b=Cb(x[d+4>>2],y[d+11|0]);if((g|0)==(b+c|0)){x[31737]=0;O(46,d|0,b<<1);c=x[31737];x[31737]=0;if((c|0)==1){break b}c=Mc(d);x[31737]=0;O(46,d|0,c|0);c=x[31737];x[31737]=0;if((c|0)==1){break b}c=cc(d,0);x[a+204>>2]=b+c}x[31737]=0;b=R(1217,x[a+380>>2])|0;g=x[31737];x[31737]=0;if((g|0)==1){break d}if(py(b,a+23|0,a+22|0,c,a+204|0,i,h,a+220|0,a+32|0,a+28|0,a+24|0,a+240|0)){break c}x[31737]=0;R(1219,a+380|0)|0;b=x[31737];x[31737]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Cb(x[a+224>>2],y[a+231|0])|!y[a+23|0]){break e}b=x[a+28>>2];if((b-(a+32|0)|0)>159){break e}x[a+28>>2]=b+4;x[b>>2]=x[a+24>>2]}pK(a,c,x[a+204>>2],e);b=x[a>>2];c=x[a+4>>2];h=x[a+12>>2];x[f+8>>2]=x[a+8>>2];x[f+12>>2]=h;x[f>>2]=b;x[f+4>>2]=c;Xf(a+220|0,a+32|0,x[a+28>>2],e);x[31737]=0;b=P(1216,a+380|0,a+376|0)|0;c=x[31737];x[31737]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+380>>2];tb(d);tb(a+220|0);fb=a+384|0;break a}}b=N()|0;tb(d);tb(a+220|0);Q(b|0);p()}return b|0}function gla(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,z=0,A=0,B=0;f=fb-48|0;fb=f;a:{b:{c:{d:{e:{f:{g:{if(!a){break g}l=e<<2;if(l>>>0>d>>>0){break g}t=l-4|0;o=D(b,e);u=o-8|0;h:while(1){b=x[c+8>>2];g=x[c>>2];x[31737]=0;b=U(151,g|0,b|0,l|0)|0;g=x[31737];x[31737]=0;if((g|0)==1){break b}if(!(n>>>0<o>>>0&b)){break g}x[31737]=0;b=f+8|0;S(186,b|0,c|0,d|0);g=x[31737];x[31737]=0;if((g|0)==1){break c}g=ic(f+28|0,b);ub(b);x[31737]=0;O(576,b|0,g|0);j=x[31737];x[31737]=0;if((j|0)==1){break e}z=_e(b);q=x[f+8>>2];A=q-4|0;j=0;while(1){if((e|0)==(j|0)){Kc(f+8|0);ub(g);n=(q-l<<1)+n|0;continue h}x[31737]=0;h=R(569,g|0)|0;b=x[31737];x[31737]=0;if((b|0)!=1){x[31737]=0;b=R(198,g|0)|0;k=x[31737];x[31737]=0;if((k|0)==1){break f}x[f>>2]=b;Fe(f,0,89);x[31737]=0;P(184,g|0,1)|0;b=x[31737];x[31737]=0;if((b|0)==1){break f}k=j+n|0;b=e+j<<2;i:while(1){j:{if(k>>>0>u>>>0){break j}m=0;if(b>>>0>A>>>0){break j}while(1)if((m|0)==8){b=b+t|0;continue i}else{r=x[f>>2];i=y[b+z|0];s=m&1;i=s?i>>>4|0:i&15;x[f>>2]=r+v[(i&7)+28680|0];B=h;h=w[(r<<1)+28688>>1];h=(((0-(i&1)&h>>2)+(h>>3)|0)+(i<<30>>31&h>>1)|0)+(h&i<<29>>31)|0;x[f+4>>2]=B+(i>>>0<8?h:0-h|0);Fe(f,0,88);Fe(f+4|0,-32768,32767);h=x[f+4>>2];w[(k<<1)+a>>1]=h;m=m+1|0;k=e+k|0;b=b+s|0;continue}}break}j=j+1|0;continue}break}break}break f}ub(c);fb=f+48|0;return}b=N()|0;Kc(f+8|0);break d}b=N()|0}ub(g);break a}b=N()|0;break a}b=N()|0}ub(c);Q(b|0);p()}function A8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;d=x[d+28>>2];a=fb-272|0;fb=a;x[a+264>>2]=c;x[a+268>>2]=b;wy(a+208|0,d,a+224|0,a+223|0,a+222|0);d=Fb(a+196|0);b=Mc(d);x[31737]=0;O(46,d|0,b|0);b=x[31737];x[31737]=0;a:{b:{c:{if((b|0)!=1){c=cc(d,0);x[a+192>>2]=c;x[a+28>>2]=a+32;x[a+24>>2]=0;v[a+23|0]=1;v[a+22|0]=69;h=v[a+222|0];i=v[a+223|0];while(1){d:{x[31737]=0;b=P(1201,a+268|0,a+264|0)|0;g=x[31737];x[31737]=0;if((g|0)==1){break d}if(b){break c}g=x[a+192>>2];b=Cb(x[d+4>>2],y[d+11|0]);if((g|0)==(b+c|0)){x[31737]=0;O(46,d|0,b<<1);c=x[31737];x[31737]=0;if((c|0)==1){break b}c=Mc(d);x[31737]=0;O(46,d|0,c|0);c=x[31737];x[31737]=0;if((c|0)==1){break b}c=cc(d,0);x[a+192>>2]=b+c}x[31737]=0;b=R(1202,x[a+268>>2])|0;g=x[31737];x[31737]=0;if((g|0)==1){break d}if(vy(b,a+23|0,a+22|0,c,a+192|0,i,h,a+208|0,a+32|0,a+28|0,a+24|0,a+224|0)){break c}x[31737]=0;R(1204,a+268|0)|0;b=x[31737];x[31737]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Cb(x[a+212>>2],y[a+219|0])|!y[a+23|0]){break e}b=x[a+28>>2];if((b-(a+32|0)|0)>159){break e}x[a+28>>2]=b+4;x[b>>2]=x[a+24>>2]}pK(a,c,x[a+192>>2],e);b=x[a>>2];c=x[a+4>>2];h=x[a+12>>2];x[f+8>>2]=x[a+8>>2];x[f+12>>2]=h;x[f>>2]=b;x[f+4>>2]=c;Xf(a+208|0,a+32|0,x[a+28>>2],e);x[31737]=0;b=P(1201,a+268|0,a+264|0)|0;c=x[31737];x[31737]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+268>>2];tb(d);tb(a+208|0);fb=a+272|0;break a}}b=N()|0;tb(d);tb(a+208|0);Q(b|0);p()}return b|0}function Poa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=x[a>>2];d=Ud(c,x[a+4>>2]);if(d>>>0<b>>>0){i=fb-32|0;fb=i;b=b-d|0;d=x[zb(a)>>2];c=x[a+4>>2];a:{if(b>>>0<=(d-c|0)/12>>>0){d=fb-16|0;fb=d;b=rv(d+4|0,a,b);a=x[b+4>>2];c=x[b+8>>2];while(1){if((a|0)==(c|0)){hc(b);fb=d+16|0}else{EW(a);a=a+12|0;x[b+4>>2]=a;continue}break}break a}d=zb(a);d=Dm(i+12|0,Wp(a,Ud(x[a>>2],c)+b|0),Ud(x[a>>2],x[a+4>>2]),d);f=fb-16|0;fb=f;b=DW(f+4|0,d+8|0,b);c=x[b>>2];while(1){if(x[b+4>>2]!=(c|0)){EW(c);c=x[b>>2]+12|0;x[b>>2]=c;continue}break}he(b);fb=f+16|0;f=fb-16|0;fb=f;e=zb(a);b=vb(f+12|0,x[a+4>>2]);g=vb(f+8|0,x[a>>2]);h=vb(f+4|0,x[d+4>>2]);c=x[b>>2];g=x[g>>2];b=fb+-64|0;fb=b;h=x[h>>2];x[b+56>>2]=h;x[b+60>>2]=c;x[b+52>>2]=h;e=Re(b+24|0,e,b+52|0,b+56|0);x[b+16>>2]=x[e+8>>2];h=x[e+4>>2];x[b+8>>2]=x[e>>2];x[b+12>>2]=h;Qe(b+36|0,b+8|0);while(1){if(pd(c,g)){CW(Vp(x[b+56>>2]),il(c));c=qk(b+60|0);qk(b+56|0);c=x[c>>2];continue}break}Pe(b+36|0);h=x[b+56>>2];if(!y[b+48|0]){e=fb-16|0;fb=e;c=vb(e+12|0,x[x[b+44>>2]>>2]);j=x[vb(e+8|0,x[x[b+40>>2]>>2])>>2];g=fb-16|0;fb=g;c=x[c>>2];x[g+12>>2]=c;while(1){if(ci(c,j)){uC(ux(c));c=x[hl(g+12|0)>>2];continue}break}fb=g+16|0;fb=e+16|0}fb=b- -64|0;x[d+4>>2]=h;Tb(a,d+4|0);Tb(a+4|0,d+8|0);Tb(zb(a),nc(d));x[d>>2]=x[d+4>>2];fb=f+16|0;a=x[d+4>>2];while(1){b=x[d+8>>2];if((b|0)!=(a|0)){b=b-12|0;x[d+8>>2]=b;uC(b);continue}break}a=x[d>>2];if(a){ys(d);Db(a)}}fb=i+32|0;return}if(b>>>0<d>>>0){FW(a,c+D(b,12)|0)}}function Zja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-96|0;fb=c;_j(c+76|0,b,1413829443);x[31737]=0;b=R(173,x[c+76>>2])|0;d=x[31737];x[31737]=0;a:{b:{c:{if((d|0)==1){break c}if(!b){x[31737]=0;d=c+56|0;S(812,d|0,a+140|0,1413894985);a=x[31737];x[31737]=0;d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{if((a|0)!=1){x[31737]=0;a=P(895,d|0,13752)|0;b=x[31737];x[31737]=0;if((b|0)==1){break e}b=28591;if(a){b=Fb(c+44|0);x[31737]=0;a=R(203,d|0)|0;e=x[31737];x[31737]=0;if((e|0)==1){break m}x[31737]=0;S(271,d|0,b|0,a|0);a=x[31737];x[31737]=0;if((a|0)==1){break m}x[31737]=0;d=P(71,c+20|0,b|0)|0;a=x[31737];x[31737]=0;if((a|0)==1){break l}x[31737]=0;e=c+8|0;W(896,e|0);a=x[31737];x[31737]=0;if((a|0)==1){break k}x[31737]=0;a=c+32|0;S(897,a|0,d|0,e|0);f=x[31737];x[31737]=0;if((f|0)==1){break j}f=Ab(b,a);tb(a);tb(e);tb(d);x[31737]=0;S(259,a|0,2,f|0);d=x[31737];x[31737]=0;if((d|0)==1){break h}x[31737]=0;d=R(775,a|0)|0;e=x[31737];x[31737]=0;if((e|0)==1){break g}tb(a);tb(f);b=d-1>>>0<19398657?1252:28591}ub(c+56|0);break a}a=N()|0;break b}a=N()|0;break f}a=N()|0;break f}a=N()|0;break i}a=N()|0;tb(c+8|0)}tb(d);break f}a=N()|0;break f}a=N()|0;tb(c+32|0)}tb(b);break d}a=N()|0}ub(c+56|0);break b}x[31737]=0;a=U(151,x[c+76>>2],x[c+84>>2],2)|0;b=x[31737];x[31737]=0;if((b|0)==1){break c}b=28591;if(!a){break a}x[31737]=0;b=R(190,c+76|0)|0;a=x[31737];x[31737]=0;if((a|0)!=1){break a}a=N()|0;break b}a=N()|0}ub(c+76|0);Q(a|0);p()}ub(c+76|0);fb=c+96|0;return b|0}function Mna(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=fb-32|0;fb=e;w[e+30>>1]=254;d=Oj(a);c=fb-16|0;fb=c;f=e+16|0;x[f>>2]=0;x[f+4>>2]=0;sc(f+8|0);Rd(c+8|0,x[vb(c+4|0,f)>>2]);a:{b:{if(d){x[31737]=0;O(642,f|0,d|0);g=x[31737];x[31737]=0;if((g|0)==1){break b}QE(f,d)}g=c+8|0;Qd(g);Yj(g);fb=c+16|0;break a}a=N()|0;Yj(c+8|0);Q(a|0);p()}c=x[a>>2];g=x[f>>2];while(1){if((b|0)==(d|0)){c:{if(!(h&65535)){break c}c=wb(c);d=wb(x[a+4>>2]);b=fb-16|0;fb=b;c=KC(c,d,z[e+30>>1]);x[b+12>>2]=c;if(Ib(c,d)){x[b+8>>2]=c;while(1){c=x[Md(b+8|0)>>2];if(Ib(c,d)){c=z[c>>1];if((c|0)==z[e+30>>1]){continue}w[x[b+12>>2]>>1]=c;Md(b+12|0);continue}break}c=x[b+12>>2]}fb=b+16|0;b=vb(e+12|0,c);c=x[vb(e+8|0,wb(x[a+4>>2]))>>2];d=x[b>>2];b=x[a>>2];b=(pp(d,wb(b))<<1)+b|0;if(Ib(d,c)){In(a,Wg(b+(pp(c,d)<<1)|0,x[a+4>>2],b))}wb(b);b=wb(x[a>>2]);x[e+4>>2]=b;d=wb(x[a+4>>2]);while(1){if(Ib(b,d)){d:{c=x[a+24>>2];h=x[c+484344>>2];b=z[b>>1];if(!He(h,x[c+484348>>2],b)){break d}b=Wb(h,b);k=e,l=wb(x[b>>2]),x[k>>2]=l;h=wb(x[b+4>>2]);g=x[f+4>>2];c=x[f>>2];while(1){b=x[e>>2];if(!Ib(b,h)){break d}e:{if(y[b+3|0]!=12){break e}j=Zc(c,g);i=y[b+5|0];if(j>>>0<=i>>>0){break e}k=b,l=y[_b(c,i)|0],v[k+5|0]=l}vg(e);continue}}b=x[Md(e+4|0)>>2];continue}else{b=x[f>>2];d=Zc(b,x[f+4>>2]);c=z[a+28>>1];if(d>>>0<=c>>>0){break c}k=a,l=z[_b(b,c)>>1],w[k+28>>1]=l}break}}}else{k=_b(g,b),l=b-h|0,w[k>>1]=l;h=(z[_b(c,b)>>1]==254)+h|0;b=b+1|0;continue}break}md(f);fb=e+32|0}function Sla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0;g=fb-16|0;fb=g;t=x[a+16>>2];u=Fg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);m=x[a+8>>2];n=x[a+12>>2];h=x[a>>2];e=x[a+4>>2];o=x[a+128>>2];if(o){p=Gg(m,n,o);q=hb;b=x[a+76>>2];hg(h,e,vf(m,n,d),hb);r=hb>>>0>b>>>0?d:0}i=a+112|0;f=x[a+48>>2];k=x[a+40>>2];l=x[a+36>>2];b=x[a+44>>2];x[g>>2]=h;x[g+4>>2]=e;a:while(1){b:{s=b;if(!d){break b}d=d-1|0;x[g+8>>2]=h;x[g+12>>2]=0;r=r-1|0;b=r;p=b?p:0;q=b?q:0;h=(e<<1)+t|0;b=o;while(1)if((b|0)<=0){Pb(i,x[a+120>>2],x[a+124>>2]);b=x[a+116>>2];if(b){be(i,w[h+(x[g+12>>2]<<1)>>1]/4<<16>>16);ae(i,b);x[i>>2]=x[i>>2];x[i+4>>2]=0}b=Eg(i,u);v=x[a+72>>2];y=x[a+32>>2];l=x[a+28>>2]+l|0;h=b<<8;b=h;e=x[a+60>>2];b=Sua(e,e>>31,b,b>>31);z=hb;e=b;b=x[a+64>>2];j=b;A=b>>31;b=Yb(s,-16777216,16776704);j=Sua(j,A,b,b>>31);e=e+j|0;b=hb+z|0;b=e>>>0<j>>>0?b+1|0:b;j=e;e=x[a+68>>2];f=Yb(f,-16777216,16776704);e=Sua(e,e>>31,f,f>>31);f=j+e|0;b=hb+b|0;b=e>>>0>f>>>0?b+1|0:b;f=f+8388608|0;b=f>>>0<8388608?b+1|0:b;b=Rc(f,b,24);f=(b|0)/256|0;x[c>>2]=D(l>>12,f)+x[c>>2];k=k+y|0;x[c+4>>2]=x[c+4>>2]+D(k>>12,f);Pb(g,m,n);b=b-(h&v)|0;c=c+8|0;h=x[g>>2];e=x[g+4>>2];f=s;continue a}else{be(i,w[h+(x[g+12>>2]<<1)>>1]/4<<16>>16);ae(i,4);Pb(g+8|0,p,q);b=b-1|0;continue}}break}x[a>>2]=h;x[a+4>>2]=e;x[a+40>>2]=k;x[a+20>>2]=l>>12;x[a+36>>2]=l;x[a+48>>2]=f;x[a+44>>2]=s;x[a+24>>2]=k>>12;fb=g+16|0}function LO(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=fb-32|0;fb=d;g=Nb(a);a:{b:{c:{a=x[b+36>>2];c=x[b+40>>2];d:{if(Ib(a,c)){sc(d+28|0);break d}x[31737]=0;a=d+16|0;O(1078,a|0,b|0);c=x[31737];x[31737]=0;if((c|0)==1){break b}x[31737]=0;c=R(1062,a|0)|0;e=x[31737];x[31737]=0;if((e|0)==1){break c}x[d+28>>2]=c;nf(a);c=x[b+40>>2];a=x[b+36>>2]}e:{if(Ib(a,c)){c=b+36|0;break e}c=x[d+28>>2];a=x[c>>2]}e=x[c+4>>2];x[31737]=0;O(177,g|0,oj(a,e)|0);a=x[31737];x[31737]=0;f:{if((a|0)!=1){a=wb(x[c>>2]);x[d+12>>2]=a;h=wb(x[c+4>>2]);g:{h:{i:{j:{k:{while(1){if(!Ib(a,h)){El(d+28|0);fb=d+32|0;return}c=y[a+16|0];e=x[x[b+24>>2]+484360>>2];x[31737]=0;e=Tj(e,c);O(1079,d|0,e|0);c=x[31737];x[31737]=0;if((c|0)==1){break g}x[31737]=0;c=d+16|0;O(1065,c|0,d|0);f=x[31737];x[31737]=0;if((f|0)!=1){x[31737]=0;O(179,g|0,c|0);f=x[31737];x[31737]=0;if((f|0)==1){break k}tb(c);tb(d);f=il(x[g+4>>2]);l:{if(!Ad(x[f+4>>2],y[f+11|0])){break l}a=x[a+12>>2];if(!bj(e,a&255)){break l}f=x[b+24>>2];i=x[f+1298404>>2];a=z[_b(x[e>>2],a)>>1];e=x[f+484344>>2];x[31737]=0;O(1072,d|0,Wb(e,a)|0);a=x[31737];x[31737]=0;if((a|0)==1){break i}x[31737]=0;S(1080,c|0,i|0,d|0);a=x[31737];x[31737]=0;if((a|0)==1){break h}Ab(il(x[g+4>>2]),c);tb(c);tb(d)}a=x[fA(d+12|0)>>2];continue}break}a=N()|0;break j}a=N()|0;tb(d+16|0)}tb(d);break f}a=N()|0;break f}a=N()|0;tb(d);break f}a=N()|0;break f}a=N()|0}El(d+28|0);break a}a=N()|0;nf(d+16|0);break a}a=N()|0}Td(g);Q(a|0);p()}function q8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=fb-320|0;fb=a;x[a+312>>2]=c;x[a+316>>2]=b;h=Fb(a+196|0);g=a+16|0;bd(g,x[d+28>>2]);x[31737]=0;b=R(1211,x[a+16>>2])|0;c=x[31737];x[31737]=0;a:{b:{if((c|0)==1){break b}x[31737]=0;V(1222,b|0,111776,111802,a+208|0);b=x[31737];x[31737]=0;if((b|0)==1){break b}Zb(g);c=Fb(a+184|0);b=Mc(c);x[31737]=0;O(46,c|0,b|0);b=x[31737];x[31737]=0;if((b|0)!=1){c:{b=cc(c,0);x[a+180>>2]=b;x[a+12>>2]=g;x[a+8>>2]=0;while(1){d:{x[31737]=0;g=P(1216,a+316|0,a+312|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break d}d=x[a+180>>2];e:{if(!g){g=d;d=Cb(x[c+4>>2],y[c+11|0]);if((g|0)==(d+b|0)){x[31737]=0;O(46,c|0,d<<1);b=x[31737];x[31737]=0;if((b|0)==1){break c}b=Mc(c);x[31737]=0;O(46,c|0,b|0);b=x[31737];x[31737]=0;if((b|0)==1){break c}b=cc(c,0);x[a+180>>2]=d+b}x[31737]=0;d=R(1217,x[a+316>>2])|0;g=x[31737];x[31737]=0;if((g|0)==1){break d}if(!fo(d,16,b,a+180|0,a+8|0,0,x[h+4>>2],y[h+11|0],a+16|0,a+12|0,a+208|0)){break e}d=x[a+180>>2]}x[31737]=0;O(46,c|0,d-b|0);b=x[31737];x[31737]=0;if((b|0)==1){break d}b=Jb(c);d=Od();x[a>>2]=f;if((oK(b,d,a)|0)!=1){x[e>>2]=4}x[31737]=0;b=P(1216,a+316|0,a+312|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break d}if(b){x[e>>2]=x[e>>2]|2}b=x[a+316>>2];tb(c);tb(h);fb=a+320|0;return b|0}x[31737]=0;R(1219,a+316|0)|0;d=x[31737];x[31737]=0;if((d|0)!=1){continue}}break}}}b=N()|0;tb(c);break a}b=N()|0;Zb(a+16|0)}tb(h);Q(b|0);p()}function Z7(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0;n=b;i=fb-416|0;fb=i;x[i+408>>2]=37;x[i+412>>2]=0;b=i+408|0;l=gt(b|1,13966,x[c+4>>2]);j=i+368|0;x[i+364>>2]=j;a=Od();a:{if(l){k=x[c+8>>2];m=i- -64|0;x[m>>2]=g;x[m+4>>2]=h;x[i+56>>2]=e;x[i+60>>2]=f;x[i+48>>2]=k;j=ph(j,30,a,b,i+48|0);break a}x[i+80>>2]=e;x[i+84>>2]=f;x[i+88>>2]=g;x[i+92>>2]=h;j=ph(i+368|0,30,a,i+408|0,i+80|0)}x[i+128>>2]=1199;k=Be(i+356|0,0,i+128|0);b=i+368|0;a=b;b:{c:{d:{e:{if((j|0)>=30){a=Od();f:{if(l){j=x[c+8>>2];x[i+16>>2]=g;x[i+20>>2]=h;x[i+8>>2]=e;x[i+12>>2]=f;x[i>>2]=j;j=rj(i+364|0,a,i+408|0,i);break f}x[i+32>>2]=e;x[i+36>>2]=f;x[i+40>>2]=g;x[i+44>>2]=h;j=rj(i+364|0,a,i+408|0,i+32|0)}if((j|0)==-1){x[31737]=0;X(1200);a=x[31737];x[31737]=0;if((a|0)==1){break d}break e}a=x[i+364>>2];Se(k,a)}f=a+j|0;g=sj(a,f,x[c+4>>2]);x[i+116>>2]=1199;e=Be(i+120|0,0,i+116|0);g:{h:{if((i+368|0)==(a|0)){j=i+128|0;break h}j=Ed(j<<3);if(!j){x[31737]=0;X(1200);a=x[31737];x[31737]=0;if((a|0)!=1){break e}a=N()|0;break g}Se(e,j);b=a}a=i+108|0;bd(a,x[c+28>>2]);x[31737]=0;ga(1230,b|0,g|0,f|0,j|0,i+116|0,i+112|0,a|0);b=x[31737];x[31737]=0;i:{if((b|0)!=1){Zb(a);x[31737]=0;a=ea(1231,n|0,j|0,x[i+116>>2],x[i+112>>2],c|0,d|0)|0;b=x[31737];x[31737]=0;if((b|0)==1){break i}Lc(e);Lc(k);fb=i+416|0;break b}a=N()|0;Zb(i+108|0);break g}a=N()|0}Lc(e);break c}p()}a=N()|0}Lc(k);Q(a|0);p()}return a|0}function dna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0;f=fb-48|0;fb=f;q=x[a+16>>2];b=0;while(1){if((b|0)!=2){g=b<<3;l=g+(f+28|0)|0;g=a+g|0;x[l+4>>2]=x[g+44>>2];x[l+8>>2]=x[g+48>>2];b=b+1|0;continue}break}r=x[a+24>>2];s=x[a+20>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;t=x[a+72>>2];m=x[a+68>>2];u=m>>31;n=x[a+64>>2];v=n>>31;o=x[a+60>>2];y=o>>31;l=x[a+8>>2];z=x[a+12>>2];while(1){if(d){g=x[f+16>>2];i=g>>>18|0;e=((((x[f+20>>2]&2147483647)<<1|g>>>31)&2147483646)<<1)+q|0;b=0;h=0;while(1){if((h|0)!=2){g=e+(h<<1)|0;k=w[g>>1];x[(f+8|0)+(h<<2)>>2]=k+((D(i,w[g+4>>1]-k|0)|0)/16384|0);h=h+1|0;continue}break}while(1){if((b|0)!=2){p=(f+8|0)+(b<<2)|0;e=x[p>>2];g=(f+28|0)+(b<<3)|0;A=x[g+8>>2];h=x[g+4>>2];x[g+8>>2]=h;k=e<<8;e=k;e=Sua(e,e>>31,o,y);i=hb;j=e;e=Yb(h,-16777216,16776704);e=Sua(n,v,e,e>>31);h=j+e|0;j=hb+i|0;j=e>>>0>h>>>0?j+1|0:j;e=Yb(A,-16777216,16776704);i=Sua(m,u,e,e>>31);h=i+h|0;e=hb+j|0;e=h>>>0<i>>>0?e+1|0:e;i=h+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Rc(i,e,24);x[g+4>>2]=e-(k&t);x[p>>2]=(e|0)/256;b=b+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[f+8>>2],s);x[c+4>>2]=x[c+4>>2]+D(r,x[f+12>>2]);Pb(f+16|0,l,z);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+28|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}fb=f+48|0}function z8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=fb-256|0;fb=a;x[a+248>>2]=c;x[a+252>>2]=b;h=Fb(a+196|0);g=a+16|0;bd(g,x[d+28>>2]);x[31737]=0;b=R(28,x[a+16>>2])|0;c=x[31737];x[31737]=0;a:{b:{if((c|0)==1){break b}x[31737]=0;V(1209,b|0,111776,111802,a+208|0);b=x[31737];x[31737]=0;if((b|0)==1){break b}Zb(g);c=Fb(a+184|0);b=Mc(c);x[31737]=0;O(46,c|0,b|0);b=x[31737];x[31737]=0;if((b|0)!=1){c:{b=cc(c,0);x[a+180>>2]=b;x[a+12>>2]=g;x[a+8>>2]=0;while(1){d:{x[31737]=0;g=P(1201,a+252|0,a+248|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break d}d=x[a+180>>2];e:{if(!g){g=d;d=Cb(x[c+4>>2],y[c+11|0]);if((g|0)==(d+b|0)){x[31737]=0;O(46,c|0,d<<1);b=x[31737];x[31737]=0;if((b|0)==1){break c}b=Mc(c);x[31737]=0;O(46,c|0,b|0);b=x[31737];x[31737]=0;if((b|0)==1){break c}b=cc(c,0);x[a+180>>2]=d+b}x[31737]=0;d=R(1202,x[a+252>>2])|0;g=x[31737];x[31737]=0;if((g|0)==1){break d}if(!go(d,16,b,a+180|0,a+8|0,0,x[h+4>>2],y[h+11|0],a+16|0,a+12|0,a+208|0)){break e}d=x[a+180>>2]}x[31737]=0;O(46,c|0,d-b|0);b=x[31737];x[31737]=0;if((b|0)==1){break d}b=Jb(c);d=Od();x[a>>2]=f;if((oK(b,d,a)|0)!=1){x[e>>2]=4}x[31737]=0;b=P(1201,a+252|0,a+248|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break d}if(b){x[e>>2]=x[e>>2]|2}b=x[a+252>>2];tb(c);tb(h);fb=a+256|0;return b|0}x[31737]=0;R(1204,a+252|0)|0;d=x[31737];x[31737]=0;if((d|0)!=1){continue}}break}}}b=N()|0;tb(c);break a}b=N()|0;Zb(a+16|0)}tb(h);Q(b|0);p()}function h8(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0;n=b;i=fb-256|0;fb=i;x[i+248>>2]=37;x[i+252>>2]=0;b=i+248|0;l=gt(b|1,13966,x[c+4>>2]);j=i+208|0;x[i+204>>2]=j;a=Od();a:{if(l){k=x[c+8>>2];m=i- -64|0;x[m>>2]=g;x[m+4>>2]=h;x[i+56>>2]=e;x[i+60>>2]=f;x[i+48>>2]=k;j=ph(j,30,a,b,i+48|0);break a}x[i+80>>2]=e;x[i+84>>2]=f;x[i+88>>2]=g;x[i+92>>2]=h;j=ph(i+208|0,30,a,i+248|0,i+80|0)}x[i+128>>2]=1199;k=Be(i+196|0,0,i+128|0);b=i+208|0;a=b;b:{c:{d:{e:{if((j|0)>=30){a=Od();f:{if(l){j=x[c+8>>2];x[i+16>>2]=g;x[i+20>>2]=h;x[i+8>>2]=e;x[i+12>>2]=f;x[i>>2]=j;j=rj(i+204|0,a,i+248|0,i);break f}x[i+32>>2]=e;x[i+36>>2]=f;x[i+40>>2]=g;x[i+44>>2]=h;j=rj(i+204|0,a,i+248|0,i+32|0)}if((j|0)==-1){x[31737]=0;X(1200);a=x[31737];x[31737]=0;if((a|0)==1){break d}break e}a=x[i+204>>2];Se(k,a)}f=a+j|0;g=sj(a,f,x[c+4>>2]);x[i+116>>2]=1199;e=Be(i+120|0,0,i+116|0);g:{h:{if((i+208|0)==(a|0)){j=i+128|0;break h}j=Ed(j<<1);if(!j){x[31737]=0;X(1200);a=x[31737];x[31737]=0;if((a|0)!=1){break e}a=N()|0;break g}Se(e,j);b=a}a=i+108|0;bd(a,x[c+28>>2]);x[31737]=0;ga(1225,b|0,g|0,f|0,j|0,i+116|0,i+112|0,a|0);b=x[31737];x[31737]=0;i:{if((b|0)!=1){Zb(a);x[31737]=0;a=ea(23,n|0,j|0,x[i+116>>2],x[i+112>>2],c|0,d|0)|0;b=x[31737];x[31737]=0;if((b|0)==1){break i}Lc(e);Lc(k);fb=i+256|0;break b}a=N()|0;Zb(i+108|0);break g}a=N()|0}Lc(e);break c}p()}a=N()|0}Lc(k);Q(a|0);p()}return a|0}function Tla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0,A=0;g=fb-16|0;fb=g;t=x[a+16>>2];u=Fg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);m=x[a+8>>2];n=x[a+12>>2];h=x[a>>2];e=x[a+4>>2];o=x[a+128>>2];if(o){p=Gg(m,n,o);q=hb;b=x[a+76>>2];hg(h,e,vf(m,n,d),hb);r=hb>>>0>b>>>0?d:0}i=a+112|0;f=x[a+48>>2];k=x[a+40>>2];l=x[a+36>>2];b=x[a+44>>2];x[g>>2]=h;x[g+4>>2]=e;a:while(1){b:{s=b;if(!d){break b}d=d-1|0;x[g+8>>2]=h;x[g+12>>2]=0;r=r-1|0;b=r;p=b?p:0;q=b?q:0;h=e+t|0;b=o;while(1)if((b|0)<=0){Pb(i,x[a+120>>2],x[a+124>>2]);b=x[a+116>>2];if(b){be(i,v[h+x[g+12>>2]|0]<<6);ae(i,b);x[i>>2]=x[i>>2];x[i+4>>2]=0}b=Eg(i,u);w=x[a+72>>2];y=x[a+32>>2];l=x[a+28>>2]+l|0;h=b<<8;b=h;e=x[a+60>>2];b=Sua(e,e>>31,b,b>>31);z=hb;e=b;b=x[a+64>>2];j=b;A=b>>31;b=Yb(s,-16777216,16776704);j=Sua(j,A,b,b>>31);e=e+j|0;b=hb+z|0;b=e>>>0<j>>>0?b+1|0:b;j=e;e=x[a+68>>2];f=Yb(f,-16777216,16776704);e=Sua(e,e>>31,f,f>>31);f=j+e|0;b=hb+b|0;b=e>>>0>f>>>0?b+1|0:b;f=f+8388608|0;b=f>>>0<8388608?b+1|0:b;b=Rc(f,b,24);f=(b|0)/256|0;x[c>>2]=D(l>>12,f)+x[c>>2];k=k+y|0;x[c+4>>2]=x[c+4>>2]+D(k>>12,f);Pb(g,m,n);b=b-(h&w)|0;c=c+8|0;h=x[g>>2];e=x[g+4>>2];f=s;continue a}else{be(i,v[h+x[g+12>>2]|0]<<6);ae(i,4);Pb(g+8|0,p,q);b=b-1|0;continue}}break}x[a>>2]=h;x[a+4>>2]=e;x[a+40>>2]=k;x[a+20>>2]=l>>12;x[a+36>>2]=l;x[a+48>>2]=f;x[a+44>>2]=s;x[a+24>>2]=k>>12;fb=g+16|0}function tna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0;f=fb-48|0;fb=f;r=x[a+16>>2];l=mg(1,2);b=hb;s=b;Pb(a,l,b);b=0;while(1){if((b|0)!=2){g=b<<3;k=g+(f+28|0)|0;g=a+g|0;x[k+4>>2]=x[g+44>>2];x[k+8>>2]=x[g+48>>2];b=b+1|0;continue}break}t=x[a+24>>2];u=x[a+20>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;v=x[a+72>>2];m=x[a+68>>2];y=m>>31;n=x[a+64>>2];z=n>>31;o=x[a+60>>2];A=o>>31;k=x[a+8>>2];B=x[a+12>>2];while(1){if(d){d=d-1|0;b=x[f+16>>2];g=((((x[f+20>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+r|0;b=0;e=0;while(1){if((e|0)!=2){x[(f+8|0)+(e<<2)>>2]=w[g+(e<<1)>>1];e=e+1|0;continue}break}while(1){if((b|0)!=2){p=(f+8|0)+(b<<2)|0;e=x[p>>2];g=(f+28|0)+(b<<3)|0;C=x[g+8>>2];h=x[g+4>>2];x[g+8>>2]=h;q=e<<8;e=q;e=Sua(e,e>>31,o,A);i=hb;j=e;e=Yb(h,-16777216,16776704);e=Sua(n,z,e,e>>31);h=j+e|0;j=hb+i|0;j=e>>>0>h>>>0?j+1|0:j;e=Yb(C,-16777216,16776704);i=Sua(m,y,e,e>>31);h=i+h|0;e=hb+j|0;e=h>>>0<i>>>0?e+1|0:e;i=h+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Rc(i,e,24);x[g+4>>2]=e-(v&q);x[p>>2]=(e|0)/256;b=b+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[f+8>>2],u);x[c+4>>2]=x[c+4>>2]+D(t,x[f+12>>2]);Pb(f+16|0,k,B);c=c+8|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+28|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}Hg(a,l,s);fb=f+48|0}function Ama(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0;h=fb-16|0;fb=h;f=x[a+8>>2];j=f;e=x[a+12>>2];i=e;a:{b:{c:{d:{if((e|0)<=1&f>>>0<=805306368|(e|0)<=0){f=e;if((e|0)>-2){f=1}else{f=(f|0)>=-2&j>>>0>=3489660928}if(f){break c}if((i|0)==-2&j>>>0>2147483647|(i|0)==-1){break d}break b}if((i|0)==1&j>>>0>2147483648|i>>>0>1){break b}}n=b+196648|0;break a}n=b+131112|0;break a}n=b+262184|0}r=x[a+16>>2];e=x[a+48>>2];s=x[a+24>>2];t=x[a+20>>2];b=x[a+44>>2];f=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=f;u=x[a+72>>2];o=x[a+68>>2];v=o>>31;p=x[a+64>>2];y=p>>31;q=x[a+60>>2];z=q>>31;while(1){f=b;if(d){b=Yb(b,-16777216,16776704);k=Sua(p,y,b,b>>31);l=hb;b=x[h+8>>2];g=(x[h+12>>2]<<1)+r|0;b=(b>>>16&65520)+n|0;g=(((((((D(w[g-4>>1],w[b+2>>1])+D(w[g-6>>1],w[b>>1])|0)+D(w[g-2>>1],w[b+4>>1])|0)+D(w[g>>1],w[b+6>>1])|0)+D(w[g+2>>1],w[b+8>>1])|0)+D(w[g+4>>1],w[b+10>>1])|0)+D(w[g+6>>1],w[b+12>>1])|0)+D(w[g+8>>1],w[b+14>>1])|0)/32768<<8;b=g;b=Sua(b,b>>31,q,z);k=b+k|0;m=hb+l|0;m=b>>>0>k>>>0?m+1|0:m;b=Yb(e,-16777216,16776704);e=Sua(o,v,b,b>>31);l=e+k|0;b=hb+m|0;b=e>>>0>l>>>0?b+1|0:b;e=l+8388608|0;b=e>>>0<8388608?b+1|0:b;e=Rc(e,b,24);b=(e|0)/256|0;x[c>>2]=D(b,t)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(b,s);Pb(h+8|0,j,i);b=e-(g&u)|0;c=c+8|0;d=d-1|0;e=f;continue}break}b=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=b;x[a+48>>2]=e;x[a+44>>2]=f;fb=h+16|0}function ena(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0,A=0;f=fb-48|0;fb=f;q=x[a+16>>2];b=0;while(1){if((b|0)!=2){g=b<<3;l=g+(f+28|0)|0;g=a+g|0;x[l+4>>2]=x[g+44>>2];x[l+8>>2]=x[g+48>>2];b=b+1|0;continue}break}r=x[a+24>>2];s=x[a+20>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;t=x[a+72>>2];m=x[a+68>>2];u=m>>31;n=x[a+64>>2];w=n>>31;o=x[a+60>>2];y=o>>31;l=x[a+8>>2];z=x[a+12>>2];while(1){if(d){g=x[f+16>>2];i=g>>>10&4194048;e=(((x[f+20>>2]&2147483647)<<1|g>>>31)&-2)+q|0;b=0;h=0;while(1){if((h|0)!=2){g=e+h|0;k=v[g|0];x[(f+8|0)+(h<<2)>>2]=((D(i,v[g+2|0]-k|0)|0)/16384|0)+(k<<8);h=h+1|0;continue}break}while(1){if((b|0)!=2){p=(f+8|0)+(b<<2)|0;e=x[p>>2];g=(f+28|0)+(b<<3)|0;A=x[g+8>>2];h=x[g+4>>2];x[g+8>>2]=h;k=e<<8;e=k;e=Sua(e,e>>31,o,y);i=hb;j=e;e=Yb(h,-16777216,16776704);e=Sua(n,w,e,e>>31);h=j+e|0;j=hb+i|0;j=e>>>0>h>>>0?j+1|0:j;e=Yb(A,-16777216,16776704);i=Sua(m,u,e,e>>31);h=i+h|0;e=hb+j|0;e=h>>>0<i>>>0?e+1|0:e;i=h+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Rc(i,e,24);x[g+4>>2]=e-(k&t);x[p>>2]=(e|0)/256;b=b+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[f+8>>2],s);x[c+4>>2]=x[c+4>>2]+D(r,x[f+12>>2]);Pb(f+16|0,l,z);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+28|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}fb=f+48|0}function AD(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;i=fb-16|0;fb=i;a:{if(b&4){break a}d=y[a+14|0];b:{if(d>>>0>=y[a+15|0]){break b}c=y[a+12|0];if(!(c&2)){break b}v[a+12|0]=c&251}if(!(y[a+12|0]&2)|d>>>0<=y[a+13|0]){break a}f=x[a>>2];c=x[a+4>>2];if(Sd(f,c)>>>0<=d>>>0){break a}f=z[Oc(f,c,d)>>1];c=Oc(x[a>>2],x[a+4>>2],y[a+14|0]-1|0);d=y[a+14|0];if(z[c>>1]<(f-1|0)){d=z[Oc(x[a>>2],x[a+4>>2],d)>>1]-1&65535;f=Uq(a,d,64,64);c=vb(i+12|0,Jk(wb(x[a>>2]),y[a+14|0]));j=em(i+8|0,d,f&255);m=fb-32|0;fb=m;g=x[c>>2];c=x[a>>2];g=(Gv(g,wb(c))<<2)+c|0;c=x[a+4>>2];c:{d:{if(c>>>0<A[zb(a)>>2]){if((c|0)!=(g|0)){break d}cZ(a,j);break c}f=zb(a);e=$f(m+12|0,Mf(a,oc(x[a>>2],c)+1|0),g-x[a>>2]>>2,f);x[31737]=0;O(782,e|0,j|0);c=x[31737];x[31737]=0;if((c|0)!=1){h=fb-16|0;fb=h;c=x[e+4>>2];k=vb(h+12|0,g);d=vb(h+8|0,x[a>>2]);f=vb(h+4|0,x[e+4>>2]);n=e,o=NF(x[k>>2],x[d>>2],x[f>>2]),x[n+4>>2]=o;n=e,o=zr(g,x[a+4>>2],x[e+8>>2]),x[n+8>>2]=o;Tb(a,e+4|0);Tb(a+4|0,e+8|0);Tb(zb(a),nc(e));x[e>>2]=x[e+4>>2];fb=h+16|0;g=c;_f(e);break c}a=N()|0;_f(e);Q(a|0);p()}e=fb-16|0;fb=e;k=x[a+4>>2];f=(k-(g+4|0)|0)+g|0;h=Tg(e+4|0,a,c-f>>2);l=x[h+4>>2];d=f;while(1){if(c>>>0<=d>>>0){hc(h);Ar(g,f,k);fb=e+16|0}else{gp(l,z[d>>1]|z[d+2>>1]<<16);l=l+4|0;x[h+4>>2]=l;d=d+4|0;continue}break}v[g+2|0]=y[j+2|0];w[g>>1]=z[j>>1]}wb(g);fb=m+32|0;break a}v[a+14|0]=d-1}if((b|0)!=16777216){v[a+17|0]=255}fb=i+16|0}function QA(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;h=89;i=92;j=91;k=85;l=84;m=83;n=5;o=118;p=113;q=111;r=107;s=106;t=96;c=88;u=82;v=80;w=78;x=79;y=77;z=57;A=47;d=10;e=8;f=7;a=hs(a);a:{b:{c:{d:{switch(b-1|0){default:c=(b|0)==16777216;if(!c&(b|0)!=32){break c}Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(a,0,1),7,1),8,1),9,1),10,1),11,1),12,1),13,1),14,1),15,1),16,1),17,1),18,1),19,1),20,1),21,1),22,1),23,1),24,1),25,1),26,1),27,1),28,1),29,1),30,1),31,1),32,1),33,1),34,1),35,1),36,1),37,1),38,1),39,1),40,1),41,1),42,1),43,1),44,1),45,1),46,1),47,1),48,1),103,1),50,1),87,1),88,1),100,1),102,1),104,1),115,1),119,1),120,1);if(!c){break a}d=111;e=105;f=99;break b;case 3:Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(a,0,1),4,1),8,1),9,1),10,1),17,1),40,1),51,1),52,1),53,1),54,1),55,1),56,1),57,1),58,1),59,1),60,1),61,1),62,1),63,1),64,1),65,1),66,1);o=112;p=98;q=93;r=90;s=89;t=88;c=86;u=76;v=75;w=74;x=73;y=72;z=71;A=70;d=69;e=68;g=67;case 1:Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(a,g,1),e,1),d,1),A,1),z,1),y,1),x,1),w,1),v,1);n=u;m=c;l=t;k=s;j=r;i=q;c=p;h=o;break;case 2:break c;case 0:break d}}Lb(Lb(Lb(Lb(a,n,1),m,1),l,1),k,1);g=j;f=i;e=c;d=h}Lb(a,g,1)}Lb(Lb(Lb(a,f,1),e,1),d,1)}}function u3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=fb-2096|0;fb=d;tu(d+48|0);a:{b:{c:{if(Jp(x[(x[x[c>>2]-12>>2]+c|0)+16>>2])){a=ac(8);x[31737]=0;c=P(36,d+36|0,10469)|0;b=x[31737];x[31737]=0;if((b|0)!=1){pc(a,c);x[31737]=0;S(98,a|0,48540,1006);a=x[31737];x[31737]=0;if((a|0)!=1){break b}b=N()|0;tb(c);break c}b=N()|0;jc(a);break c}g=tM(c);if(g){b=rM(c)}else{b=0}x[d+24>>2]=b;x[d+28>>2]=0;h=c+16|0;b=2048;d:{while(1){e:{if(!b){break e}if(!sM(x[x[x[c>>2]-12>>2]+h>>2])){break e}e=x[x[x[Dj(c,(d+48|0)+f|0,b)>>2]-12>>2]+h>>2];if(Jp(e)){a=ac(8);x[31737]=0;c=P(36,d+36|0,10469)|0;b=x[31737];x[31737]=0;if((b|0)==1){break d}pc(a,c);x[31737]=0;S(98,a|0,48540,1006);a=x[31737];x[31737]=0;if((a|0)!=1){break b}b=N()|0;tb(c);break c}f:{if(VF(e)){break f}if(!tk(e)){break f}a=ac(8);x[31737]=0;c=P(36,d+36|0,10469)|0;b=x[31737];x[31737]=0;if((b|0)!=1){pc(a,c);x[31737]=0;S(98,a|0,48540,1006);a=x[31737];x[31737]=0;if((a|0)!=1){break b}b=N()|0;tb(c);break c}b=N()|0;jc(a);break c}e=x[c+4>>2];b=b-e|0;f=e+f|0;continue}break}b=gc(d+16|0,d+48|0,f);c=x[b+4>>2];x[d+8>>2]=x[b>>2];x[d+12>>2]=c;a=zu(a,d+8|0,g?d+24|0:0);if(a+1>>>0>=3){a=ac(8);x[31737]=0;c=P(36,d+36|0,8057)|0;b=x[31737];x[31737]=0;if((b|0)!=1){pc(a,c);x[31737]=0;S(98,a|0,48540,1006);a=x[31737];x[31737]=0;if((a|0)!=1){break b}b=N()|0;tb(c);break c}b=N()|0;jc(a);break c}fb=d+2096|0;break a}b=N()|0;jc(a)}Q(b|0)}p()}return a|0}function Bma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0;h=fb-16|0;fb=h;g=x[a+8>>2];j=g;e=x[a+12>>2];i=e;a:{b:{c:{d:{if((e|0)<=1&g>>>0<=805306368|(e|0)<=0){g=e;if((e|0)>-2){g=1}else{g=(g|0)>=-2&j>>>0>=3489660928}if(g){break c}if((i|0)==-2&j>>>0>2147483647|(i|0)==-1){break d}break b}if((i|0)==1&j>>>0>2147483648|i>>>0>1){break b}}l=b+196648|0;break a}l=b+131112|0;break a}l=b+262184|0}q=x[a+16>>2];b=x[a+48>>2];r=x[a+24>>2];s=x[a+20>>2];e=x[a+44>>2];g=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=g;t=x[a+72>>2];m=x[a+68>>2];u=m>>31;n=x[a+64>>2];y=n>>31;o=x[a+60>>2];z=o>>31;while(1){g=e;if(d){e=Yb(e,-16777216,16776704);f=Sua(n,y,e,e>>31);e=hb;b=Yb(b,-16777216,16776704);b=Sua(m,u,b,b>>31);f=b+f|0;e=hb+e|0;e=b>>>0>f>>>0?e+1|0:e;b=x[h+8>>2];k=f;f=x[h+12>>2]+q|0;b=(b>>>16&65520)+l|0;p=(((((((D(v[f-2|0],w[b+2>>1])+D(v[f-3|0],w[b>>1])|0)+D(v[f-1|0],w[b+4>>1])|0)+D(v[f|0],w[b+6>>1])|0)+D(v[f+1|0],w[b+8>>1])|0)+D(v[f+2|0],w[b+10>>1])|0)+D(v[f+3|0],w[b+12>>1])|0)+D(v[f+4|0],w[b+14>>1])<<8)/32768<<8;b=p;f=Sua(b,b>>31,o,z);k=k+f|0;b=hb+e|0;b=f>>>0>k>>>0?b+1|0:b;e=k+8388608|0;b=e>>>0<8388608?b+1|0:b;e=Rc(e,b,24);b=(e|0)/256|0;x[c>>2]=D(b,s)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(b,r);Pb(h+8|0,j,i);e=e-(t&p)|0;c=c+8|0;d=d-1|0;b=g;continue}break}c=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=c;x[a+48>>2]=b;x[a+44>>2]=g;fb=h+16|0}function l1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=fb-16|0;fb=f;xc(c);while(1){a:{if(!Mb(x[c>>2],x[c+8>>2],3)){break a}d=f+13|0;Xr(d,c);i=Jc(d);h=$e(d);d=y[f+13|0];if(d>>>0>=A[a+12>>2]){break a}g=jd(x[a>>2],x[x[a+48>>2]+12>>2],d,b);d=y[i|0];if(d>>>0<=126){if(!(d|y[h|0])){v[g|0]=254;continue}v[g|0]=d+1;if(y[h|0]==255){continue}v[g+2|0]=1;v[g+4|0]=y[h|0];continue}b:{switch(d-127|0){case 1:v[g+1|0]=y[h|0]+1;continue;case 0:continue;default:break b}}e=v[h|0];v[f+12|0]=e;h=0;j=y[i|0];d=j&127;if(d>>>0<=23){h=y[d+24624|0]}c:{d:{e:{f:{g:{switch(d-2|0){case 0:case 8:case 9:if((e|0)>=0){break f}d=0-e&15;break e;case 1:v[f+8|0]=64;e=y[Qb(f+12|0,f+8|0)|0];if(y[g+2|0]>1){break d}v[g+4|0]=e;v[g+2|0]=1;continue;case 2:d=3;if((e|0)>=0){break c}d=0-e&127;break e;case 15:if(!e){continue}d=0-e|-16;if((e|0)<0){break e}d=e<<4|15;break e;case 16:case 20:if(!e){continue}d=(e|0)>=0;if(!d){e=0-e&15;v[f+12|0]=e;j=y[i|0]}d=d?3:2;e=((j|0)==22?-32:-16)|e;v[f+12|0]=e;break c;case 17:d=e&15|-48;break e;case 18:d=e&15|-64;break e;case 21:break g;default:break d}}d=164;if((e|0)==100){break e}x[f+8>>2]=e- -64;x[f+4>>2]=0;x[f>>2]=128;e=x[dk(f+8|0,f+4|0,f)>>2];if(!y[g+3|0]){break d}h:{switch(y[g+2|0]){case 0:case 2:break h;default:continue}}v[g+2|0]=2;v[g+4|0]=(e&254)>>>1;continue}d=e<<4}e=d;v[f+12|0]=e}d=h;if(!d){continue}}v[g+5|0]=e;v[g+3|0]=d;continue}break}fb=f+16|0}function LS(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;f=fb-48|0;fb=f;b=Gw(f+30|0,x[a>>2]);c=pq(f+29|0,x[a+4>>2]);JY(f+32|0,z[b>>1],c);c=pq(f+28|0,x[a+8>>2]);d=z[f+32>>1];b=fb-16|0;fb=b;v[b+15|0]=y[f+34|0];FS(f+36|0,d,b+15|0,c);fb=b+16|0;c=fb-16|0;fb=c;d=fb-16|0;fb=d;h=z[f+36>>1]<<16>>16;g=y[f+38|0];b=Pf(g);e=Pf(2);g=Pf(g);b=h-(((b|0)!=(e|0)?b>>>0<e>>>0?-1:1:0)<<24>>24<=0)|0;e=(((b|0)<0?b-399|0:b)|0)/400|0;b=D(e,-400)+b|0;b=x[vb(d+12|0,((((Pf(y[f+39|0])+D(e,146097)|0)+((D(g+(g>>>0>2?-3:9)|0,153)+2>>>0)/5|0)+(b>>>2)|0)+D(b,365)|0)-((b>>>0)/100|0)|0)-719469|0)>>2];fb=d+16|0;e=x[vb(c+12|0,b)>>2];fb=c+16|0;g=vb(f+24|0,x[a+12>>2]);c=fb-16|0;fb=c;b=fb-16|0;fb=b;d=fb-16|0;fb=d;e=x[vb(d+12|0,D(e,24))>>2];fb=d+16|0;x[b+8>>2]=e;d=x[vb(b+12|0,x[g>>2]+x[b+8>>2]|0)>>2];fb=b+16|0;e=x[vb(c+12|0,d)>>2];fb=c+16|0;g=vb(f+20|0,x[a+16>>2]);c=fb-16|0;fb=c;b=fb-16|0;fb=b;d=fb-16|0;fb=d;e=x[vb(d+12|0,D(e,60))>>2];fb=d+16|0;x[b+8>>2]=e;d=x[vb(b+12|0,x[g>>2]+x[b+8>>2]|0)>>2];fb=b+16|0;b=x[vb(c+12|0,d)>>2];fb=c+16|0;c=we(f+8|0,x[a+24>>2],x[a+28>>2]);d=fb-16|0;fb=d;a=fb-16|0;fb=a;e=fb-16|0;fb=e;b=we(e+8|0,Sua(b,b>>31,60,0),hb);g=x[b>>2];b=x[b+4>>2];fb=e+16|0;x[a>>2]=g;x[a+4>>2]=b;b=x[a>>2];e=b+x[c>>2]|0;c=x[c+4>>2]+x[a+4>>2]|0;b=we(a+8|0,e,b>>>0>e>>>0?c+1|0:c);c=x[b>>2];fb=a+16|0;a=we(d+8|0,c,x[b+4>>2]);b=x[a>>2];fb=d+16|0;a=Du(f+40|0,b,x[a+4>>2]);b=x[a>>2];fb=f+48|0;hb=x[a+4>>2];return b}function vna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0,A=0,B=0,C=0;f=fb-48|0;fb=f;r=x[a+16>>2];l=mg(1,2);b=hb;s=b;Pb(a,l,b);b=0;while(1){if((b|0)!=2){g=b<<3;k=g+(f+28|0)|0;g=a+g|0;x[k+4>>2]=x[g+44>>2];x[k+8>>2]=x[g+48>>2];b=b+1|0;continue}break}t=x[a+24>>2];u=x[a+20>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;w=x[a+72>>2];m=x[a+68>>2];y=m>>31;n=x[a+64>>2];z=n>>31;o=x[a+60>>2];A=o>>31;k=x[a+8>>2];B=x[a+12>>2];while(1){if(d){d=d-1|0;b=x[f+16>>2];g=(((x[f+20>>2]&2147483647)<<1|b>>>31)&-2)+r|0;b=0;e=0;while(1){if((e|0)!=2){x[(f+8|0)+(e<<2)>>2]=v[e+g|0]<<8;e=e+1|0;continue}break}while(1){if((b|0)!=2){p=(f+8|0)+(b<<2)|0;e=x[p>>2];g=(f+28|0)+(b<<3)|0;C=x[g+8>>2];h=x[g+4>>2];x[g+8>>2]=h;q=e<<8;e=q;e=Sua(e,e>>31,o,A);i=hb;j=e;e=Yb(h,-16777216,16776704);e=Sua(n,z,e,e>>31);h=j+e|0;j=hb+i|0;j=e>>>0>h>>>0?j+1|0:j;e=Yb(C,-16777216,16776704);i=Sua(m,y,e,e>>31);h=i+h|0;e=hb+j|0;e=h>>>0<i>>>0?e+1|0:e;i=h+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Rc(i,e,24);x[g+4>>2]=e-(w&q);x[p>>2]=(e|0)/256;b=b+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[f+8>>2],u);x[c+4>>2]=x[c+4>>2]+D(t,x[f+12>>2]);Pb(f+16|0,k,B);c=c+8|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+28|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}Hg(a,l,s);fb=f+48|0}function TO(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=fb+-64|0;fb=e;g=Nb(a);a=0;c=x[b+24>>2];h=Oj(Xb(x[c+484360>>2],y[c+484376|0]));x[31737]=0;O(177,g|0,h|0);c=x[31737];x[31737]=0;a:{if((c|0)!=1){while(1){b:{if((a|0)!=(h|0)){c=x[b+24>>2];f=x[c+484344>>2];d=x[c+484348>>2];c=z[_b(x[Xb(x[c+484360>>2],y[c+484376|0])>>2],a)>>1];if(vp(f,d,c)){x[31737]=0;d=e+40|0;O(1072,d|0,Wb(f,c)|0);c=x[31737];x[31737]=0;c:{d:{e:{if((c|0)!=1){f=x[b+24>>2];x[31737]=0;c=e+52|0;S(1059,c|0,f|0,d|0);f=x[31737];x[31737]=0;if((f|0)==1){break e}x[31737]=0;O(179,g|0,c|0);f=x[31737];x[31737]=0;if((f|0)==1){break d}tb(c);tb(d);break b}a=N()|0;break a}a=N()|0;break c}a=N()|0;tb(e+52|0)}tb(e+40|0);break a}f:{switch(c-65534|0){case 0:x[31737]=0;c=P(36,e+28|0,9256)|0;d=x[31737];x[31737]=0;g:{if((d|0)!=1){x[31737]=0;O(179,g|0,c|0);d=x[31737];x[31737]=0;if((d|0)==1){break g}tb(c);break b}a=N()|0;break a}a=N()|0;tb(c);break a;case 1:x[31737]=0;c=P(36,e+16|0,9218)|0;d=x[31737];x[31737]=0;h:{if((d|0)!=1){x[31737]=0;O(179,g|0,c|0);d=x[31737];x[31737]=0;if((d|0)==1){break h}tb(c);break b}a=N()|0;break a}a=N()|0;tb(c);break a;default:break f}}x[31737]=0;c=P(36,e+4|0,14661)|0;d=x[31737];x[31737]=0;i:{if((d|0)!=1){x[31737]=0;O(179,g|0,c|0);d=x[31737];x[31737]=0;if((d|0)==1){break i}tb(c);break b}a=N()|0;break a}a=N()|0;tb(c);break a}fb=e- -64|0;return}a=a+1|0;continue}}a=N()|0}Td(g);Q(a|0);p()}function Aja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;m=fb-32|0;fb=m;e=b;b=x[a>>2];g=D(wu(e,wb(b)),6)+b|0;a:{if(!c){break a}b=x[zb(a)>>2];i=x[a+4>>2];if((b-i|0)/6>>>0>=c>>>0){b=c;e=(i-g|0)/6|0;if(e>>>0<c>>>0){tD(a,c-e|0,d);b=e;if((g|0)==(i|0)){break a}}n=fb-16|0;fb=n;o=x[a+4>>2];h=D((o-(D(c,6)+g|0)|0)/6|0,6)+g|0;f=Ir(n+4|0,a,(i-h|0)/6|0);k=x[f+4>>2];e=h;while(1){if(e>>>0>=i>>>0){hc(f);i=fb-16|0;fb=i;j=fb-32|0;fb=j;Id(j+24|0,g,h);l=fb-16|0;fb=l;k=x[j+28>>2];f=x[j+24>>2];h=k-f|0;e=D((h|0)/-6|0,6)+o|0;x[l+12>>2]=e;ml(e,f,h);Ac(j+16|0,k,l+12|0);fb=l+16|0;e=wR(g,x[j+16>>2]);p=j,q=rA(o,x[j+20>>2]),x[p+12>>2]=q;Ac(i+8|0,e,j+12|0);fb=j+32|0;fb=i+16|0;fb=n+16|0}else{Ov(k,e);k=k+6|0;x[f+4>>2]=k;e=e+6|0;continue}break}e=g;c=D(e>>>0<=d>>>0?A[a+4>>2]>d>>>0?c:0:0,6)+d|0;while(1){if(b){a=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);v[e|0]=a;v[e+1|0]=a>>>8;v[e+2|0]=a>>>16;v[e+3|0]=a>>>24;a=y[c+4|0]|y[c+5|0]<<8;v[e+4|0]=a;v[e+5|0]=a>>>8;b=b-1|0;e=e+6|0;continue}break}break a}b=zb(a);f=yZ(m+12|0,oD(a,Mk(x[a>>2],i)+c|0),(g-x[a>>2]|0)/6|0,b);xZ(f,c,d);h=fb-16|0;fb=h;b=x[f+4>>2];e=vb(h+12|0,g);d=vb(h+8|0,x[a>>2]);c=vb(h+4|0,x[f+4>>2]);p=f,q=uZ(x[e>>2],x[d>>2],x[c>>2]),x[p+4>>2]=q;p=f,q=tA(g,x[a+4>>2],x[f+8>>2]),x[p+8>>2]=q;Tb(a,f+4|0);Tb(a+4|0,f+8|0);Tb(zb(a),nc(f));x[f>>2]=x[f+4>>2];fb=h+16|0;g=b;wZ(f)}wb(g);fb=m+32|0}function t8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=E(0);d=x[d+28>>2];a=fb-368|0;fb=a;x[a+360>>2]=c;x[a+364>>2]=b;qy(a+204|0,d,a+224|0,a+220|0,a+216|0);d=Fb(a+192|0);b=Mc(d);x[31737]=0;O(46,d|0,b|0);b=x[31737];x[31737]=0;a:{b:{c:{if((b|0)!=1){c=cc(d,0);x[a+188>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;v[a+7|0]=1;v[a+6|0]=69;h=x[a+216>>2];i=x[a+220>>2];while(1){d:{x[31737]=0;b=P(1216,a+364|0,a+360|0)|0;g=x[31737];x[31737]=0;if((g|0)==1){break d}if(b){break c}g=x[a+188>>2];b=Cb(x[d+4>>2],y[d+11|0]);if((g|0)==(b+c|0)){x[31737]=0;O(46,d|0,b<<1);c=x[31737];x[31737]=0;if((c|0)==1){break b}c=Mc(d);x[31737]=0;O(46,d|0,c|0);c=x[31737];x[31737]=0;if((c|0)==1){break b}c=cc(d,0);x[a+188>>2]=b+c}x[31737]=0;b=R(1217,x[a+364>>2])|0;g=x[31737];x[31737]=0;if((g|0)==1){break d}if(py(b,a+7|0,a+6|0,c,a+188|0,i,h,a+204|0,a+16|0,a+12|0,a+8|0,a+224|0)){break c}x[31737]=0;R(1219,a+364|0)|0;b=x[31737];x[31737]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Cb(x[a+208>>2],y[a+215|0])|!y[a+7|0]){break e}b=x[a+12>>2];if((b-(a+16|0)|0)>159){break e}x[a+12>>2]=b+4;x[b>>2]=x[a+8>>2]}j=f,k=sK(c,x[a+188>>2],e),B[j>>2]=k;Xf(a+204|0,a+16|0,x[a+12>>2],e);x[31737]=0;b=P(1216,a+364|0,a+360|0)|0;c=x[31737];x[31737]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+364>>2];tb(d);tb(a+204|0);fb=a+368|0;break a}}b=N()|0;tb(d);tb(a+204|0);Q(b|0);p()}return b|0}function C8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=E(0);d=x[d+28>>2];a=fb-256|0;fb=a;x[a+248>>2]=c;x[a+252>>2]=b;wy(a+192|0,d,a+208|0,a+207|0,a+206|0);d=Fb(a+180|0);b=Mc(d);x[31737]=0;O(46,d|0,b|0);b=x[31737];x[31737]=0;a:{b:{c:{if((b|0)!=1){c=cc(d,0);x[a+176>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;v[a+7|0]=1;v[a+6|0]=69;h=v[a+206|0];i=v[a+207|0];while(1){d:{x[31737]=0;b=P(1201,a+252|0,a+248|0)|0;g=x[31737];x[31737]=0;if((g|0)==1){break d}if(b){break c}g=x[a+176>>2];b=Cb(x[d+4>>2],y[d+11|0]);if((g|0)==(b+c|0)){x[31737]=0;O(46,d|0,b<<1);c=x[31737];x[31737]=0;if((c|0)==1){break b}c=Mc(d);x[31737]=0;O(46,d|0,c|0);c=x[31737];x[31737]=0;if((c|0)==1){break b}c=cc(d,0);x[a+176>>2]=b+c}x[31737]=0;b=R(1202,x[a+252>>2])|0;g=x[31737];x[31737]=0;if((g|0)==1){break d}if(vy(b,a+7|0,a+6|0,c,a+176|0,i,h,a+192|0,a+16|0,a+12|0,a+8|0,a+208|0)){break c}x[31737]=0;R(1204,a+252|0)|0;b=x[31737];x[31737]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Cb(x[a+196>>2],y[a+203|0])|!y[a+7|0]){break e}b=x[a+12>>2];if((b-(a+16|0)|0)>159){break e}x[a+12>>2]=b+4;x[b>>2]=x[a+8>>2]}j=f,k=sK(c,x[a+176>>2],e),B[j>>2]=k;Xf(a+192|0,a+16|0,x[a+12>>2],e);x[31737]=0;b=P(1201,a+252|0,a+248|0)|0;c=x[31737];x[31737]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+252>>2];tb(d);tb(a+192|0);fb=a+256|0;break a}}b=N()|0;tb(d);tb(a+192|0);Q(b|0);p()}return b|0}function s8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;d=x[d+28>>2];a=fb-368|0;fb=a;x[a+360>>2]=c;x[a+364>>2]=b;qy(a+204|0,d,a+224|0,a+220|0,a+216|0);d=Fb(a+192|0);b=Mc(d);x[31737]=0;O(46,d|0,b|0);b=x[31737];x[31737]=0;a:{b:{c:{if((b|0)!=1){c=cc(d,0);x[a+188>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;v[a+7|0]=1;v[a+6|0]=69;h=x[a+216>>2];i=x[a+220>>2];while(1){d:{x[31737]=0;b=P(1216,a+364|0,a+360|0)|0;g=x[31737];x[31737]=0;if((g|0)==1){break d}if(b){break c}g=x[a+188>>2];b=Cb(x[d+4>>2],y[d+11|0]);if((g|0)==(b+c|0)){x[31737]=0;O(46,d|0,b<<1);c=x[31737];x[31737]=0;if((c|0)==1){break b}c=Mc(d);x[31737]=0;O(46,d|0,c|0);c=x[31737];x[31737]=0;if((c|0)==1){break b}c=cc(d,0);x[a+188>>2]=b+c}x[31737]=0;b=R(1217,x[a+364>>2])|0;g=x[31737];x[31737]=0;if((g|0)==1){break d}if(py(b,a+7|0,a+6|0,c,a+188|0,i,h,a+204|0,a+16|0,a+12|0,a+8|0,a+224|0)){break c}x[31737]=0;R(1219,a+364|0)|0;b=x[31737];x[31737]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Cb(x[a+208>>2],y[a+215|0])|!y[a+7|0]){break e}b=x[a+12>>2];if((b-(a+16|0)|0)>159){break e}x[a+12>>2]=b+4;x[b>>2]=x[a+8>>2]}j=f,k=qK(c,x[a+188>>2],e),C[j>>3]=k;Xf(a+204|0,a+16|0,x[a+12>>2],e);x[31737]=0;b=P(1216,a+364|0,a+360|0)|0;c=x[31737];x[31737]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+364>>2];tb(d);tb(a+204|0);fb=a+368|0;break a}}b=N()|0;tb(d);tb(a+204|0);Q(b|0);p()}return b|0}function B8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;d=x[d+28>>2];a=fb-256|0;fb=a;x[a+248>>2]=c;x[a+252>>2]=b;wy(a+192|0,d,a+208|0,a+207|0,a+206|0);d=Fb(a+180|0);b=Mc(d);x[31737]=0;O(46,d|0,b|0);b=x[31737];x[31737]=0;a:{b:{c:{if((b|0)!=1){c=cc(d,0);x[a+176>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;v[a+7|0]=1;v[a+6|0]=69;h=v[a+206|0];i=v[a+207|0];while(1){d:{x[31737]=0;b=P(1201,a+252|0,a+248|0)|0;g=x[31737];x[31737]=0;if((g|0)==1){break d}if(b){break c}g=x[a+176>>2];b=Cb(x[d+4>>2],y[d+11|0]);if((g|0)==(b+c|0)){x[31737]=0;O(46,d|0,b<<1);c=x[31737];x[31737]=0;if((c|0)==1){break b}c=Mc(d);x[31737]=0;O(46,d|0,c|0);c=x[31737];x[31737]=0;if((c|0)==1){break b}c=cc(d,0);x[a+176>>2]=b+c}x[31737]=0;b=R(1202,x[a+252>>2])|0;g=x[31737];x[31737]=0;if((g|0)==1){break d}if(vy(b,a+7|0,a+6|0,c,a+176|0,i,h,a+192|0,a+16|0,a+12|0,a+8|0,a+208|0)){break c}x[31737]=0;R(1204,a+252|0)|0;b=x[31737];x[31737]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Cb(x[a+196>>2],y[a+203|0])|!y[a+7|0]){break e}b=x[a+12>>2];if((b-(a+16|0)|0)>159){break e}x[a+12>>2]=b+4;x[b>>2]=x[a+8>>2]}j=f,k=qK(c,x[a+176>>2],e),C[j>>3]=k;Xf(a+192|0,a+16|0,x[a+12>>2],e);x[31737]=0;b=P(1201,a+252|0,a+248|0)|0;c=x[31737];x[31737]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+252>>2];tb(d);tb(a+192|0);fb=a+256|0;break a}}b=N()|0;tb(d);tb(a+192|0);Q(b|0);p()}return b|0}function p7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=fb-480|0;fb=a;bd(a+476|0,x[d+28>>2]);x[31737]=0;n=R(1211,x[a+476>>2])|0;g=x[31737];x[31737]=0;a:{b:{c:{d:{e:{if((g|0)!=1){if(Cb(x[f+4>>2],y[f+11|0])){g=x[Vd(f,0)>>2];x[31737]=0;h=P(1228,n|0,45)|0;j=x[31737];x[31737]=0;if((j|0)==1){break e}o=(g|0)==(h|0)}j=Fb(a+452|0);g=Fb(a+440|0);h=Fb(a+428|0);x[31737]=0;ka(1250,c|0,o|0,x[a+476>>2],a+472|0,a+468|0,a+464|0,j|0,g|0,h|0,a+424|0);c=x[31737];x[31737]=0;if((c|0)==1){break d}x[a+4>>2]=1199;c=Be(a+8|0,0,a+4|0);k=a+16|0;l=Cb(x[f+4>>2],y[f+11|0]);m=x[a+424>>2];f:{if((l|0)>(m|0)){i=((Cb(x[h+4>>2],y[h+11|0])+(l-m<<1)|0)+Cb(x[g+4>>2],y[g+11|0])|0)+1|0;break f}i=(Cb(x[h+4>>2],y[h+11|0])+Cb(x[g+4>>2],y[g+11|0])|0)+2|0}g:{i=i+m|0;if(i>>>0>=101){Se(c,Ed(i<<2));k=x[c>>2];if(!k){break g}l=Cb(x[f+4>>2],y[f+11|0])}i=x[d+4>>2];f=Jb(f);x[31737]=0;ma(1251,k|0,a+4|0,a|0,i|0,f|0,f+(l<<2)|0,n|0,o|0,a+472|0,x[a+468>>2],x[a+464>>2],j|0,g|0,h|0,m|0);f=x[31737];x[31737]=0;if((f|0)==1){break c}x[31737]=0;b=ea(1231,b|0,k|0,x[a+4>>2],x[a>>2],d|0,e|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break c}Lc(c);Ub(h);Ub(g);tb(j);Zb(a+476|0);fb=a+480|0;return b|0}x[31737]=0;X(1200);b=x[31737];x[31737]=0;if((b|0)==1){break c}p()}f=N()|0;break a}f=N()|0;break a}f=N()|0;break b}f=N()|0;Lc(c)}Ub(h);Ub(g);tb(j)}Zb(a+476|0);Q(f|0);p()}function l7(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;n=fb-16|0;fb=n;b=c;while(1){a:{if((b|0)==(d|0)){b=d;break a}if(!x[b>>2]){break a}b=b+4|0;continue}break}x[h>>2]=f;x[e>>2]=c;while(1){b:{c:{if(!((c|0)==(d|0)|(f|0)==(g|0))){q=1;r=fb-16|0;fb=r;s=Nh(r+12|0,x[a+8>>2]);i=f;j=g-f|0;m=0;o=fb-16|0;fb=o;k=x[e>>2];p=b-c>>2;d:{if(!k|!p){break d}j=f?j:0;while(1){l=Vy(j>>>0<4?o+12|0:i,x[k>>2]);if((l|0)==-1){m=-1;break d}if(i){if(j>>>0<=3){if(j>>>0<l>>>0){break d}yc(i,o+12|0,l)}j=j-l|0;i=i+l|0}else{i=0}if(!x[k>>2]){k=0;break d}m=m+l|0;k=k+4|0;p=p-1|0;if(p){continue}break}}if(i){x[e>>2]=k}fb=o+16|0;Mh(s);fb=r+16|0;e:{f:{g:{h:{switch(m+1|0){case 0:x[h>>2]=f;while(1){i:{if(x[e>>2]==(c|0)){break i}b=fy(f,x[c>>2],x[a+8>>2]);if((b|0)==-1){break i}f=b+x[h>>2]|0;x[h>>2]=f;c=c+4|0;continue}break};x[e>>2]=c;break g;case 1:break c;default:break h}}f=x[h>>2]+m|0;x[h>>2]=f;if((f|0)==(g|0)){break e}if((b|0)==(d|0)){c=x[e>>2];b=d;continue}b=fy(n+12|0,0,x[a+8>>2]);if((b|0)!=-1){break f}}q=2;break c}c=n+12|0;if(g-x[h>>2]>>>0<b>>>0){break c}while(1){if(b){f=y[c|0];i=x[h>>2];x[h>>2]=i+1;v[i|0]=f;b=b-1|0;c=c+1|0;continue}break}c=x[e>>2]+4|0;x[e>>2]=c;b=c;while(1){if((b|0)==(d|0)){b=d;break b}if(!x[b>>2]){break b}b=b+4|0;continue}}c=x[e>>2]}q=(c|0)!=(d|0)}fb=n+16|0;return q|0}f=x[h>>2];continue}}function Lqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=fb-16|0;fb=e;a:{if((c|0)!=4){g=b+236|0;h=b+108|0;while(1){if((d|0)==120){break a}f=(d<<2)+a|0;i=y[f+4|0];j=xb(h,d),k=i+1|0,v[j|0]=k;f=y[f+6|0]|y[f+7|0]<<8;j=_b(g,d),k=f+1|0,w[j>>1]=k;d=d+1|0;continue}}f=b+236|0;while(1){if((d|0)==96){break a}g=(d<<2)+a|0;g=y[g+6|0]|y[g+7|0]<<8;j=_b(f,d+12|0),k=g+1|0,w[j>>1]=k;d=d+1|0;continue}}XC(a+484|0,b+48|0,0,c);XC(a+590|0,b+68|0,0,c);XC(a+696|0,b+88|0,5,c);x[b>>2]=y[a+806|0]|y[a+807|0]<<8;d=v[a+808|0];b:{if((d|0)<0){v[b+34|0]=d-127;break b}if(d>>>0>16){break b}if(v[a|0]&1){v[b+31|0]=d+1;break b}if(!d){break b}v[b+31|0]=d+1}if(y[b+31|0]){c:{d:{if((c|0)==4){d=y[a+810|0];break d}d=v[a+809|0];if((d|0)>=0){w[b+28>>1]=(d&255)+1}d=v[a+810|0];if((d|0)<0){break c}}v[b+30|0]=d+1}v[b+33|0]=y[a+811|0]}if((c|0)==32){v[e+15|0]=y[a+812|0];v[e+14|0]=128;j=b,k=y[Qb(e+15|0,e+14|0)|0]>>>1|0,x[j+4>>2]=k}c=y[a+813|0]|y[a+814|0]<<8;if(c>>>0<=256){x[b+8>>2]=c;v[b+15|0]=y[b+15|0]|1}v[b+16|0]=y[a+815|0];v[b+26|0]=y[a+816|0];v[b+27|0]=y[a+817|0];v[b+17|0]=y[a+818|0];v[b+18|0]=y[a+819|0];w[e+12>>1]=y[a+820|0]|y[a+821|0]<<8;w[e+10>>1]=100;j=b,k=y[Nc(e+12|0,e+10|0)|0],v[j+20|0]=k;w[e+8>>1]=y[a+822|0]|y[a+823|0]<<8;w[e+6>>1]=256;j=b,k=z[Nc(e+8|0,e+6|0)>>1]>>>2|0,v[j+19|0]=k;c=y[a+824|0];ik(b,c&127,c>>>7|0);a=y[a+825|0];hk(b,a&127,a>>>7|0);fb=e+16|0}function wG(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=x[a>>2];e=jh(c,x[a+4>>2]);if(e>>>0<b>>>0){j=fb-32|0;fb=j;c=b-e|0;b=x[zb(a)>>2];d=x[a+4>>2];a:{if(c>>>0<=b-d>>3>>>0){e=fb-16|0;fb=e;b=ks(e+4|0,a,c);a=x[b+4>>2];c=x[b+8>>2];while(1){if((a|0)==(c|0)){hc(b);fb=e+16|0}else{el(a);a=a+8|0;x[b+4>>2]=a;continue}break}break a}b=zb(a);e=ms(j+12|0,ns(a,jh(x[a>>2],d)+c|0),jh(x[a>>2],x[a+4>>2]),b);d=fb-16|0;fb=d;f=x[e+8>>2];b=d+4|0;x[b+8>>2]=e+8;x[b>>2]=f;x[b+4>>2]=f+(c<<3);c=x[b>>2];while(1){if(x[b+4>>2]!=(c|0)){el(c);c=x[b>>2]+8|0;x[b>>2]=c;continue}break}he(b);fb=d+16|0;h=fb-16|0;fb=h;b=vb(h+12|0,x[a+4>>2]);d=vb(h+8|0,x[a>>2]);g=x[vb(h+4|0,x[e+4>>2])>>2];i=fb-16|0;fb=i;c=fb-32|0;fb=c;Id(c+24|0,x[b>>2],x[d>>2]);k=c+16|0;b=x[c+24>>2];l=x[c+28>>2];f=fb-16|0;fb=f;x[f+8>>2]=g;x[f+12>>2]=b;while(1){if(pd(b,l)){d=Op(b);g=Op(x[f+8>>2]);b=y[d+4|0]|y[d+5|0]<<8|(y[d+6|0]<<16|y[d+7|0]<<24);d=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);v[g|0]=d;v[g+1|0]=d>>>8;v[g+2|0]=d>>>16;v[g+3|0]=d>>>24;v[g+4|0]=b;v[g+5|0]=b>>>8;v[g+6|0]=b>>>16;v[g+7|0]=b>>>24;b=Np(f+12|0);Np(f+8|0);b=x[b>>2];continue}break}Ac(k,b,f+8|0);fb=f+16|0;b=x[c+16>>2];x[c+12>>2]=x[c+20>>2];Ac(i+8|0,b,c+12|0);fb=c+32|0;fb=i+16|0;x[e+4>>2]=x[i+12>>2];Tb(a,e+4|0);Tb(a+4|0,e+8|0);Tb(zb(a),nc(e));x[e>>2]=x[e+4>>2];fb=h+16|0;ls(e)}fb=j+32|0;return}if(b>>>0<e>>>0){uG(a,c+(b<<3)|0)}}function Boa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;i=fb-16|0;fb=i;ld(d,32);h=i+8|0;qW(h,y[a+24|0]|y[a+25|0]<<8|(y[a+26|0]<<16|y[a+27|0]<<24),y[a+28|0]|y[a+29|0]<<8|(y[a+30|0]<<16|y[a+31|0]<<24),x[b>>2]);h=ec(h);qW(i,y[a+40|0]|y[a+41|0]<<8|(y[a+42|0]<<16|y[a+43|0]<<24),y[a+44|0]|y[a+45|0]<<8|(y[a+46|0]<<16|y[a+47|0]<<24),x[c>>2]);a=0;a:{h=x[h>>2];if(h-838861>>>0<4294128436){break a}e=x[ec(i)>>2];x[d>>2]=D(h,320);w[d+34>>1]=1;if(!Eh(d)){break a}k=h<<2;f=+(k>>>0);o=+(e>>>0)/f;p=+(h>>>0)/f;q=1/+A[d>>2];r=+A[i>>2];s=+A[i+8>>2];h=0;b:while(1){if((h|0)==(k|0)){a=1;break a}l=+(h>>>0);m=0;n=0;e=x[b+20>>2];if(je(x[b>>2],e)){f=l*p+s;c:{if(f<4294967296&f>=0){g=~~f>>>0;break c}g=0}a=g;f=f-+(a>>>0);j=z[b+34>>1];a=_d(j);g=D(g,a);d:{if(j&1){e=e+(g<<1)|0;a=z[e+(a<<1)>>1];e=z[e>>1];break d}g=e+g|0;e=y[g|0]<<8;a=y[a+g|0]<<8}n=+(e<<16>>16)*(1-f)+f*+(a<<16>>16)}e=x[c+20>>2];if(je(x[c>>2],e)){f=l*o+r;e:{if(f<4294967296&f>=0){g=~~f>>>0;break e}g=0}a=g;f=f-+(a>>>0);j=z[c+34>>1];a=_d(j);g=D(g,a);f:{if(j&1){e=e+(g<<1)|0;a=z[e+(a<<1)>>1];e=z[e>>1];break f}g=e+g|0;e=y[g|0]<<8;a=y[a+g|0]<<8}m=+(e<<16>>16)*(1-f)+f*+(a<<16>>16)}e=0;a=h;while(1)if((e|0)==80){h=h+1|0;continue b}else{f=q*+(a>>>0);t=x[d+20>>2]+(a<<1)|0,u=qC(n*(1-f)+m*f),w[t>>1]=u;a=a+k|0;e=e+1|0;continue}}}fb=i+16|0;return a|0}function w8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;a=fb-336|0;fb=a;x[a+328>>2]=c;x[a+332>>2]=b;b=vj(x[d+4>>2]);i=lq(x[d+28>>2],a+208|0);kq(a+196|0,x[d+28>>2],a+324|0);d=Fb(a+184|0);c=Mc(d);x[31737]=0;O(46,d|0,c|0);c=x[31737];x[31737]=0;a:{b:{c:{if((c|0)!=1){c=cc(d,0);x[a+180>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;while(1){d:{x[31737]=0;g=P(1216,a+332|0,a+328|0)|0;h=x[31737];x[31737]=0;if((h|0)==1){break d}if(g){break c}h=x[a+180>>2];g=Cb(x[d+4>>2],y[d+11|0]);if((h|0)==(g+c|0)){x[31737]=0;O(46,d|0,g<<1);c=x[31737];x[31737]=0;if((c|0)==1){break b}c=Mc(d);x[31737]=0;O(46,d|0,c|0);c=x[31737];x[31737]=0;if((c|0)==1){break b}c=cc(d,0);x[a+180>>2]=g+c}x[31737]=0;g=R(1217,x[a+332>>2])|0;h=x[31737];x[31737]=0;if((h|0)==1){break d}if(fo(g,b,c,a+180|0,a+8|0,x[a+324>>2],x[a+200>>2],y[a+207|0],a+16|0,a+12|0,i)){break c}x[31737]=0;R(1219,a+332|0)|0;g=x[31737];x[31737]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Cb(x[a+200>>2],y[a+207|0])){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}j=f,k=xK(c,x[a+180>>2],e,b),x[j>>2]=k;x[f+4>>2]=hb;Xf(a+196|0,a+16|0,x[a+12>>2],e);x[31737]=0;b=P(1216,a+332|0,a+328|0)|0;c=x[31737];x[31737]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+332>>2];tb(d);tb(a+196|0);fb=a+336|0;break a}}b=N()|0;tb(d);tb(a+196|0);Q(b|0);p()}return b|0}function u8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;a=fb-336|0;fb=a;x[a+328>>2]=c;x[a+332>>2]=b;b=vj(x[d+4>>2]);i=lq(x[d+28>>2],a+208|0);kq(a+196|0,x[d+28>>2],a+324|0);d=Fb(a+184|0);c=Mc(d);x[31737]=0;O(46,d|0,c|0);c=x[31737];x[31737]=0;a:{b:{c:{if((c|0)!=1){c=cc(d,0);x[a+180>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;while(1){d:{x[31737]=0;g=P(1216,a+332|0,a+328|0)|0;h=x[31737];x[31737]=0;if((h|0)==1){break d}if(g){break c}h=x[a+180>>2];g=Cb(x[d+4>>2],y[d+11|0]);if((h|0)==(g+c|0)){x[31737]=0;O(46,d|0,g<<1);c=x[31737];x[31737]=0;if((c|0)==1){break b}c=Mc(d);x[31737]=0;O(46,d|0,c|0);c=x[31737];x[31737]=0;if((c|0)==1){break b}c=cc(d,0);x[a+180>>2]=g+c}x[31737]=0;g=R(1217,x[a+332>>2])|0;h=x[31737];x[31737]=0;if((h|0)==1){break d}if(fo(g,b,c,a+180|0,a+8|0,x[a+324>>2],x[a+200>>2],y[a+207|0],a+16|0,a+12|0,i)){break c}x[31737]=0;R(1219,a+332|0)|0;g=x[31737];x[31737]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Cb(x[a+200>>2],y[a+207|0])){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}j=f,k=tK(c,x[a+180>>2],e,b),x[j>>2]=k;x[f+4>>2]=hb;Xf(a+196|0,a+16|0,x[a+12>>2],e);x[31737]=0;b=P(1216,a+332|0,a+328|0)|0;c=x[31737];x[31737]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+332>>2];tb(d);tb(a+196|0);fb=a+336|0;break a}}b=N()|0;tb(d);tb(a+196|0);Q(b|0);p()}return b|0}function t7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=fb-176|0;fb=a;bd(a+172|0,x[d+28>>2]);x[31737]=0;n=R(28,x[a+172>>2])|0;g=x[31737];x[31737]=0;a:{b:{c:{d:{e:{if((g|0)!=1){if(Cb(x[f+4>>2],y[f+11|0])){g=y[cc(f,0)|0];x[31737]=0;h=P(29,n|0,45)|0;j=x[31737];x[31737]=0;if((j|0)==1){break e}o=(h&255)==(g|0)}j=Fb(a+152|0);g=Fb(a+140|0);h=Fb(a+128|0);x[31737]=0;ka(1248,c|0,o|0,x[a+172>>2],a+168|0,a+167|0,a+166|0,j|0,g|0,h|0,a+124|0);c=x[31737];x[31737]=0;if((c|0)==1){break d}x[a+4>>2]=1199;c=Be(a+8|0,0,a+4|0);k=a+16|0;l=Cb(x[f+4>>2],y[f+11|0]);m=x[a+124>>2];f:{if((l|0)>(m|0)){i=((Cb(x[h+4>>2],y[h+11|0])+(l-m<<1)|0)+Cb(x[g+4>>2],y[g+11|0])|0)+1|0;break f}i=(Cb(x[h+4>>2],y[h+11|0])+Cb(x[g+4>>2],y[g+11|0])|0)+2|0}g:{i=i+m|0;if(i>>>0>=101){Se(c,Ed(i));k=x[c>>2];if(!k){break g}l=Cb(x[f+4>>2],y[f+11|0])}i=x[d+4>>2];f=Jb(f);x[31737]=0;ma(1249,k|0,a+4|0,a|0,i|0,f|0,f+l|0,n|0,o|0,a+168|0,v[a+167|0],v[a+166|0],j|0,g|0,h|0,m|0);f=x[31737];x[31737]=0;if((f|0)==1){break c}x[31737]=0;b=ea(23,b|0,k|0,x[a+4>>2],x[a>>2],d|0,e|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break c}Lc(c);tb(h);tb(g);tb(j);Zb(a+172|0);fb=a+176|0;return b|0}x[31737]=0;X(1200);b=x[31737];x[31737]=0;if((b|0)==1){break c}p()}f=N()|0;break a}f=N()|0;break a}f=N()|0;break b}f=N()|0;Lc(c)}tb(h);tb(g);tb(j)}Zb(a+172|0);Q(f|0);p()}function pY(a,b){var c=0;a:{b:{c:{if(ne(a,16791)){break c}if(ne(a,17558)){break c}if(ne(a,13697)){break c}if(ne(a,13822)){break c}if(!ne(a,14304)){break b}}w[b+10>>1]=4;x[b>>2]=12052;break a}d:{e:{if(ne(a,17553)){break e}if(ne(a,13702)){break e}if(!ne(a,16781)){break d}}v[b+15|0]=1;v[b+12|0]=1;x[b>>2]=8391;w[b+10>>1]=4;break a}f:{if(!ne(a,14342)){if(!ne(a,14347)){break f}}w[b+10>>1]=8;x[b>>2]=8169;break a}g:{if(!ne(a,15485)){if(!ne(a,15490)){break g}}x[b>>2]=17145;w[b+10>>1]=v[a+2|0]-48;break a}h:{if(!ne(a,25290)){if(!ne(a,25295)){break h}}x[b+4>>2]=1;x[b>>2]=16951;w[b+10>>1]=y[a|0]==56?8:4;break a}if(!(kd(a,15584,3)|(y[a+3|0]-52&255)>>>0>4)){x[b>>2]=8509;a=v[a+3|0];w[b+8>>1]=1088;w[b+10>>1]=a-48;break a}i:{j:{if(kd(a,13760,3)){if(kd(a,13879,3)){break j}}if((y[a+3|0]-52&255)>>>0>5){break j}v[b+15|0]=1;v[b+13|0]=1;x[b>>2]=8268;break i}k:{if((y[a|0]-49&255)>>>0>8){break k}if(!kd(a+1|0,13900,3)){v[b+14|0]=1;x[b>>2]=8589;w[b+10>>1]=v[a|0]-48;break a}c=y[a+2|0]|y[a+3|0]<<8;if((c|0)!=18499&(c|0)!=20035|(y[a+1|0]-48&255)>>>0>9){break k}v[b+14|0]=1;x[b>>2]=8589;w[b+10>>1]=(v[a+1|0]+D(v[a|0],10)|0)-528;break a}if(!(kd(a,13588,3)|(y[a+3|0]-49&255)>>>0>8)){x[b>>2]=8418;break i}if(ne(a,13972)){v[b+16|0]=1;w[b+10>>1]=4;break a}if(ne(a,14299)){v[b+14|0]=1;x[b>>2]=8589;w[b+10>>1]=8;a=1}else{a=0}return a}w[b+10>>1]=v[a+3|0]-48}return 1}function vN(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=+e;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=fb-16|0;fb=h;g=x[a+32>>2];f=xq(g);if(!f){f=wq(g)}a:{b:{c:{if(b>>>0>=f>>>0){b=ac(8);x[31737]=0;c=P(36,h+4|0,6e3)|0;a=x[31737];x[31737]=0;if((a|0)==1){break c}pc(b,c);x[31737]=0;S(98,b|0,48540,1006);a=x[31737];x[31737]=0;if((a|0)!=1){break a}a=N()|0;tb(c);break b}if(c>>>0>=120){b=ac(8);x[31737]=0;c=P(36,h+4|0,11334)|0;a=x[31737];x[31737]=0;if((a|0)!=1){pc(b,c);x[31737]=0;S(98,b|0,48540,1006);a=x[31737];x[31737]=0;if((a|0)!=1){break a}a=N()|0;tb(c);break b}a=N()|0;jc(b);break b}f=dB(g,65535);j=(f|0)==65535?255:f;w[h+4>>1]=j;f=g+D(j,872)|0;i=f+1074992|0;Uo(i,g,65535,1024);c=c+1|0;v[f+1075794|0]=c;v[f+1075791|0]=c;w[f+1075778>>1]=0;cn(i);Po(x[a+32>>2],i,b+1|0,0,1,1);x[f+1075688>>2]=65536;Qu(x[a+32>>2],i,c,0,1,1,65535);l=f+1075684|0,m=Zi(Uv(e*128,-128,128)+128),x[l>>2]=m;l=f+1075680|0,m=Zi(Uv(d*256,0,256)),x[l>>2]=m;c=x[a+32>>2];i=c+1074478|0;b=i;c=b+(z[c+480212>>1]<<1)|0;g=z[h+4>>1];f=g;while(1){d:{e:{if((b|0)!=(c|0)){if((f|0)!=z[b>>1]){break e}}else{b=c}break d}b=b+2|0;continue}break}f:{if((b|0)==(c|0)){break f}f=b;while(1){while(1){f=f+2|0;if((f|0)==(c|0)){c=b;break f}k=z[f>>1];if((k|0)==(g|0)){continue}break}w[b>>1]=k;b=b+2|0;g=z[h+4>>1];continue}}l=x[a+32>>2],m=HB(i,c),w[l+480212>>1]=m;fb=h+16|0;return j|0}a=N()|0;jc(b)}Q(a|0)}p()}function hua(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;i=Fb(a);a=y[b+11|0];g=x[b+4>>2];x[31737]=0;k=xh(g,a);O(111,i|0,k|0);a=x[31737];x[31737]=0;a:{b:{if((a|0)!=1){g=0;a=0;while(1){c:{if((a|0)==(k|0)){a=!f;if(!(l?a&(m^-1):a)){break c}return}e=v[cc(b,a)|0];h=e&255;d:{e:{f:{g:{switch(f+1|0){case 1:f=1;h:{switch(h-123|0){case 2:break h;case 0:break d;default:break f}}f=3;break d;case 2:i:{switch(h-123|0){case 2:m=1;e=g+1|0;f=0;if(d>>>0<=g>>>0){g=e;break d}x[31737]=0;O(303,i|0,Hd(c,g)|0);h=x[31737];x[31737]=0;g=e;if((h|0)!=1){break d}a=N()|0;break b;case 0:break f;default:break i}}f=-1;e=e-48|0;if((e&255)>>>0>9){break d}l=1;f=2;j=e;break d;case 3:f=-1;j:{switch(h-123|0){case 2:f=0;if(d>>>0<=j>>>0){break d}x[31737]=0;O(303,i|0,Hd(c,j)|0);e=x[31737];x[31737]=0;if((e|0)!=1){break d}a=N()|0;break b;case 0:break d;default:break j}}if((e-48&255)>>>0>9){break d}j=(D(j,10)+e|0)-48|0;l=1;f=2;break d;case 4:break g;case 0:break e;default:break d}}h=(e|0)!=125;f=-1;e=125;if(h){break d}}f=0;x[31737]=0;O(112,i|0,e|0);e=x[31737];x[31737]=0;if((e|0)!=1){break d}a=N()|0;break b}f=-1}a=a+1|0;continue}break}b=ac(8);x[31737]=0;a=R(97,b|0)|0;c=x[31737];x[31737]=0;if((c|0)!=1){x[31737]=0;S(98,a|0,40292,17);a=x[31737];x[31737]=0;if((a|0)!=1){break a}a=N()|0;break b}a=N()|0;jc(b);break b}a=N()|0}tb(i);Q(a|0)}p()}function _oa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=fb-48|0;fb=e;ld(b,2);f=e+24|0;Pk(f,2,a+1|0);d=e+36|0;Cc(d,f);ze(b+43|0,d);tb(d);a:{b:{c:{d:{switch(y[a|0]){case 0:f=x[b+4>>2];d=x[b+8>>2];break c;case 2:break b;case 1:break d;default:break a}}d=y[a+16|0]|y[a+17|0]<<8|(y[a+18|0]<<16|y[a+19|0]<<24);x[b>>2]=d;x[e+36>>2]=y[a+20|0]|y[a+21|0]<<8|(y[a+22|0]<<16|y[a+23|0]<<24);x[e+24>>2]=d-1;d=e+36|0;f=x[Gb(d,e+24|0)>>2];x[b+4>>2]=f;x[e+36>>2]=y[a+24|0]|y[a+25|0]<<8|(y[a+26|0]<<16|y[a+27|0]<<24);d=x[Gb(d,b)>>2];x[b+8>>2]=d;w[b+34>>1]=z[b+34>>1]&65533|y[a+31|0]<<1&2}if(d>>>0>f>>>0&d>>>0>=2){break a}w[b+34>>1]=0;x[b+4>>2]=0;x[b+8>>2]=0;break a}f=e+24|0;nh(f,a+16|0);d=x[e+24>>2];x[e+36>>2]=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);nh(f,a+20|0);d=x[e+24>>2];x[e+40>>2]=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);nh(f,a+24|0);d=x[e+24>>2];d=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);x[e+44>>2]=d;x[e+16>>2]=d;d=x[e+40>>2];x[e+8>>2]=x[e+36>>2];x[e+12>>2]=d;Yk(b,1,e+8|0)}v[e+36|0]=y[a+28|0];v[e+24|0]=64;g=b,h=y[Qb(e+36|0,e+24|0)|0]<<2,w[g+30>>1]=h;d=y[a+32|0]|y[a+33|0]<<8|(y[a+34|0]<<16|y[a+35|0]<<24);x[b+24>>2]=d;b=b+24|0;e:{if(!c){break e}if(y[a|0]==2){d=d&65535;x[b>>2]=d;break e}if(A[b>>2]>=65536){x[b>>2]=65535}d=x[b>>2]}f:{g:{if(!d){a=8363;break g}a=1024;if(d>>>0>1023){break f}}x[b>>2]=a}fb=e+48|0}function x8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;a=fb-336|0;fb=a;x[a+328>>2]=c;x[a+332>>2]=b;b=vj(x[d+4>>2]);i=lq(x[d+28>>2],a+208|0);kq(a+196|0,x[d+28>>2],a+324|0);d=Fb(a+184|0);c=Mc(d);x[31737]=0;O(46,d|0,c|0);c=x[31737];x[31737]=0;a:{b:{c:{if((c|0)!=1){c=cc(d,0);x[a+180>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;while(1){d:{x[31737]=0;g=P(1216,a+332|0,a+328|0)|0;h=x[31737];x[31737]=0;if((h|0)==1){break d}if(g){break c}h=x[a+180>>2];g=Cb(x[d+4>>2],y[d+11|0]);if((h|0)==(g+c|0)){x[31737]=0;O(46,d|0,g<<1);c=x[31737];x[31737]=0;if((c|0)==1){break b}c=Mc(d);x[31737]=0;O(46,d|0,c|0);c=x[31737];x[31737]=0;if((c|0)==1){break b}c=cc(d,0);x[a+180>>2]=g+c}x[31737]=0;g=R(1217,x[a+332>>2])|0;h=x[31737];x[31737]=0;if((h|0)==1){break d}if(fo(g,b,c,a+180|0,a+8|0,x[a+324>>2],x[a+200>>2],y[a+207|0],a+16|0,a+12|0,i)){break c}x[31737]=0;R(1219,a+332|0)|0;g=x[31737];x[31737]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Cb(x[a+200>>2],y[a+207|0])){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}j=f,k=zK(c,x[a+180>>2],e,b),x[j>>2]=k;Xf(a+196|0,a+16|0,x[a+12>>2],e);x[31737]=0;b=P(1216,a+332|0,a+328|0)|0;c=x[31737];x[31737]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+332>>2];tb(d);tb(a+196|0);fb=a+336|0;break a}}b=N()|0;tb(d);tb(a+196|0);Q(b|0);p()}return b|0}function v8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;a=fb-336|0;fb=a;x[a+328>>2]=c;x[a+332>>2]=b;b=vj(x[d+4>>2]);i=lq(x[d+28>>2],a+208|0);kq(a+196|0,x[d+28>>2],a+324|0);d=Fb(a+184|0);c=Mc(d);x[31737]=0;O(46,d|0,c|0);c=x[31737];x[31737]=0;a:{b:{c:{if((c|0)!=1){c=cc(d,0);x[a+180>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;while(1){d:{x[31737]=0;g=P(1216,a+332|0,a+328|0)|0;h=x[31737];x[31737]=0;if((h|0)==1){break d}if(g){break c}h=x[a+180>>2];g=Cb(x[d+4>>2],y[d+11|0]);if((h|0)==(g+c|0)){x[31737]=0;O(46,d|0,g<<1);c=x[31737];x[31737]=0;if((c|0)==1){break b}c=Mc(d);x[31737]=0;O(46,d|0,c|0);c=x[31737];x[31737]=0;if((c|0)==1){break b}c=cc(d,0);x[a+180>>2]=g+c}x[31737]=0;g=R(1217,x[a+332>>2])|0;h=x[31737];x[31737]=0;if((h|0)==1){break d}if(fo(g,b,c,a+180|0,a+8|0,x[a+324>>2],x[a+200>>2],y[a+207|0],a+16|0,a+12|0,i)){break c}x[31737]=0;R(1219,a+332|0)|0;g=x[31737];x[31737]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Cb(x[a+200>>2],y[a+207|0])){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}j=f,k=wK(c,x[a+180>>2],e,b),w[j>>1]=k;Xf(a+196|0,a+16|0,x[a+12>>2],e);x[31737]=0;b=P(1216,a+332|0,a+328|0)|0;c=x[31737];x[31737]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+332>>2];tb(d);tb(a+196|0);fb=a+336|0;break a}}b=N()|0;tb(d);tb(a+196|0);Q(b|0);p()}return b|0}function lK(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;a=fb-336|0;fb=a;x[a+328>>2]=c;x[a+332>>2]=b;b=vj(x[d+4>>2]);i=lq(x[d+28>>2],a+208|0);kq(a+196|0,x[d+28>>2],a+324|0);d=Fb(a+184|0);c=Mc(d);x[31737]=0;O(46,d|0,c|0);c=x[31737];x[31737]=0;a:{b:{c:{if((c|0)!=1){c=cc(d,0);x[a+180>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;while(1){d:{x[31737]=0;g=P(1216,a+332|0,a+328|0)|0;h=x[31737];x[31737]=0;if((h|0)==1){break d}if(g){break c}h=x[a+180>>2];g=Cb(x[d+4>>2],y[d+11|0]);if((h|0)==(g+c|0)){x[31737]=0;O(46,d|0,g<<1);c=x[31737];x[31737]=0;if((c|0)==1){break b}c=Mc(d);x[31737]=0;O(46,d|0,c|0);c=x[31737];x[31737]=0;if((c|0)==1){break b}c=cc(d,0);x[a+180>>2]=g+c}x[31737]=0;g=R(1217,x[a+332>>2])|0;h=x[31737];x[31737]=0;if((h|0)==1){break d}if(fo(g,b,c,a+180|0,a+8|0,x[a+324>>2],x[a+200>>2],y[a+207|0],a+16|0,a+12|0,i)){break c}x[31737]=0;R(1219,a+332|0)|0;g=x[31737];x[31737]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Cb(x[a+200>>2],y[a+207|0])){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}j=f,k=uK(c,x[a+180>>2],e,b),x[j>>2]=k;Xf(a+196|0,a+16|0,x[a+12>>2],e);x[31737]=0;b=P(1216,a+332|0,a+328|0)|0;c=x[31737];x[31737]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+332>>2];tb(d);tb(a+196|0);fb=a+336|0;break a}}b=N()|0;tb(d);tb(a+196|0);Q(b|0);p()}return b|0}function aJ(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0;a=fb-16|0;fb=a;x[a+12>>2]=c;x[a+8>>2]=f;x[a+12>>2]=c;x[a+8>>2]=f;a:{b:{c:{while(1){c=x[a+12>>2];if(!(c>>>0>=d>>>0|f>>>0>=g>>>0)){i=v[c|0];j=i&255;d:{if((i|0)>=0){w[f>>1]=j;b=c+1|0;break d}b=2;if(i>>>0<4294967234){break b}if(i>>>0<=4294967263){if((d-c|0)<2){break c}i=y[c+1|0];if((i&192)!=128){break a}w[f>>1]=i&63|j<<6&1984;b=c+2|0;break d}if(i>>>0<=4294967279){if((d-c|0)<3){break c}k=y[c+2|0];i=y[c+1|0];e:{f:{if((j|0)!=237){if((j|0)!=224){break f}if((i&224)==160){break e}break a}if((i&224)==128){break e}break a}if((i&192)!=128){break a}}if((k&192)!=128){break a}w[f>>1]=k&63|((i&63)<<6|j<<12);b=c+3|0;break d}if(i>>>0>4294967284){break b}b=1;if((d-c|0)<4){break a}k=y[c+3|0];i=y[c+2|0];c=y[c+1|0];g:{h:{switch(j-240|0){case 0:if((c+112&255)>>>0>=48){break b}break g;case 4:if((c&240)!=128){break b}break g;default:break h}}if((c&192)!=128){break b}}if((i&192)!=128|(k&192)!=128){break b}if((g-f|0)<4){break a}b=2;j=j&7;if((c<<12&196608|j<<18)>>>0>1114111){break a}b=c<<2;w[f>>1]=(i>>>4&3|(b&192|j<<8|b&60))+16320|55296;x[a+8>>2]=f+2;w[f+2>>1]=i<<6&960|k&63|56320;b=x[a+12>>2]+4|0}x[a+12>>2]=b;f=x[a+8>>2]+2|0;x[a+8>>2]=f;continue}break}b=c>>>0<d>>>0;break a}b=1;break a}b=2}x[e>>2]=x[a+12>>2];x[h>>2]=x[a+8>>2];fb=a+16|0;return b|0}function F8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;g=x[d+4>>2];d=x[d+28>>2];a=fb-224|0;fb=a;x[a+216>>2]=c;x[a+220>>2]=b;b=vj(g);mq(a+200|0,d,a+215|0);d=Fb(a+188|0);c=Mc(d);x[31737]=0;O(46,d|0,c|0);c=x[31737];x[31737]=0;a:{b:{c:{if((c|0)!=1){c=cc(d,0);x[a+184>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;while(1){d:{x[31737]=0;g=P(1201,a+220|0,a+216|0)|0;h=x[31737];x[31737]=0;if((h|0)==1){break d}if(g){break c}h=x[a+184>>2];g=Cb(x[d+4>>2],y[d+11|0]);if((h|0)==(g+c|0)){x[31737]=0;O(46,d|0,g<<1);c=x[31737];x[31737]=0;if((c|0)==1){break b}c=Mc(d);x[31737]=0;O(46,d|0,c|0);c=x[31737];x[31737]=0;if((c|0)==1){break b}c=cc(d,0);x[a+184>>2]=g+c}x[31737]=0;g=R(1202,x[a+220>>2])|0;h=x[31737];x[31737]=0;if((h|0)==1){break d}if(go(g,b,c,a+184|0,a+8|0,v[a+215|0],x[a+204>>2],y[a+211|0],a+16|0,a+12|0,111776)){break c}x[31737]=0;R(1204,a+220|0)|0;g=x[31737];x[31737]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Cb(x[a+204>>2],y[a+211|0])){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}i=f,j=xK(c,x[a+184>>2],e,b),x[i>>2]=j;x[f+4>>2]=hb;Xf(a+200|0,a+16|0,x[a+12>>2],e);x[31737]=0;b=P(1201,a+220|0,a+216|0)|0;c=x[31737];x[31737]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+220>>2];tb(d);tb(a+200|0);fb=a+224|0;break a}}b=N()|0;tb(d);tb(a+200|0);Q(b|0);p()}return b|0}function D8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;g=x[d+4>>2];d=x[d+28>>2];a=fb-224|0;fb=a;x[a+216>>2]=c;x[a+220>>2]=b;b=vj(g);mq(a+200|0,d,a+215|0);d=Fb(a+188|0);c=Mc(d);x[31737]=0;O(46,d|0,c|0);c=x[31737];x[31737]=0;a:{b:{c:{if((c|0)!=1){c=cc(d,0);x[a+184>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;while(1){d:{x[31737]=0;g=P(1201,a+220|0,a+216|0)|0;h=x[31737];x[31737]=0;if((h|0)==1){break d}if(g){break c}h=x[a+184>>2];g=Cb(x[d+4>>2],y[d+11|0]);if((h|0)==(g+c|0)){x[31737]=0;O(46,d|0,g<<1);c=x[31737];x[31737]=0;if((c|0)==1){break b}c=Mc(d);x[31737]=0;O(46,d|0,c|0);c=x[31737];x[31737]=0;if((c|0)==1){break b}c=cc(d,0);x[a+184>>2]=g+c}x[31737]=0;g=R(1202,x[a+220>>2])|0;h=x[31737];x[31737]=0;if((h|0)==1){break d}if(go(g,b,c,a+184|0,a+8|0,v[a+215|0],x[a+204>>2],y[a+211|0],a+16|0,a+12|0,111776)){break c}x[31737]=0;R(1204,a+220|0)|0;g=x[31737];x[31737]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Cb(x[a+204>>2],y[a+211|0])){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}i=f,j=tK(c,x[a+184>>2],e,b),x[i>>2]=j;x[f+4>>2]=hb;Xf(a+200|0,a+16|0,x[a+12>>2],e);x[31737]=0;b=P(1201,a+220|0,a+216|0)|0;c=x[31737];x[31737]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+220>>2];tb(d);tb(a+200|0);fb=a+224|0;break a}}b=N()|0;tb(d);tb(a+200|0);Q(b|0);p()}return b|0}function Wla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0;g=fb-16|0;fb=g;r=x[a+16>>2];s=Fg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);k=x[a+8>>2];l=x[a+12>>2];h=x[a>>2];e=x[a+4>>2];m=x[a+128>>2];if(m){n=Gg(k,l,m);o=hb;b=x[a+76>>2];hg(h,e,vf(k,l,d),hb);p=hb>>>0>b>>>0?d:0}i=a+112|0;f=x[a+48>>2];t=x[a+24>>2];u=x[a+20>>2];b=x[a+44>>2];x[g>>2]=h;x[g+4>>2]=e;a:while(1){b:{q=b;if(!d){break b}d=d-1|0;x[g+8>>2]=h;x[g+12>>2]=0;p=p-1|0;b=p;n=b?n:0;o=b?o:0;h=(e<<1)+r|0;b=m;while(1)if((b|0)<=0){Pb(i,x[a+120>>2],x[a+124>>2]);b=x[a+116>>2];if(b){be(i,w[h+(x[g+12>>2]<<1)>>1]/4<<16>>16);ae(i,b);x[i>>2]=x[i>>2];x[i+4>>2]=0}b=Eg(i,s);v=x[a+72>>2];y=x[c>>2];h=b<<8;b=h;e=x[a+60>>2];b=Sua(e,e>>31,b,b>>31);z=hb;e=b;b=x[a+64>>2];j=b;A=b>>31;b=Yb(q,-16777216,16776704);j=Sua(j,A,b,b>>31);e=e+j|0;b=hb+z|0;b=e>>>0<j>>>0?b+1|0:b;j=e;e=x[a+68>>2];f=Yb(f,-16777216,16776704);e=Sua(e,e>>31,f,f>>31);f=j+e|0;b=hb+b|0;b=e>>>0>f>>>0?b+1|0:b;f=f+8388608|0;b=f>>>0<8388608?b+1|0:b;b=Rc(f,b,24);f=(b|0)/256|0;x[c>>2]=D(f,u)+y;x[c+4>>2]=x[c+4>>2]+D(f,t);Pb(g,k,l);b=b-(h&v)|0;c=c+8|0;h=x[g>>2];e=x[g+4>>2];f=q;continue a}else{be(i,w[h+(x[g+12>>2]<<1)>>1]/4<<16>>16);ae(i,4);Pb(g+8|0,n,o);b=b-1|0;continue}}break}x[a>>2]=h;x[a+4>>2]=e;x[a+48>>2]=f;x[a+44>>2]=q;fb=g+16|0}function D4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=Fb(a);a=y[b+11|0];g=x[b+4>>2];x[31737]=0;k=xh(g,a);O(94,h|0,k|0);a=x[31737];x[31737]=0;a:{b:{if((a|0)!=1){g=0;a=0;while(1){c:{if((a|0)==(k|0)){a=!f;if(!(l?a&(m^-1):a)){break c}return}e=y[cc(b,a)|0];d:{e:{f:{g:{switch(f+1|0){case 1:f=1;h:{switch(e-123|0){case 2:break h;case 0:break d;default:break f}}f=3;break d;case 2:i:{switch(e-123|0){case 2:m=1;e=g+1|0;f=0;if(d>>>0<=g>>>0){g=e;break d}x[31737]=0;O(95,h|0,Hd(c,g)|0);j=x[31737];x[31737]=0;g=e;if((j|0)!=1){break d}a=N()|0;break b;case 0:break f;default:break i}}f=-1;e=e-48|0;if((e&255)>>>0>9){break d}l=1;f=2;i=e;break d;case 3:f=-1;j:{switch(e-123|0){case 2:f=0;if(d>>>0<=i>>>0){break d}x[31737]=0;O(95,h|0,Hd(c,i)|0);e=x[31737];x[31737]=0;if((e|0)!=1){break d}a=N()|0;break b;case 0:break d;default:break j}}if((e-48&255)>>>0>9){break d}i=(D(i,10)+e|0)-48|0;l=1;f=2;break d;case 4:break g;case 0:break e;default:break d}}j=(e|0)!=125;f=-1;e=125;if(j){break d}}f=0;x[31737]=0;O(96,h|0,e|0);e=x[31737];x[31737]=0;if((e|0)!=1){break d}a=N()|0;break b}f=-1}a=a+1|0;continue}break}b=ac(8);x[31737]=0;a=R(97,b|0)|0;c=x[31737];x[31737]=0;if((c|0)!=1){x[31737]=0;S(98,a|0,40292,17);a=x[31737];x[31737]=0;if((a|0)!=1){break a}a=N()|0;break b}a=N()|0;jc(b);break b}a=N()|0}tb(h);Q(a|0)}p()}function fz(a){var b=0,c=0,d=0,e=0;Ie(x[a+80>>2],x[a+20>>2]);while(1){c=x[a+28>>2];if((b|0)<x[a+24>>2]){Ie(x[a+80>>2],x[c+(b<<2)>>2]);b=b+1|0;continue}break}Ie(x[a+80>>2],c);a:{if(!x[a+396>>2]){break a}c=0;while(1){if(x[a+264>>2]<=(c|0)){break a}e=x[a+396>>2]+D(c,24)|0;d=x[e+16>>2];if(d){b=0;while(1){if((b|0)<x[(x[a+124>>2]+D(y[e+13|0],2096)|0)+4>>2]){Ie(x[a+80>>2],x[(b<<2)+d>>2]);b=b+1|0;d=x[e+16>>2];continue}break}Ie(x[a+80>>2],d)}Ie(x[a+80>>2],x[e+20>>2]);c=c+1|0;continue}}d=x[a+124>>2];if(d){c=0;while(1){if((c|0)<x[a+120>>2]){b=D(c,2096)+d|0;Ie(x[a+80>>2],x[b+8>>2]);Ie(x[a+80>>2],x[b+28>>2]);Ie(x[a+80>>2],x[b+32>>2]);Ie(x[a+80>>2],x[b+2084>>2]);b=x[b+2088>>2];Ie(x[a+80>>2],b?b-4|0:0);c=c+1|0;d=x[a+124>>2];continue}break}Ie(x[a+80>>2],d)}Ie(x[a+80>>2],x[a+260>>2]);Ie(x[a+80>>2],x[a+396>>2]);c=x[a+404>>2];if(c){b=0;while(1){if((b|0)<x[a+400>>2]){Ie(x[a+80>>2],x[(D(b,40)+c|0)+4>>2]);b=b+1|0;c=x[a+404>>2];continue}break}Ie(x[a+80>>2],c)}c=0;b=0;while(1){if(!(x[a+4>>2]<=(b|0)|b>>>0>15)){d=(b<<2)+a|0;Ie(x[a+80>>2],x[d+800>>2]);Ie(x[a+80>>2],x[d+928>>2]);Ie(x[a+80>>2],x[d+996>>2]);b=b+1|0;continue}break}while(1){if((c|0)!=2){b=(c<<2)+a|0;Ie(x[a+80>>2],x[b+1068>>2]);Ie(x[a+80>>2],x[b+1076>>2]);Ie(x[a+80>>2],x[b+1084>>2]);Ie(x[a+80>>2],x[b+1092>>2]);Ie(x[a+80>>2],x[b+1100>>2]);c=c+1|0;continue}break}}function d8(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;k=fb-16|0;fb=k;l=Ny(x[g>>2]);g=sy(x[g>>2]);rh(k+4|0,g);a:{b:{if(Ad(x[k+8>>2],y[k+15|0])){x[31737]=0;V(1222,l|0,a|0,c|0,d|0);g=x[31737];x[31737]=0;if((g|0)==1){break b}g=(c-a<<2)+d|0;x[f>>2]=g;break a}x[f>>2]=d;c:{d:{j=a;h=y[j|0];switch(h-43|0){case 0:case 2:break d;default:break c}}x[31737]=0;j=P(1228,l|0,h<<24>>24)|0;h=x[31737];x[31737]=0;if((h|0)==1){break b}h=x[f>>2];x[f>>2]=h+4;x[h>>2]=j;j=a+1|0}if(!(y[j|0]!=48|(c-j|0)<2|(y[j+1|0]|32)!=120)){x[31737]=0;h=P(1228,l|0,48)|0;i=x[31737];x[31737]=0;if((i|0)==1){break b}i=x[f>>2];x[f>>2]=i+4;x[i>>2]=h;h=v[j+1|0];x[31737]=0;h=P(1228,l|0,h|0)|0;i=x[31737];x[31737]=0;if((i|0)==1){break b}i=x[f>>2];x[f>>2]=i+4;x[i>>2]=h;j=j+2|0}Hm(j,c);i=0;x[31737]=0;o=R(1220,g|0)|0;g=x[31737];x[31737]=0;if((g|0)==1){break b}h=0;g=j;while(1){if(c>>>0<=g>>>0){jt((j-a<<2)+d|0,x[f>>2]);g=x[f>>2];break a}e:{if(!y[cc(k+4|0,h)|0]){break e}if(v[cc(k+4|0,h)|0]!=(i|0)){break e}i=x[f>>2];x[f>>2]=i+4;x[i>>2]=o;h=(Cb(x[k+8>>2],y[k+15|0])-1>>>0>h>>>0)+h|0;i=0}n=v[g|0];x[31737]=0;n=P(1228,l|0,n|0)|0;m=x[31737];x[31737]=0;if((m|0)!=1){m=x[f>>2];x[f>>2]=m+4;x[m>>2]=n;g=g+1|0;i=i+1|0;continue}break}}a=N()|0;tb(k+4|0);Q(a|0);p()}x[e>>2]=(b|0)==(c|0)?g:(b-a<<2)+d|0;tb(k+4|0);fb=k+16|0}function OU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;h=fb-16|0;fb=h;c=x[a>>2];a:{if(Mj(c)){i=fb-16|0;fb=i;e=Ec(3848);d=e+808|0;c=e+16|0;while(1){x[c+16>>2]=0;x[c+20>>2]=0;x[c+36>>2]=0;v[c+42|0]=1;w[c+40>>1]=257;x[c+24>>2]=0;x[c+28>>2]=0;w[c+32>>1]=0;c=c+44|0;if((c|0)!=(d|0)){continue}break}c=e+3832|0;while(1){x[d>>2]=0;x[d+4>>2]=0;x[d+68>>2]=0;x[d+72>>2]=0;x[d+24>>2]=0;x[d+28>>2]=0;w[d+20>>1]=511;x[d+16>>2]=-1;w[d+14>>1]=1;w[d+6>>1]=0;w[d+8>>1]=0;w[d+10>>1]=0;w[d+12>>1]=0;v[d+73|0]=0;v[d+74|0]=0;v[d+75|0]=0;v[d+76|0]=0;v[d+77|0]=0;v[d+78|0]=0;v[d+79|0]=0;v[d+80|0]=0;d=d+84|0;if((c|0)!=(d|0)){continue}break}x[e+3832>>2]=0;x[e+3836>>2]=0;c=e+3837|0;v[c|0]=0;v[c+1|0]=0;v[c+2|0]=0;v[c+3|0]=0;v[c+4|0]=0;v[c+5|0]=0;v[c+6|0]=0;v[c+7|0]=0;while(1){if((g|0)==36){while(1){if((f|0)==18){b:{f=0;g=0;while(1)if((f|0)==18){while(1){if((g|0)==36){break b}To((e+D(g,84)|0)+808|0);g=g+1|0;continue}}else{d=(e+D(f,44)|0)+16|0;c=x[(f<<2)+27328>>2];c:{if(!(!(1<<f&3591)|f>>>0>11)){c=e+D(c,84)|0;TU(d,c+808|0,c+1060|0,c+1312|0,c+1564|0);break c}c=e+D(c,84)|0;TU(d,c+808|0,c+1060|0,0,0)}f=f+1|0;continue}}}else{x[(e+D(f,44)|0)+32>>2]=e;f=f+1|0;continue}break}SU(e,b)}else{yd((e+D(g,84)|0)+808|0,e);g=g+1|0;continue}break}b=x[yf(i+12|0,e)>>2];fb=i+16|0;x[h+12>>2]=b;b=h+12|0;BA(a,b);Nl(b);break a}SU(c,b)}NU(a);fb=h+16|0}function wsa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=fb+-64|0;fb=d;b=b&4095;w[d+62>>1]=b;a:{b:{c:{d:{if(b>>>0>=81){e=((b|0)==4095?c:b-80|0)+734016|0;c=Sua(e,e>>31,1e4,0);b=hb;c=c+14780|0;b=c>>>0<14780?b+1|0:b;b=Tua(c,b,3652425,0);c=(((e+((b|0)/-4|0)|0)+D(b,-365)|0)+((b|0)/100|0)|0)+((b|0)/-400|0)|0;if((c|0)<0){b=b-1|0;c=(((e+((b|0)/-4|0)|0)+D(b,-365)|0)+((b|0)/100|0)|0)+((b|0)/-400|0)|0}e=fb-16|0;fb=e;h=d+48|0;f=tc(e+4|0,4451);_c(h,f);tb(f);fb=e+16|0;x[31737]=0;f=(D(c,100)+52|0)/3060|0;e=f+2|0;g=(e|0)/12|0;x[d+32>>2]=g+b;b=d+36|0;O(74,b|0,d+32|0);i=x[31737];x[31737]=0;e:{f:{g:{h:{i:{j:{if((i|0)!=1){x[31737]=0;x[d+16>>2]=(e+D(g,-12)|0)+1;e=d+20|0;O(77,e|0,d+16|0);g=x[31737];x[31737]=0;if((g|0)==1){break j}x[31737]=0;x[d>>2]=(((D(f,306)+5|0)/-10|0)+c|0)+1;c=d+4|0;O(77,c|0,d|0);f=x[31737];x[31737]=0;if((f|0)==1){break i}x[31737]=0;aa(414,a|0,h|0,b|0,e|0,c|0);a=x[31737];x[31737]=0;if((a|0)==1){break h}tb(c);tb(e);tb(b);Eb(h);break d}b=N()|0;break e}b=N()|0;break f}b=N()|0;break g}b=N()|0;tb(d+4|0)}tb(d+20|0)}tb(d+36|0)}break a}b=d+48|0;ig(b,4431);x[31737]=0;c=d+36|0;O(415,c|0,d+62|0);e=x[31737];x[31737]=0;if((e|0)==1){break c}x[31737]=0;S(140,a|0,b|0,c|0);a=x[31737];x[31737]=0;if((a|0)==1){break b}tb(c);Eb(b)}fb=d- -64|0;return}b=N()|0;break a}b=N()|0;tb(d+36|0)}Eb(d+48|0);Q(b|0);p()}function YE(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=fb-16|0;fb=h;d=x[b>>2];e=Zc(d,x[b+4>>2]);a:{if(e>>>0<c>>>0){l=fb-32|0;fb=l;d=c-e|0;e=x[zb(b)>>2];f=x[b+4>>2];b:{if(d>>>0<=e-f>>1>>>0){f=fb-16|0;fb=f;d=_h(f+4|0,b,d);e=x[d+4>>2];g=x[d+8>>2];while(1){if((e|0)==(g|0)){hc(d);fb=f+16|0}else{wp(e);e=e+2|0;x[d+4>>2]=e;continue}break}break b}e=zb(b);e=kk(l+12|0,lk(b,Zc(x[b>>2],f)+d|0),Zc(x[b>>2],x[b+4>>2]),e);g=fb-16|0;fb=g;d=Gp(g+4|0,e+8|0,d);f=x[d>>2];while(1){if(x[d+4>>2]!=(f|0)){wp(f);f=x[d>>2]+2|0;x[d>>2]=f;continue}break}he(d);fb=g+16|0;i=fb-16|0;fb=i;f=vb(i+12|0,x[b+4>>2]);g=vb(i+8|0,x[b>>2]);j=x[vb(i+4|0,x[e+4>>2])>>2];k=fb-16|0;fb=k;m=k+8|0;d=fb-32|0;fb=d;Id(d+24|0,x[f>>2],x[g>>2]);n=d+16|0;g=x[d+24>>2];o=x[d+28>>2];f=fb-16|0;fb=f;x[f+8>>2]=j;x[f+12>>2]=g;while(1){if(pd(g,o)){g=Mn(g);j=Mn(x[f+8>>2]);g=y[g|0]|y[g+1|0]<<8;v[j|0]=g;v[j+1|0]=g>>>8;g=ij(f+12|0);ij(f+8|0);g=x[g>>2];continue}break}Ac(n,g,f+8|0);fb=f+16|0;f=x[d+16>>2];x[d+12>>2]=x[d+20>>2];Ac(m,f,d+12|0);fb=d+32|0;fb=k+16|0;x[e+4>>2]=x[k+12>>2];Tb(b,e+4|0);Tb(b+4|0,e+8|0);Tb(zb(b),nc(e));x[e>>2]=x[e+4>>2];fb=i+16|0;jj(e)}fb=l+32|0;break a}if(c>>>0<e>>>0){In(b,d+(c<<1)|0)}}c=Mb(x[a>>2],x[a+8>>2],c<<1);if(c){e=x[b>>2];bc(h+8|0,e,Zc(e,x[b+4>>2])<<1);rd(h,a,x[h+8>>2],x[h+12>>2])}fb=h+16|0;return c|0}function vK(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;g=x[d+4>>2];d=x[d+28>>2];a=fb-224|0;fb=a;x[a+216>>2]=c;x[a+220>>2]=b;b=vj(g);mq(a+200|0,d,a+215|0);d=Fb(a+188|0);c=Mc(d);x[31737]=0;O(46,d|0,c|0);c=x[31737];x[31737]=0;a:{b:{c:{if((c|0)!=1){c=cc(d,0);x[a+184>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;while(1){d:{x[31737]=0;g=P(1201,a+220|0,a+216|0)|0;h=x[31737];x[31737]=0;if((h|0)==1){break d}if(g){break c}h=x[a+184>>2];g=Cb(x[d+4>>2],y[d+11|0]);if((h|0)==(g+c|0)){x[31737]=0;O(46,d|0,g<<1);c=x[31737];x[31737]=0;if((c|0)==1){break b}c=Mc(d);x[31737]=0;O(46,d|0,c|0);c=x[31737];x[31737]=0;if((c|0)==1){break b}c=cc(d,0);x[a+184>>2]=g+c}x[31737]=0;g=R(1202,x[a+220>>2])|0;h=x[31737];x[31737]=0;if((h|0)==1){break d}if(go(g,b,c,a+184|0,a+8|0,v[a+215|0],x[a+204>>2],y[a+211|0],a+16|0,a+12|0,111776)){break c}x[31737]=0;R(1204,a+220|0)|0;g=x[31737];x[31737]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Cb(x[a+204>>2],y[a+211|0])){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}i=f,j=uK(c,x[a+184>>2],e,b),x[i>>2]=j;Xf(a+200|0,a+16|0,x[a+12>>2],e);x[31737]=0;b=P(1201,a+220|0,a+216|0)|0;c=x[31737];x[31737]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+220>>2];tb(d);tb(a+200|0);fb=a+224|0;break a}}b=N()|0;tb(d);tb(a+200|0);Q(b|0);p()}return b|0}function jla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;o=fb-16|0;fb=o;e=vb(o+12|0,wb(x[a+4>>2]));k=fb-32|0;fb=k;f=x[e>>2];e=x[a>>2];i=(pp(f,wb(e))<<1)+e|0;l=HB(b,c);a:{if((l|0)<=0){break a}e=x[zb(a)>>2];m=x[a+4>>2];if((l|0)<=e-m>>1){n=m-i>>1;b:{if((l|0)<=(n|0)){e=c;break b}x[k+12>>2]=b;YT(k+12|0,n);e=x[k+12>>2];f=e;p=fb-16|0;fb=p;j=_h(p+4|0,a,l-n|0);g=zb(a);d=fb-48|0;fb=d;h=x[j+4>>2];x[d+44>>2]=h;x[d+40>>2]=h;g=Re(d+12|0,g,d+40|0,d+44|0);x[d+8>>2]=x[g+8>>2];h=x[g+4>>2];x[d>>2]=x[g>>2];x[d+4>>2]=h;Qe(d+24|0,d);while(1){if((c|0)!=(f|0)){fj(x[d+44>>2],z[f>>1]);x[d+44>>2]=x[d+44>>2]+2;f=f+2|0;continue}break}Pe(d+24|0);q=x[d+44>>2];if(!y[d+36|0]){f=fb-16|0;fb=f;c=vb(f+12|0,x[x[d+32>>2]>>2]);r=x[vb(f+8|0,x[x[d+28>>2]>>2])>>2];g=fb-16|0;fb=g;c=x[c>>2];x[g+12>>2]=c;while(1){if(pd(c,r)){h=fb-16|0;fb=h;x[h+12>>2]=c;YT(h+12|0,-1);fb=h+16|0;c=x[ij(g+12|0)>>2];continue}break}fb=g+16|0;fb=f+16|0}fb=d+48|0;x[j+4>>2]=q;hc(j);fb=p+16|0;if((n|0)<=0){break a}}dV(a,i,m,(l<<1)+i|0);Kk(b,e,i);break a}e=zb(a);j=kk(k+12|0,lk(a,Zc(x[a>>2],m)+l|0),i-x[a>>2]>>1,e);d=fb-16|0;fb=d;c=Gp(d+4|0,j+8|0,HB(b,c));e=x[c>>2];while(1){if(x[c+4>>2]!=(e|0)){fj(e,z[b>>1]);e=x[c>>2]+2|0;x[c>>2]=e;b=b+2|0;continue}break}he(c);fb=d+16|0;i=cV(a,j,i);jj(j)}wb(i);fb=k+32|0;fb=o+16|0;return a|0}function aQ(){var a=0,b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=fb-240|0;fb=e;if(!y[127112]){if(!y[126984]){b=fb-16|0;fb=b;Fb(126960);x[31743]=0;v[126976]=0;x[31745]=0;x[31737]=0;a=ca(55)|0;c=x[31737];x[31737]=0;a:{b:{c:{d:{e:{f:{if((c|0)!=1){x[b+12>>2]=a;a=b+12|0;SA(126972,me(a));Nl(a);v[126976]=0;break f}a=ta(125048,125632)|0;c=gb;if(($(125048)|0)==(c|0)){Y(a|0)|0;x[31737]=0;X(56);b=x[31737];x[31737]=0;if((b|0)==1){break d}p()}if(($(125632)|0)!=(c|0)){break c}Y(a|0)|0;x[31737]=0;v[126976]=0;X(26);a=x[31737];x[31737]=0;if((a|0)==1){a=N()|0;break c}if(y[126976]){break e}}x[31737]=0;W(57,126956);a=x[31737];x[31737]=0;if((a|0)!=1){break e}a=N()|0;break c}fb=b+16|0;break a}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)==1){break b}}Nl(126980);Nl(126972);tb(126960);Q(a|0);p()}T(0)|0;Sb();p()}v[126984]=1}c=fb+-64|0;fb=c;b=c+16|0;g=fb-16|0;fb=g;h=JP(g+8|0);j=e+120|0;l=c+4|0;while(1){if((i|0)==12){fb=g+16|0}else{f=fb-48|0;fb=f;a=x[h+4>>2];d=x[h>>2];g:{if((a|0)==(d|0)){break g}a=(a-d|0)+1|0;if(!a){a=AP(GP(f+12|0,32));break g}d=G(a);d=GP(f+12|0,(a<<d&2147483647?32:31)-d|0);while(1){k=AP(d);if(a>>>0<=k>>>0){continue}break}a=x[h>>2]+k|0}fb=f+48|0;m=yb(b,i),n=a,x[m>>2]=n;i=i+1|0;continue}break}b=WP(l,b,_P(b));TP(j,b);an(b);fb=c- -64|0;yc(126992,yc(e,j,120),116);v[127112]=1}fb=e+240|0}function G8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;g=x[d+4>>2];d=x[d+28>>2];a=fb-224|0;fb=a;x[a+216>>2]=c;x[a+220>>2]=b;b=vj(g);mq(a+200|0,d,a+215|0);d=Fb(a+188|0);c=Mc(d);x[31737]=0;O(46,d|0,c|0);c=x[31737];x[31737]=0;a:{b:{c:{if((c|0)!=1){c=cc(d,0);x[a+184>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;while(1){d:{x[31737]=0;g=P(1201,a+220|0,a+216|0)|0;h=x[31737];x[31737]=0;if((h|0)==1){break d}if(g){break c}h=x[a+184>>2];g=Cb(x[d+4>>2],y[d+11|0]);if((h|0)==(g+c|0)){x[31737]=0;O(46,d|0,g<<1);c=x[31737];x[31737]=0;if((c|0)==1){break b}c=Mc(d);x[31737]=0;O(46,d|0,c|0);c=x[31737];x[31737]=0;if((c|0)==1){break b}c=cc(d,0);x[a+184>>2]=g+c}x[31737]=0;g=R(1202,x[a+220>>2])|0;h=x[31737];x[31737]=0;if((h|0)==1){break d}if(go(g,b,c,a+184|0,a+8|0,v[a+215|0],x[a+204>>2],y[a+211|0],a+16|0,a+12|0,111776)){break c}x[31737]=0;R(1204,a+220|0)|0;g=x[31737];x[31737]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Cb(x[a+204>>2],y[a+211|0])){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}i=f,j=zK(c,x[a+184>>2],e,b),x[i>>2]=j;Xf(a+200|0,a+16|0,x[a+12>>2],e);x[31737]=0;b=P(1201,a+220|0,a+216|0)|0;c=x[31737];x[31737]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+220>>2];tb(d);tb(a+200|0);fb=a+224|0;break a}}b=N()|0;tb(d);tb(a+200|0);Q(b|0);p()}return b|0}function E8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;g=x[d+4>>2];d=x[d+28>>2];a=fb-224|0;fb=a;x[a+216>>2]=c;x[a+220>>2]=b;b=vj(g);mq(a+200|0,d,a+215|0);d=Fb(a+188|0);c=Mc(d);x[31737]=0;O(46,d|0,c|0);c=x[31737];x[31737]=0;a:{b:{c:{if((c|0)!=1){c=cc(d,0);x[a+184>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;while(1){d:{x[31737]=0;g=P(1201,a+220|0,a+216|0)|0;h=x[31737];x[31737]=0;if((h|0)==1){break d}if(g){break c}h=x[a+184>>2];g=Cb(x[d+4>>2],y[d+11|0]);if((h|0)==(g+c|0)){x[31737]=0;O(46,d|0,g<<1);c=x[31737];x[31737]=0;if((c|0)==1){break b}c=Mc(d);x[31737]=0;O(46,d|0,c|0);c=x[31737];x[31737]=0;if((c|0)==1){break b}c=cc(d,0);x[a+184>>2]=g+c}x[31737]=0;g=R(1202,x[a+220>>2])|0;h=x[31737];x[31737]=0;if((h|0)==1){break d}if(go(g,b,c,a+184|0,a+8|0,v[a+215|0],x[a+204>>2],y[a+211|0],a+16|0,a+12|0,111776)){break c}x[31737]=0;R(1204,a+220|0)|0;g=x[31737];x[31737]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Cb(x[a+204>>2],y[a+211|0])){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}i=f,j=wK(c,x[a+184>>2],e,b),w[i>>1]=j;Xf(a+200|0,a+16|0,x[a+12>>2],e);x[31737]=0;b=P(1201,a+220|0,a+216|0)|0;c=x[31737];x[31737]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+220>>2];tb(d);tb(a+200|0);fb=a+224|0;break a}}b=N()|0;tb(d);tb(a+200|0);Q(b|0);p()}return b|0}function WI(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=fb-80|0;fb=c;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{if(!b){tc(a,9766);break j}f=b>>>24|0;if(!(b&65535)){d=fb-16|0;fb=d;g=c+68|0;e=tc(d+4|0,4399);_c(g,e);tb(e);fb=d+16|0;x[31737]=0;x[c+24>>2]=f;f=c+56|0;O(88,f|0,c+24|0);d=x[31737];x[31737]=0;k:{l:{m:{n:{if((d|0)!=1){x[31737]=0;x[c+8>>2]=b>>>16&255;b=c+44|0;O(89,b|0,c+8|0);d=x[31737];x[31737]=0;if((d|0)==1){break n}x[31737]=0;V(90,a|0,g|0,f|0,b|0);a=x[31737];x[31737]=0;if((a|0)==1){break m}tb(b);tb(f);Eb(g);break j}b=N()|0;break k}b=N()|0;break l}b=N()|0;tb(c+44|0)}tb(c+56|0)}break a}d=fb-16|0;fb=d;g=c+68|0;e=tc(d+4|0,4123);_c(g,e);tb(e);fb=d+16|0;x[31737]=0;x[c+40>>2]=f;f=c+56|0;O(88,f|0,c+40|0);d=x[31737];x[31737]=0;if((d|0)==1){break i}x[31737]=0;x[c+36>>2]=b>>>16&255;d=c+44|0;O(89,d|0,c+36|0);e=x[31737];x[31737]=0;if((e|0)==1){break h}x[31737]=0;x[c+20>>2]=b>>>8&255;e=c+24|0;O(89,e|0,c+20|0);h=x[31737];x[31737]=0;if((h|0)==1){break g}x[31737]=0;x[c+4>>2]=b&255;b=c+8|0;O(89,b|0,c+4|0);h=x[31737];x[31737]=0;if((h|0)==1){break f}x[31737]=0;ja(91,a|0,g|0,f|0,d|0,e|0,b|0);a=x[31737];x[31737]=0;if((a|0)==1){break e}tb(b);tb(e);tb(d);tb(f);Eb(g)}fb=c+80|0;return}b=N()|0;break a}b=N()|0;break b}b=N()|0;break c}b=N()|0;break d}b=N()|0;tb(c+8|0)}tb(c+24|0)}tb(c+44|0)}tb(c+56|0)}Eb(c+68|0);Q(b|0);p()}function UU(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0;a:{b:{switch(e<<31|e-2>>>1){case 4:KB(a,b,c,d);return;case 0:e=32-G(d|1)|0;if((e|0)<=(c-b|0)){c=b+e|0;b=c;while(1){if(d>>>0<17){while(1){b=b-1|0;v[b|0]=y[(d&1)+15526|0];e=d>>>0>1;d=d>>>1|0;if(e){continue}break}}else{b=b-4|0;fn((d<<2&60)+78848|0,4,b);d=d>>>4|0;continue}break}b=0}else{b=61}x[a+4>>2]=b;break a;case 3:e=(34-G(d|1)>>>0)/3|0;if((e|0)<=(c-b|0)){c=b+e|0;b=c;while(1){if(d>>>0<65){while(1){b=b-1|0;v[b|0]=y[(d&7)+14823|0];e=d>>>0>7;d=d>>>3|0;if(e){continue}break}}else{b=b-2|0;fn((d<<1&126)+78912|0,2,b);d=d>>>6|0;continue}break}b=0}else{b=61}x[a+4>>2]=b;break a;case 7:e=35-G(d|1)>>>2|0;if((e|0)<=(c-b|0)){c=b+e|0;b=c;while(1){if(d>>>0<257){while(1){b=b-1|0;v[b|0]=y[(d&15)+11181|0];e=d>>>0>15;d=d>>>4|0;if(e){continue}break}}else{b=b-2|0;fn((d<<1&510)+79040|0,2,b);d=d>>>8|0;continue}break}b=0}else{b=61}x[a+4>>2]=b;break a;default:break b}}g=d;i=D(e,e);k=D(i,e);j=D(i,i);c:{while(1){h=f|1;if(e>>>0>g>>>0){break c}h=f|2;if(g>>>0<i>>>0){break c}h=f|3;if(g>>>0<k>>>0){break c}if(g>>>0<j>>>0){h=f+4|0}else{f=f+4|0;g=(g>>>0)/(j>>>0)|0;continue}break}}f=h;if((f|0)>(c-b|0)){x[a+4>>2]=61;break a}f=b+f|0;c=f;while(1){c=c-1|0;b=(d>>>0)/(e>>>0)|0;v[c|0]=y[(d-D(b,e)|0)+4895|0];g=d>>>0>=e>>>0;d=b;if(g){continue}break}x[a+4>>2]=0;x[a>>2]=f;return}x[a>>2]=c}function n8(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;k=fb-16|0;fb=k;l=Bw(x[g>>2]);g=Ay(x[g>>2]);rh(k+4|0,g);a:{b:{if(Ad(x[k+8>>2],y[k+15|0])){x[31737]=0;V(1209,l|0,a|0,c|0,d|0);g=x[31737];x[31737]=0;if((g|0)==1){break b}g=(c-a|0)+d|0;x[f>>2]=g;break a}x[f>>2]=d;c:{d:{j=a;h=y[j|0];switch(h-43|0){case 0:case 2:break d;default:break c}}x[31737]=0;j=P(29,l|0,h<<24>>24)|0;h=x[31737];x[31737]=0;if((h|0)==1){break b}h=x[f>>2];x[f>>2]=h+1;v[h|0]=j;j=a+1|0}if(!(y[j|0]!=48|(c-j|0)<2|(y[j+1|0]|32)!=120)){x[31737]=0;h=P(29,l|0,48)|0;i=x[31737];x[31737]=0;if((i|0)==1){break b}i=x[f>>2];x[f>>2]=i+1;v[i|0]=h;h=v[j+1|0];x[31737]=0;h=P(29,l|0,h|0)|0;i=x[31737];x[31737]=0;if((i|0)==1){break b}i=x[f>>2];x[f>>2]=i+1;v[i|0]=h;j=j+2|0}Hm(j,c);i=0;x[31737]=0;o=R(1207,g|0)|0;g=x[31737];x[31737]=0;if((g|0)==1){break b}h=0;g=j;while(1){if(c>>>0<=g>>>0){Hm((j-a|0)+d|0,x[f>>2]);g=x[f>>2];break a}e:{if(!y[cc(k+4|0,h)|0]){break e}if(v[cc(k+4|0,h)|0]!=(i|0)){break e}i=x[f>>2];x[f>>2]=i+1;v[i|0]=o;h=(Cb(x[k+8>>2],y[k+15|0])-1>>>0>h>>>0)+h|0;i=0}n=v[g|0];x[31737]=0;n=P(29,l|0,n|0)|0;m=x[31737];x[31737]=0;if((m|0)!=1){m=x[f>>2];x[f>>2]=m+1;v[m|0]=n;g=g+1|0;i=i+1|0;continue}break}}a=N()|0;tb(k+4|0);Q(a|0);p()}x[e>>2]=(b|0)==(c|0)?g:(b-a|0)+d|0;tb(k+4|0);fb=k+16|0}function wB(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=fb-16|0;fb=h;f=x[c+656>>2];a:{if(!Rj(f)){i=x[c+704>>2];f=fb-16|0;fb=f;x[f+12>>2]=d;g=0;b:{if(!d){break b}j=x[b+480180>>2];if(j&20){e=b+1074312|0;d=Ob(e,73)?d&65535:d;if(y[b+480208|0]&16){e=Ob(e,73)?14-((9983-d>>>0)/768|0)&31:((d>>>0)/768|0)+2|0;g=x[((d>>>0)%768<<2)+32416>>2]<<6>>>e|0;break b}g=229079296/((d>>>0<=1?1:d)>>>0)|0;break b}g=227001280/(d>>>0)|0;if(En(j)){break b}g=(d+i<<4)-133808|0;if((j|0)==64){break b}wc(f+12|0,16777215);if(j&17408){g=Bc(Uua(Sua(i?i:8363,0,3506176,0),hb,(x[f+12>>2]<<8)+e|0,0),hb);break b}if(Gj(b)){d=x[f+12>>2];i=d>>>24|0;j=d<<8;d=j+e|0;e=i+(e>>31)|0;g=((d>>>0<j>>>0?e+1|0:e)&15)<<28|d>>>4;break b}if(y[b+480208|0]&16){g=Bc(Uua(Sua(i?i:8363,0,7012352,0),hb,(x[f+12>>2]<<8)+e|0,0),hb);break b}g=Bc(Uua(-1485242368,13,(x[f+12>>2]<<8)+e|0,0),hb)}e=g;fb=f+16|0;f=x[c+656>>2];break a}e=x[c+700>>2]}x[h+12>>2]=e;c=w[c+774>>1];c:{if(!c){break c}c=f?D(v[f+33|0],c):c;if(!c){break c}e=Ze(Di(+(c|0)/393216)*+(e>>>0));x[h+12>>2]=e}d:{if(!f){break d}c=x[f+40>>2];if(!c){break d}d=(c|0)/2|0;f=x[b+1074420>>2];e=Sua(f,f>>31,e,e>>31);f=d+e|0;d=hb+(d>>31)|0;k=h,l=Gc(Tua(f,e>>>0>f>>>0?d+1|0:d,c,c>>31),hb),x[k+12>>2]=l}wc(h+12|0,2147483647);c=x[h+12>>2];b=mg(c,x[b+24620>>2]<<4);x[a+8>>2]=c;x[a>>2]=b;x[a+4>>2]=hb;fb=h+16|0}function HA(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;i=WR(b,c);a:{if(!x[b+656>>2]|!(v[i+6|0]&1)){break a}e=x[i>>2];j=a+1074312|0;f=Ob(j,31);d=Jw(x[b+656>>2],c);if(mc(x[d>>2],x[d+4>>2])){break a}f=(f^1)+e|0;g=Ob(j,31);e=y[d+12|0];b:{c:{if(!g){d:{if(!(e&2)){break d}h=y[d+14|0];k=!(x[a+480180>>2]&1048580)+z[yb(x[d>>2],h)>>1]|0;g=0;if(!(!(y[b+89|0]&8)|(!(e&4)|(h|0)!=y[d+16|0]))){g=Ob(j,70)}if(g|(f|0)!=(k|0)){break d}f=z[yb(x[d>>2],y[d+13|0])>>1]}if(!(!(y[d+12|0]&4)|y[b+89|0]&8)){a=x[d>>2];if((z[yb(a,y[d+16|0])>>1]+1|0)!=(f|0)){break b}f=z[yb(a,y[d+15|0])>>1];if(!Ob(j,93)|(c|0)!=1|y[b+89|0]&8){break b}v[i+6|0]=y[i+6|0]&254;break b}h=0;e=z[xf(x[d+4>>2])>>1];if(f>>>0>e>>>0){break c}break b}e:{f:{if(!(!(e&4)|y[b+669|0]&8)){if(z[i+4>>1]==65535){break f}if(Ob(j,97)){break f}e=y[d+12|0]}if(e&2){g=x[d>>2];e=z[yb(g,y[d+13|0])>>1];h=1;g=z[yb(g,y[d+14|0])>>1]+1|0;break e}e=z[xf(x[d+4>>2])>>1];h=f>>>0<=e>>>0;g=e;break e}g=x[d>>2];e=z[yb(g,y[d+15|0])>>1];h=1;g=z[yb(g,y[d+16|0])>>1]+1|0}e=f>>>0<g>>>0?f:e}g:{if(c|h){break g}f=x[a+480180>>2];c=x[b+88>>2];if(!(!(f&16777248)&(!(c&2048)|(f|0)==16384))){c=c|4096;x[b+88>>2]=c}if(y[xf(x[d+4>>2])+2|0]|!(z[b+786>>1]|x[a+480180>>2]&16777248)){break g}x[b+696>>2]=0;x[b+720>>2]=0;x[b+680>>2]=0;x[b+88>>2]=c|4096}f=e}l=i,m=Ob(j,31)+f|0,x[l>>2]=m}}function Xla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0,A=0;g=fb-16|0;fb=g;r=x[a+16>>2];s=Fg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);k=x[a+8>>2];l=x[a+12>>2];h=x[a>>2];e=x[a+4>>2];m=x[a+128>>2];if(m){n=Gg(k,l,m);o=hb;b=x[a+76>>2];hg(h,e,vf(k,l,d),hb);p=hb>>>0>b>>>0?d:0}i=a+112|0;f=x[a+48>>2];t=x[a+24>>2];u=x[a+20>>2];b=x[a+44>>2];x[g>>2]=h;x[g+4>>2]=e;a:while(1){b:{q=b;if(!d){break b}d=d-1|0;x[g+8>>2]=h;x[g+12>>2]=0;p=p-1|0;b=p;n=b?n:0;o=b?o:0;h=e+r|0;b=m;while(1)if((b|0)<=0){Pb(i,x[a+120>>2],x[a+124>>2]);b=x[a+116>>2];if(b){be(i,v[h+x[g+12>>2]|0]<<6);ae(i,b);x[i>>2]=x[i>>2];x[i+4>>2]=0}b=Eg(i,s);w=x[a+72>>2];y=x[c>>2];h=b<<8;b=h;e=x[a+60>>2];b=Sua(e,e>>31,b,b>>31);z=hb;e=b;b=x[a+64>>2];j=b;A=b>>31;b=Yb(q,-16777216,16776704);j=Sua(j,A,b,b>>31);e=e+j|0;b=hb+z|0;b=e>>>0<j>>>0?b+1|0:b;j=e;e=x[a+68>>2];f=Yb(f,-16777216,16776704);e=Sua(e,e>>31,f,f>>31);f=j+e|0;b=hb+b|0;b=e>>>0>f>>>0?b+1|0:b;f=f+8388608|0;b=f>>>0<8388608?b+1|0:b;b=Rc(f,b,24);f=(b|0)/256|0;x[c>>2]=D(f,u)+y;x[c+4>>2]=x[c+4>>2]+D(f,t);Pb(g,k,l);b=b-(h&w)|0;c=c+8|0;h=x[g>>2];e=x[g+4>>2];f=q;continue a}else{be(i,v[h+x[g+12>>2]|0]<<6);ae(i,4);Pb(g+8|0,n,o);b=b-1|0;continue}}break}x[a>>2]=h;x[a+4>>2]=e;x[a+48>>2]=f;x[a+44>>2]=q;fb=g+16|0}function ac(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=SY(a+24|0);a=h;i=a>>>0<=1?1:a;a=i;b=a+15&-16;a=a>>>0<b>>>0?b:a;b=0;f=fb-16|0;fb=f;if(!(a&15)){if(a>>>0>4294967216){a=48}else{a:{if(a>>>0>=4294967216){x[31612]=48;b=0;break a}d=a>>>0<11?16:a+11&-8;a=Ed(d+28|0);b=0;if(!a){break a}b=a-8|0;b:{if(!(a&15)){a=b;break b}g=a-4|0;j=x[g>>2];a=(a+15&-16)-8|0;a=(a-b>>>0<=15?16:0)+a|0;c=a-b|0;e=(j&-8)-c|0;if(!(j&3)){b=x[b>>2];x[a+4>>2]=e;x[a>>2]=b+c;break b}x[a+4>>2]=e|x[a+4>>2]&1|2;e=a+e|0;x[e+4>>2]=x[e+4>>2]|1;x[g>>2]=c|x[g>>2]&1|2;e=b+c|0;x[e+4>>2]=x[e+4>>2]|1;Ev(b,c)}b=x[a+4>>2];c:{if(!(b&3)){break c}c=b&-8;if(c>>>0<=d+16>>>0){break c}x[a+4>>2]=d|b&1|2;b=a+d|0;d=c-d|0;x[b+4>>2]=d|3;c=a+c|0;x[c+4>>2]=x[c+4>>2]|1;Ev(b,d)}b=a+8|0}if(b){x[f+12>>2]=b;a=0}else{a=48}}b=a?0:x[f+12>>2]}fb=f+16|0;a=b;if(!a){d:{b=0;a=x[125562];if(!a){x[125562]=502268;w[251135]=125;k=502268,l=Qx(502768),w[k>>1]=l;a=x[125562]}d=(i+3>>>2|0)+1|0;while(1){e:{if(!a|(a|0)==502768){a=0}else{c=z[a+2>>1];f=d+(d>>>0<c>>>0?c-d&3:0)|0;if(c>>>0>f>>>0){b=c-f|0;w[a+2>>1]=b;a=((b&65535)<<2)+a|0;w[a+2>>1]=f;w[a>>1]=0;a=a+4|0;break d}if(d>>>0>c>>>0){break e}d=z[a>>1];f:{if(!b){k=502248,l=Rx(d),x[k>>2]=l;break f}w[b>>1]=d}w[a>>1]=0;a=a+4|0}break d}b=a;a=Rx(z[a>>1]);continue}}}if(!a){Sb();p()}return $R(Rb(a,0,h))}function C4(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;k=fb-128|0;fb=k;j=lt(c,d);x[k+4>>2]=1199;n=kt(k+8|0,k+4|0);i=k+16|0;a:{b:{c:{if(j>>>0>=101){i=Ed(j);if(!i){x[31737]=0;X(1200);a=x[31737];x[31737]=0;if((a|0)!=1){break c}break a}Se(n,i)}h=i;g=c;while(1)if((d|0)==(g|0)){d:while(1){g=x[a>>2];h=(g|0)==(b|0);if(j?h:1){if(h){x[f>>2]=x[f>>2]|2}break b}g=x[g>>2];x[31737]=0;s=P(1218,e|0,g|0)|0;g=x[31737];x[31737]=0;if((g|0)==1){break a}l=o+1|0;r=0;h=i;g=c;while(1){if((d|0)==(g|0)){o=l;if(!r){continue d}x[a>>2]=x[a>>2]+4;h=i;g=c;if(j+m>>>0<2){continue d}while(1){if((d|0)==(g|0)){continue d}e:{if(y[h|0]!=2){break e}if((Cb(x[g+4>>2],y[g+11|0])|0)==(o|0)){break e}v[h|0]=0;m=m-1|0}h=h+1|0;g=g+12|0;continue}}f:{if(y[h|0]!=1){break f}q=x[Vd(g,o)>>2];x[31737]=0;q=P(1218,e|0,q|0)|0;t=x[31737];x[31737]=0;if((t|0)==1){break a}g:{if((q|0)==(s|0)){r=1;if((Cb(x[g+4>>2],y[g+11|0])|0)!=(l|0)){break f}v[h|0]=2;m=m+1|0;break g}v[h|0]=0}j=j-1|0}h=h+1|0;g=g+12|0;continue}}}else{l=Ad(x[g+4>>2],y[g+11|0]);v[h|0]=l?2:1;m=m+l|0;j=j-l|0;h=h+1|0;g=g+12|0;continue}}p()}h:{i:{while(1){if((c|0)==(d|0)){break i}if(y[i|0]!=2){i=i+1|0;c=c+12|0;continue}break}d=c;break h}x[f>>2]=x[f>>2]|4}Lc(n);fb=k+128|0;return d|0}a=N()|0;Lc(n);Q(a|0);p()}function s4(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;k=fb-128|0;fb=k;j=lt(c,d);x[k+4>>2]=1199;n=kt(k+8|0,k+4|0);i=k+16|0;a:{b:{c:{if(j>>>0>=101){i=Ed(j);if(!i){x[31737]=0;X(1200);a=x[31737];x[31737]=0;if((a|0)!=1){break c}break a}Se(n,i)}h=i;g=c;while(1)if((d|0)==(g|0)){d:while(1){g=x[a>>2];h=(g|0)==(b|0);if(j?h:1){if(h){x[f>>2]=x[f>>2]|2}break b}g=v[g|0];x[31737]=0;s=P(1203,e|0,g|0)|0;g=x[31737];x[31737]=0;if((g|0)==1){break a}l=o+1|0;r=0;h=i;g=c;while(1){if((d|0)==(g|0)){o=l;if(!r){continue d}x[a>>2]=x[a>>2]+1;h=i;g=c;if(j+m>>>0<2){continue d}while(1){if((d|0)==(g|0)){continue d}e:{if(y[h|0]!=2){break e}if((Cb(x[g+4>>2],y[g+11|0])|0)==(o|0)){break e}v[h|0]=0;m=m-1|0}h=h+1|0;g=g+12|0;continue}}f:{if(y[h|0]!=1){break f}q=v[cc(g,o)|0];x[31737]=0;q=P(1203,e|0,q|0)|0;t=x[31737];x[31737]=0;if((t|0)==1){break a}g:{if((q|0)==(s|0)){r=1;if((Cb(x[g+4>>2],y[g+11|0])|0)!=(l|0)){break f}v[h|0]=2;m=m+1|0;break g}v[h|0]=0}j=j-1|0}h=h+1|0;g=g+12|0;continue}}}else{l=Ad(x[g+4>>2],y[g+11|0]);v[h|0]=l?2:1;m=m+l|0;j=j-l|0;h=h+1|0;g=g+12|0;continue}}p()}h:{i:{while(1){if((c|0)==(d|0)){break i}if(y[i|0]!=2){i=i+1|0;c=c+12|0;continue}break}d=c;break h}x[f>>2]=x[f>>2]|4}Lc(n);fb=k+128|0;return d|0}a=N()|0;Lc(n);Q(a|0);p()}function Lna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=fb-32|0;fb=e;c=z[a+480190>>1];v[e+20|0]=0;f=c+1|0;c=e+20|0;mU(b,f,c);if(z[a+480192>>1]){g=Nb(c);m=e,n=wb(x[a+484344>>2]),x[m+16>>2]=n;l=wb(x[a+484348>>2]);while(1){f=x[e+16>>2];if(Ib(f,l)){a:{if(!Ib(x[f>>2],x[f+4>>2])){break a}c=z[a+480188>>1];x[31737]=0;v[e+4|0]=0;S(781,g|0,c|0,e+4|0);c=x[31737];x[31737]=0;if((c|0)!=1){m=e,n=wb(x[f>>2]),x[m+12>>2]=n;j=0;b:while(1){h=0;if(A[f+12>>2]<=j>>>0){break a}while(1)if(z[a+480188>>1]<=h>>>0){j=j+1|0;continue b}else{c:{c=x[e+12>>2];if(!Sc(y[c|0])){break c}d:{e:{c=y[c+1|0];if(c){d=z[a+480192>>1];break e}d=z[a+480192>>1];c=y[xb(x[g>>2],h)|0];if(c){break e}c=1;break d}m=xb(x[g>>2],h),n=c,v[m|0]=n;d=d&65535;i=d>>>0<c>>>0;d=i?d:c;c=i?1:c}i=d&65535;while(1){d=c&65535;if(d>>>0>i>>>0){break c}d=x[((d<<2)+a|0)+900380>>2];f:{if(!d){break f}d=z[_b(d+236|0,y[x[e+12>>2]]-1|0)>>1];if(d>>>0>z[a+480190>>1]){break f}k=e+4|0;Kb(k,x[b>>2],d);If(k,1)}c=c+1|0;continue}}h=h+1|0;IC(e+12|0);continue}}}a=N()|0;dc(g);Q(a|0);p()}am(e+16|0);continue}else{c=z[a+480190>>1];d=0;while(1){if(c){Kb(e+4|0,x[b>>2],c);if(!Hb(x[x[e+4>>2]>>2],x[e+8>>2])){f=d;d=D(c,104)+a|0;d=f+je(x[d+484380>>2],x[d+484400>>2])|0}c=c-1|0;continue}else{dc(g)}break}}break}}fb=e+32|0;return d&65535}function YO(a){a=a|0;var b=0,c=0,d=0,e=0;e=fb-160|0;fb=e;d=Dc(e+4|0,11616);x[31737]=0;b=d+12|0;P(36,b|0,11021)|0;c=x[31737];x[31737]=0;a:{if((c|0)==1){break a}x[31737]=0;b=d+24|0;P(36,b|0,11446)|0;c=x[31737];x[31737]=0;if((c|0)==1){break a}x[31737]=0;b=d+36|0;P(36,b|0,11013)|0;c=x[31737];x[31737]=0;if((c|0)==1){break a}x[31737]=0;b=d+48|0;P(36,b|0,8243)|0;c=x[31737];x[31737]=0;if((c|0)==1){break a}x[31737]=0;b=d+60|0;P(36,b|0,10998)|0;c=x[31737];x[31737]=0;if((c|0)==1){break a}x[31737]=0;b=d+72|0;P(36,b|0,8309)|0;c=x[31737];x[31737]=0;if((c|0)==1){break a}x[31737]=0;b=d+84|0;P(36,b|0,5620)|0;c=x[31737];x[31737]=0;if((c|0)==1){break a}x[31737]=0;b=d+96|0;P(36,b|0,12020)|0;c=x[31737];x[31737]=0;if((c|0)==1){break a}x[31737]=0;b=d+108|0;P(36,b|0,11389)|0;c=x[31737];x[31737]=0;if((c|0)==1){break a}x[31737]=0;b=d+120|0;P(36,b|0,12289)|0;c=x[31737];x[31737]=0;if((c|0)==1){break a}x[31737]=0;b=d+132|0;P(36,b|0,5472)|0;c=x[31737];x[31737]=0;if((c|0)==1){break a}x[31737]=0;b=d+144|0;P(36,b|0,7335)|0;c=x[31737];x[31737]=0;if((c|0)==1){break a}x[31737]=0;U(1069,a|0,d|0,13)|0;a=x[31737];x[31737]=0;if((a|0)!=1){b=d+156|0;while(1){b=tb(b-12|0);if((d|0)!=(b|0)){continue}break}fb=e+160|0;return}b=d+156|0}a=N()|0;while(1){b=tb(b-12|0);if((d|0)!=(b|0)){continue}break}Q(a|0);p()}function bJ(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;a=fb-16|0;fb=a;x[a+12>>2]=c;x[a+8>>2]=f;x[a+12>>2]=c;x[a+8>>2]=f;c=x[a+12>>2];a:{while(1){if(c>>>0>=d>>>0){f=0;break a}b:{b=z[c>>1];c:{if(b>>>0<=127){f=1;c=x[a+8>>2];if((g-c|0)<=0){break a}x[a+8>>2]=c+1;v[c|0]=b;break c}if(b>>>0<=2047){c=x[a+8>>2];if((g-c|0)<2){break b}x[a+8>>2]=c+1;v[c|0]=b>>>6|192;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b&63|128;break c}if(b>>>0<=55295){c=x[a+8>>2];if((g-c|0)<3){break b}x[a+8>>2]=c+1;v[c|0]=b>>>12|224;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b>>>6&63|128;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b&63|128;break c}d:{e:{if(b>>>0<=56319){f=1;if((d-c|0)<4){break a}i=z[c+2>>1];if((i&64512)!=56320){break e}if((g-x[a+8>>2]|0)<4){break a}x[a+12>>2]=c+2;c=x[a+8>>2];x[a+8>>2]=c+1;f=c;c=(b>>>6&15)+1|0;v[f|0]=c>>>2|240;f=x[a+8>>2];x[a+8>>2]=f+1;v[f|0]=c<<4&48|b>>>2&15|128;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=i>>>6&15|b<<4&48|128;b=x[a+8>>2];x[a+8>>2]=b+1;v[b|0]=i&63|128;break c}if(b>>>0>=57344){break d}}f=2;break a}c=x[a+8>>2];if((g-c|0)<3){break b}x[a+8>>2]=c+1;v[c|0]=b>>>12|224;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b>>>6&63|128;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b&63|128}c=x[a+12>>2]+2|0;x[a+12>>2]=c;continue}break}f=1}x[e>>2]=x[a+12>>2];x[h>>2]=x[a+8>>2];fb=a+16|0;return f|0}function Kra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=fb-16|0;fb=e;i=Hf(a,c);$d(e,x[a+36>>2]);j=a;a:{if(!i){Pc(e,a+32|0,5);c=0;if(Hb(x[x[e>>2]>>2],x[e+4>>2])){break a}}d=fb-160|0;fb=d;f=Pm(d+48|0,x[a+36>>2]);x[31737]=0;a=P(462,d+36|0,42324)|0;c=x[31737];x[31737]=0;b:{c:{d:{e:{if((c|0)!=1){x[31737]=0;x[d+16>>2]=20054022;x[d+20>>2]=0;S(463,f|0,a|0,d+16|0);c=x[31737];x[31737]=0;if((c|0)==1){break e}Eb(a);if(!vl(y[f|0])){break d}break b}c=N()|0;break c}c=N()|0;Eb(a);break c}l=d,m=ck(x[b>>2],x[b+4>>2]),w[l+34>>1]=m;w[d+32>>1]=65535;x[31737]=0;a=P(462,d+16|0,10121)|0;c=x[31737];x[31737]=0;f:{if((c|0)!=1){x[31737]=0;c=U(492,f|0,d+32|0,a|0)|0;g=x[31737];x[31737]=0;if((g|0)==1){break f}Eb(a);if(c){w[d+34>>1]=z[d+32>>1]}Gf(d+34|0,4e3);a=z[d+34>>1];g:{if(ck(x[b>>2],x[b+4>>2])>>>0>=a>>>0){break g}x[31737]=0;O(224,b|0,a|0);c=x[31737];x[31737]=0;if((c|0)!=1){break g}c=N()|0;break c}c=0;h:{while(1){if((a|0)==(c|0)){break b}h=x[b>>2];x[31737]=0;g=d+4|0;O(493,g|0,c|0);k=x[31737];x[31737]=0;if((k|0)!=1){x[31737]=0;V(494,f|0,Wb(h,c)|0,g|0,495);h=x[31737];x[31737]=0;if((h|0)==1){break h}c=c+1|0;Eb(g);continue}break}c=N()|0;break c}c=N()|0;Eb(d+4|0);break c}c=N()|0;break c}c=N()|0;Eb(a)}Ah(f);Q(c|0);p()}Ah(f);fb=d+160|0;c=i}ff(j,c);fb=e+16|0}function PK(a,b){var c=0,d=0,e=0,f=0,g=0;a:{b:{c:{d:{e:{f:{c=x[a+4>>2];g:{if((c|0)!=x[a+104>>2]){x[a+4>>2]=c+1;c=y[c|0];break g}c=sd(a)}switch(c-43|0){case 0:case 2:break f;default:break e}}d=(c|0)==45;f=!b;c=x[a+4>>2];h:{if((c|0)!=x[a+104>>2]){x[a+4>>2]=c+1;c=y[c|0];break h}c=sd(a)}b=c-58|0;if(f|b>>>0>4294967285){break d}b=x[a+116>>2];if((b|0)>0){b=1}else{b=(b|0)>=0}if(b){break c}break a}b=c-58|0}f=d;if(b>>>0<=4294967285){if(x[a+116>>2]<0){break a}break b}i:{if(c-48>>>0>=10){break i}while(1){e=(D(e,10)+c|0)-48|0;d=(e|0)<214748364;c=x[a+4>>2];j:{if((c|0)!=x[a+104>>2]){x[a+4>>2]=c+1;c=y[c|0];break j}c=sd(a)}b=c-48|0;if(d&b>>>0<=9){continue}break}g=e>>31;if(b>>>0>=10){break i}while(1){b=c;c=Sua(e,g,10,0);d=b+c|0;b=hb;e=d-48|0;d=(c>>>0>d>>>0?b+1|0:b)-(d>>>0<48)|0;g=d;d=e>>>0<2061584302&(d|0)<=21474836|(d|0)<21474836;c=x[a+4>>2];k:{if((c|0)!=x[a+104>>2]){x[a+4>>2]=c+1;c=y[c|0];break k}c=sd(a)}b=c-48|0;if(d&b>>>0<=9){continue}break}if(b>>>0>=10){break i}while(1){b=x[a+4>>2];l:{if((b|0)!=x[a+104>>2]){x[a+4>>2]=b+1;b=y[b|0];break l}b=sd(a)}if(b-48>>>0<10){continue}break}}b=x[a+116>>2];if((b|0)>0){b=1}else{b=(b|0)>=0}if(b){x[a+4>>2]=x[a+4>>2]-1}hb=f?0-(((e|0)!=0)+g|0)|0:g;return f?0-e|0:e}x[a+4>>2]=x[a+4>>2]-1}x[a+4>>2]=x[a+4>>2]-1}hb=-2147483648;return 0}function Ce(a,b){var c=0,d=0,e=0,f=0,g=0,h=E(0),i=0,k=0;d=(q(b),j(2));c=pI(d);a:{b:{c:{d:{e=(q(a),j(2));e:{if(e-2139095040>>>0>=2164260864){if(c){break e}break c}if(!c){break d}}h=E(1);if((e|0)==1065353216){break b}c=d<<1;if(!c){break b}i=c>>>0<4278190081;c=e<<1;a=E(a+b);if(!(i&c>>>0<=4278190080)){break a}if((c|0)==2130706432){break b}a=c>>>0>2130706431^(d|0)>=0?E(0):E(b*b);break a}if(pI(e)){h=E(a*a);if((e|0)<0){h=(oI(d)|0)==1?E(-h):h}if((d|0)>=0){break b}a=zx(E(E(1)/h));break a}if((e|0)<0){c=oI(d);if(!c){a=SI(a);break a}e=(q(a),j(2))&2147483647;i=((c|0)==1)<<16}if(e>>>0>8388607){break c}e=((q(E(a*E(8388608))),j(2))&2147483647)-192937984|0}d=e-1060306944|0;c=d>>>15&240;f=+(l(2,e-(d&-8388608)|0),r())*C[c+125672>>3]+-1;g=f*f;f=((f*.288457581109214+-.36092606229713164)*(g*g)+((f*.480898481472577+-.7213474675006291)*g+(f*1.4426950408774342+(C[c+125680>>3]+ +(d>>23)))))*+b;o(+f);c=j(1)|0;j(0)|0;f:{c=c&2147450880;if((c|0)==1079967744|c>>>0<1079967744){break f}if(f>127.99999995700433){a=DG(i);break a}if(!(f<=-150)){break f}a=bG(i);break a}k=f;g=C[160];f=g+f;g=k-(f-g);g=(C[161]*g+C[162])*(g*g)+(C[163]*g+1);o(+f);j(1)|0;e=j(0)|0;d=i+e|0;i=d<<15;d=((e&31)<<3)+1024|0;c=x[d>>2];d=x[d+4>>2]+i|0;l(0,c|0);l(1,(c>>>0>c>>>0?d+1|0:d)|0);h=E(g*+n())}a=h}return a}function GM(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0;c=fb+-64|0;fb=c;d=x[a>>2];a=x[d>>2];f=x[a+4>>2];x[c+40>>2]=x[a+20>>2];g=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=g;Zf(c+48|0,c+32|0,f);a=x[d+4>>2];f=x[a+8>>2];g=x[a+4>>2];d=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=d;d=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=d;x[c+8>>2]=x[a+8>>2];d=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=d;a=fb-32|0;fb=a;a:{b:{c:{d:{k=x[c+4>>2];if(k>>>0>=g>>>0){l=x[c+20>>2];if(l>>>0<g>>>0){break d}if(f>>>0>A[c+8>>2]){break c}m=x[c+28>>2];if(f>>>0>x[c+24>>2]-m>>>0){break b}n=b+12|0;o=x[c+16>>2];q=x[c>>2];e:while(1){if((f|0)==(h|0)){break a}r=(D(h,k)<<3)+q|0;s=(D(h+m|0,l)<<1)+o|0;d=0;while(1)if((d|0)==(g|0)){h=h+1|0;continue e}else{e=yb(x[b>>2],d);i=Ee(Ig(C[(d<<3)+r>>3])*134217728);j=e;e=(x[e>>2]>>1)+Cn(i)|0;t=e;e=Xt(n)+e&-4096;x[j>>2]=t-e;C[a+24>>3]=+(e|0)*7.450580596923828e-9;x[a+16>>2]=0;x[a+20>>2]=-1074790400;x[a+8>>2]=0;x[a+12>>2]=1072693248;j=(d<<1)+s|0;i=Ee(C[Yg(a+24|0,a+16|0,a+8|0)>>3]*32768);f:{if(F(i)<2147483648){e=~~i;break f}e=-2147483648}u=j,v=ed(e),w[u>>1]=v;d=d+1|0;continue}}}_(7244,9061,77,8741);p()}_(7209,9061,78,8741);p()}_(5897,9061,79,8741);p()}_(5867,9061,80,8741);p()}fb=a+32|0;fb=c- -64|0}function gma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0;h=fb-16|0;fb=h;e=x[a+48>>2];i=x[a+40>>2];j=x[a+36>>2];f=x[a+44>>2];q=x[a+16>>2];l=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=l;r=b+24|0;s=x[a+32>>2];t=x[a+28>>2];u=x[a+72>>2];m=x[a+68>>2];v=m>>31;n=x[a+64>>2];y=n>>31;o=x[a+60>>2];z=o>>31;l=x[a+8>>2];A=x[a+12>>2];while(1){b=f;if(d){f=Yb(f,-16777216,16776704);g=Sua(n,y,f,f>>31);f=hb;e=Yb(e,-16777216,16776704);e=Sua(m,v,e,e>>31);g=e+g|0;f=hb+f|0;f=e>>>0>g>>>0?f+1|0:f;e=x[h+8>>2];k=g;g=(x[h+12>>2]<<1)+q|0;e=(((e>>>16|0)+4&131064)<<1)+r|0;p=(((((D(w[g+4>>1],w[e+10>>1])+D(w[g+2>>1],w[e+8>>1])|0)+D(w[g+6>>1],w[e+12>>1])|0)+D(w[g+8>>1],w[e+14>>1])|0)/2|0)+((((D(w[g-4>>1],w[e+2>>1])+D(w[g-6>>1],w[e>>1])|0)+D(w[g-2>>1],w[e+4>>1])|0)+D(w[g>>1],w[e+6>>1])|0)/2|0)|0)/16384<<8;e=p;g=Sua(e,e>>31,o,z);k=k+g|0;e=hb+f|0;e=g>>>0>k>>>0?e+1|0:e;f=k+8388608|0;e=f>>>0<8388608?e+1|0:e;f=Rc(f,e,24);e=(f|0)/256|0;j=j+t|0;x[c>>2]=D(e,j>>12)+x[c>>2];i=i+s|0;x[c+4>>2]=x[c+4>>2]+D(i>>12,e);Pb(h+8|0,l,A);f=f-(u&p)|0;c=c+8|0;d=d-1|0;e=b;continue}break}c=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=c;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+48>>2]=e;x[a+44>>2]=b;x[a+24>>2]=i>>12;fb=h+16|0}function PL(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=E(0),k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=E(0);d=(b<<2)+a|0;h=d+1068|0;k=c<<1&-4;p=h,q=te(a,k),x[p>>2]=q;g=d+1076|0;p=g,q=te(a,k),x[p>>2]=q;i=te(a,c&-4);x[d+1084>>2]=i;a:{h=x[h>>2];if(!h){break a}g=x[g>>2];if(!g|!i){break a}d=c>>2;o=(d|0)>0?d:0;j=E(c|0);d=0;while(1){if((e|0)==(o|0)){d=0;e=c>>3;h=(e|0)>0?e:0;e=0;while(1){if((d|0)!=(h|0)){g=e|1;f=+E(E(E(g<<1)*E(3.1415927410125732))/j);p=i+(e<<2)|0,r=E(jf(f)),B[p>>2]=r;p=i+(g<<2)|0,r=E(-E(Wi(f))),B[p>>2]=r;e=e+2|0;d=d+1|0;continue}break}}else{l=d<<2;f=+E(E(E(e<<2)*E(3.1415927410125732))/j);p=h+l|0,r=E(jf(f)),B[p>>2]=r;m=d|1;n=m<<2;p=h+n|0,r=E(-E(Wi(f))),B[p>>2]=r;f=+E(E(E(E(m|0)*E(3.1415927410125732))/j)*E(.5));p=g+l|0,r=E(E(jf(f))*E(.5)),B[p>>2]=r;p=g+n|0,r=E(E(Wi(f))*E(.5)),B[p>>2]=r;d=d+2|0;e=e+1|0;continue}break}i=(b<<2)+a|0;d=te(a,k);x[i+1092>>2]=d;if(!d){break a}b=0;e=c>>1;k=(e|0)>0?e:0;f=+(e|0);while(1){if((b|0)!=(k|0)){j=E(Wi((+(b|0)+.5)/f*.5*3.1415927410125732));p=d+(b<<2)|0,r=E(Wi(+E(j*j)*1.5707963705062866)),B[p>>2]=r;b=b+1|0;continue}break}b=te(a,c>>2&-2);x[i+1100>>2]=b;if(!b){break a}a=0;d=c>>3;d=(d|0)>0?d:0;c=36-Om(c)|0;while(1){if((a|0)!=(d|0)){p=b+(a<<1)|0,q=Mm(a)>>>c<<2,w[p>>1]=q;a=a+1|0;continue}break}return 1}fc(a,3);return 0}function Pj(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;a:{if(!je(x[a>>2],x[a+20>>2])){break a}_k(a);b:{switch(On(z[a+34>>1])-1|0){case 1:h=fb-48|0;fb=h;g=x[a+20>>2];d=x[a>>2];c=_d(z[a+34>>1]);e=g+(D(d,c)<<1)|0;while(1){c:{d:{if((f|0)!=16){j=e+(D(c,f)<<1)|0;k=g+(D(c,f^-1)<<1)|0;d=0;break d}f=e+(c<<5)|0;d=z[a+34>>1];if(d&2){e=x[a+4>>2];i=x[a+8>>2]-e|0;mV(h+28|0,f,g+(D(c,e)<<1)|0,i,c,(d&4)>>>2|0,Ob(b+1074312|0,33));d=z[a+34>>1]}if(d&8){e=x[a+16>>2];a=x[a+12>>2];e=e-a|0;mV(h+8|0,f+(c<<7)|0,g+(D(a,c)<<1)|0,e,c,(d&16)>>>4|0,Ob(b+1074312|0,33))}fb=h+48|0;break c}while(1){if((c|0)!=(d|0)){i=d<<1;w[i+j>>1]=z[e+(d-c<<1)>>1];w[i+k>>1]=z[g+i>>1];d=d+1|0;continue}break}f=f+1|0;continue}break};return;case 0:break b;default:break a}}h=fb-48|0;fb=h;g=x[a+20>>2];c=x[a>>2];d=_d(z[a+34>>1]);e=g+D(c,d)|0;while(1){e:{f:{if((f|0)!=16){i=e+D(d,f)|0;j=g+D(d,f^-1)|0;c=0;break f}f=e+(d<<4)|0;c=z[a+34>>1];if(c&2){e=x[a+4>>2];i=x[a+8>>2]-e|0;lV(h+28|0,f,g+D(d,e)|0,i,d,(c&4)>>>2|0,Ob(b+1074312|0,33));c=z[a+34>>1]}if(c&8){e=x[a+16>>2];a=x[a+12>>2];e=e-a|0;lV(h+8|0,f+(d<<6)|0,g+D(a,d)|0,e,d,(c&16)>>>4|0,Ob(b+1074312|0,33))}fb=h+48|0;break e}while(1){if((c|0)!=(d|0)){v[c+i|0]=y[e+(c-d|0)|0];v[c+j|0]=y[c+g|0];c=c+1|0;continue}break}f=f+1|0;continue}break}}}function Zla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=fb-16|0;fb=e;r=x[a+16>>2];s=Fg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);l=x[a+8>>2];m=x[a+12>>2];b=x[a>>2];f=x[a+4>>2];n=x[a+128>>2];if(n){o=Gg(l,m,n);p=hb;h=x[a+76>>2];hg(b,f,vf(l,m,d),hb);q=hb>>>0>h>>>0?d:0}h=a+112|0;i=x[a+40>>2];j=x[a+36>>2];x[e>>2]=b;x[e+4>>2]=f;while(1){if(d){d=d-1|0;x[e+8>>2]=b;x[e+12>>2]=0;q=q-1|0;g=q;o=g?o:0;p=g?p:0;k=(((f&2147483647)<<1|b>>>31)&-2)+r|0;f=n;a:{b:while(1){c:{if((f|0)<=0){Pb(h,x[a+120>>2],x[a+124>>2]);f=x[a+116>>2];if(!f){break a}g=x[e+8>>2];k=(((x[e+12>>2]&2147483647)<<1|g>>>31)&-2)+k|0;g=0;b=0;break c}g=x[e+8>>2];t=(((x[e+12>>2]&2147483647)<<1|g>>>31)&-2)+k|0;b=0;g=0;while(1)if((b|0)==2){be(h,g>>>3<<16>>16);ae(h,4);Pb(e+8|0,o,p);f=f-1|0;continue b}else{g=(v[b+t|0]<<8)+g|0;b=b+1|0;continue}}break}while(1){if((b|0)!=2){g=(v[b+k|0]<<8)+g|0;b=b+1|0;continue}break}be(h,g>>>3<<16>>16);ae(h,f);x[h>>2]=x[h>>2];x[h+4>>2]=0}b=Eg(h,s);f=x[a+32>>2];j=x[a+28>>2]+j|0;x[c>>2]=x[c>>2]+D(b,j>>12);i=f+i|0;x[c+4>>2]=x[c+4>>2]+D(b,i>>12);Pb(e,l,m);c=c+8|0;b=x[e>>2];f=x[e+4>>2];continue}break}x[a>>2]=b;x[a+4>>2]=f;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+24>>2]=i>>12;fb=e+16|0}function MM(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;c=fb+-64|0;fb=c;d=x[a>>2];a=x[d>>2];f=x[a+4>>2];x[c+40>>2]=x[a+20>>2];g=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=g;Zf(c+48|0,c+32|0,f);a=x[d+4>>2];f=x[a+8>>2];g=x[a+4>>2];d=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=d;d=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=d;x[c+8>>2]=x[a+8>>2];d=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=d;a=fb-32|0;fb=a;a:{b:{c:{d:{k=x[c+4>>2];if(k>>>0>=g>>>0){if(A[c+20>>2]<g>>>0){break d}if(f>>>0>A[c+8>>2]){break c}l=x[c+28>>2];if(f>>>0>x[c+24>>2]-l>>>0){break b}m=b+12|0;n=x[c+16>>2];o=x[c>>2];e:while(1){if((f|0)==(h|0)){break a}q=(D(h,k)<<3)+o|0;d=0;while(1)if((d|0)==(g|0)){h=h+1|0;continue e}else{e=yb(x[b>>2],d);i=Ee(Ig(C[(d<<3)+q>>3])*134217728);j=e;e=(x[e>>2]>>1)+Cn(i)|0;r=e;e=Xt(m)+e&-4096;x[j>>2]=r-e;C[a+24>>3]=+(e|0)*7.450580596923828e-9;x[a+16>>2]=0;x[a+20>>2]=-1074790400;x[a+8>>2]=0;x[a+12>>2]=1072693248;j=(d<<2)+n|0;i=Ee(C[Yg(a+24|0,a+16|0,a+8|0)>>3]*32768);f:{if(F(i)<2147483648){e=~~i;break f}e=-2147483648}s=(x[j>>2]+(l<<1)|0)+(h<<1)|0,t=ed(e),w[s>>1]=t;d=d+1|0;continue}}}_(7244,9061,77,8741);p()}_(7209,9061,78,8741);p()}_(5897,9061,79,8741);p()}_(5867,9061,80,8741);p()}fb=a+32|0;fb=c- -64|0}function M1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;g=fb-1088|0;fb=g;e=ai(a);Rb(e+20|0,0,1040);x[e+1064>>2]=0;x[e+1068>>2]=0;x[e+1060>>2]=c;v[e+1084|0]=d;a=e+1072|0;x[a>>2]=0;x[a+4>>2]=0;x[e+1080>>2]=0;i=e+1064|0;a=c;d=0;a:{b:{c:while(1){if(_d(z[a+34>>1])>>>0<=d>>>0){break a}x[e+1064>>2]=0;x[e+1068>>2]=0;a=0;while(1){d:{e:{f:{g:{h:{i:{j:{if(A[c>>2]<=a>>>0){break j}a=x[b+8>>2];f=x[b>>2];x[31737]=0;a=U(151,f|0,a|0,2)|0;f=x[31737];x[31737]=0;if((f|0)==1){break i}if(!a){break j}x[31737]=0;a=R(190,b|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break h}if(!a){break e}x[31737]=0;f=g+8|0;S(186,f|0,b|0,a|0);a=x[31737];x[31737]=0;if((a|0)==1){break g}a=qs(g+28|0,f);h=hd(e,a);yc(h+20|0,a+20|0,1040);ub(a);ub(f);x[e+1076>>2]=0;x[e+1080>>2]=0;f=x[e+1060>>2];a=x[f+20>>2];if(On(z[f+34>>1])>>>0>=2){x[31737]=0;O(191,h|0,a+(d<<1)|0);a=x[31737];x[31737]=0;if((a|0)!=1){break e}break f}x[31737]=0;O(192,h|0,a+d|0);a=x[31737];x[31737]=0;if((a|0)==1){break f}break e}d=d+1|0;a=x[e+1060>>2];continue c}a=N()|0;break b}a=N()|0;break b}a=N()|0;break b}a=T(28896)|0;if((gb|0)!=($(28896)|0)){break b}Y(a|0)|0;x[31737]=0;X(26);a=x[31737];x[31737]=0;if((a|0)==1){break d}}a=x[i>>2];continue}break}break}a=N()|0}ub(e);Q(a|0);p()}fb=g+1088|0;return e|0}function wba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if(A[a+4>>2]<A[zb(a)>>2]){c=fb-16|0;fb=c;a=gv(c+4|0,a,1);zz(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+16;hc(a);fb=c+16|0;return}i=fb-32|0;fb=i;c=zb(a);d=YV(i+12|0,ZV(a,Ik(x[a>>2],x[a+4>>2])+1|0),Ik(x[a>>2],x[a+4>>2]),c);zz(x[d+8>>2],b);x[d+8>>2]=x[d+8>>2]+16;h=fb-16|0;fb=h;e=zb(a);b=vb(h+12|0,x[a+4>>2]);c=vb(h+8|0,x[a>>2]);f=vb(h+4|0,x[d+4>>2]);b=x[b>>2];g=x[c>>2];c=fb+-64|0;fb=c;f=x[f>>2];x[c+56>>2]=f;x[c+60>>2]=b;x[c+52>>2]=f;e=Re(c+24|0,e,c+52|0,c+56|0);x[c+16>>2]=x[e+8>>2];f=x[e+4>>2];x[c+8>>2]=x[e>>2];x[c+12>>2]=f;Qe(c+36|0,c+8|0);while(1){if(pd(b,g)){zz(Az(x[c+56>>2]),kC(b));b=$q(c+60|0);$q(c+56|0);b=x[b>>2];continue}break}Pe(c+36|0);j=x[c+56>>2];if(!y[c+48|0]){f=fb-16|0;fb=f;b=vb(f+12|0,x[x[c+44>>2]>>2]);k=x[vb(f+8|0,x[x[c+40>>2]>>2])>>2];g=fb-16|0;fb=g;b=x[b>>2];x[g+12>>2]=b;while(1){if(ci(b,k)){e=fb-16|0;fb=e;x[e+12>>2]=b;x[e+12>>2]=x[e+12>>2]+16;fb=e+16|0;Wj(Az(x[e+12>>2]));b=x[Zo(g+12|0)>>2];continue}break}fb=g+16|0;fb=f+16|0}fb=c- -64|0;x[d+4>>2]=j;Tb(a,d+4|0);Tb(a+4|0,d+8|0);Tb(zb(a),nc(d));x[d>>2]=x[d+4>>2];fb=h+16|0;a=x[d+4>>2];while(1){b=x[d+8>>2];if((b|0)!=(a|0)){b=b-16|0;x[d+8>>2]=b;Wj(b);continue}break}a=x[d>>2];if(a){ys(d);Db(a)}fb=i+32|0}function hma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0,A=0,B=0;h=fb-16|0;fb=h;e=x[a+48>>2];i=x[a+40>>2];j=x[a+36>>2];f=x[a+44>>2];q=x[a+16>>2];l=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=l;r=b+24|0;s=x[a+32>>2];t=x[a+28>>2];u=x[a+72>>2];m=x[a+68>>2];y=m>>31;n=x[a+64>>2];z=n>>31;o=x[a+60>>2];A=o>>31;l=x[a+8>>2];B=x[a+12>>2];while(1){b=f;if(d){f=Yb(f,-16777216,16776704);g=Sua(n,z,f,f>>31);f=hb;e=Yb(e,-16777216,16776704);e=Sua(m,y,e,e>>31);g=e+g|0;f=hb+f|0;f=e>>>0>g>>>0?f+1|0:f;e=x[h+8>>2];k=g;g=x[h+12>>2]+q|0;e=(((e>>>16|0)+4&131064)<<1)+r|0;p=((((D(v[g+2|0],w[e+10>>1])+D(v[g+1|0],w[e+8>>1])|0)+D(v[g+3|0],w[e+12>>1])|0)+D(v[g+4|0],w[e+14>>1])<<8>>1)+(((D(v[g-2|0],w[e+2>>1])+D(v[g-3|0],w[e>>1])|0)+D(v[g-1|0],w[e+4>>1])|0)+D(v[g|0],w[e+6>>1])<<8>>1)|0)/16384<<8;e=p;g=Sua(e,e>>31,o,A);k=k+g|0;e=hb+f|0;e=g>>>0>k>>>0?e+1|0:e;f=k+8388608|0;e=f>>>0<8388608?e+1|0:e;f=Rc(f,e,24);e=(f|0)/256|0;j=j+t|0;x[c>>2]=D(e,j>>12)+x[c>>2];i=i+s|0;x[c+4>>2]=x[c+4>>2]+D(i>>12,e);Pb(h+8|0,l,B);f=f-(u&p)|0;c=c+8|0;d=d-1|0;e=b;continue}break}c=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=c;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+48>>2]=e;x[a+44>>2]=b;x[a+24>>2]=i>>12;fb=h+16|0}function wh(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;f=fb-16|0;fb=f;x[f+12>>2]=d;e=0;a:{if(b-251>>>0<4294967046){break a}e=b-1|0;g=x[a+480180>>2];if(!En(g)){if(g&17408){a=((e&255)>>>0)/12|0;e=z[((D(a,-12)+e&255)<<1)+31728>>1]<<4>>>a|0;break a}if(!d){x[f+12>>2]=8363;d=8363}if(Gj(a)){a=((e&255)>>>0)/12|0;b=Sua(x[(D(a,-12)+e<<6&960)+35616>>2]<<a,0,d,0);a=hb;c=a>>>21|0;h=f,i=Bc((a&2097151)<<11|b>>>21,c),x[h+8>>2]=i;wc(f+8|0,2147483647);e=x[f+8>>2];break a}if(y[a+480208|0]&16){a=e&255;e=z[((a>>>0)%12<<1)+31728>>1]<<5>>>(a>>>0)/12|0;break a}a=((e&255)>>>0)/12|0;wc(f+12|0,-1>>>a|0);e=Bc(Uua(Sua(z[((D(a,-12)+e&255)<<1)+31728>>1],0,267616,0),hb,x[f+12>>2]<<a,0),hb);break a}if(g&20){d=e>>>0>12;if((g|0)==16){b=c<<4}else{b=Ob(a+1074312|0,76)?c&-8:c}c=d?e:12;if(y[a+480208|0]&16){a=((b|0)/-2|0)-(c<<6)|0;e=((a|0)<=-8447?-8447:a)+8448|0;break a}a=c-12|0;c=((a&255)>>>0)/12|0;d=((b|0)/16|0)+(D(c,-12)+a<<3&248)|0;x[f+4>>2]=d+8;Fe(f+4|0,0,103);a=b>>31;b=(a^b)-a&15;a=d+(a|1)|0;a=(a|0)<=-8?-8:a;e=D(b,z[(((a|0)>=95?95:a)<<1)+32224>>1])+D(z[(x[f+4>>2]<<1)+32208>>1],16-b|0)<<1>>>c|0;break a}if(!(!(c&240)&b-25>>>0<84)){a=((e&255)>>>0)/12|0;e=z[(D(c>>>4&15,12)+(D(a,-12)+e&255)<<1)+31328>>1]<<5>>>a|0;break a}e=z[(b<<1)+31102>>1]<<2}fb=f+16|0;return e}function lQ(a){var b=0,c=E(0),d=0,e=0,f=0,g=E(0),h=0,i=0,k=E(0),m=0,n=0,o=E(0);d=fb-16|0;fb=d;b=x[x[a+16>>2]+24620>>2];e=a+4208|0;n=a,o=Ce(E(10),E(E(E(B[yb(e,0)>>2]*E(120))+E(-60))/E(20))),B[n+4232>>2]=o;k=E(E(b>>>0)/E(1e3));n=a,o=Ce(E(10),E(E(-1)/E(k*E(E(B[yb(e,1)>>2]*E(499.989990234375))+E(.009999999776482582))))),B[n+4236>>2]=o;n=a,o=Ce(E(10),E(E(-1)/E(k*E(E(B[yb(e,2)>>2]*E(2950))+E(50))))),B[n+4240>>2]=o;x[d+12>>2]=1325400064;c=E(Ce(E(10),E(E(E(B[yb(e,3)>>2]*E(60))+E(-60))/E(20)))*E(2147483648));b=(q(c),j(2));g=E(0);a:{if((b|0)==1065353216){break a}b:{if(b-2139095040>>>0<=2164260863){f=b<<1;if(!f){g=E(zx(E(-1))/E(0));break a}if((b|0)==2139095040){break b}if(!(f>>>0<4278190080&(b|0)>=0)){g=SI(c);break a}b=(q(E(c*E(8388608))),j(2))-192937984|0}f=b-1060306944|0;h=f>>>15&240;i=+(l(2,b-(f&-8388608)|0),r())*C[h+3568>>3]+-1;m=i*i;c=E((C[479]*m+(C[480]*i+C[481]))*m+(+(f>>23)*C[478]+C[h+3576>>3]+i))}g=c}B[d+8>>2]=E(E(g*E(67108864))/E(.6931471824645996))+E(67108864);n=a,o=E(B[Xm(d+12|0,d+8|0)>>2]*E(4.656612873077393e-10)),B[n+4244>>2]=o;n=a,o=E(E(E(-1)/E(E(B[yb(e,4)>>2]*E(99))+E(1)))+E(1)),B[n+4248>>2]=o;c=E(E(E(B[yb(e,5)>>2]*E(4))*k)+E(2));c:{if(E(F(c))<E(2147483648)){h=~~c;break c}h=-2147483648}x[a+4252>>2]=h;fb=d+16|0}function L3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;if(mh(a,x[b+8>>2],e)){Ox(b,c,d);return}a:{if(mh(a,x[b>>2],e)){if(!(x[b+16>>2]!=(c|0)&x[b+20>>2]!=(c|0))){if((d|0)!=1){break a}x[b+32>>2]=1;return}x[b+32>>2]=d;b:{if(x[b+44>>2]==4){break b}f=a+16|0;h=f+(x[a+12>>2]<<3)|0;d=0;c:{while(1){d:{if(f>>>0>=h>>>0){break d}w[b+52>>1]=0;Lx(x[f>>2],x[f+4>>2],b,c,c,1,e);if(y[b+54|0]){break d}e:{if(!y[b+53|0]){break e}if(y[b+52|0]){if(x[b+24>>2]!=1){d=1;g=1;if(y[a+8|0]&2){break e}}x[b+44>>2]=3;return}d=1;if(!(v[a+8|0]&1)){break c}}f=f+8|0;continue}break}x[b+44>>2]=d?3:4;if(!g){break b}break a}x[b+44>>2]=3;if(g){break a}}x[b+20>>2]=c;x[b+40>>2]=x[b+40>>2]+1;if(x[b+36>>2]!=1|x[b+24>>2]!=2){break a}v[b+54|0]=1;return}g=x[a+12>>2];Rs(x[a+16>>2],x[a+20>>2],b,c,d,e);f=a+24|0;g=(a+16|0)+(g<<3)|0;if(f>>>0>=g>>>0){break a}a=x[a+8>>2];if(!(!(a&2)&x[b+36>>2]!=1)){while(1){if(y[b+54|0]){break a}Rs(x[f>>2],x[f+4>>2],b,c,d,e);f=f+8|0;if(g>>>0>f>>>0){continue}break}break a}if(!(a&1)){while(1){if(y[b+54|0]|x[b+36>>2]==1){break a}Rs(x[f>>2],x[f+4>>2],b,c,d,e);f=f+8|0;if(g>>>0>f>>>0){continue}break a}}while(1){if(y[b+54|0]|x[b+36>>2]==1&x[b+24>>2]==1){break a}Rs(x[f>>2],x[f+4>>2],b,c,d,e);f=f+8|0;if(g>>>0>f>>>0){continue}break}}}function nla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;l=fb-16|0;fb=l;j=fb-32|0;fb=j;f=j+28|0;e=j+24|0;k=c;g=fb-16|0;fb=g;a:{b:{c=b;if(!mc(b,x[vb(g+12|0,rg(a))>>2])){b=z[k>>1];h=x[k+4>>2];i=td(c);m=z[i>>1];i=x[i+4>>2];if(!Vl(b,h,m,i)){break b}}x[g+12>>2]=c;c:{if(!mc(c,x[vb(g+8|0,wb(x[a>>2]))>>2])){b=x[MB(g+12|0)>>2];e=td(b);i=z[e>>1];m=x[e+4>>2];e=z[k>>1];h=x[k+4>>2];if(Vl(i,m,e,h)){break c}c=LB(a,f,e,h);break a}b=c}if(!x[c>>2]){x[f>>2]=c;break a}x[f>>2]=b;c=b+4|0;break a}if(Vl(m,i,b,h)){d:{b=JB(c);if(!mc(b,x[vb(g+12|0,rg(a))>>2])){e=z[k>>1];h=x[k+4>>2];i=td(b);if(!Vl(e,h,z[i>>1],x[i+4>>2])){break d}}if(!x[c+4>>2]){x[f>>2]=c;c=c+4|0;break a}x[f>>2]=b;c=b;break a}c=LB(a,f,e,h);break a}x[f>>2]=c;x[e>>2]=c;c=e}fb=g+16|0;b=x[c>>2];if(!b){b=fb-16|0;fb=b;f=ec(a);e=j+12|0;g=Bh(e,Ec(36),Mg(b+8|0,f));f=x[g>>2]+16|0;h=x[k+4>>2];x[f>>2]=x[k>>2];x[f+4>>2]=h;_l(f+8|0,d);o=ec(g),p=1,v[o+4|0]=p;fb=b+16|0;$g(a,x[j+28>>2],c,x[j+12>>2]);b=me(e);gU(e);n=1}a=l+4|0;_g(a,x[vb(j+12|0,b)>>2],n);fb=j+32|0;if(!y[ec(a)|0]){a=td(x[l+4>>2])+8|0;fU(a);x[a>>2]=x[d>>2];x[a+4>>2]=x[d+4>>2];b=zb(d);o=zb(a),p=x[b>>2],x[o>>2]=p;x[b>>2]=0;x[d>>2]=0;x[d+4>>2]=0}a=vb(l+12|0,x[l+4>>2]);fb=l+16|0;return x[a>>2]}function isa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=fb-48|0;fb=d;l=b+484344|0;m=b+480280|0;n=b+906300|0;while(1){a:{b:{c:{if(Mb(x[c>>2],x[c+8>>2],9)){nr(c,d+43|0);e=Pg(c);d:{f=y[d+43|0]|y[d+44|0]<<8|(y[d+45|0]<<16|y[d+46|0]<<24);if(!((f|0)==1229999433|(f|0)==1397771593|((f|0)==1297110104|(f|0)==1297110099))){if(Mb(x[c>>2],x[c+8>>2],e)){break d}}v[d+47|0]=j;Gh(c,8);break c}fe(d,c,e);f=ic(d+20|0,d);ub(d);e=m;e:{if((y[d+43|0]|y[d+44|0]<<8|(y[d+45|0]<<16|y[d+46|0]<<24))==1481001027){while(1){if((e|0)==(l|0)){h=1;break a}x[31737]=0;h=R(152,f|0)|0;g=x[31737];x[31737]=0;if((g|0)==1){break e}v[e+8|0]=h;e=e+32|0;continue}}if(y[d+43|0]!=70){break b}g=y[d+44|0];k=(g|0)==88;f:{if(!k){if((g-48&255)>>>0>9){break b}e=v[d+45|0];if((e|0)>47){break f}break b}e=v[d+45|0];if((e|0)<48){break b}}if(e>>>0>57){break b}i=v[d+46|0];if((i|0)<48|(i|0)>57){break b}h=1;e=((i&255)+(k?-528:D(g,100)-5328|0)|0)+D(e&255,10)&65535;if(e>>>0>249){break a}e=vd(n,e);x[31737]=0;O(451,f|0,e|0);e=x[31737];x[31737]=0;if((e|0)!=1){break a}}a=N()|0;ub(f);Q(a|0);p()}v[d+47|0]=j}vD(a,h,d+47|0);fb=d+48|0;return}if((y[d+43|0]|y[d+44|0]<<8|(y[d+45|0]<<16|y[d+46|0]<<24))!=1430540109){break a}x[b+1074308>>2]=0;j=1}ub(f);continue}}function Via(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if(A[a+4>>2]<A[zb(a)>>2]){c=fb-16|0;fb=c;a=gC(c+4|0,a);eA(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+4;hc(a);fb=c+16|0;return}i=fb-32|0;fb=i;c=zb(a);d=$f(i+12|0,Mf(a,oc(x[a>>2],x[a+4>>2])+1|0),oc(x[a>>2],x[a+4>>2]),c);eA(x[d+8>>2],b);x[d+8>>2]=x[d+8>>2]+4;h=fb-16|0;fb=h;e=zb(a);b=vb(h+12|0,x[a+4>>2]);c=vb(h+8|0,x[a>>2]);f=vb(h+4|0,x[d+4>>2]);b=x[b>>2];g=x[c>>2];c=fb+-64|0;fb=c;f=x[f>>2];x[c+56>>2]=f;x[c+60>>2]=b;x[c+52>>2]=f;e=Re(c+24|0,e,c+52|0,c+56|0);x[c+16>>2]=x[e+8>>2];f=x[e+4>>2];x[c+8>>2]=x[e>>2];x[c+12>>2]=f;Qe(c+36|0,c+8|0);while(1){if(pd(b,g)){eA(qA(x[c+56>>2]),xf(b));b=Mi(c+60|0);Mi(c+56|0);b=x[b>>2];continue}break}Pe(c+36|0);j=x[c+56>>2];if(!y[c+48|0]){f=fb-16|0;fb=f;b=vb(f+12|0,x[x[c+44>>2]>>2]);k=x[vb(f+8|0,x[x[c+40>>2]>>2])>>2];g=fb-16|0;fb=g;b=x[b>>2];x[g+12>>2]=b;while(1){if(ci(b,k)){e=fb-16|0;fb=e;x[e+12>>2]=b;x[e+12>>2]=x[e+12>>2]+4;fb=e+16|0;og(qA(x[e+12>>2]));b=x[Je(g+12|0)>>2];continue}break}fb=g+16|0;fb=f+16|0}fb=c- -64|0;x[d+4>>2]=j;Tb(a,d+4|0);Tb(a+4|0,d+8|0);Tb(zb(a),nc(d));x[d>>2]=x[d+4>>2];fb=h+16|0;a=x[d+4>>2];while(1){b=x[d+8>>2];if((b|0)!=(a|0)){b=b-4|0;x[d+8>>2]=b;og(b);continue}break}a=x[d>>2];if(a){Uz(d);Db(a)}fb=i+32|0}function xO(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=fb+-64|0;fb=e;a:{b:{c:{d:{d=x[a+36>>2];c=x[a+40>>2];e:{if(Ib(d,c)){sc(e+60|0);break e}c=e+24|0;zo(c,a);x[31737]=0;f=R(1062,c|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break d}x[e+60>>2]=f;nf(c);c=x[a+40>>2];d=x[a+36>>2]}c=(k=a+36|0,l=x[e+60>>2],m=Ib(d,c),m?k:l);f=x[a+8>>2];if((f|0)==-1){d=x[c+4>>2];f=ol(d);g=x[c>>2];i=oj(g,d);j=C[f>>3];d=0;while(1){if((d|0)==(i|0)){c=f;break c}c=wf(g,d);if(h+C[c>>3]>b){break c}d=d+1|0;h=h+j;continue}}c=wf(x[c>>2],f);break b}d=N()|0;nf(e+24|0);break a}b=b-h}f=z[c+12>>1];d=x[a+24>>2];x[31737]=0;O(1096,d|0,f|0);f=x[31737];x[31737]=0;if((f|0)!=1){f:{f=x[a+24>>2];d=y[a+64|0];c=aS(jY(e+24|0,b),y[c+16|0],z[c+12>>1],x[c+8>>2]);x[31737]=0;g=x[c+12>>2];x[e+8>>2]=x[c+8>>2];x[e+12>>2]=g;g=x[c+20>>2];x[e+16>>2]=x[c+16>>2];x[e+20>>2]=g;g=x[c+4>>2];x[e>>2]=x[c>>2];x[e+4>>2]=g;g=e+48|0;V(1097,g|0,f|0,(d?7:1)|0,e|0);c=x[31737];x[31737]=0;if((c|0)==1){break f}c=ln(x[e+52>>2]);f=v[c+26|0]&1;d=x[(f?c+8|0:c+12|0)>>2];f=z[(f?c+20|0:c+22|0)>>1];b=C[c>>3];Xi(g);c=x[a+24>>2];w[c+1074450>>1]=f;w[c+1074448>>1]=f;x[c+1074428>>2]=d;x[c+1074392>>2]=-2;b=h+b;C[a+16>>3]=b;El(e+60|0);fb=e- -64|0;return+b}}d=N()|0;El(e+60|0)}Q(d|0);p()}function Bd(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=fb-80|0;fb=e;x[a+480180>>2]=b;c=wr(a);vr(e+12|0,c);f=x[e+24>>2];d=a+1074320|0;x[d>>2]=x[e+20>>2];x[d+4>>2]=f;d=x[e+16>>2];x[a+1074312>>2]=x[e+12>>2];x[a+1074316>>2]=d;if(!((b|0)==32|(c|0)!=32)){dg(a+1074312|0,120)}Au(a+8|0,c);b=1;while(1){c=b&65535;if(c>>>0>z[a+480192>>1]){x[a+480184>>2]=0;x[a+480188>>2]=0;x[a+480236>>2]=65536;x[a+480228>>2]=48;x[a+480232>>2]=48;v[a+480268|0]=5;x[a+480260>>2]=16;x[a+480264>>2]=32767;x[a+480204>>2]=125e4;x[a+480208>>2]=0;x[a+480196>>2]=6;x[a+480200>>2]=256;x[a+1074304>>2]=0;x[a+1074308>>2]=0;w[a+480192>>1]=0;RA(a,4);d=fb+-64|0;fb=d;b=a+484344|0;Cu(b);f=pm(x[b>>2],x[b+4>>2]);c=pA(d+12|0,b);x[31737]=0;S(858,b|0,f|0,c|0);b=x[31737];x[31737]=0;a:{if((b|0)!=1){Bk(c);fb=d- -64|0;break a}a=N()|0;Bk(c);Q(a|0);p()}bV(a+484360|0);sf(a+1298308|0);sf(a+1298320|0);sf(a+1298332|0);b=e+12|0;Rb(b,0,68);b=DS(b);c=Ab(a+1298344|0,b);Ab(c+12|0,b+12|0);Ab(c+24|0,b+24|0);Ab(c+36|0,b+36|0);Ab(c+48|0,b+48|0);d=x[b+64>>2];x[c+60>>2]=x[b+60>>2];x[c+64>>2]=d;YA(b);gw(a+1298412|0);Nf(a+480248|0);if(x[a+480180>>2]&738230281){x[a+480208>>2]=x[a+480208>>2]|8388608}fb=e+80|0;return}c=((c<<2)+a|0)+900380|0;d=x[c>>2];if(d){Db(Hv(d))}x[c>>2]=0;b=b+1|0;continue}}function G1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-32|0;fb=d;if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))==1397771593){ld(b,32);Cp(b);c=d+8|0;jk(c,1,a+4|0);e=d+20|0;Cc(e,c);ze(b+43|0,e);tb(e);w[b+30>>1]=y[a+19|0]<<2;Gf(b+30|0,256);w[b+32>>1]=y[a+17|0];Gf(b+32|0,64);w[b+28>>1]=(y[a+47|0]&127)<<2;Gf(b+28|0,256);if(v[a+47|0]<0){w[b+34>>1]=z[b+34>>1]|32}c=y[a+18|0];if(c&16){w[b+34>>1]=z[b+34>>1]|2;c=y[a+18|0]}if(c&32){w[b+34>>1]=z[b+34>>1]|8;c=y[a+18|0]}if(c&64){w[b+34>>1]=z[b+34>>1]|4;c=y[a+18|0]}if(c<<24>>24<0){w[b+34>>1]=z[b+34>>1]|16}c=y[a+60|0]|y[a+61|0]<<8|(y[a+62|0]<<16|y[a+63|0]<<24);x[b+24>>2]=c?c>>>0<=256?256:c:8363;x[b>>2]=y[a+48|0]|y[a+49|0]<<8|(y[a+50|0]<<16|y[a+51|0]<<24);x[b+4>>2]=y[a+52|0]|y[a+53|0]<<8|(y[a+54|0]<<16|y[a+55|0]<<24);x[b+8>>2]=y[a+56|0]|y[a+57|0]<<8|(y[a+58|0]<<16|y[a+59|0]<<24);x[b+12>>2]=y[a+64|0]|y[a+65|0]<<8|(y[a+66|0]<<16|y[a+67|0]<<24);x[b+16>>2]=y[a+68|0]|y[a+69|0]<<8|(y[a+70|0]<<16|y[a+71|0]<<24);_k(b);v[b+38|0]=y[(y[a+79|0]&7)+38176|0];v[b+41|0]=y[a+76|0];v[b+40|0]=y[a+77|0]&127;v[b+39|0]=y[a+78|0];c=y[a+46|0];a:{if((c|0)==64){c=512}else{if((c|0)!=128){break a}c=16384}w[b+34>>1]=c|z[b+34>>1]}c=y[a+72|0]|y[a+73|0]<<8|(y[a+74|0]<<16|y[a+75|0]<<24)}fb=d+32|0;return c|0}function Cma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0;e=fb-16|0;fb=e;a:{b:{c:{f=x[a+12>>2];g=x[a+8>>2];d:{if((f|0)<=1&g>>>0<=805306368|(f|0)<=0){if((f|0)>=-2&g>>>0>=3489660928|(f|0)>-2){break c}if((f|0)==-2&g>>>0>2147483647|(f|0)==-1){break d}break b}if((f|0)==1&g>>>0>2147483648|f>>>0>1){break b}}k=b+196648|0;break a}k=b+131112|0;break a}k=b+262184|0}l=x[a+16>>2];h=x[a+40>>2];i=x[a+36>>2];b=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=b;m=x[a+32>>2];n=x[a+28>>2];while(1){if(d){b=x[e+8>>2];o=((((x[e+12>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+l|0;b=(b>>>16&65520)+k|0;p=w[b+14>>1];q=w[b+12>>1];r=w[b+10>>1];s=w[b+8>>1];t=w[b+6>>1];u=w[b+4>>1];v=w[b+2>>1];y=w[b>>1];j=0;while(1){if((j|0)!=2){b=(j<<1)+o|0;x[(j<<2)+e>>2]=(((((((D(w[b-8>>1],v)+D(w[b-12>>1],y)|0)+D(w[b-4>>1],u)|0)+D(w[b>>1],t)|0)+D(w[b+4>>1],s)|0)+D(w[b+8>>1],r)|0)+D(w[b+12>>1],q)|0)+D(w[b+16>>1],p)|0)/32768;j=j+1|0;continue}break}i=i+n|0;x[c>>2]=x[c>>2]+D(x[e>>2],i>>12);h=h+m|0;x[c+4>>2]=x[c+4>>2]+D(x[e+4>>2],h>>12);Pb(e+8|0,g,f);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;x[a+40>>2]=h;x[a+20>>2]=i>>12;x[a+36>>2]=i;x[a+24>>2]=h>>12;fb=e+16|0}function $7(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;k=b;f=fb-368|0;fb=f;x[f+360>>2]=37;x[f+364>>2]=0;b=f+360|0;h=gt(b|1,22303,x[c+4>>2]);g=f+320|0;x[f+316>>2]=g;a=Od();a:{if(h){i=x[c+8>>2];C[f+40>>3]=e;x[f+32>>2]=i;g=ph(g,30,a,b,f+32|0);break a}C[f+48>>3]=e;g=ph(f+320|0,30,a,f+360|0,f+48|0)}x[f+80>>2]=1199;i=Be(f+308|0,0,f+80|0);b=f+320|0;a=b;b:{c:{d:{e:{if((g|0)>=30){a=Od();f:{if(h){g=x[c+8>>2];C[f+8>>3]=e;x[f>>2]=g;g=rj(f+316|0,a,f+360|0,f);break f}C[f+16>>3]=e;g=rj(f+316|0,a,f+360|0,f+16|0)}if((g|0)==-1){x[31737]=0;X(1200);a=x[31737];x[31737]=0;if((a|0)==1){break d}break e}a=x[f+316>>2];Se(i,a)}j=a+g|0;l=sj(a,j,x[c+4>>2]);x[f+68>>2]=1199;h=Be(f+72|0,0,f+68|0);g:{h:{if((f+320|0)==(a|0)){g=f+80|0;break h}g=Ed(g<<3);if(!g){x[31737]=0;X(1200);a=x[31737];x[31737]=0;if((a|0)!=1){break e}a=N()|0;break g}Se(h,g);b=a}a=f+60|0;bd(a,x[c+28>>2]);x[31737]=0;ga(1230,b|0,l|0,j|0,g|0,f+68|0,f- -64|0,a|0);b=x[31737];x[31737]=0;i:{if((b|0)!=1){Zb(a);x[31737]=0;a=ea(1231,k|0,g|0,x[f+68>>2],x[f+64>>2],c|0,d|0)|0;b=x[31737];x[31737]=0;if((b|0)==1){break i}Lc(h);Lc(i);fb=f+368|0;break b}a=N()|0;Zb(f+60|0);break g}a=N()|0}Lc(h);break c}p()}a=N()|0}Lc(i);Q(a|0);p()}return a|0}function j8(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;k=b;f=fb-208|0;fb=f;x[f+200>>2]=37;x[f+204>>2]=0;b=f+200|0;h=gt(b|1,22303,x[c+4>>2]);g=f+160|0;x[f+156>>2]=g;a=Od();a:{if(h){i=x[c+8>>2];C[f+40>>3]=e;x[f+32>>2]=i;g=ph(g,30,a,b,f+32|0);break a}C[f+48>>3]=e;g=ph(f+160|0,30,a,f+200|0,f+48|0)}x[f+80>>2]=1199;i=Be(f+148|0,0,f+80|0);b=f+160|0;a=b;b:{c:{d:{e:{if((g|0)>=30){a=Od();f:{if(h){g=x[c+8>>2];C[f+8>>3]=e;x[f>>2]=g;g=rj(f+156|0,a,f+200|0,f);break f}C[f+16>>3]=e;g=rj(f+156|0,a,f+200|0,f+16|0)}if((g|0)==-1){x[31737]=0;X(1200);a=x[31737];x[31737]=0;if((a|0)==1){break d}break e}a=x[f+156>>2];Se(i,a)}j=a+g|0;l=sj(a,j,x[c+4>>2]);x[f+68>>2]=1199;h=Be(f+72|0,0,f+68|0);g:{h:{if((f+160|0)==(a|0)){g=f+80|0;break h}g=Ed(g<<1);if(!g){x[31737]=0;X(1200);a=x[31737];x[31737]=0;if((a|0)!=1){break e}a=N()|0;break g}Se(h,g);b=a}a=f+60|0;bd(a,x[c+28>>2]);x[31737]=0;ga(1225,b|0,l|0,j|0,g|0,f+68|0,f- -64|0,a|0);b=x[31737];x[31737]=0;i:{if((b|0)!=1){Zb(a);x[31737]=0;a=ea(23,k|0,g|0,x[f+68>>2],x[f+64>>2],c|0,d|0)|0;b=x[31737];x[31737]=0;if((b|0)==1){break i}Lc(h);Lc(i);fb=f+208|0;break b}a=N()|0;Zb(f+60|0);break g}a=N()|0}Lc(h);break c}p()}a=N()|0}Lc(i);Q(a|0);p()}return a|0}function Qaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0;c=fb+-64|0;fb=c;d=x[a>>2];a=x[d>>2];e=x[a+4>>2];x[c+40>>2]=x[a+20>>2];f=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=f;Zf(c+48|0,c+32|0,e);a=x[d+4>>2];e=x[a+8>>2];f=x[a+4>>2];d=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=d;d=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=d;x[c+8>>2]=x[a+8>>2];d=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=d;a=fb-32|0;fb=a;a:{b:{c:{d:{g=x[c+4>>2];if(g>>>0>=f>>>0){h=x[c+20>>2];if(h>>>0<f>>>0){break d}if(e>>>0>A[c+8>>2]){break c}i=x[c+28>>2];if(e>>>0>x[c+24>>2]-i>>>0){break b}l=b+12|0;m=x[c+16>>2];n=x[c>>2];b=0;e:while(1){if((b|0)==(e|0)){break a}o=(D(b,g)<<3)+n|0;q=(D(b+i|0,h)<<1)+m|0;d=0;while(1)if((d|0)==(f|0)){b=b+1|0;continue e}else{s=a,t=+(Cn(Ee(Ig(C[(d<<3)+o>>3])*134217728))+qd(Wt(l),21)|0)*7.450580596923828e-9,C[s+24>>3]=t;x[a+16>>2]=0;x[a+20>>2]=-1074790400;x[a+8>>2]=0;x[a+12>>2]=1072693248;r=(d<<1)+q|0;j=Ee(C[Yg(a+24|0,a+16|0,a+8|0)>>3]*32768);f:{if(F(j)<2147483648){k=~~j;break f}k=-2147483648}s=r,u=ed(k),w[s>>1]=u;d=d+1|0;continue}}}_(7244,9061,77,8741);p()}_(7209,9061,78,8741);p()}_(5897,9061,79,8741);p()}_(5867,9061,80,8741);p()}fb=a+32|0;fb=c- -64|0}function kja(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=E(0),m=0,n=0,o=E(0);g=w[d>>1];h=w[d+2>>1];a:{if((g|0)>(h|0)){break a}k=x[b>>2];i=oc(k,x[b+4>>2]);if(!i){break a}j=w[e>>1];if((g|0)>(j|0)|(h|0)<(j|0)|(i-1&65535)>>>0>(h-j&65535)>>>0|A[a+36>>2]>65535){break a}b:{while(1){if((f|0)==(i|0)){break b}j=yb(k,f);f=f+1|0;if(!(B[j>>2]<E(0))){continue}break}return 0}f=0;l=B[c>>2];if(l<=E(0)){break a}w[a+28>>1]=g;w[a>>1]=1;m=a,n=gR(i),w[m+30>>1]=n;B[a+32>>2]=F(l);Jl(a+4|0,(h-g|0)+1|0);c=wb(x[b>>2]);h=wb(x[b+4>>2]);f=Jk(wb(x[a+4>>2]),w[e>>1]-w[d>>1]|0);g=fb-16|0;fb=g;b=fb-32|0;fb=b;Id(b+24|0,c,h);wn(b+16|0,x[b+24>>2],x[b+28>>2],f);c=kA(c,x[b+16>>2]);m=b,n=fR(f,x[b+20>>2]),x[m+12>>2]=n;Ac(g+8|0,c,b+12|0);fb=b+32|0;fb=g+16|0;c=x[a+4>>2];g=w[a+30>>1];h=w[a+28>>1];b=w[e>>1];f=b;while(1){if((b&65535)!=32768&(f|0)>(h|0)){f=f-1|0;b=f-h|0;i=yb(c,b+g|0);m=yb(c,b),o=E(B[i>>2]/B[a+32>>2]),B[m>>2]=o;b=w[e>>1];continue}else{c=w[a+30>>1];e=w[a+28>>1];h=c+e|0;f=g;g=b<<16>>16;f=f+g|0;b=x[a+4>>2];d=w[d+2>>1];c=(g|0)<=(32767-c|0);while(1){if(c&(d|0)>=(f|0)){g=yb(b,f-h|0);m=yb(b,f-e|0),o=E(B[a+32>>2]*B[g>>2]),B[m>>2]=o;f=f+1|0;continue}else{Cq(a)}break}}break}f=1}return f|0}function Zaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0;c=fb+-64|0;fb=c;d=x[a>>2];a=x[d>>2];e=x[a+4>>2];x[c+40>>2]=x[a+20>>2];f=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=f;Zf(c+48|0,c+32|0,e);a=x[d+4>>2];e=x[a+8>>2];f=x[a+4>>2];d=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=d;d=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=d;x[c+8>>2]=x[a+8>>2];d=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=d;a=fb-32|0;fb=a;a:{b:{c:{d:{g=x[c+4>>2];if(g>>>0>=f>>>0){if(A[c+20>>2]<f>>>0){break d}if(e>>>0>A[c+8>>2]){break c}h=x[c+28>>2];if(e>>>0>x[c+24>>2]-h>>>0){break b}k=b+12|0;l=x[c+16>>2];m=x[c>>2];b=0;e:while(1){if((b|0)==(e|0)){break a}n=(D(b,g)<<3)+m|0;d=0;while(1)if((d|0)==(f|0)){b=b+1|0;continue e}else{q=a,r=+(Cn(Ee(Ig(C[(d<<3)+n>>3])*134217728))+qd(Wt(k),21)|0)*7.450580596923828e-9,C[q+24>>3]=r;x[a+16>>2]=0;x[a+20>>2]=-1074790400;x[a+8>>2]=0;x[a+12>>2]=1072693248;o=(d<<2)+l|0;i=Ee(C[Yg(a+24|0,a+16|0,a+8|0)>>3]*32768);f:{if(F(i)<2147483648){j=~~i;break f}j=-2147483648}q=(x[o>>2]+(h<<1)|0)+(b<<1)|0,s=ed(j),w[q>>1]=s;d=d+1|0;continue}}}_(7244,9061,77,8741);p()}_(7209,9061,78,8741);p()}_(5897,9061,79,8741);p()}_(5867,9061,80,8741);p()}fb=a+32|0;fb=c- -64|0}function boa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;g=fb-48|0;fb=g;c=wb(x[a>>2]);x[g+44>>2]=c;k=wb(x[a+4>>2]);while(1){if(Ib(c,k)){i=g+24|0;a=wb(x[c>>2]);l=wb(x[c+4>>2]);c=tX(g+4|0,b);v[c+16|0]=y[b+16|0];x[c+12>>2]=x[b+12>>2];h=fb-16|0;fb=h;x[h+12>>2]=a;while(1){if(Ib(a,l)){f=fb-16|0;fb=f;if(!(y[a+5|0]|y[a+3|0]!=4)){e=f+8|0;Kb(e,x[c>>2],z[c+14>>1]);If(e,0);v[a+3|0]=0}e=y[a+2|0];if(!(y[a+4|0]|(e|0)!=11)){d=f+8|0;Kb(d,x[c>>2],z[c+14>>1]);If(d,0);v[a+2|0]=0;e=0}a:{b:{if(!y[a|0]){Kb(f+8|0,x[c>>2],z[c+14>>1]);e=y[a+2|0];d=y[a+3|0];if(!Hb(x[x[f+8>>2]>>2],x[f+12>>2])){break b}if(!((e|0)==11|d)){v[a+5|0]=0;d=4;v[a+3|0]=4;break a}if((d|0)==4|e){break a}v[a+4|0]=0;v[a+2|0]=11;break a}d=y[a+3|0]}j=f+8|0;Kb(j,x[c>>2],z[c+14>>1]);If(j,(d|0)==4|(e|0)==11);d=y[a+3|0]}c:{d:{e:{if(!(!y[c+16|0]|d)){v[a+3|0]=17;d=125;e=0;break e}e=0;f:{switch(d-16|0){case 1:break d;case 0:break f;default:break c}}if(y[a+5|0]){break c}d=6;e=1}v[a+5|0]=d}v[c+16|0]=e}a=z[c+14>>1]+1|0;w[c+14>>1]=z[c+12>>1]>(a&65535)>>>0?a:0;fb=f+16|0;a=x[vg(h+12|0)>>2];continue}break}a=AC(i,c);v[a+16|0]=y[c+16|0];x[a+12>>2]=x[c+12>>2];fb=h+16|0;tf(i);tf(c);c=x[am(g+44|0)>>2];continue}else{fb=g+48|0}break}}function nka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;i=fb-16|0;fb=i;d=x[b+1298304>>2];if(!Dd(d)){c=fb-16|0;fb=c;d=Ec(12);x[31737]=0;g=R(957,d|0)|0;e=x[31737];x[31737]=0;a:{if((e|0)!=1){d=yf(c+12|0,g);fb=c+16|0;c=x[d>>2];break a}a=N()|0;Db(d);Q(a|0);p()}x[i+12>>2]=c;c=b+1298304|0;d=i+12|0;vS(c,me(d));XA(d);d=x[c>>2]}g=fb-32|0;fb=g;c=g+8|0;kS(c,a);x[31737]=0;O(958,g+20|0,c|0);e=x[31737];x[31737]=0;b:{c:{if((e|0)!=1){tb(c);e=wb(x[d>>2]);x[g+4>>2]=e;l=wb(x[d+4>>2]);d=0;while(1){d:{if(!Ib(e,l)){e:{if(!d){break e}f=x[d+4>>2];if(!f){break e}x[31737]=0;b=U(f|0,d|0,b|0,a|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break d}if(b){f=x[d>>2];x[b+4>>2]=f;if(f){x[f+8>>2]=b}x[d>>2]=b}x[a>>2]=b}tb(g+20|0);fb=g+32|0;break b}j=0;c=x[e>>2];if(x[c+32>>2]==x[a+16>>2]){j=x[c+36>>2]==x[a+20>>2]}x[31737]=0;k=g+8|0;O(959,k|0,c+8|0);c=x[31737];x[31737]=0;if((c|0)!=1){h=fb-16|0;fb=h;ee(h+8|0,k);ee(h,g+20|0);c=OR(x[h+8>>2],x[h+12>>2],x[h>>2],x[h+4>>2]);fb=h+16|0;tb(k);f:{if(!(!j|(c|0)!=0)){d=x[e>>2];f=3;break f}if((f|0)<2&j){d=x[e>>2];f=2;break f}c=!c&(f|0)<=0;d=c?x[e>>2]:d;f=c?1:f}e=x[Je(g+4|0)>>2];continue}}break}e=N()|0;tb(g+20|0);break c}e=N()|0;tb(g+8|0)}Q(e|0);p()}fb=i+16|0}
function Dma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0;e=fb-16|0;fb=e;a:{b:{c:{f=x[a+12>>2];g=x[a+8>>2];d:{if((f|0)<=1&g>>>0<=805306368|(f|0)<=0){if((f|0)>=-2&g>>>0>=3489660928|(f|0)>-2){break c}if((f|0)==-2&g>>>0>2147483647|(f|0)==-1){break d}break b}if((f|0)==1&g>>>0>2147483648|f>>>0>1){break b}}k=b+196648|0;break a}k=b+131112|0;break a}k=b+262184|0}l=x[a+16>>2];h=x[a+40>>2];i=x[a+36>>2];b=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=b;m=x[a+32>>2];n=x[a+28>>2];while(1){if(d){b=x[e+8>>2];o=(((x[e+12>>2]&2147483647)<<1|b>>>31)&-2)+l|0;b=(b>>>16&65520)+k|0;p=w[b+14>>1];q=w[b+12>>1];r=w[b+10>>1];s=w[b+8>>1];t=w[b+6>>1];u=w[b+4>>1];y=w[b+2>>1];z=w[b>>1];j=0;while(1){if((j|0)!=2){b=j+o|0;x[(j<<2)+e>>2]=(((((((D(v[b-4|0],y)+D(v[b-6|0],z)|0)+D(v[b-2|0],u)|0)+D(v[b|0],t)|0)+D(v[b+2|0],s)|0)+D(v[b+4|0],r)|0)+D(v[b+6|0],q)|0)+D(v[b+8|0],p)<<8)/32768;j=j+1|0;continue}break}i=i+n|0;x[c>>2]=x[c>>2]+D(x[e>>2],i>>12);h=h+m|0;x[c+4>>2]=x[c+4>>2]+D(x[e+4>>2],h>>12);Pb(e+8|0,g,f);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;x[a+40>>2]=h;x[a+20>>2]=i>>12;x[a+36>>2]=i;x[a+24>>2]=h>>12;fb=e+16|0}function dJ(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;a=fb-16|0;fb=a;x[a+12>>2]=c;x[a+8>>2]=f;x[a+12>>2]=c;x[a+8>>2]=f;a:{b:{while(1){b=x[a+12>>2];if(!(d>>>0<=b>>>0|f>>>0>=g>>>0)){i=v[b|0];c=i&255;c:{if((i|0)>=0){i=1;break c}k=2;if(i>>>0<4294967234){break a}if(i>>>0<=4294967263){if((d-b|0)<2){break b}i=y[b+1|0];if((i&192)!=128){break a}c=i&63|c<<6&1984;i=2;break c}if(i>>>0<=4294967279){if((d-b|0)<3){break b}j=y[b+2|0];i=y[b+1|0];d:{e:{if((c|0)!=237){if((c|0)!=224){break e}if((i&224)==160){break d}break a}if((i&224)==128){break d}break a}if((i&192)!=128){break a}}if((j&192)!=128){break a}c=j&63|(c<<12&61440|(i&63)<<6);i=3;break c}if(i>>>0>4294967284){break a}if((d-b|0)<4){break b}l=y[b+3|0];m=y[b+2|0];j=y[b+1|0];f:{g:{switch(c-240|0){case 0:if((j+112&255)>>>0<48){break f}break a;case 4:if((j&240)==128){break f}break a;default:break g}}if((j&192)!=128){break a}}if((m&192)!=128|(l&192)!=128){break a}i=4;c=l&63|(m<<6&4032|(c<<18&1835008|(j&63)<<12));if(c>>>0>1114111){break a}}x[f>>2]=c;x[a+12>>2]=b+i;f=x[a+8>>2]+4|0;x[a+8>>2]=f;continue}break}k=b>>>0<d>>>0;break a}k=1}x[e>>2]=x[a+12>>2];x[h>>2]=x[a+8>>2];fb=a+16|0;return k|0}function Iqa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;ld(b,0);Cp(b);f=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);a:{if(c&34){if(d){x[b+24>>2]=f;break a}g=b,h=Ze(Di(+(f+1408|0)/1536)*8363),x[g+24>>2]=h;break a}v[b+37|0]=(c|0)==16?f:f^128;v[b+36|0]=y[a+4|0]}v[e+15|0]=y[a+5|0];v[e+14|0]=64;g=b,h=y[Qb(e+15|0,e+14|0)|0]<<2,w[g+30>>1]=h;d=y[a+6|0]|y[a+7|0]<<8;if(d>>>0<=256){w[b+28>>1]=d;w[b+34>>1]=z[b+34>>1]|32}x[b>>2]=y[a+8|0]|y[a+9|0]<<8|(y[a+10|0]<<16|y[a+11|0]<<24);x[b+4>>2]=y[a+12|0]|y[a+13|0]<<8|(y[a+14|0]<<16|y[a+15|0]<<24);x[b+8>>2]=y[a+16|0]|y[a+17|0]<<8|(y[a+18|0]<<16|y[a+19|0]<<24);d=y[a+20|0]|y[a+21|0]<<8;if(d&16){w[b+34>>1]=z[b+34>>1]|2;d=y[a+20|0]|y[a+21|0]<<8}if(d&32){w[b+34>>1]=z[b+34>>1]|4;d=y[a+20|0]|y[a+21|0]<<8}if(d&256){w[b+34>>1]=z[b+34>>1]|8;d=y[a+20|0]|y[a+21|0]<<8}if(d&512){w[b+34>>1]=z[b+34>>1]|16}v[b+38|0]=y[(y[a+22|0]&7)+38176|0];v[b+39|0]=y[a+23|0];v[b+40|0]=y[a+24|0];v[b+41|0]=y[a+25|0];if((c|0)==32){v[e+13|0]=y[a+26|0];v[e+12|0]=64;g=b,h=y[Qb(e+13|0,e+12|0)|0],w[g+32>>1]=h}x[b+12>>2]=y[a+27|0]|y[a+28|0]<<8|(y[a+29|0]<<16|y[a+30|0]<<24);x[b+16>>2]=y[a+31|0]|y[a+32|0]<<8|(y[a+33|0]<<16|y[a+34|0]<<24);fb=e+16|0}function Bka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;l=fb-16|0;fb=l;x[l+12>>2]=b;q=Rf(a);while(1){if(Zg(b,c)){e=x[vb(l+8|0,q)>>2];j=td(b);o=fb-16|0;fb=o;p=0;m=fb-16|0;fb=m;h=fb-32|0;fb=h;f=h+28|0;d=h+24|0;k=fb-16|0;fb=k;a:{b:{b=e;if(!mc(b,x[vb(k+12|0,rg(a))>>2])){e=y[j|0];i=x[j+4>>2];g=td(b);n=y[g|0];g=x[g+4>>2];if(!Fo(e,i,n,g)){break b}}x[k+12>>2]=b;c:{if(!mc(b,x[vb(k+8|0,wb(x[a>>2]))>>2])){d=x[MB(k+12|0)>>2];e=td(d);g=y[e|0];n=x[e+4>>2];e=y[j|0];i=x[j+4>>2];if(Fo(g,n,e,i)){break c}b=eB(a,f,e,i);break a}d=b}if(!x[b>>2]){x[f>>2]=b;break a}x[f>>2]=d;b=d+4|0;break a}if(Fo(n,g,e,i)){d:{d=JB(b);if(!mc(d,x[vb(k+12|0,rg(a))>>2])){e=y[j|0];i=x[j+4>>2];g=td(d);if(!Fo(e,i,y[g|0],x[g+4>>2])){break d}}if(!x[b+4>>2]){x[f>>2]=b;b=b+4|0;break a}x[f>>2]=d;b=d;break a}b=eB(a,f,e,i);break a}x[f>>2]=b;x[d>>2]=b;b=d}fb=k+16|0;d=x[b>>2];if(!d){d=fb-16|0;fb=d;f=ec(a);e=h+12|0;f=Bh(e,Ec(28),Mg(d+8|0,f));tC(x[f>>2]+16|0,j);r=ec(f),s=1,v[r+4|0]=s;fb=d+16|0;$g(a,x[h+28>>2],b,x[h+12>>2]);d=me(e);dm(e);p=1}_g(m+8|0,x[vb(h+12|0,d)>>2],p);fb=h+32|0;fb=m+16|0;vb(o+12|0,x[m+8>>2]);fb=o+16|0;b=x[ah(l+12|0)>>2];continue}else{fb=l+16|0}break}}function Tga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=E(0),q=E(0),r=0,s=0,t=0,u=E(0),v=0;i=fb-16|0;fb=i;if(zi(a+44|0)){n=x[a+44>>2];j=Hc(n,0);k=Hc(n,1);n=x[a+56>>2];t=Hc(n,0);n=Hc(n,1);u=B[yb(a+4208|0,1)>>2];x[i+12>>2]=d;s=x[a+4220>>2];q=E(E(1)/E(s>>>0));v=x[a+4216>>2];o=d;f=n;g=t;while(1){if(o){h=x[a+4224>>2];a:{if(s>>>0>h>>>0){x[i+8>>2]=s-h;r=x[Gb(i+12|0,i+8|0)>>2];m=0;b:{if(u<E(1)){l=h+r|0;e=h>>>0>l>>>0?h:l;while(1){if((h|0)==(e|0)){break b}p=E(h>>>0);B[g>>2]=q*E(B[j>>2]*p);B[f>>2]=q*E(B[k>>2]*p);h=h+1|0;f=f+4|0;k=k+4|0;g=g+4|0;j=j+4|0;continue}}while(1){if((m|0)!=(r|0)){B[g>>2]=B[j>>2];B[f>>2]=B[k>>2];m=m+1|0;f=f+4|0;k=k+4|0;g=g+4|0;j=j+4|0;continue}break}l=h+r|0}o=o-r|0;x[i+12>>2]=o;break a}m=v-h|0;x[i+4>>2]=m;l=x[Gb(i+12|0,i+4|0)>>2];e=0;c:{if(u<E(1)){e=m-l|0;while(1){if(e>>>0>=m>>>0){break c}p=E(m>>>0);B[g>>2]=q*E(B[j>>2]*p);B[f>>2]=q*E(B[k>>2]*p);m=m-1|0;f=f+4|0;k=k+4|0;g=g+4|0;j=j+4|0;continue}}while(1){if((e|0)!=(l|0)){x[g>>2]=0;x[f>>2]=0;e=e+1|0;f=f+4|0;g=g+4|0;continue}break}e=l<<2;k=e+k|0;j=j+e|0}o=o-l|0;x[i+12>>2]=o;e=h+l|0;l=e>>>0<v>>>0?e:0}x[a+4224>>2]=l;continue}else{Pi(a,b,c,t,n,d)}break}}fb=i+16|0}function hS(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=fb-16|0;fb=d;c=Xb(x[a+484360>>2],y[a+484376|0]);f=Zc(x[c>>2],x[c+4>>2]);a:{while(1){e=b&65535;if(e>>>0>=f>>>0){break a}if(!bj(c,e)){b=b+1|0;continue}break}f=a+1074312|0;e=a+1298224|0;c=a+1074992|0;b:{while(1){c:{if((c|0)==(e|0)){gS(a);if(b&65535){break c}b=0;while(1){if((b|0)==256){Qo(a+1298264|0,1);x[a+1074456>>2]=x[a+480200>>2];x[a+1074416>>2]=x[a+480196>>2];x[a+1074420>>2]=x[a+480204>>2];x[a+480208>>2]=x[a+480208>>2]&-769;sB(a+1074376|0);w[a+1074450>>1]=0;x[a+1074392>>2]=-2;b=a+1074428|0;x[b>>2]=0;x[b+4>>2]=0;b=a+1074396|0;x[b>>2]=0;x[b+4>>2]=0;x[a+1074376>>2]=0;x[a+1074380>>2]=0}else{Uo((D(b,872)+a|0)+1074992|0,a,b&65535,67108864);b=b+1|0;continue}break}break b}v[c+797|0]=0;x[c+700>>2]=0;v[c+841|0]=0;v[c+805|0]=0;x[c+708>>2]=0;v[c+821|0]=0;x[c+764>>2]=0;v[c+819|0]=0;v[c+820|0]=0;Kb(d+8|0,f,23);if(Hb(x[x[d+8>>2]>>2],x[d+12>>2])){v[c+807|0]=1;v[c+808|0]=0}v[c+839|0]=0;c=c+872|0;continue}break}w[a+1074450>>1]=b;w[a+1074446>>1]=0;b=a+1074424|0;x[b>>2]=0;x[b+4>>2]=0;x[a+1074392>>2]=-2;x[a+1074432>>2]=0;b=a+1074396|0;x[b>>2]=0;x[b+4>>2]=0;x[a+1074380>>2]=0}x[a+480208>>2]=x[a+480208>>2]&-769}fb=d+16|0}function Cqa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;g=fb-48|0;fb=g;w[a>>1]=0;w[a+2>>1]=0;w[a+4>>1]=0;x[g+44>>2]=0;d=g+44|0;c=fb-16|0;fb=c;a:{if(!Mb(x[b>>2],x[b+8>>2],4)){lD(d);break a}nh(c+8|0,d);rd(c,b,x[c+8>>2],x[c+12>>2])}fb=c+16|0;b:{if(!xV(d)){break b}e=y[g+46|0];f=y[g+47|0];d=y[g+45|0];v[a+4|0]=1;h=d>>>3&3;c=(h|0)!=3;d=(d^-1)>>>1&3;f=f>>>0<192;w[a+2>>1]=z[(D(c,6)+(d<<1)|0)+25784>>1]<<f;i=D(D(y[(d+D(c,3)|0)+25560|0],z[((D(c,90)+D(d,30)|0)+(e>>>3&30)|0)+25568>>1]),1e3);e=e>>>1|0;e=((i>>>0)/z[(D(h,6)+(e&6)|0)+25760>>1]|0)+(e&1)<<(!d<<1);w[a>>1]=e;d=y[(f|c<<1)+25796|0];if(d+8>>>0>(e&65535)>>>0){break b}e=Rb(g,0,36);c=fb-32|0;fb=c;x[c+28>>2]=d+4;x[c+8>>2]=36;h=x[b>>2];i=x[b+8>>2];f=x[Gb(c+28|0,c+8|0)>>2];if(!Mb(h,i,f)){f=kf(b)}h=c+8|0;fs(h,e);i=gc(c+16|0,x[c+8>>2],f);lc(c,x[b>>2],x[b+8>>2],x[i>>2],x[i+4>>2]);fs(h,e);Rb(x[c+8>>2]+f|0,0,36-f|0);Vb(b,x[c+28>>2]);fb=c+32|0;b=2;c=d>>>0<=2?2:d;while(1){if((b|0)!=(c|0)){f=b+e|0;b=b+1|0;if(!y[f|0]){continue}break b}break}b=d+e|0;if((y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24))==1868983881){b=1}else{b=(y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24))==1735289176}v[a+5|0]=b}fb=g+48|0;return a|0}function _da(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;b=fb-2160|0;fb=b;tu(b+112|0);a:{b:{c:{f=x[c+4>>2];if(!f){a=ac(8);x[31737]=0;b=P(36,b+100|0,10469)|0;c=x[31737];x[31737]=0;if((c|0)==1){break c}pc(a,b);x[31737]=0;S(98,a|0,48540,1006);a=x[31737];x[31737]=0;if((a|0)!=1){break a}c=N()|0;tb(b);break b}g=x[c>>2];d=x[c+12>>2];e=x[c+8>>2];x[b+92>>2]=e;x[b+96>>2]=d;c=x[b+96>>2];x[b+40>>2]=x[b+92>>2];x[b+44>>2]=c;x[b+88>>2]=f;x[b+84>>2]=g;c=x[b+88>>2];x[b+32>>2]=x[b+84>>2];x[b+36>>2]=c;h=CM(b+32|0);if(h){c=b- -64|0;x[c>>2]=e;x[b+68>>2]=d;d=x[c+4>>2];x[b+24>>2]=x[c>>2];x[b+28>>2]=d;x[b+60>>2]=f;x[b+56>>2]=g;c=x[b+60>>2];x[b+16>>2]=x[b+56>>2];x[b+20>>2]=c;c=vM(b+16|0)}else{c=0}x[b+72>>2]=c;x[b+76>>2]=0;d=0;c=2048;while(1){if(c){e=ib[f|0](g,(b+112|0)+d|0,c)|0;c=c-e|0;d=d+e|0;if(e){continue}}break}c=gc(b+48|0,b+112|0,d);d=x[c+4>>2];x[b+8>>2]=x[c>>2];x[b+12>>2]=d;a=zu(a,b+8|0,h?b+72|0:0);if(a+1>>>0>=3){a=ac(8);x[31737]=0;b=P(36,b+100|0,8057)|0;c=x[31737];x[31737]=0;if((c|0)!=1){pc(a,b);x[31737]=0;S(98,a|0,48540,1006);a=x[31737];x[31737]=0;if((a|0)!=1){break a}c=N()|0;tb(b);break b}c=N()|0;jc(a);break b}fb=b+2160|0;return a|0}c=N()|0;jc(a)}Q(c|0)}p()}function bma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=fb-16|0;fb=e;p=x[a+16>>2];q=Fg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);j=x[a+8>>2];k=x[a+12>>2];b=x[a>>2];g=x[a+4>>2];l=x[a+128>>2];if(l){m=Gg(j,k,l);n=hb;h=x[a+76>>2];hg(b,g,vf(j,k,d),hb);o=hb>>>0>h>>>0?d:0}h=a+112|0;r=x[a+24>>2];s=x[a+20>>2];x[e>>2]=b;x[e+4>>2]=g;while(1){if(d){g=x[e+4>>2];b=x[e>>2];x[e+8>>2]=b;x[e+12>>2]=0;o=o-1|0;f=o;m=f?m:0;n=f?n:0;d=d-1|0;i=(((g&2147483647)<<1|b>>>31)&-2)+p|0;g=l;a:{b:while(1){c:{if((g|0)<=0){Pb(h,x[a+120>>2],x[a+124>>2]);g=x[a+116>>2];if(!g){break a}f=x[e+8>>2];i=(((x[e+12>>2]&2147483647)<<1|f>>>31)&-2)+i|0;f=0;b=0;break c}f=x[e+8>>2];t=(((x[e+12>>2]&2147483647)<<1|f>>>31)&-2)+i|0;b=0;f=0;while(1)if((b|0)==2){be(h,f>>>3<<16>>16);ae(h,4);Pb(e+8|0,m,n);g=g-1|0;continue b}else{f=(v[b+t|0]<<8)+f|0;b=b+1|0;continue}}break}while(1){if((b|0)!=2){f=(v[b+i|0]<<8)+f|0;b=b+1|0;continue}break}be(h,f>>>3<<16>>16);ae(h,g);x[h>>2]=x[h>>2];x[h+4>>2]=0}b=Eg(h,q);x[c>>2]=x[c>>2]+D(b,s);x[c+4>>2]=x[c+4>>2]+D(b,r);Pb(e,j,k);c=c+8|0;continue}break}b=x[e+4>>2];x[a>>2]=x[e>>2];x[a+4>>2]=b;fb=e+16|0}function tM(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;f=fb-16|0;fb=f;d=f+8|0;vz(d,a);b=fb-96|0;fb=b;a=x[d+4>>2];kg(x[x[a>>2]-12>>2]+a|0,0);$d(b+80|0,x[d+4>>2]);a:{b:{e=x[d+4>>2];a=x[x[e>>2]-12>>2]+e|0;if(!tk(x[a+16>>2])){c=gi(b- -64|0,-1,-1);if(!eo(x[b+88>>2],x[b+92>>2],x[c+8>>2],x[c+12>>2])){break b}}kg(a,0);break a}Hi(e,0,0,0);c=x[d+4>>2];a=x[x[c>>2]-12>>2]+c|0;if(tk(x[a+16>>2])){kg(a,0);c=x[d+4>>2];a=x[b+92>>2];x[b+8>>2]=x[b+88>>2];x[b+12>>2]=a;a=x[b+84>>2];x[b>>2]=x[b+80>>2];x[b+4>>2]=a;Zm(c,b);a=x[d+4>>2];kg(x[x[a>>2]-12>>2]+a|0,0);break a}Hi(c,0,0,2);c=x[d+4>>2];a=x[x[c>>2]-12>>2]+c|0;if(tk(x[a+16>>2])){kg(a,0);c=x[d+4>>2];a=x[b+92>>2];x[b+24>>2]=x[b+88>>2];x[b+28>>2]=a;a=x[b+84>>2];x[b+16>>2]=x[b+80>>2];x[b+20>>2]=a;Zm(c,b+16|0);a=x[d+4>>2];kg(x[x[a>>2]-12>>2]+a|0,0);break a}$d(b- -64|0,c);e=x[d+4>>2];a=e+x[x[e>>2]-12>>2]|0;c:{if(!tk(x[a+16>>2])){c=gi(b+48|0,-1,-1);g=1;if(!eo(x[b+72>>2],x[b+76>>2],x[c+8>>2],x[c+12>>2])){break c}}kg(a,0);e=x[d+4>>2];g=0}a=x[b+92>>2];x[b+40>>2]=x[b+88>>2];x[b+44>>2]=a;a=x[b+84>>2];x[b+32>>2]=x[b+80>>2];x[b+36>>2]=a;Zm(e,b+32|0);a=x[d+4>>2];kg(x[x[a>>2]-12>>2]+a|0,0)}fb=b+96|0;fb=f+16|0;return g|0}function Yla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=fb-16|0;fb=e;q=x[a+16>>2];r=Fg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);l=x[a+8>>2];m=x[a+12>>2];b=x[a>>2];f=x[a+4>>2];n=x[a+128>>2];if(n){o=Gg(l,m,n);p=hb;g=x[a+76>>2];hg(b,f,vf(l,m,d),hb);k=hb>>>0>g>>>0?d:0}g=a+112|0;i=x[a+40>>2];j=x[a+36>>2];x[e>>2]=b;x[e+4>>2]=f;a:while(1){if(d){d=d-1|0;x[e+8>>2]=b;x[e+12>>2]=0;k=k-1|0;o=k?o:0;p=k?p:0;f=((((f&2147483647)<<1|b>>>31)&2147483646)<<1)+q|0;b=n;while(1)if((b|0)<=0){Pb(g,x[a+120>>2],x[a+124>>2]);b=x[a+116>>2];if(b){h=x[e+8>>2];f=((((x[e+12>>2]&2147483647)<<1|h>>>31)&2147483646)<<1)+f|0;be(g,(w[f>>1]+w[f+2>>1]|0)/8<<16>>16);ae(g,b);x[g>>2]=x[g>>2];x[g+4>>2]=0}b=Eg(g,r);f=x[a+32>>2];j=x[a+28>>2]+j|0;x[c>>2]=x[c>>2]+D(b,j>>12);i=f+i|0;x[c+4>>2]=x[c+4>>2]+D(b,i>>12);Pb(e,l,m);c=c+8|0;b=x[e>>2];f=x[e+4>>2];continue a}else{h=x[e+8>>2];h=((((x[e+12>>2]&2147483647)<<1|h>>>31)&2147483646)<<1)+f|0;be(g,(w[h>>1]+w[h+2>>1]|0)/8<<16>>16);ae(g,4);Pb(e+8|0,o,p);b=b-1|0;continue}}break}x[a>>2]=b;x[a+4>>2]=f;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+24>>2]=i>>12;fb=e+16|0}function kma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0;h=fb-16|0;fb=h;e=x[a+48>>2];o=x[a+24>>2];p=x[a+20>>2];f=x[a+44>>2];q=x[a+16>>2];j=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=j;r=b+24|0;s=x[a+72>>2];k=x[a+68>>2];t=k>>31;l=x[a+64>>2];u=l>>31;m=x[a+60>>2];v=m>>31;j=x[a+8>>2];y=x[a+12>>2];while(1){b=f;if(d){f=Yb(f,-16777216,16776704);g=Sua(l,u,f,f>>31);f=hb;e=Yb(e,-16777216,16776704);e=Sua(k,t,e,e>>31);g=e+g|0;f=hb+f|0;f=e>>>0>g>>>0?f+1|0:f;e=x[h+8>>2];i=g;g=(x[h+12>>2]<<1)+q|0;e=(((e>>>16|0)+4&131064)<<1)+r|0;n=(((((D(w[g+4>>1],w[e+10>>1])+D(w[g+2>>1],w[e+8>>1])|0)+D(w[g+6>>1],w[e+12>>1])|0)+D(w[g+8>>1],w[e+14>>1])|0)/2|0)+((((D(w[g-4>>1],w[e+2>>1])+D(w[g-6>>1],w[e>>1])|0)+D(w[g-2>>1],w[e+4>>1])|0)+D(w[g>>1],w[e+6>>1])|0)/2|0)|0)/16384<<8;e=n;g=Sua(e,e>>31,m,v);i=i+g|0;e=hb+f|0;e=g>>>0>i>>>0?e+1|0:e;f=i+8388608|0;e=f>>>0<8388608?e+1|0:e;f=Rc(f,e,24);e=(f|0)/256|0;x[c>>2]=D(e,p)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(e,o);Pb(h+8|0,j,y);f=f-(s&n)|0;c=c+8|0;d=d-1|0;e=b;continue}break}c=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=c;x[a+48>>2]=e;x[a+44>>2]=b;fb=h+16|0}function Nsa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;ld(b,32);kp(b);f=b,g=xe((y[a+50|0]|y[a+51|0]<<8)<<16>>16)>>>2|0,w[f+32>>1]=g;if((xe((y[a+32|0]|y[a+33|0]<<8)<<16>>16)|0)>0){w[b+34>>1]=z[b+34>>1]|32;c=xe((y[a+32|0]|y[a+33|0]<<8)<<16>>16);e=c>>>24|0;d=(c<<8&-256)+2047|0;c=e&255;f=b,g=Bc(Uua(d,d>>>0<2047?c+1|0:c,4095,0),hb),w[f+28>>1]=g}c=$b(y[a+38|0]|y[a+39|0]<<8|(y[a+40|0]<<16|y[a+41|0]<<24));x[b>>2]=c;d=$b(y[a+42|0]|y[a+43|0]<<8|(y[a+44|0]<<16|y[a+45|0]<<24));x[b+4>>2]=d;e=$b(y[a+42|0]|y[a+43|0]<<8|(y[a+44|0]<<16|y[a+45|0]<<24))+$b(y[a+46|0]|y[a+47|0]<<8|(y[a+48|0]<<16|y[a+49|0]<<24))|0;x[b+8>>2]=e;if((Bb(y[a+34|0]|y[a+35|0]<<8)|0)==16){x[b+8>>2]=e>>>1;x[b+4>>2]=d>>>1;x[b>>2]=c>>>1}a:{b:{c:{if($b(y[a+42|0]|y[a+43|0]<<8|(y[a+44|0]<<16|y[a+45|0]<<24))){c=z[b+34>>1];break c}c=z[b+34>>1];if($b(y[a+46|0]|y[a+47|0]<<8|(y[a+48|0]<<16|y[a+49|0]<<24))>>>0<3){break b}}c=c|2;break a}c=c&65533}w[b+34>>1]=c;f=b,g=c&65531|Bb(y[a+30|0]|y[a+31|0]<<8)<<1&4,w[f+34>>1]=g;f=b,g=Bb(y[a+36|0]|y[a+37|0]<<8)<<1,x[f+24>>2]=g;c=xe((y[a+52|0]|y[a+53|0]<<8)<<16>>16);if(c){gm(b,+(c|0)/96);c=xe((y[a+52|0]|y[a+53|0]<<8)<<16>>16)}v[b+37|0]=c<<4}function Nka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if(x[a+4>>2]!=x[zb(a)>>2]){d=fb-16|0;fb=d;c=d+4|0;x[c>>2]=a;a=x[a+4>>2];x[c+4>>2]=a;x[c+8>>2]=a+32;VS(x[c+4>>2],b);x[c+4>>2]=x[c+4>>2]+32;hc(c);fb=d+16|0;return}j=fb-32|0;fb=j;c=zb(a);c=fv(j+12|0,_q(a,Lg(x[a>>2],x[a+4>>2])+1|0),Lg(x[a>>2],x[a+4>>2]),c);VS(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+32;h=fb-16|0;fb=h;b=vb(h+12|0,x[a+4>>2]);e=vb(h+8|0,x[a>>2]);f=x[vb(h+4|0,x[c+4>>2])>>2];i=fb-16|0;fb=i;d=fb-32|0;fb=d;Id(d+24|0,x[b>>2],x[e>>2]);k=d+16|0;b=x[d+24>>2];l=x[d+28>>2];g=fb-16|0;fb=g;x[g+8>>2]=f;x[g+12>>2]=b;while(1){if(pd(b,l)){b=ln(b);e=ln(x[g+8>>2]);f=y[b+23|0]|y[b+24|0]<<8|(y[b+25|0]<<16|y[b+26|0]<<24);v[e+23|0]=f;v[e+24|0]=f>>>8;v[e+25|0]=f>>>16;v[e+26|0]=f>>>24;f=x[b+20>>2];x[e+16>>2]=x[b+16>>2];x[e+20>>2]=f;f=x[b+12>>2];x[e+8>>2]=x[b+8>>2];x[e+12>>2]=f;f=x[b+4>>2];x[e>>2]=x[b>>2];x[e+4>>2]=f;b=Yo(g+12|0);Yo(g+8|0);b=x[b>>2];continue}break}Ac(k,b,g+8|0);fb=g+16|0;b=x[d+16>>2];x[d+12>>2]=x[d+20>>2];Ac(i+8|0,b,d+12|0);fb=d+32|0;fb=i+16|0;x[c+4>>2]=x[i+12>>2];Tb(a,c+4|0);Tb(a+4|0,c+8|0);Tb(zb(a),nc(c));x[c>>2]=x[c+4>>2];fb=h+16|0;UV(c);fb=j+32|0}function uia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=fb-16|0;fb=h;if(!y[a+4242|0]){Yz(a);a:{if(!y[a+4240|0]){break a}e=OA(x[a+16>>2]);if(e==C[a+4288>>3]){break a}C[a+4288>>3]=e;nu(a)}f=a+4256|0;b:{if(y[a+4244|0]){if(C[f>>3]>1){x[f>>2]=0;x[f+4>>2]=1072693248}break b}i=(x[a+4232>>2]&-2)!=4;e=C[f>>3];c:{if(F(e)<2147483648){g=~~e;break c}g=-2147483648}if(!(i|(g|0)<=0)){Xz(a);e=C[a+4256>>3]}C[f>>3]=e-+(g|0)}e=0;d:{e:{switch(x[a+4232>>2]){case 0:e=Wi(C[f>>3]*6.283185307179586);break d;case 1:e=F(C[f>>3]+-.5)*-4+1;break d;case 2:e=C[f>>3];e=e+e+-1;break d;case 3:e=C[f>>3]<.5?-1:1;break d;case 4:e=C[a+4272>>3];break d;case 5:break e;default:break d}}e=C[a+4256>>3];e=e*(e*e)*(e*(e*6+-15)+10);e=C[a+4280>>3]*e+C[a+4272>>3]*(1-e)}C[h+8>>3]=(y[a+4241|0]?-e:e)*+B[a+4220>>2]+ +B[a+4224>>2];OT(h+8|0,1);g=Ej(a);f:{if(!g){break f}f=x[a+4236>>2];if(y[a+4243|0]){k=g,l=(f>>>8&15|176)&191|(f&127)<<8|fm(C[h+8>>3]*127)<<16,j=x[x[g>>2]+68>>2],ib[j](k|0,l|0)|0;break f}ib[x[x[g>>2]+44>>2]](g,f,E(C[h+8>>3]))}C[a+4256>>3]=C[a+4264>>3]*+(d>>>0)+C[a+4256>>3]}g=a;a=x[a+44>>2];Pi(g,b,c,Hc(a,0),Hc(a,1),d);fb=h+16|0}function fZ(a,b,c){var d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;v[d+15|0]=c;a:{if(b>>>0>=22){v[d+14|0]=0;de(a,0,d+14|0);break a}e=y[b+25088|0];b:{c:{switch(b-8|0){case 0:v[d+15|0]=c<<1;break b;case 4:v[d+15|0]=c+1>>>1;break b;case 5:v[d+15|0]=D(c>>>4|0,10)+(c&15);break b;case 6:d:{switch((c>>>4|0)-1|0){default:e=0;break b;case 0:v[d+13|0]=c&15;v[d+12|0]=14;f=d,g=y[Qb(d+13|0,d+12|0)|0]<<4|15,v[f+15|0]=g;e=29;break b;case 1:v[d+11|0]=c&15;v[d+10|0]=14;f=d,g=y[Qb(d+11|0,d+10|0)|0]|240,v[f+15|0]=g;e=29;break b;case 3:v[d+15|0]=c&15|48;break b;case 4:v[d+15|0]=c<<4^128;e=35;break b;case 5:v[d+15|0]=c&15|176;break b;case 6:v[d+15|0]=c&15|64;break b;case 8:e=15;v[d+15|0]=c&15;break b;case 9:v[d+15|0]=(c<<3&120)+8&240;e=24;break b;case 10:v[d+15|0]=(c&15)+1>>>1;e=24;break b;case 14:break d;case 11:case 12:case 13:break b}}e=10;break b;case 8:if(c>>>0<=223){b=c>>>2|0;v[d+15|0]=(b>>>0>=15?15:b)<<4;break b}if(c>>>0<=239){v[d+15|0]=c<<2&48|15;break b}v[d+15|0]=c<<4|15;break b;case 9:break c;default:break b}}if(c>>>0<=223){b=c>>>2|0;v[d+15|0]=b>>>0>=15?15:b;break b}if(c>>>0>239){break b}v[d+15|0]=c>>>2&3|240}de(a,e,d+15|0)}fb=d+16|0}function y7(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0;a=fb-448|0;fb=a;x[a+440>>2]=c;x[a+444>>2]=b;x[a+20>>2]=1232;i=a+20|0;b=Be(a+24|0,a+32|0,i);j=a+16|0;bd(j,x[e+28>>2]);x[31737]=0;h=R(1211,x[a+16>>2])|0;k=x[31737];x[31737]=0;if((k|0)!=1){a:{v[a+15|0]=0;e=x[e+4>>2];x[31737]=0;c=na(1241,a+444|0,c|0,d|0,j|0,e|0,f|0,a+15|0,h|0,b|0,i|0,a+432|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break a}b:{c:{if(!c){break c}d:{if(Cd(y[g+11|0])){yd(x[g>>2],0);Yd(g,0);break d}yd(g,0);Me(g,0)}if(y[a+15|0]){x[31737]=0;c=P(1228,h|0,45)|0;d=x[31737];x[31737]=0;if((d|0)==1){break a}x[31737]=0;O(35,g|0,c|0);c=x[31737];x[31737]=0;if((c|0)==1){break a}}x[31737]=0;d=P(1228,h|0,48)|0;c=x[31737];x[31737]=0;if((c|0)==1){break b}e=x[a+20>>2];h=e-4|0;c=x[b>>2];while(1){if(!((d|0)!=x[c>>2]|c>>>0>=h>>>0)){c=c+4|0;continue}break}x[31737]=0;U(1246,g|0,c|0,e|0)|0;c=x[31737];x[31737]=0;if((c|0)!=1){break c}break a}x[31737]=0;c=P(1216,a+444|0,a+440|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break a}if(c){x[f>>2]=x[f>>2]|2}c=x[a+444>>2];Zb(a+16|0);Lc(b);fb=a+448|0;return c|0}}}c=N()|0;Zb(a+16|0);Lc(b);Q(c|0);p()}function lma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0;h=fb-16|0;fb=h;e=x[a+48>>2];o=x[a+24>>2];p=x[a+20>>2];f=x[a+44>>2];q=x[a+16>>2];j=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=j;r=b+24|0;s=x[a+72>>2];k=x[a+68>>2];t=k>>31;l=x[a+64>>2];u=l>>31;m=x[a+60>>2];y=m>>31;j=x[a+8>>2];z=x[a+12>>2];while(1){b=f;if(d){f=Yb(f,-16777216,16776704);g=Sua(l,u,f,f>>31);f=hb;e=Yb(e,-16777216,16776704);e=Sua(k,t,e,e>>31);g=e+g|0;f=hb+f|0;f=e>>>0>g>>>0?f+1|0:f;e=x[h+8>>2];i=g;g=x[h+12>>2]+q|0;e=(((e>>>16|0)+4&131064)<<1)+r|0;n=((((D(v[g+2|0],w[e+10>>1])+D(v[g+1|0],w[e+8>>1])|0)+D(v[g+3|0],w[e+12>>1])|0)+D(v[g+4|0],w[e+14>>1])<<8>>1)+(((D(v[g-2|0],w[e+2>>1])+D(v[g-3|0],w[e>>1])|0)+D(v[g-1|0],w[e+4>>1])|0)+D(v[g|0],w[e+6>>1])<<8>>1)|0)/16384<<8;e=n;g=Sua(e,e>>31,m,y);i=i+g|0;e=hb+f|0;e=g>>>0>i>>>0?e+1|0:e;f=i+8388608|0;e=f>>>0<8388608?e+1|0:e;f=Rc(f,e,24);e=(f|0)/256|0;x[c>>2]=D(e,p)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(e,o);Pb(h+8|0,j,z);f=f-(s&n)|0;c=c+8|0;d=d-1|0;e=b;continue}break}c=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=c;x[a+48>>2]=e;x[a+44>>2]=b;fb=h+16|0}function Mma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0;g=fb-16|0;fb=g;f=x[a+48>>2];i=x[a+40>>2];j=x[a+36>>2];e=x[a+44>>2];q=x[a+16>>2];b=x[a+4>>2];x[g+8>>2]=x[a>>2];x[g+12>>2]=b;r=x[a+32>>2];s=x[a+28>>2];t=x[a+72>>2];n=x[a+68>>2];u=n>>31;o=x[a+64>>2];v=o>>31;p=x[a+60>>2];y=p>>31;z=x[a+8>>2];A=x[a+12>>2];while(1){b=e;if(d){e=Yb(e,-16777216,16776704);k=Sua(o,v,e,e>>31);l=hb;e=x[g+8>>2];h=(x[g+12>>2]<<1)+q|0;e=e>>>21&2040;h=(((D(w[h>>1],w[e+38194>>1])+D(w[h-2>>1],w[e+38192>>1])|0)+D(w[h+2>>1],w[e+38196>>1])|0)+D(w[h+4>>1],w[e+38198>>1])|0)/16384<<8;e=h;e=Sua(e,e>>31,p,y);k=e+k|0;m=hb+l|0;m=e>>>0>k>>>0?m+1|0:m;f=Yb(f,-16777216,16776704);e=Sua(n,u,f,f>>31);l=e+k|0;f=hb+m|0;f=e>>>0>l>>>0?f+1|0:f;e=l+8388608|0;f=e>>>0<8388608?f+1|0:f;e=Rc(e,f,24);f=(e|0)/256|0;j=j+s|0;x[c>>2]=D(f,j>>12)+x[c>>2];i=i+r|0;x[c+4>>2]=x[c+4>>2]+D(f,i>>12);Pb(g+8|0,z,A);e=e-(h&t)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=x[g+12>>2];x[a>>2]=x[g+8>>2];x[a+4>>2]=c;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+48>>2]=f;x[a+44>>2]=b;x[a+24>>2]=i>>12;fb=g+16|0}function Raa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0;b=fb+-64|0;fb=b;c=x[a>>2];a=x[c>>2];d=x[a+4>>2];x[b+40>>2]=x[a+20>>2];e=x[a+16>>2];x[b+32>>2]=x[a+12>>2];x[b+36>>2]=e;Zf(b+48|0,b+32|0,d);a=x[c+4>>2];d=x[a+8>>2];e=x[a+4>>2];c=x[b+60>>2];x[b+24>>2]=x[b+56>>2];x[b+28>>2]=c;c=x[b+52>>2];x[b+16>>2]=x[b+48>>2];x[b+20>>2]=c;x[b+8>>2]=x[a+8>>2];c=x[a+4>>2];x[b>>2]=x[a>>2];x[b+4>>2]=c;a=fb-32|0;fb=a;a:{b:{c:{d:{g=x[b+4>>2];if(g>>>0>=e>>>0){h=x[b+20>>2];if(h>>>0<e>>>0){break d}if(d>>>0>A[b+8>>2]){break c}i=x[b+28>>2];if(d>>>0>x[b+24>>2]-i>>>0){break b}l=x[b+16>>2];m=x[b>>2];e:while(1){if((d|0)==(f|0)){break a}n=(D(f,g)<<3)+m|0;o=(D(f+i|0,h)<<1)+l|0;c=0;while(1)if((c|0)==(e|0)){f=f+1|0;continue e}else{C[a+24>>3]=C[(c<<3)+n>>3];x[a+16>>2]=0;x[a+20>>2]=-1074790400;x[a+8>>2]=0;x[a+12>>2]=1072693248;q=(c<<1)+o|0;j=Ee(C[Yg(a+24|0,a+16|0,a+8|0)>>3]*32768);f:{if(F(j)<2147483648){k=~~j;break f}k=-2147483648}r=q,s=ed(k),w[r>>1]=s;c=c+1|0;continue}}}_(7244,9061,77,8741);p()}_(7209,9061,78,8741);p()}_(5897,9061,79,8741);p()}_(5867,9061,80,8741);p()}fb=a+32|0;fb=b- -64|0}function Nma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0,A=0;h=fb-16|0;fb=h;e=x[a+48>>2];i=x[a+40>>2];j=x[a+36>>2];f=x[a+44>>2];p=x[a+16>>2];b=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=b;q=x[a+32>>2];r=x[a+28>>2];s=x[a+72>>2];l=x[a+68>>2];t=l>>31;m=x[a+64>>2];u=m>>31;n=x[a+60>>2];y=n>>31;z=x[a+8>>2];A=x[a+12>>2];while(1){b=f;if(d){f=Yb(f,-16777216,16776704);g=Sua(m,u,f,f>>31);f=hb;e=Yb(e,-16777216,16776704);e=Sua(l,t,e,e>>31);g=e+g|0;f=hb+f|0;f=e>>>0>g>>>0?f+1|0:f;e=x[h+8>>2];k=g;g=x[h+12>>2]+p|0;e=e>>>21&2040;o=(((D(v[g|0],w[e+38194>>1])+D(v[g-1|0],w[e+38192>>1])|0)+D(v[g+1|0],w[e+38196>>1])|0)+D(v[g+2|0],w[e+38198>>1])<<8)/16384<<8;e=o;g=Sua(e,e>>31,n,y);k=k+g|0;e=hb+f|0;e=g>>>0>k>>>0?e+1|0:e;f=k+8388608|0;e=f>>>0<8388608?e+1|0:e;f=Rc(f,e,24);e=(f|0)/256|0;j=j+r|0;x[c>>2]=D(e,j>>12)+x[c>>2];i=i+q|0;x[c+4>>2]=x[c+4>>2]+D(i>>12,e);Pb(h+8|0,z,A);f=f-(s&o)|0;c=c+8|0;d=d-1|0;e=b;continue}break}c=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=c;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+48>>2]=e;x[a+44>>2]=b;x[a+24>>2]=i>>12;fb=h+16|0}function _aa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;b=fb+-64|0;fb=b;c=x[a>>2];a=x[c>>2];d=x[a+4>>2];x[b+40>>2]=x[a+20>>2];e=x[a+16>>2];x[b+32>>2]=x[a+12>>2];x[b+36>>2]=e;Zf(b+48|0,b+32|0,d);a=x[c+4>>2];d=x[a+8>>2];e=x[a+4>>2];c=x[b+60>>2];x[b+24>>2]=x[b+56>>2];x[b+28>>2]=c;c=x[b+52>>2];x[b+16>>2]=x[b+48>>2];x[b+20>>2]=c;x[b+8>>2]=x[a+8>>2];c=x[a+4>>2];x[b>>2]=x[a>>2];x[b+4>>2]=c;a=fb-32|0;fb=a;a:{b:{c:{d:{g=x[b+4>>2];if(g>>>0>=e>>>0){if(A[b+20>>2]<e>>>0){break d}if(d>>>0>A[b+8>>2]){break c}h=x[b+28>>2];if(d>>>0>x[b+24>>2]-h>>>0){break b}k=x[b+16>>2];l=x[b>>2];e:while(1){if((d|0)==(f|0)){break a}m=(D(f,g)<<3)+l|0;c=0;while(1)if((c|0)==(e|0)){f=f+1|0;continue e}else{C[a+24>>3]=C[(c<<3)+m>>3];x[a+16>>2]=0;x[a+20>>2]=-1074790400;x[a+8>>2]=0;x[a+12>>2]=1072693248;n=(c<<2)+k|0;i=Ee(C[Yg(a+24|0,a+16|0,a+8|0)>>3]*32768);f:{if(F(i)<2147483648){j=~~i;break f}j=-2147483648}o=(x[n>>2]+(h<<1)|0)+(f<<1)|0,q=ed(j),w[o>>1]=q;c=c+1|0;continue}}}_(7244,9061,77,8741);p()}_(7209,9061,78,8741);p()}_(5897,9061,79,8741);p()}_(5867,9061,80,8741);p()}fb=a+32|0;fb=b- -64|0}function CK(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;l=fb-16|0;fb=l;g=y[a|0];a:{if(!g){f=a;break a}f=a;b:{while(1){if(!wl(g<<24>>24)){break b}g=y[f+1|0];f=f+1|0;if(g){continue}break}break a}c:{g=g&255;switch(g-43|0){case 0:case 2:break c;default:break a}}i=(g|0)==45?-1:0;f=f+1|0}d:{if(!((c|16)!=16|y[f|0]!=48)){o=1;if((y[f+1|0]&223)==88){f=f+2|0;m=16;break d}f=f+1|0;m=c?c:8;break d}m=c?c:10}c=0;while(1){e:{g=-48;j=v[f|0];f:{if((j-48&255)>>>0<10){break f}g=-87;if((j-97&255)>>>0<26){break f}g=-55;if((j-65&255)>>>0>25){break e}}n=g+j|0;if((n|0)>=(m|0)){break e}Of(l,m,0,0,0,k,h,0,0);g=1;g:{if(x[l+8>>2]|x[l+12>>2]){break g}p=Sua(k,h,m,0);j=hb;if((j|0)==-1&(n^-1)>>>0<p>>>0){break g}h=j;k=n+p|0;h=k>>>0<n>>>0?h+1|0:h;o=1;g=c}f=f+1|0;c=g;continue}break}if(b){x[b>>2]=o?f:a}h:{i:{j:{if(c){x[31612]=68;a=d&1;i=a?0:i;k=d;h=e;break j}if((e|0)==(h|0)&d>>>0>k>>>0|e>>>0>h>>>0){break i}a=d&1}if(!(a|i)){x[31612]=68;a=d;d=a-1|0;e=e-!a|0;break h}if((e|0)==(h|0)&d>>>0>=k>>>0|e>>>0>h>>>0){break i}x[31612]=68;break h}a=i^k;d=a-i|0;b=i>>31;e=(b^h)-((a>>>0<i>>>0)+b|0)|0}fb=l+16|0;hb=e;return d}function zT(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;e=x[b+64>>2];a:{b:{g=x[b+60>>2];f=z[b+68>>1];if(!((g|0)==-1&(f|0)==65535)){c:{d:{if((e|0)==-1){break d}e=a+1074312|0;if(Ob(e,68)){break d}f=(f|0)!=65535;if(h=Ob(e,103),i=0,j=f,j?h:i){break c}if(h=Ob(e,49),i=0,j=f,j?h:i){break c}e=x[b+64>>2];break b}if((f|0)!=65535){break c}w[b+68>>1]=z[b+72>>1]+1}if((g|0)==-1){x[b+60>>2]=0}f=Zc(x[c>>2],x[c+4>>2]);e=z[b+68>>1];if(f>>>0<=e>>>0){e=z[c+28>>1];w[b+68>>1]=e}e:{if(z[b+72>>1]==(e&65535)){break e}c=a+1074312|0;if(Ob(c,26)){break e}if(Ob(c,68)|x[a+480180>>2]==1){break e}c=z[a+480188>>1];e=0;while(1){if((c|0)==(e|0)){break e}v[(D(e,872)+b|0)+1457|0]=0;e=e+1|0;continue}}x[b+52>>2]=x[b+60>>2];if(d){e=1;if(y[a+480208|0]&32){break a}}w[b+74>>1]=z[b+68>>1];return 1}if((e|0)!=-1){break b}e=0;break a}x[b+52>>2]=e;w[b+74>>1]=z[b+72>>1];f:{if(!x[b+20>>2]){break f}c=x[a+480180>>2];if((c|0)==32){if(Ob(a+1074312|0,103)){break f}c=x[a+480180>>2]}if((c|0)==2){break f}x[b+52>>2]=x[b+52>>2]+1}e=0;if(A[b+64>>2]<A[Wb(x[a+484344>>2],z[b+70>>1])+12>>2]){break a}x[b+52>>2]=0;w[b+74>>1]=z[b+74>>1]+1;return 0}return e}function Gma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;e=fb-16|0;fb=e;a:{b:{c:{f=x[a+12>>2];g=x[a+8>>2];d:{if((f|0)<=1&g>>>0<=805306368|(f|0)<=0){if((f|0)>=-2&g>>>0>=3489660928|(f|0)>-2){break c}if((f|0)==-2&g>>>0>2147483647|(f|0)==-1){break d}break b}if((f|0)==1&g>>>0>2147483648|f>>>0>1){break b}}i=b+196648|0;break a}i=b+131112|0;break a}i=b+262184|0}j=x[a+16>>2];k=x[a+24>>2];l=x[a+20>>2];b=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=b;while(1){if(d){b=x[e+8>>2];m=((((x[e+12>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+j|0;b=(b>>>16&65520)+i|0;n=w[b+14>>1];o=w[b+12>>1];p=w[b+10>>1];q=w[b+8>>1];r=w[b+6>>1];s=w[b+4>>1];t=w[b+2>>1];u=w[b>>1];h=0;while(1){if((h|0)!=2){b=(h<<1)+m|0;x[(h<<2)+e>>2]=(((((((D(w[b-8>>1],t)+D(w[b-12>>1],u)|0)+D(w[b-4>>1],s)|0)+D(w[b>>1],r)|0)+D(w[b+4>>1],q)|0)+D(w[b+8>>1],p)|0)+D(w[b+12>>1],o)|0)+D(w[b+16>>1],n)|0)/32768;h=h+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[e>>2],l);x[c+4>>2]=x[c+4>>2]+D(x[e+4>>2],k);Pb(e+8|0,g,f);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;fb=e+16|0}function Oo(a,b,c){var d=0,e=0,f=0,g=0;f=a+1074312|0;d=Ob(f,96);x[b+660>>2]=(d?0:x[b+660>>2])+c;e=x[a+480180>>2];d=x[b+84>>2];if(!(!(e&18)|d>>>0>c>>>0|(!(y[b+88|0]&2)|!d))){g=c;c=x[b+80>>2];c=((g-c>>>0)%(d-c>>>0)|0)+c|0}c=c>>>(x[b+88>>2]&(e|0)==16384)|0;a:{b:{if(!Sc(y[b+788|0])){if(!Ob(f,114)){break b}}d=x[b+656>>2];c:{if(!d){break c}e=y[b+788|0];if(!Sc(e)){break c}if((z[_b(d+236|0,e-1|0)>>1]-1&65535)>>>0>=z[a+480190>>1]){break a}}if(y[a+480210|0]&32){d=c;c=x[b+660>>2];x[b+660>>2]=d+c}x[b>>2]=0;x[b+4>>2]=c;if((!(y[b+88|0]&2)|A[b+84>>2]>c>>>0)&A[b+76>>2]>c>>>0){break a}d:{if(!Ob(f,57)){c=x[a+480180>>2];if((c|0)!=16){break d}}x[b+700>>2]=0;x[b+88>>2]=x[b+88>>2]|2097152;return}if(!(c&1048581)){if(Ob(f,27)){if(y[a+480208|0]&4){c=x[b+76>>2];x[b>>2]=0;x[b+4>>2]=c;return}x[b>>2]=0;x[b+4>>2]=0;return}c=x[b+80>>2];d=0;x[b>>2]=d;x[b+4>>2]=c;if(!(y[a+480208|0]&4)){break a}a=x[b+76>>2];if(a>>>0<5){break a}x[b>>2]=d;x[b+4>>2]=a-2;return}if(!(y[b+88|0]&2)|(c|0)!=1){break a}a=x[b+80>>2];x[b>>2]=0;x[b+4>>2]=a;return}if(!(x[a+480180>>2]&268582928)|A[b+76>>2]<=c>>>0){break a}x[b>>2]=0;x[b+4>>2]=c}}function Cka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;i=fb-16|0;fb=i;x[i+12>>2]=b;o=Rf(a);while(1){if(Zg(b,c)){e=x[vb(i+8|0,o)>>2];j=td(b);m=fb-16|0;fb=m;n=0;k=fb-16|0;fb=k;g=fb-32|0;fb=g;f=g+28|0;d=g+24|0;h=fb-16|0;fb=h;a:{b:{b=e;if(!mc(b,x[vb(h+12|0,rg(a))>>2])){e=y[j|0];l=y[td(b)|0];if(!Go(e,l)){break b}}x[h+12>>2]=b;c:{if(!mc(b,x[vb(h+8|0,wb(x[a>>2]))>>2])){d=x[MB(h+12|0)>>2];l=y[td(d)|0];e=y[j|0];if(Go(l,e)){break c}b=fB(a,f,e);break a}d=b}if(!x[b>>2]){x[f>>2]=b;break a}x[f>>2]=d;b=d+4|0;break a}if(Go(l,e)){d:{d=JB(b);if(!mc(d,x[vb(h+12|0,rg(a))>>2])){e=y[j|0];if(!Go(e,y[td(d)|0])){break d}}if(!x[b+4>>2]){x[f>>2]=b;b=b+4|0;break a}x[f>>2]=d;b=d;break a}b=fB(a,f,e);break a}x[f>>2]=b;x[d>>2]=b;b=d}fb=h+16|0;d=x[b>>2];if(!d){d=fb-16|0;fb=d;f=ec(a);e=g+12|0;f=Bh(e,Ec(24),Mg(d+8|0,f));WS(x[f>>2]+16|0,x[j>>2],x[j+4>>2]);p=ec(f),q=1,v[p+4|0]=q;fb=d+16|0;$g(a,x[g+28>>2],b,x[g+12>>2]);d=me(e);dm(e);n=1}_g(k+8|0,x[vb(g+12|0,d)>>2],n);fb=g+32|0;fb=k+16|0;vb(m+12|0,x[k+8>>2]);fb=m+16|0;b=x[ah(i+12|0)>>2];continue}else{fb=i+16|0}break}}function Dua(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=fb-32|0;fb=g;v[g+16|0]=0;m=H0(g+20|0,d,g+16|0);f=x[m>>2];x[g+16>>2]=d;h=d;while(1){if(!(!b|!h)){a:{i=b-1|0;k=y[a|0];if(!(!i|(k|0)!=(e&255))){x[g+12>>2]=y[a+1|0];i=a+2|0;j=Gb(g+12|0,g+16|0);b:{k=b-2|0;if(!k){break b}j=x[j>>2];if(!(j&255)){break b}i=y[i|0];while(1){if(!(j&255)){break a}v[f|0]=i;h=x[g+16>>2]-1|0;x[g+16>>2]=h;f=f+1|0;j=j-1|0;continue}}v[f|0]=e;h=x[g+16>>2]-1|0;x[g+16>>2]=h;f=f+1|0;b=k;a=i;continue}a=a+1|0;v[f|0]=k;h=x[g+16>>2]-1|0;x[g+16>>2]=h;f=f+1|0;b=i;continue}b=b-3|0;a=a+3|0;continue}break}e=d-h|0;a=x[m>>2];k=0;f=128;b=0;i=0;c:while(1){if((e|0)==(i|0)){while(1){if(e){d=k<<24>>24;b=v[c|0];a=128;d:{if((b|0)==-128){break d}a=b;if((b|0)>=0){break d}a=0-(b&127)|0}k=d-(a&255)|0;v[c|0]=k;e=e-1|0;c=c+1|0;continue}break}dc(m);fb=g+32|0;return}n=y[a|0];h=0;j=0;while(1)if((j&65535)>>>0>=8){f=f&65535;f=(f<<8|f)>>>h&255;i=i+1|0;a=a+1|0;continue c}else{l=b+c|0;v[l|0]=y[l|0]|D(f&n,257)>>>(h-j&7);b=b+1|0;l=b>>>0>=d>>>0;b=l?0:b;j=j+1|0;h=h+l|0;f=(f<<8|f)>>>1&255;continue}}}function Dta(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;d=fb-1072|0;fb=d;x[d+1068>>2]=c;o=d,q=Zd(b),v[o+8|0]=q;v[d+4|0]=1;c=d+8|0;e=d+4|0;h=y[df(c,e)|0];f=aE(c,b);l=Gr(f);x[31737]=0;c=R(203,b|0)|0;g=x[31737];x[31737]=0;a:{if((g|0)!=1){x[d+4>>2]=c;x[d>>2]=536870911;wc(d+1068|0,x[Gb(e,d)>>2]<<3);x[31737]=0;m=x[d+1068>>2];k=P(342,a|0,m|0)|0;a=x[31737];x[31737]=0;if((a|0)!=1){x[31737]=0;c=8;i=P(159,f|0,8)|0;a=x[31737];x[31737]=0;b:{if((a|0)!=1){c:{o=xb(x[k>>2],0),q=i,v[o|0]=q;g=1;a=h;while(1){c=c&255;n=c>>>0<=9?9:c;e=a;d:{e:{while(1){if(g>>>0>=m>>>0){break d}x[31737]=0;j=P(159,f|0,c|0)|0;a=x[31737];x[31737]=0;if((a|0)!=1){if(j){break e}if((c|0)==(n|0)){break d}c=c+1|0;e=h;continue}break}break c}a=j>>>1|0;i=(j&1?0-a|0:a)+i|0;o=xb(x[k>>2],g),q=i,v[o|0]=q;g=g+1|0;a=h;if(j>>>c-1|0){continue}a=e-1|0;e=a&255;a=e?a:h;c=c-(!e&(c&255)>>>0>1)|0;continue}break}a=Gr(f);x[31737]=0;P(150,b|0,((a-l|0)+3&-4)+l|0)|0;a=x[31737];x[31737]=0;if((a|0)!=1){break b}}}c=N()|0;dc(k);break a}ub(f);fb=d+1072|0;return}c=N()|0;break a}c=N()|0}ub(f);Q(c|0);p()}function wY(a,b,c,d,e){var f=0,g=0;f=fb-16|0;fb=f;g=z[c>>1];a:{if((d&255)>>>0<=4){while(1){d=g<<1;w[c>>1]=d;v[b|0]=(d&65534)>>>0>255;d=y[c|0];w[c>>1]=d;if(!d){if(!Af(a,f+15|0)){break a}d=y[f+15|0];w[c>>1]=d<<1|1;v[b|0]=d>>>7;w[c>>1]=y[c|0]}w[e>>1]=v[b|0]+(z[e>>1]<<1);d=z[c>>1]<<1;w[c>>1]=d;v[b|0]=(d&65534)>>>0>255;d=y[c|0];w[c>>1]=d;if(!d){if(!Af(a,f+14|0)){break a}d=y[f+14|0];w[c>>1]=d<<1|1;v[b|0]=d>>>7;w[c>>1]=y[c|0]}w[e>>1]=v[b|0]+(z[e>>1]<<1);d=z[c>>1]<<1;w[c>>1]=d;v[b|0]=(d&65534)>>>0>255;g=y[c|0];w[c>>1]=g;if(!g){if(!Af(a,f+13|0)){break a}d=y[f+13|0];w[c>>1]=d<<1|1;v[b|0]=d>>>7;g=y[c|0];w[c>>1]=g;if(y[b|0]){continue}break a}if(y[b|0]){continue}break a}}while(1){d=g<<1;w[c>>1]=d;v[b|0]=(d&65534)>>>0>255;d=y[c|0];w[c>>1]=d;if(!d){if(!Af(a,f+12|0)){break a}d=y[f+12|0];w[c>>1]=d<<1|1;v[b|0]=d>>>7;w[c>>1]=y[c|0]}w[e>>1]=v[b|0]+(z[e>>1]<<1);d=z[c>>1]<<1;w[c>>1]=d;v[b|0]=(d&65534)>>>0>255;g=y[c|0];w[c>>1]=g;if(!g){if(!Af(a,f+11|0)){break a}d=y[f+11|0];w[c>>1]=d<<1|1;v[b|0]=d>>>7;g=y[c|0];w[c>>1]=g;if(y[b|0]){continue}break a}if(y[b|0]){continue}break}}fb=f+16|0}function FQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=E(0);c=fb-80|0;fb=c;d=x[b>>2];b=x[b+4>>2];e=Nd(c+52|0);f=x[e+4>>2];x[c+8>>2]=x[e>>2];x[c+12>>2]=f;b=lx(c+60|0,d,b,c+8|0);x[31737]=0;d=R(203,b|0)|0;e=x[31737];x[31737]=0;a:{if((e|0)==1){break a}x[31737]=0;d=U(955,b|0,c+19|0,d|0)|0;e=x[31737];x[31737]=0;if((e|0)==1){break a}if(!(!d|(y[c+23|0]|y[c+24|0]<<8|(y[c+25|0]<<16|y[c+26|0]<<24)|(y[c+19|0]|y[c+20|0]<<8|(y[c+21|0]<<16|y[c+22|0]<<24))!=542066252))){g=a,h=Pd((l(2,y[c+27|0]|y[c+28|0]<<8|(y[c+29|0]<<16|y[c+30|0]<<24)),r()),E(0)),B[g+4220>>2]=h;g=a,h=Pd((l(2,y[c+31|0]|y[c+32|0]<<8|(y[c+33|0]<<16|y[c+34|0]<<24)),r()),E(0)),B[g+4224>>2]=h;g=a,h=Pd((l(2,y[c+35|0]|y[c+36|0]<<8|(y[c+37|0]<<16|y[c+38|0]<<24)),r()),E(0)),B[g+4228>>2]=h;d=y[c+39|0]|y[c+40|0]<<8|(y[c+41|0]<<16|y[c+42|0]<<24);if(d>>>0<=5){x[a+4232>>2]=d}x[a+4236>>2]=y[c+43|0]|y[c+44|0]<<8|(y[c+45|0]<<16|y[c+46|0]<<24);v[a+4240|0]=y[c+47|0]!=0;v[a+4241|0]=y[c+48|0]!=0;v[a+4242|0]=y[c+49|0]!=0;v[a+4243|0]=y[c+50|0]!=0;v[a+4244|0]=y[c+51|0]!=0;ou(a)}ub(b);fb=c+80|0;return}a=N()|0;ub(b);Q(a|0);p()}function Rha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=E(0),g=0,h=0,i=0,j=0,k=0,l=0,m=E(0),n=0,o=0,p=E(0),q=E(0),r=E(0),s=E(0),t=E(0),u=0,v=0,w=0,z=E(0);h=x[a+44>>2];g=Hc(h,0);h=Hc(h,1);j=x[a+56>>2];n=Hc(j,0);j=Hc(j,1);e=oc(x[a+4208>>2],x[a+4212>>2]);o=D(x[x[a+16>>2]+1074404>>2],y[a+4233|0]);k=o<<1;if(e>>>0<k>>>0){Jl(a+4208|0,k)}l=y[a+4232|0];a:{if(l){e=x[a+4220>>2];k=x[a+4208>>2];u=l-1|0;l=0;while(1){if((d|0)==(l|0)){break a}r=B[h>>2];e=e>>>0<o>>>0?e:0;i=e-o|0;i=((i|0)<0?e:i)<<1;v=yb(k,i);f=B[yb(k,i|1)>>2];s=B[g>>2];t=B[v>>2];p=E(s+t);B[n>>2]=p;q=E(r+f);B[j>>2]=q;f=E(0);m=E(0);b:{c:{switch(u|0){case 0:f=B[a+4224>>2];m=E(q*f);f=E(p*f);break b;case 1:case 2:f=B[a+4224>>2];m=E(p*f);f=E(q*f);break b;case 3:break c;default:break b}}f=E(E(E(E(s+r)*E(.5))+t)*B[a+4224>>2]);m=f}j=j+4|0;n=n+4|0;h=h+4|0;g=g+4|0;i=e<<1;w=yb(k,i),z=E(F(f))<E(10000000195414814e-40)?E(0):f,B[w>>2]=z;w=yb(k,i|1),z=E(F(m))<E(10000000195414814e-40)?E(0):m,B[w>>2]=z;e=e+1|0;x[a+4220>>2]=e;l=l+1|0;continue}}e=g;g=d<<2;Kk(e,e+g|0,n);Kk(h,h+g|0,j)}g=a;a=x[a+56>>2];Pi(g,b,c,Hc(a,0),Hc(a,1),d)}function Hma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;e=fb-16|0;fb=e;a:{b:{c:{f=x[a+12>>2];g=x[a+8>>2];d:{if((f|0)<=1&g>>>0<=805306368|(f|0)<=0){if((f|0)>=-2&g>>>0>=3489660928|(f|0)>-2){break c}if((f|0)==-2&g>>>0>2147483647|(f|0)==-1){break d}break b}if((f|0)==1&g>>>0>2147483648|f>>>0>1){break b}}i=b+196648|0;break a}i=b+131112|0;break a}i=b+262184|0}j=x[a+16>>2];k=x[a+24>>2];l=x[a+20>>2];b=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=b;while(1){if(d){b=x[e+8>>2];m=(((x[e+12>>2]&2147483647)<<1|b>>>31)&-2)+j|0;b=(b>>>16&65520)+i|0;n=w[b+14>>1];o=w[b+12>>1];p=w[b+10>>1];q=w[b+8>>1];r=w[b+6>>1];s=w[b+4>>1];t=w[b+2>>1];u=w[b>>1];h=0;while(1){if((h|0)!=2){b=h+m|0;x[(h<<2)+e>>2]=(((((((D(v[b-4|0],t)+D(v[b-6|0],u)|0)+D(v[b-2|0],s)|0)+D(v[b|0],r)|0)+D(v[b+2|0],q)|0)+D(v[b+4|0],p)|0)+D(v[b+6|0],o)|0)+D(v[b+8|0],n)<<8)/32768;h=h+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[e>>2],l);x[c+4>>2]=x[c+4>>2]+D(x[e+4>>2],k);Pb(e+8|0,g,f);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;fb=e+16|0}function VL(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0,n=0,o=E(0),q=0;a:{if(y[b+21|0]){q=D(d,g);j=x[e>>2];l=x[f>>2];m=x[b>>2];b:{while(1){if((h|0)>0){if(x[a+1396>>2]<=9){Cl(a)}g=x[a+1392>>2];k=w[(((g&1023)<<1)+b|0)+36>>1];c:{if((k|0)>=0){i=g;k=k&65535;g=y[k+x[b+8>>2]|0];x[a+1392>>2]=i>>>g;g=x[a+1396>>2]-g|0;x[a+1396>>2]=(g|0)>0?g:0;k=(g|0)<0?-1:k;break c}k=Nm(a,b)}if((k|0)>=x[b+2092>>2]?y[b+23|0]:0){break a}if((k|0)<0){if(!y[a+1376|0]){b=0;if(x[a+1384>>2]){break b}}fc(a,21);return 0}else{g=0;n=D(d,l);m=((m+n|0)+j|0)>(q|0)?(q-n|0)+j|0:m;n=(m|0)>0?m:0;k=D(k,x[b>>2]);o=E(0);d:{if(y[b+22|0]){while(1){if((g|0)==(n|0)){break d}o=E(o+B[(x[b+28>>2]+(k<<2)|0)+(g<<2)>>2]);i=x[(j<<2)+c>>2];if(i){i=i+(l<<2)|0;B[i>>2]=o+B[i>>2]}j=j+1|0;i=(j|0)==(d|0);j=i?0:j;g=g+1|0;l=i+l|0;continue}}while(1){if((g|0)==(n|0)){break d}i=x[(j<<2)+c>>2];if(i){i=i+(l<<2)|0;B[i>>2]=B[i>>2]+E(B[(x[b+28>>2]+(k<<2)|0)+(g<<2)>>2]+E(0))}j=j+1|0;i=(j|0)==(d|0);j=i?0:j;g=g+1|0;l=i+l|0;continue}}h=h-m|0;continue}}break}x[e>>2]=j;x[f>>2]=l;b=1}return b}fc(a,21);return 0}_(7552,13274,1887,6586);p()}function kaa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=fb-32|0;fb=f;l=b+20|0;k=x[d+4>>2];o=x[d>>2];m=o;while(1){a:{if(!k){break a}e=0;g=fb-32|0;fb=g;h=b+20|0;i=b+212|0;n=c&-4096;b:{c:{while(1){if((e|0)==16){break c}d:{d=x[yb(i,e)>>2];if(y[Hd(h,d)+8|0]){if(x[Hd(h,d)>>2]==(n|0)){break d}}e=e+1|0;continue}break}j=x[yb(i,e)>>2];h=i+(e<<2)|0;Ar(i,h,h+4|0);q=yb(i,0),r=j,x[q>>2]=r;break b}d=x[yb(i,15)>>2];Ar(i,b+272|0,b+276|0);q=yb(i,0),r=d,x[q>>2]=r;d=x[yb(i,0)>>2];e=Hd(h,d);x[e>>2]=n;mz(g+16|0,x[b+8>>2],d);j=x[x[b>>2]+44>>2];h=x[g+20>>2];x[g+8>>2]=x[g+16>>2];x[g+12>>2]=h;ib[j|0](g+24|0,b,n,g+8|0);x[e+4>>2]=x[g+28>>2];v[e+8|0]=1}fb=g+32|0;j=c-x[Hd(l,d)>>2]|0;x[f+16>>2]=4096-j;x[f+8>>2]=k;q=f,r=x[Gb(f+16|0,f+8|0)>>2],x[q+28>>2]=r;if(j>>>0<A[Hd(l,d)+4>>2]){e=x[Hd(l,d)+4>>2]-j|0}else{e=0}x[f+24>>2]=e;e=x[Gb(f+28|0,f+24|0)>>2];mz(f+16|0,x[b+8>>2],d);h=x[f+16>>2];mz(f+8|0,x[b+8>>2],d);Wg(h+j|0,e+(j+x[f+8>>2]|0)|0,m);p=e+p|0;if(e>>>0<A[f+28>>2]){break a}c=c+e|0;m=e+m|0;k=k-e|0;continue}break}bc(a,o,p);fb=f+32|0}function xD(a,b,c,d){v[a+5|0]=c;a:{b:{switch((b|64)+-64|0){case 0:v[a+3|0]=c?37:0;return;case 1:v[a+3|0]=16;return;case 2:v[a+3|0]=12;return;case 3:v[a+3|0]=14;if(d){break a}v[a+5|0]=D(c>>>4|0,10)+(c&15);return;case 4:v[a+3|0]=11;return;case 5:v[a+3|0]=3;return;case 6:v[a+3|0]=2;return;case 7:v[a+3|0]=4;return;case 8:v[a+3|0]=5;return;case 9:v[a+3|0]=18;return;case 10:v[a+3|0]=1;return;case 11:v[a+3|0]=7;return;case 12:v[a+3|0]=6;return;case 13:v[a+3|0]=21;return;case 14:v[a+3|0]=22;return;case 15:v[a+3|0]=10;return;case 16:v[a+3|0]=29;return;case 17:v[a+3|0]=15;return;case 18:v[a+3|0]=8;return;case 19:v[a+3|0]=20;return;case 20:v[a+3|0]=17;return;case 21:v[a+3|0]=26;return;case 22:v[a+3|0]=23;return;case 23:v[a+3|0]=24;return;case 24:v[a+3|0]=9;return;case 25:v[a+3|0]=27;return;case 26:v[a+3|0]=31;return;case 28:v[a+3|0]=d?32:31;return;case 29:v[a+3|0]=d?33:0;return;case 27:v[a+3|0]=d?34:0;return;case 30:v[a+3|0]=d?35:0;return;case 31:v[a+3|0]=d?36:0;return;case 50:v[a+3|0]=d?25:0;return;case 51:v[a+3|0]=d?30:0;return;default:break b}}v[a+3|0]=0}}function P1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=fb-96|0;fb=d;xc(b);Rp(a);e=d+60|0;a:{if(!Zw(b,e)){break a}if(!_F(e)){break a}b:{if(!c){break b}if(!Mb(x[b>>2],x[b+8>>2],$b(y[d+64|0]|y[d+65|0]<<8|(y[d+66|0]<<16|y[d+67|0]<<24))-28|0)){break a}px(a);g=d,h=nx(),x[g+40>>2]=h;c=d+40|0;mx(lj(x[a+4>>2])+32|0,c);rs(c);e=x[lj(x[a+4>>2])+32>>2];f=y[d+64|0]|y[d+65|0]<<8|(y[d+66|0]<<16|y[d+67|0]<<24);x[31737]=0;S(187,c|0,b|0,$b(f)-28|0);b=x[31737];x[31737]=0;c:{d:{if((b|0)!=1){Rn(d+32|0,c);b=y[d+72|0]|y[d+73|0]<<8|(y[d+74|0]<<16|y[d+75|0]<<24);x[31737]=0;b=ba(188,x[d+32>>2],x[d+36>>2],e|0,$b(b)|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break d}Kc(c);f=0;if(!b){break a}re(d+16|0,x[e>>2],x[e+4>>2]);lf(d+24|0,x[d+16>>2],x[d+20>>2]);b=Nd(d+8|0);e=x[b+4>>2];x[d>>2]=x[b>>2];x[d+4>>2]=e;b=lx(c,x[d+24>>2],x[d+28>>2],d);hd(lj(x[a+4>>2])+12|0,b);ub(b);break b}a=ta(125048,24488)|0;b=gb;break c}a=ta(125048,24488)|0;b=gb;Kc(d+40|0)}e:{if(($(125048)|0)==(b|0)){break e}if(($(24488)|0)==(b|0)){break e}Q(a|0);p()}Y(a|0)|0;Z();f=0;break a}f=1}fb=d+96|0;return f|0}function E7(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0;a=fb-144|0;fb=a;x[a+136>>2]=c;x[a+140>>2]=b;x[a+20>>2]=1232;i=a+20|0;b=Be(a+24|0,a+32|0,i);j=a+16|0;bd(j,x[e+28>>2]);x[31737]=0;h=R(28,x[a+16>>2])|0;k=x[31737];x[31737]=0;if((k|0)!=1){a:{v[a+15|0]=0;e=x[e+4>>2];x[31737]=0;c=na(1233,a+140|0,c|0,d|0,j|0,e|0,f|0,a+15|0,h|0,b|0,i|0,a+132|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break a}b:{c:{if(!c){break c}sf(g);if(y[a+15|0]){x[31737]=0;c=P(29,h|0,45)|0;d=x[31737];x[31737]=0;if((d|0)==1){break a}x[31737]=0;O(116,g|0,c|0);c=x[31737];x[31737]=0;if((c|0)==1){break a}}x[31737]=0;d=P(29,h|0,48)|0;c=x[31737];x[31737]=0;if((c|0)==1){break b}e=x[a+20>>2];h=e-1|0;c=x[b>>2];d=d&255;while(1){if(!((d|0)!=y[c|0]|c>>>0>=h>>>0)){c=c+1|0;continue}break}x[31737]=0;U(1239,g|0,c|0,e|0)|0;c=x[31737];x[31737]=0;if((c|0)!=1){break c}break a}x[31737]=0;c=P(1201,a+140|0,a+136|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break a}if(c){x[f>>2]=x[f>>2]|2}c=x[a+140>>2];Zb(a+16|0);Lc(b);fb=a+144|0;return c|0}}}c=N()|0;Zb(a+16|0);Lc(b);Q(c|0);p()}function vha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=E(0),f=0,g=E(0),h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=E(0),t=0,u=0,v=0,w=0,y=0,z=E(0);a:{j=x[a+4272>>2];if(!j){break a}if(!zi(a+44|0)){break a}f=x[a+44>>2];l=Hc(f,0);m=Hc(f,1);u=x[a+4252>>2]-1|0;i=x[a+4268>>2];k=x[a+4256>>2];n=d;f=x[a+56>>2];q=Hc(f,0);o=q;r=Hc(f,1);p=r;while(1){if(n){e=B[m>>2];f=i<<1;h=yb(k,f);g=B[l>>2];B[h>>2]=g;y=yb(k,f|1),z=e,B[y>>2]=z;s=B[a+4276>>2];e=E(E(F(kQ(E(E(E(F(g))+E(F(e)))*E(536870912)),31,5)))*E(4.656612873077393e-10));e=E(E(E(s-e)*B[(e>=s?4236:4240)+a>>2])+e);B[a+4276>>2]=e;g=B[a+4244>>2];e=E(E(E(E(g-(e<g?g:e))*B[a+4248>>2])+E(.9999998807907104))*E(2147483648));b:{if(e<E(4294967296)&e>=E(0)){f=~~e>>>0;break b}f=0}t=((((i<<12)+u|0)+j|0)/4096|0)%(j|0)<<1;g=B[yb(k,t)>>2];h=f<<5;v=h;w=h|-2147483648;h=f>>>0<67108864;e=E(B[a+4232>>2]*E(E((h?v:w)>>>(h?31:32-(f>>>26|0)|0)>>>0)*E(4.656612873077393e-10)));B[o>>2]=g*e;y=p,z=E(B[yb(k,t|1)>>2]*e),B[y>>2]=z;i=((i?0:j)+i|0)-1|0;x[a+4268>>2]=i;n=n-1|0;p=p+4|0;o=o+4|0;m=m+4|0;l=l+4|0;continue}else{Pi(a,b,c,q,r,d)}break}}}function G0(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=fb-16|0;fb=f;a:{if((y[a|0]-16&255)>>>0<241){break a}c=a+1954|0;d=a+1698|0;while(1){if((d|0)==(c|0)){d=0;c=0;while(1){if((d|0)==32){g=c;break a}g=0;e=D(d,13)+a|0;if(y[nc(e+2|0)|0]){break a}b=(d<<4)+a|0;if(y[b+418|0]|y[b+419|0]<<8|(y[b+420|0]<<16|y[b+421|0]<<24)){break a}h=y[b+422|0]|y[b+423|0]<<8|(y[b+424|0]<<16|y[b+425|0]<<24);if(h>>>0>1048575){break a}if(y[nc(e+930|0)|0]){break a}e=(D(d,11)+a|0)+1346|0;if(y[xb(e,0)|0]>15){break a}if(y[xb(e,5)|0]>3){break a}if(y[xb(e,10)|0]>3){break a}b:{c:{d:{if(h){i=y[b+430|0]|y[b+431|0]<<8|(y[b+432|0]<<16|y[b+433|0]<<24);if(i>>>0<=1048574){if(h>>>0<i>>>0|(y[b+426|0]|y[b+427|0]<<8|(y[b+428|0]<<16|y[b+429|0]<<24))>>>0>i>>>0){break a}}if(c|h){break c}break d}if(c){break c}}v[f+7|0]=0;v[f+8|0]=0;v[f+9|0]=0;v[f+10|0]=0;x[f>>2]=0;x[f+4>>2]=0;g=e+11|0;c=f;while(1){e:{b=(e|0)==(g|0);if(b){break e}if(!F0(y[e|0],y[c|0])){break e}c=c+1|0;e=e+1|0;continue}break}c=0;if(b){break b}}c=1}d=d+1|0;continue}}b=v[d|0];d=d+1|0;if((b|0)>-2){continue}break}}fb=f+16|0;return g&1}function zo(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=fb-80|0;fb=c;g=Nb(a);a=x[b+24>>2];a:{b:{if(Nj(x[a+484360>>2],x[a+484364>>2])){c:{d:{e:while(1){if(Nj(x[a+484360>>2],x[a+484364>>2])>>>0<=f>>>0){break d}d=aS(kY(c+40|0,1),f&255,0,0);x[31737]=0;e=x[d+12>>2];x[c+16>>2]=x[d+8>>2];x[c+20>>2]=e;e=x[d+20>>2];x[c+24>>2]=x[d+16>>2];x[c+28>>2]=e;e=x[d+4>>2];x[c+8>>2]=x[d>>2];x[c+12>>2]=e;V(1097,c+68|0,a|0,0,c+8|0);a=x[31737];x[31737]=0;if((a|0)==1){break c}j=c,k=wb(x[c+68>>2]),x[j+36>>2]=k;d=wb(x[c+72>>2]);while(1){a=x[c+36>>2];if(!Ib(a,d)){f=f+1|0;Xi(c+68|0);a=x[b+24>>2];continue e}h=C[a>>3];e=x[a+16>>2];i=z[a+24>>1];a=c+40|0;x[a+16>>2]=f;x[a+12>>2]=i;x[a+8>>2]=e;C[a>>3]=h;x[31737]=0;O(1132,g|0,a|0);a=x[31737];x[31737]=0;if((a|0)!=1){br(c+36|0);continue}break}break}a=N()|0;Xi(c+68|0);break b}fb=c+80|0;return}a=N()|0;break b}b=ac(8);x[31737]=0;d=P(36,c+40|0,7310)|0;a=x[31737];x[31737]=0;if((a|0)!=1){pc(b,d);x[31737]=0;S(98,b|0,48540,1006);a=x[31737];x[31737]=0;if((a|0)!=1){break a}a=N()|0;tb(d);break b}a=N()|0;jc(b)}nf(g);Q(a|0)}p()}function dia(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=fb+-64|0;fb=b;g=Nb(a);x[31737]=0;W(960,g|0);a=x[31737];x[31737]=0;a:{if((a|0)!=1){a=43088;b:{c:{d:{e:{f:{g:{h:{i:{j:{while(1){if((a|0)==43400){fb=b- -64|0;return g|0}k:{h=yu(44);if(h){x[31737]=0;d=P(36,b+36|0,x[a+4>>2])|0;c=x[31737];x[31737]=0;if((c|0)==1){break k}c=x[a>>2];x[31737]=0;i=b+48|0;O(961,i|0,d|0);e=x[31737];x[31737]=0;if((e|0)==1){break j}x[31737]=0;e=P(36,b+12|0,x[a+8>>2])|0;f=x[31737];x[31737]=0;if((f|0)==1){break i}x[31737]=0;f=b+24|0;O(961,f|0,e|0);j=x[31737];x[31737]=0;if((j|0)==1){break h}x[31737]=0;c=ba(962,h|0,c|0,i|0,f|0)|0;j=x[31737];x[31737]=0;if((j|0)==1){break g}Eb(f);tb(e);Eb(i);tb(d);x[b+60>>2]=c;x[31737]=0;O(963,g|0,b+60|0);d=x[31737];x[31737]=0;if((d|0)==1){break b}v[c+40|0]=y[a+20|0];d=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=d;v[c+41|0]=y[c+41|0]&253|y[a+21|0]<<1}a=a+24|0;continue}break}a=N()|0;break c}a=N()|0;break d}a=N()|0;break e}a=N()|0;break f}a=N()|0;Eb(b+24|0)}tb(e)}Eb(b+48|0)}tb(d)}Db(h);break a}a=N()|0;break a}a=N()|0}vc(g);Q(a|0);p()}function bC(a,b){var c=0,d=0,e=0,f=0,g=0;d=fb-32|0;fb=d;if(b&5){if((b|0)==1){e=Sua(x[a+24>>2],0,8363,0);c=hb;e=e+4143|0;c=e>>>0<4143?c+1|0:c;f=a,g=Bc(Uua(e,c,8287,0),hb),x[f+24>>2]=g}DV(a)}if(b&3){w[a+38>>1]=0;w[a+40>>1]=0;v[a+36|0]=0;w[a+34>>1]=z[a+34>>1]&65499}if(b&7){w[a+32>>1]=64;c=z[a+34>>1];if(c&8){e=x[a+16>>2];x[a+4>>2]=x[a+12>>2];x[a+8>>2]=e;c=c&16?c|6:c&65529|2}x[a+12>>2]=0;x[a+16>>2]=0;w[a+34>>1]=c&65511}a:{if(!(b&4)){break a}c=z[a+34>>1];if(!(c&32)){w[a+28>>1]=128;w[a+34>>1]=c|32}Qf(a+40|0,15);Qf(a+41|0,63);if(!y[a+41|0]){break a}e=y[a+40|0];if(!e){break a}c=y[a+39|0];if(c){c=yi(Bc(((e<<8|c>>>1)>>>0)/(c>>>0)|0,0))}else{c=255}v[a+39|0]=c}b:{c:{if((b|0)!=4){if((b|0)==16777216){break b}if((b|0)!=32|y[a+38|0]!=2){break c}v[a+38|0]=3;break c}if(y[a+38|0]!=4){break c}v[a+38|0]=0}w[a+34>>1]=z[a+34>>1]&49151}d:{if(!(!(y[a+35|0]&2)|b&16777218)){x[d+24>>2]=0;x[d+8>>2]=0;x[d+16>>2]=0;x[d+20>>2]=0;x[d>>2]=0;x[d+4>>2]=0;Yk(a,0,d);break d}if(!(y[a+35|0]&2)|(b|0)!=2){break d}a=a+68|0;b=xb(a,8);v[b|0]=y[b|0]&3;a=xb(a,9);v[a|0]=y[a|0]&3}fb=d+32|0}function Uo(a,b,c,d){var e=0,f=0;e=b+1074312|0;f=Ob(e,120);v[a+797|0]=f;v[a+802|0]=f;w[a+800>>1]=0;v[a+803|0]=0;v[a+804|0]=0;v[a+841|0]=0;v[a+805|0]=0;x[a+708>>2]=0;x[a+656>>2]=0;x[a+104>>2]=0;x[a+764>>2]=0;x[a+696>>2]=0;x[a+668>>2]=0;x[a+88>>2]=x[a+88>>2]|6144;if(Ob(e,23)){v[a+807|0]=1;v[a+808|0]=0}v[a+846|0]=0;v[a+839|0]=0;w[a+774>>1]=0;v[a+850|0]=255;x[a+660>>2]=0;v[a+851|0]=y[a+851|0]&224;_o(a+788|0);x[a+84>>2]=0;x[a+76>>2]=0;x[a+80>>2]=0;x[a+700>>2]=0;x[a+656>>2]=0;x[a+104>>2]=0;x[a+92>>2]=0;x[a+96>>2]=0;x[a>>2]=0;x[a+4>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;v[a+845|0]=0;v[a+838|0]=0;v[a+821|0]=0;x[a+688>>2]=0;x[a+672>>2]=0;x[a+676>>2]=0;w[a+836>>1]=32512;v[a+819|0]=0;v[a+820|0]=0;w[a+842>>1]=0;x[a+28>>2]=0;x[a+32>>2]=0;x[a+20>>2]=0;x[a+24>>2]=0;x[a+852>>2]=0;x[a+856>>2]=0;v[a+851|0]=y[a+851|0]&159;a:{if(c>>>0<=126){b=(c<<5)+b|0;c=x[b+480280>>2];x[a+88>>2]=c;x[a+692>>2]=z[b+480284>>1];x[a+748>>2]=z[b+480286>>1];if(!(c&1024)){break a}x[a+88>>2]=c&-1025|d;break a}x[a+748>>2]=64;x[a+692>>2]=128;x[a+88>>2]=0}w[a+784>>1]=0;v[a+795|0]=0;v[a+796|0]=0}function ama(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=fb-16|0;fb=e;o=x[a+16>>2];p=Fg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);j=x[a+8>>2];k=x[a+12>>2];b=x[a>>2];g=x[a+4>>2];l=x[a+128>>2];if(l){m=Gg(j,k,l);n=hb;f=x[a+76>>2];hg(b,g,vf(j,k,d),hb);i=hb>>>0>f>>>0?d:0}f=a+112|0;q=x[a+24>>2];r=x[a+20>>2];x[e>>2]=b;x[e+4>>2]=g;a:while(1){if(d){g=x[e+4>>2];b=x[e>>2];x[e+8>>2]=b;x[e+12>>2]=0;i=i-1|0;m=i?m:0;n=i?n:0;d=d-1|0;g=((((g&2147483647)<<1|b>>>31)&2147483646)<<1)+o|0;b=l;while(1)if((b|0)<=0){Pb(f,x[a+120>>2],x[a+124>>2]);b=x[a+116>>2];if(b){h=x[e+8>>2];g=((((x[e+12>>2]&2147483647)<<1|h>>>31)&2147483646)<<1)+g|0;be(f,(w[g>>1]+w[g+2>>1]|0)/8<<16>>16);ae(f,b);x[f>>2]=x[f>>2];x[f+4>>2]=0}b=Eg(f,p);x[c>>2]=x[c>>2]+D(b,r);x[c+4>>2]=x[c+4>>2]+D(b,q);Pb(e,j,k);c=c+8|0;continue a}else{h=x[e+8>>2];h=((((x[e+12>>2]&2147483647)<<1|h>>>31)&2147483646)<<1)+g|0;be(f,(w[h>>1]+w[h+2>>1]|0)/8<<16>>16);ae(f,4);Pb(e+8|0,m,n);b=b-1|0;continue}}break}b=x[e+4>>2];x[a>>2]=x[e>>2];x[a+4>>2]=b;fb=e+16|0}function wS(a){var b=0,c=0,d=0,e=0,f=0,g=0;while(1){if((f|0)!=4e3){g=fb-32|0;fb=g;b=cv(g);d=y[b+4|0]|y[b+5|0]<<8|(y[b+6|0]<<16|y[b+7|0]<<24);c=(f<<5)+a|0;e=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);v[c|0]=e;v[c+1|0]=e>>>8;v[c+2|0]=e>>>16;v[c+3|0]=e>>>24;v[c+4|0]=d;v[c+5|0]=d>>>8;v[c+6|0]=d>>>16;v[c+7|0]=d>>>24;d=y[b+28|0]|y[b+29|0]<<8|(y[b+30|0]<<16|y[b+31|0]<<24);e=y[b+24|0]|y[b+25|0]<<8|(y[b+26|0]<<16|y[b+27|0]<<24);v[c+24|0]=e;v[c+25|0]=e>>>8;v[c+26|0]=e>>>16;v[c+27|0]=e>>>24;v[c+28|0]=d;v[c+29|0]=d>>>8;v[c+30|0]=d>>>16;v[c+31|0]=d>>>24;d=y[b+20|0]|y[b+21|0]<<8|(y[b+22|0]<<16|y[b+23|0]<<24);e=y[b+16|0]|y[b+17|0]<<8|(y[b+18|0]<<16|y[b+19|0]<<24);v[c+16|0]=e;v[c+17|0]=e>>>8;v[c+18|0]=e>>>16;v[c+19|0]=e>>>24;v[c+20|0]=d;v[c+21|0]=d>>>8;v[c+22|0]=d>>>16;v[c+23|0]=d>>>24;d=y[b+12|0]|y[b+13|0]<<8|(y[b+14|0]<<16|y[b+15|0]<<24);b=y[b+8|0]|y[b+9|0]<<8|(y[b+10|0]<<16|y[b+11|0]<<24);v[c+8|0]=b;v[c+9|0]=b>>>8;v[c+10|0]=b>>>16;v[c+11|0]=b>>>24;v[c+12|0]=d;v[c+13|0]=d>>>8;v[c+14|0]=d>>>16;v[c+15|0]=d>>>24;fb=g+32|0;f=f+1|0;continue}break}}function cna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0;h=fb-16|0;fb=h;f=x[a+48>>2];j=x[a+40>>2];k=x[a+36>>2];e=x[a+44>>2];o=x[a+16>>2];b=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=b;p=x[a+32>>2];q=x[a+28>>2];r=x[a+72>>2];l=x[a+68>>2];s=l>>31;m=x[a+64>>2];t=m>>31;n=x[a+60>>2];u=n>>31;w=x[a+8>>2];y=x[a+12>>2];while(1){b=e;if(d){e=Yb(e,-16777216,16776704);e=Sua(m,t,e,e>>31);i=hb;g=e;f=Yb(f,-16777216,16776704);e=Sua(l,s,f,f>>31);g=g+e|0;f=hb+i|0;f=e>>>0>g>>>0?f+1|0:f;z=g;e=x[h+8>>2];i=e>>>10&4194048;e=x[h+12>>2]+o|0;g=v[e|0];i=((D(v[e+1|0]-g|0,i)|0)/16384<<8)+(g<<16)|0;e=i;e=Sua(e,e>>31,n,u);g=e+z|0;f=hb+f|0;f=e>>>0>g>>>0?f+1|0:f;e=g+8388608|0;f=e>>>0<8388608?f+1|0:f;e=Rc(e,f,24);f=(e|0)/256|0;k=k+q|0;x[c>>2]=D(f,k>>12)+x[c>>2];j=j+p|0;x[c+4>>2]=x[c+4>>2]+D(j>>12,f);Pb(h+8|0,w,y);e=e-(i&r)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=c;x[a+40>>2]=j;x[a+20>>2]=k>>12;x[a+36>>2]=k;x[a+48>>2]=f;x[a+44>>2]=b;x[a+24>>2]=j>>12;fb=h+16|0}function Ifa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;x[31737]=0;W(1027,a|0);e=x[31737];x[31737]=0;a:{b:{c:{d:{e:{if((e|0)==1){break e}x[31737]=0;W(1003,b|0);e=x[31737];x[31737]=0;if((e|0)==1){break e}e=0;x[31737]=0;W(1028,c|0);f=x[31737];x[31737]=0;if((f|0)==1){break e}a=Rb(c,0,d);if(!y[b|0]){break b}if(ni(b,47408)|(d|0)!=8){break d}x[a+4>>2]=1029;x[a>>2]=1030;break c}Y(T(0)|0)|0;x[31737]=0;V(989,12360,a|0,0,0);a=x[31737];x[31737]=0;if((a|0)==1){break a}Z();return 0}if(!(ni(b,47420)|(d|0)!=64)){x[a+60>>2]=1031;x[a+56>>2]=1032;x[a+52>>2]=1033;x[a+48>>2]=1034;x[a+44>>2]=1035;x[a+40>>2]=1036;x[a+36>>2]=1037;x[a+32>>2]=1038;x[a+28>>2]=1039;x[a+24>>2]=1040;x[a+20>>2]=1041;x[a+16>>2]=1042;x[a+12>>2]=1043;x[a+8>>2]=1044;x[a+4>>2]=1045;x[a>>2]=1046;break c}if(!(ni(b,47432)|(d|0)!=24)){x[a+20>>2]=1047;x[a+16>>2]=1048;x[a+12>>2]=1049;x[a+8>>2]=1050;x[a+4>>2]=1051;x[a>>2]=1052;break c}if(ni(b,47445)|(d|0)!=4){break b}x[a>>2]=1053}e=1}return e|0}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function hia(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=E(0),j=0,k=0;c=fb-32|0;fb=c;a:{b=x[a+20>>2];b:{if(!b){break b}x[b+148>>2]=-1;j=c,k=ib[x[x[a>>2]+40>>2]](a)|0,x[j+16>>2]=k;x[c+8>>2]=1073741822;b=c+16|0;d=c+8|0;g=x[Gb(b,d)>>2];e=g<<2;if(!e){break b}h=x[a+20>>2];x[31737]=0;O(288,h+4|0,e+4|0);e=x[31737];x[31737]=0;c:{d:{if((e|0)!=1){e=d;d=x[a+20>>2];re(e,x[d+4>>2],x[d+8>>2]);x[c>>2]=0;x[c+4>>2]=0;d=x[c+12>>2];x[b>>2]=x[c+8>>2];x[b+4>>2]=d;d=x[c+4>>2];x[b+8>>2]=x[c>>2];x[b+12>>2]=d;d=fb-16|0;fb=d;x[d+12>>2]=0;CQ(b,d+12|0);fb=d+16|0;b=x[x[a>>2]+184>>2];x[31737]=0;O(b|0,a|0,-1);b=x[31737];x[31737]=0;if((b|0)==1){break d}while(1){if((f|0)==(g|0)){b=x[x[a>>2]+188>>2];x[31737]=0;W(b|0,a|0);b=x[31737];x[31737]=0;if((b|0)!=1){break b}break d}b=x[x[a>>2]+48>>2];x[31737]=0;i=E(_a(b|0,a|0,f|0));b=x[31737];x[31737]=0;if((b|0)!=1){B[c+8>>2]=i;f=f+1|0;CQ(c+16|0,c+8|0);continue}break}b=T(125048)|0;break c}b=T(125048)|0;break c}b=T(125048)|0}if((gb|0)!=($(125048)|0)){break a}Y(b|0)|0;ep(x[a+20>>2]+4|0);Z()}fb=c+32|0;return}Q(b|0);p()}function QL(a,b,c){var d=0,e=0,f=0,g=0,h=0;g=a;d=fb-208|0;fb=d;x[d+8>>2]=1;x[d+12>>2]=0;h=b<<2;a:{if(!h){break a}x[d+16>>2]=4;x[d+20>>2]=4;b=4;f=4;e=2;while(1){a=b;b=(b+f|0)+4|0;x[(d+16|0)+(e<<2)>>2]=b;e=e+1|0;f=a;if(b>>>0<h>>>0){continue}break}a=(g+h|0)-4|0;b:{if(a>>>0<=g>>>0){e=1;b=1;a=0;break b}e=1;b=1;while(1){c:{if((e&3)==3){_y(g,c,b,d+16|0);Mt(d+8|0,2);b=b+2|0;break c}h=d+16|0;f=b-1|0;d:{if(A[h+(f<<2)>>2]>=a-g>>>0){Lt(g,c,e,x[d+12>>2],b,0,h);break d}_y(g,c,b,d+16|0)}if((b|0)==1){Kt(d+8|0,1);b=0;break c}Kt(d+8|0,f);b=1}e=x[d+8>>2]|1;x[d+8>>2]=e;g=g+4|0;if(a>>>0>g>>>0){continue}break}a=x[d+12>>2]}Lt(g,c,e,a,b,0,d+16|0);f=x[d+12>>2];e=x[d+8>>2];if(!(f|((b|0)!=1|(e|0)!=1))){break a}while(1){e:{if((b|0)<=1){a=JL(e,f);Mt(d+8|0,a);a=a+b|0;break e}f=d+8|0;Kt(f,2);x[d+8>>2]=x[d+8>>2]^7;Mt(f,1);h=g-4|0;e=d+16|0;a=b-2|0;Lt(h-x[e+(a<<2)>>2]|0,c,x[d+8>>2],x[d+12>>2],b-1|0,1,e);Kt(f,1);b=x[d+8>>2]|1;x[d+8>>2]=b;Lt(h,c,b,x[d+12>>2],a,1,e)}b=a;g=g-4|0;f=x[d+12>>2];e=x[d+8>>2];if(f|((b|0)!=1|(e|0)!=1)){continue}break}}fb=d+208|0}function GT(a,b){var c=0,d=0,e=0,f=0;d=fb-16|0;fb=d;c=x[a+24620>>2];a:{b:{switch(y[a+480224|0]-1|0){default:x[d+12>>2]=1;x[d+8>>2]=x[b+44>>2]<<1;c=Sua(c,c>>31,5e4,0);e=hb;b=x[ad(d+12|0,d+8|0)>>2];c=Gc(Tua(c,e,b,b>>31),hb);break a;case 0:x[d+12>>2]=1;x[d+8>>2]=x[b+44>>2];c=Sua(c,c>>31,1e4,0);e=hb;b=x[ad(d+12|0,d+8|0)>>2];c=Gc(Tua(c,e,b,b>>31),hb);break a;case 1:break b}}f=60/(+A[b+44>>2]/1e4*(+(Sua(x[b+32>>2],0,x[b+40>>2],0)>>>0)+ +(hb>>>0)*4294967296))*+(c>>>0);c:{d:{c=x[a+484344>>2];e=z[b+70>>1];if(!He(c,x[a+484348>>2],e)){break d}c=Wb(c,e);if(!Ib(x[c+24>>2],x[c+28>>2])){break d}c=$R(c);break c}c=a+480248|0}e=x[c>>2];c=x[c+4>>2];if(!mc(e,c)){f=f*+A[yb(e,A[b+48>>2]%(oc(e,c)>>>0)|0)>>2]*5.960464477539063e-8}e:{if(F(f)<2147483648){c=~~f;break e}c=-2147483648}f=C[b+8>>3]+(f-+(c>>>0));C[b+8>>3]=f;if(f>=1){C[b+8>>3]=f+-1;c=c+1|0;break a}if(!(C[a+1074384>>3]<=-1)){break a}C[b+8>>3]=f+1;c=c-1|0}b=Sua(x[a+480244>>2],0,c,0);a=hb;b=b+32768|0;a=b>>>0<32768?a+1|0:a;a=Bc((a&65535)<<16|b>>>16,a>>>16|0);fb=d+16|0;return a>>>0<=1?1:a}function FM(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;c=fb+-64|0;fb=c;f=x[a>>2];a=x[f>>2];g=x[a+4>>2];x[c+40>>2]=x[a+20>>2];e=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=e;Zf(c+48|0,c+32|0,g);a=x[f+4>>2];f=x[a+8>>2];g=x[a+4>>2];e=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=e;e=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=e;x[c+8>>2]=x[a+8>>2];e=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=e;a:{b:{c:{d:{e=x[c+4>>2];if(g>>>0<=e>>>0){i=x[c+20>>2];if(g>>>0>i>>>0){break d}if(f>>>0>A[c+8>>2]){break c}j=x[c+28>>2];if(f>>>0>x[c+24>>2]-j>>>0){break b}k=b+12|0;l=x[c+16>>2];m=x[c>>2];e:while(1){if((f|0)==(h|0)){break a}n=(D(e,h)<<2)+m|0;o=(D(h+j|0,i)<<1)+l|0;a=0;while(1)if((a|0)==(g|0)){h=h+1|0;continue e}else{d=yb(x[b>>2],a);q=d;d=x[(a<<2)+n>>2]+(x[d>>2]>>1)|0;r=d;d=Xt(k)+d&-4096;x[q>>2]=r-d;d=qd(d|2048,12);d=(d|0)>=32767?32767:d;w[(a<<1)+o>>1]=(d|0)<=-32768?-32768:d;a=a+1|0;continue}}}_(7244,9061,33,8774);p()}_(7209,9061,34,8774);p()}_(5897,9061,35,8774);p()}_(5867,9061,36,8774);p()}fb=c- -64|0}function gX(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0;c=fb-80|0;fb=c;x[c+72>>2]=0;x[c+76>>2]=0;b=c- -64|0;x[b>>2]=0;x[b+4>>2]=0;x[c+56>>2]=0;x[c+60>>2]=0;x[c+48>>2]=0;x[c+52>>2]=0;fC(a,BV(a),c+48|0);b=qc(c+40|0,14253);qf(Oe(a,0),x[b>>2],x[b+4>>2]);b=qc(c+32|0,14336);qf(Oe(a,1),x[b>>2],x[b+4>>2]);b=qc(c+24|0,5496);qf(Oe(a,3),x[b>>2],x[b+4>>2]);b=qc(c+16|0,15780);qf(Oe(a,4),x[b>>2],x[b+4>>2]);b=qc(c+8|0,9281);qf(Oe(a,8),x[b>>2],x[b+4>>2]);d=Oe(a+288|0,0);b=fb-16|0;fb=b;e=d;d=qc(b+8|0,4932);qf(e,x[d>>2],x[d+4>>2]);fb=b+16|0;d=a+800|0;b=0;a=fb+-64|0;fb=a;a:{b:{while(1){if((b|0)==128){break a}x[a+60>>2]=b<<3;c:{d:{if(b>>>0<=15){e=a+28|0;mw(e,4084);x[31737]=0;g=a+16|0;O(290,g|0,a+60|0);f=x[31737];x[31737]=0;if((f|0)==1){break c}x[31737]=0;f=a+40|0;S(291,f|0,e|0,g|0);h=x[31737];x[31737]=0;if((h|0)!=1){ee(a+52|0,f);qf(Oe(d,b),x[a+52>>2],x[a+56>>2]);tb(f);tb(g);Eb(e);break d}b=N()|0;tb(a+16|0);break b}e=qc(a+8|0,22303);qf(Oe(d,b),x[e>>2],x[a+12>>2])}b=b+1|0;continue}break}b=N()|0}Eb(a+28|0);Q(b|0);p()}fb=a- -64|0;fb=c+80|0}function bna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0;h=fb-16|0;fb=h;e=x[a+48>>2];i=x[a+40>>2];j=x[a+36>>2];f=x[a+44>>2];p=x[a+16>>2];b=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=b;q=x[a+32>>2];r=x[a+28>>2];s=x[a+72>>2];m=x[a+68>>2];t=m>>31;n=x[a+64>>2];u=n>>31;o=x[a+60>>2];v=o>>31;y=x[a+8>>2];z=x[a+12>>2];while(1){b=f;if(d){f=Yb(f,-16777216,16776704);g=Sua(n,u,f,f>>31);f=hb;e=Yb(e,-16777216,16776704);e=Sua(m,t,e,e>>31);g=e+g|0;f=hb+f|0;f=e>>>0>g>>>0?f+1|0:f;l=g;g=(x[h+12>>2]<<1)+p|0;k=w[g>>1];k=k+((D(w[g+2>>1]-k|0,x[h+8>>2]>>>18|0)|0)/16384|0)<<8;e=k;g=Sua(e,e>>31,o,v);l=g+l|0;e=hb+f|0;e=g>>>0>l>>>0?e+1|0:e;f=l+8388608|0;e=f>>>0<8388608?e+1|0:e;f=Rc(f,e,24);e=(f|0)/256|0;j=j+r|0;x[c>>2]=D(e,j>>12)+x[c>>2];i=i+q|0;x[c+4>>2]=x[c+4>>2]+D(i>>12,e);Pb(h+8|0,y,z);f=f-(k&s)|0;c=c+8|0;d=d-1|0;e=b;continue}break}c=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=c;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+48>>2]=e;x[a+44>>2]=b;x[a+24>>2]=i>>12;fb=h+16|0}function LM(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;c=fb+-64|0;fb=c;d=x[a>>2];a=x[d>>2];f=x[a+4>>2];x[c+40>>2]=x[a+20>>2];g=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=g;Zf(c+48|0,c+32|0,f);a=x[d+4>>2];f=x[a+8>>2];g=x[a+4>>2];d=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=d;d=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=d;x[c+8>>2]=x[a+8>>2];d=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=d;a:{b:{c:{d:{i=x[c+4>>2];if(i>>>0>=g>>>0){if(A[c+20>>2]<g>>>0){break d}if(f>>>0>A[c+8>>2]){break c}j=x[c+28>>2];if(f>>>0>x[c+24>>2]-j>>>0){break b}l=b+12|0;m=x[c+16>>2];n=x[c>>2];a=0;e:while(1){if((a|0)==(f|0)){break a}o=(D(a,i)<<2)+n|0;d=0;while(1)if((d|0)==(g|0)){a=a+1|0;continue e}else{e=yb(x[b>>2],d);h=e;k=d<<2;e=x[k+o>>2]+(x[e>>2]>>1)|0;q=e;e=Xt(l)+e&-4096;x[h>>2]=q-e;h=(x[m+k>>2]+(j<<1)|0)+(a<<1)|0;e=qd(e|2048,12);e=(e|0)>=32767?32767:e;w[h>>1]=(e|0)<=-32768?-32768:e;d=d+1|0;continue}}}_(7244,9061,33,8774);p()}_(7209,9061,34,8774);p()}_(5897,9061,35,8774);p()}_(5867,9061,36,8774);p()}fb=c- -64|0}function Uua(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{if(b){if(!c){break k}if(!d){break j}e=G(d)-G(b)|0;if(e>>>0<=31){break i}break c}if((d|0)==1|d>>>0>1){break c}hb=0;a=(a>>>0)/(c>>>0)|0;break a}if(!a){break h}if(!d|d-1&d){break g}a=b>>>Rua(d)|0;hb=0;break a}if(!(c-1&c)){break f}h=(G(c)+33|0)-G(b)|0;g=0-h|0;break d}h=e+1|0;g=63-e|0;break d}hb=0;a=(b>>>0)/(d>>>0)|0;break a}e=G(d)-G(b)|0;if(e>>>0<31){break e}break c}if((c|0)==1){break b}d=Rua(c);c=d&31;if((d&63)>>>0>=32){a=b>>>c|0}else{e=b>>>c|0;a=((1<<c)-1&b)<<32-c|a>>>c}hb=e;break a}h=e+1|0;g=63-e|0}e=h&63;f=e&31;if(e>>>0>=32){e=0;i=b>>>f|0}else{e=b>>>f|0;i=((1<<f)-1&b)<<32-f|a>>>f}g=g&63;f=g&31;if(g>>>0>=32){b=a<<f;a=0}else{b=(1<<f)-1&a>>>32-f|b<<f;a=a<<f}if(h){f=d-1|0;g=c-1|0;m=(g|0)!=-1?f+1|0:f;while(1){j=e<<1|i>>>31;e=i<<1|b>>>31;f=m-(j+(e>>>0>g>>>0)|0)>>31;k=c&f;i=e-k|0;e=j-((d&f)+(e>>>0<k>>>0)|0)|0;b=b<<1|a>>>31;a=l|a<<1;l=f&1;h=h-1|0;if(h){continue}break}}hb=b<<1|a>>>31;a=l|a<<1;break a}a=0;b=0}hb=b}return a}function Fja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=fb-16|0;fb=d;ld(c,0);w[d+14>>1]=y[a+36|0]|y[a+37|0]<<8;w[d+12>>1]=32767;g=c,h=(z[Nc(d+14|0,d+12|0)>>1]<<8>>>0)/32767|0,w[g+28>>1]=h;w[d+10>>1]=y[a+38|0]|y[a+39|0]<<8;w[d+8>>1]=32767;g=c,h=(z[Nc(d+10|0,d+8|0)>>1]<<8>>>0)/32767|0,w[g+30>>1]=h;w[c+32>>1]=64;x[c>>2]=y[a+44|0]|y[a+45|0]<<8|(y[a+46|0]<<16|y[a+47|0]<<24);x[c+4>>2]=y[a+48|0]|y[a+49|0]<<8|(y[a+50|0]<<16|y[a+51|0]<<24);x[c+8>>2]=y[a+52|0]|y[a+53|0]<<8|(y[a+54|0]<<16|y[a+55|0]<<24);x[c+24>>2]=y[a+56|0]|y[a+57|0]<<8|(y[a+58|0]<<16|y[a+59|0]<<24);e=y[b+166|0];if(e>>>0<=4){v[c+38|0]=y[e+41226|0]}e=y[b+167|0]|y[b+168|0]<<8;v[c+39|0]=e;f=(y[b+171|0]|y[b+172|0]<<8)>>>4|0;v[c+41|0]=f;b=(y[b+169|0]|y[b+170|0]<<8)>>>2|0;v[c+40|0]=b;if((b|f)&255){v[c+39|0]=e^-1}b=y[a+40|0]|y[a+41|0]<<8;if(b&4){w[c+34>>1]=z[c+34>>1]|1;b=y[a+40|0]|y[a+41|0]<<8}if(b&8){w[c+34>>1]=z[c+34>>1]|2;b=y[a+40|0]|y[a+41|0]<<8}if(b&16){w[c+34>>1]=z[c+34>>1]|4;b=y[a+40|0]|y[a+41|0]<<8}if(b&32){w[c+34>>1]=z[c+34>>1]|32}fb=d+16|0}function rna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0;g=fb-16|0;fb=g;r=x[a+16>>2];l=mg(1,2);b=hb;s=b;Pb(a,l,b);f=x[a+48>>2];i=x[a+40>>2];j=x[a+36>>2];e=x[a+44>>2];b=x[a+4>>2];x[g+8>>2]=x[a>>2];x[g+12>>2]=b;t=x[a+32>>2];u=x[a+28>>2];v=x[a+72>>2];m=x[a+68>>2];y=m>>31;n=x[a+64>>2];z=n>>31;o=x[a+60>>2];A=o>>31;B=x[a+8>>2];C=x[a+12>>2];while(1){b=e;if(d){p=w[(x[g+12>>2]<<1)+r>>1]<<8;e=p;e=Sua(e,e>>31,o,A);k=hb;h=e;e=Yb(b,-16777216,16776704);e=Sua(n,z,e,e>>31);q=h+e|0;h=hb+k|0;h=e>>>0>q>>>0?h+1|0:h;f=Yb(f,-16777216,16776704);e=Sua(m,y,f,f>>31);k=e+q|0;f=hb+h|0;f=e>>>0>k>>>0?f+1|0:f;e=k+8388608|0;f=e>>>0<8388608?f+1|0:f;e=Rc(e,f,24);f=(e|0)/256|0;j=j+u|0;x[c>>2]=D(f,j>>12)+x[c>>2];i=i+t|0;x[c+4>>2]=x[c+4>>2]+D(i>>12,f);Pb(g+8|0,B,C);e=e-(v&p)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=x[g+12>>2];x[a>>2]=x[g+8>>2];x[a+4>>2]=c;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+48>>2]=f;x[a+44>>2]=b;x[a+24>>2]=i>>12;Hg(a,l,s);fb=g+16|0}function dL(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;n=fb-1040|0;fb=n;r=x[31612];a:{b:{j=n+16|0;q=z[((b>>>0<=153?b:0)<<1)+123504>>1]+121580|0;d=x[x[124243]+20>>2];if(d){k=x[d+4>>2];d=x[d>>2];e=x[d>>2]+1794895138|0;f=Im(x[d+8>>2],e);g=Im(x[d+12>>2],e);h=Im(x[d+16>>2],e);c:{if(k>>>2>>>0<=f>>>0){break c}l=k-(f<<2)|0;if((g|h)&3|(l>>>0<=g>>>0|h>>>0>=l>>>0)){break c}s=h>>>2|0;t=d+(g&-4)|0;g=0;while(1){h=f>>>1|0;l=h+g|0;m=(l<<3)+t|0;i=Im(x[m>>2],e);m=Im(x[m+4>>2],e);if(m>>>0>=k>>>0|i>>>0>=k-m>>>0){break c}o=i;i=d+m|0;if(y[o+i|0]){break c}i=ni(q,i);if(!i){g=(d+(s<<2)|0)+(l<<3)|0;f=Im(x[g>>2],e);e=Im(x[g+4>>2],e);if(e>>>0>=k>>>0|f>>>0>=k-e>>>0){break c}c=d+e|0;c=y[c+f|0]?0:c;break c}if((f|0)==1){break c}o=h;f=f-h|0;h=(i|0)<0;f=h?o:f;g=h?g:l;continue}}}c=c?c:q;d=Cf(c);d:{if(d>>>0>=1024){yc(j,c,1023);v[j+1023|0]=0;c=68;break d}yc(j,c,d+1|0);c=0}if(c){if((c|0)!=28){break b}c=22303}else{c=j}break a}va();p()}if(!y[c|0]){x[n>>2]=b;Fy(j,1024,13091,n);c=j}x[31612]=r;Dc(a,c);fb=n+1040|0}function Ema(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=fb-16|0;fb=e;a:{b:{c:{f=x[a+12>>2];h=x[a+8>>2];d:{if((f|0)<=1&h>>>0<=805306368|(f|0)<=0){if((f|0)>=-2&h>>>0>=3489660928|(f|0)>-2){break c}if((f|0)==-2&h>>>0>2147483647|(f|0)==-1){break d}break b}if((f|0)==1&h>>>0>2147483648|f>>>0>1){break b}}k=b+196648|0;break a}k=b+131112|0;break a}k=b+262184|0}l=x[a+16>>2];i=x[a+40>>2];j=x[a+36>>2];b=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=b;m=x[a+32>>2];n=x[a+28>>2];while(1){if(d){b=x[e+8>>2];g=(x[e+12>>2]<<1)+l|0;b=(b>>>16&65520)+k|0;b=(((((((D(w[g-4>>1],w[b+2>>1])+D(w[g-6>>1],w[b>>1])|0)+D(w[g-2>>1],w[b+4>>1])|0)+D(w[g>>1],w[b+6>>1])|0)+D(w[g+2>>1],w[b+8>>1])|0)+D(w[g+4>>1],w[b+10>>1])|0)+D(w[g+6>>1],w[b+12>>1])|0)+D(w[g+8>>1],w[b+14>>1])|0)/32768|0;j=j+n|0;x[c>>2]=x[c>>2]+D(b,j>>12);i=i+m|0;x[c+4>>2]=x[c+4>>2]+D(b,i>>12);Pb(e+8|0,h,f);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+24>>2]=i>>12;fb=e+16|0}function sna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0,A=0,B=0,C=0;g=fb-16|0;fb=g;r=x[a+16>>2];l=mg(1,2);b=hb;s=b;Pb(a,l,b);f=x[a+48>>2];i=x[a+40>>2];j=x[a+36>>2];e=x[a+44>>2];b=x[a+4>>2];x[g+8>>2]=x[a>>2];x[g+12>>2]=b;t=x[a+32>>2];u=x[a+28>>2];w=x[a+72>>2];m=x[a+68>>2];y=m>>31;n=x[a+64>>2];z=n>>31;o=x[a+60>>2];A=o>>31;B=x[a+8>>2];C=x[a+12>>2];while(1){b=e;if(d){p=v[x[g+12>>2]+r|0]<<16;e=p;e=Sua(e,e>>31,o,A);k=hb;h=e;e=Yb(b,-16777216,16776704);e=Sua(n,z,e,e>>31);q=h+e|0;h=hb+k|0;h=e>>>0>q>>>0?h+1|0:h;f=Yb(f,-16777216,16776704);e=Sua(m,y,f,f>>31);k=e+q|0;f=hb+h|0;f=e>>>0>k>>>0?f+1|0:f;e=k+8388608|0;f=e>>>0<8388608?f+1|0:f;e=Rc(e,f,24);f=(e|0)/256|0;j=j+u|0;x[c>>2]=D(f,j>>12)+x[c>>2];i=i+t|0;x[c+4>>2]=x[c+4>>2]+D(i>>12,f);Pb(g+8|0,B,C);e=e-(w&p)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=x[g+12>>2];x[a>>2]=x[g+8>>2];x[a+4>>2]=c;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+48>>2]=f;x[a+44>>2]=b;x[a+24>>2]=i>>12;Hg(a,l,s);fb=g+16|0}function UL(a,b,c,d,e){var f=E(0),g=0,h=E(0),i=0,j=E(0),k=E(0);if(!(a&3)){c=(c<<2)+b|0;d=c+(d<<2)|0;a=a>>2;while(1){if((a|0)>0){b=d-4|0;h=B[b>>2];j=B[c>>2];k=B[d>>2];B[c>>2]=j+k;g=c-4|0;f=B[g>>2];B[g>>2]=f+B[b>>2];j=E(j-k);f=E(f-h);B[d>>2]=E(j*B[e>>2])-E(B[e+4>>2]*f);B[b>>2]=E(f*B[e>>2])+E(j*B[e+4>>2]);b=d-12|0;j=B[b>>2];g=c-8|0;f=B[g>>2];i=g;g=d-8|0;k=B[g>>2];B[i>>2]=f+k;i=c-12|0;h=B[i>>2];B[i>>2]=h+B[b>>2];f=E(f-k);h=E(h-j);B[g>>2]=E(f*B[e+32>>2])-E(B[e+36>>2]*h);B[b>>2]=E(h*B[e+32>>2])+E(f*B[e+36>>2]);b=d-20|0;j=B[b>>2];g=c-16|0;f=B[g>>2];i=g;g=d-16|0;k=B[g>>2];B[i>>2]=f+k;i=c-20|0;h=B[i>>2];B[i>>2]=h+B[b>>2];f=E(f-k);h=E(h-j);B[g>>2]=E(f*B[e+64>>2])-E(B[e+68>>2]*h);B[b>>2]=E(h*B[e+64>>2])+E(f*B[e+68>>2]);b=d-28|0;j=B[b>>2];g=c-24|0;f=B[g>>2];i=g;g=d-24|0;k=B[g>>2];B[i>>2]=f+k;i=c-28|0;h=B[i>>2];B[i>>2]=h+B[b>>2];f=E(f-k);h=E(h-j);B[g>>2]=E(f*B[e+96>>2])-E(B[e+100>>2]*h);B[b>>2]=E(h*B[e+96>>2])+E(f*B[e+100>>2]);a=a-1|0;d=d-32|0;c=c-32|0;e=e+128|0;continue}break}return}_(15869,13274,2423,9227);p()}function Gsa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=fb-16|0;fb=e;d=Zh(b,c);n=e,o=Bb(y[a|0]|y[a+1|0]<<8),w[n+14>>1]=o;w[e+12>>1]=64;gh(d,z[Nc(e+14|0,e+12|0)>>1]);n=d,o=Bb(y[a+14|0]|y[a+15|0]<<8),v[n+13|0]=o;n=d,o=Bb(y[a+16|0]|y[a+17|0]<<8),v[n+14|0]=o;n=d,o=Bb(y[a+20|0]|y[a+21|0]<<8),v[n+15|0]=o;n=d,o=Bb(y[a+22|0]|y[a+23|0]<<8),v[n+16|0]=o;i=x[d>>2];f=x[d+4>>2];b=y[d+12|0]&-2|mc(i,f)^1;v[d+12|0]=b;b=b&-3|Bb(y[a+12|0]|y[a+13|0]<<8)>>>3&2;v[d+12|0]=b;n=d,o=b&251|Bb(y[a+12|0]|y[a+13|0]<<8)>>>3&4,v[n+12|0]=o;b=4096;a:{b:{switch(c-1|0){case 0:j=-128;b=127;break a;case 1:break b;default:break a}}j=-1616;b=1616}d=b-j|0;k=d>>>1|0;m=Sd(i,f);b=0;while(1){if(b>>>0>=m>>>0){fb=e+16|0}else{f=yb(i,b);w[f>>1]=l;g=(b<<2)+a|0;c=xe((y[g+28|0]|y[g+29|0]<<8)<<16>>16)+j|0;h=c;c=c>>31<<6|c>>>26;h=k+(h<<6)|0;c=h>>>0<k>>>0?c+1|0:c;n=f,o=Ch(Gc(Tua(h,c,d,0),hb)),v[n+2|0]=o;n=e,o=Bb(y[g+26|0]|y[g+27|0]<<8),w[n+10>>1]=o;w[e+8>>1]=1;b=b+1|0;l=z[pe(e+10|0,e+8|0)>>1]+l|0;continue}break}}function Fma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=fb-16|0;fb=e;a:{b:{c:{f=x[a+12>>2];h=x[a+8>>2];d:{if((f|0)<=1&h>>>0<=805306368|(f|0)<=0){if((f|0)>=-2&h>>>0>=3489660928|(f|0)>-2){break c}if((f|0)==-2&h>>>0>2147483647|(f|0)==-1){break d}break b}if((f|0)==1&h>>>0>2147483648|f>>>0>1){break b}}k=b+196648|0;break a}k=b+131112|0;break a}k=b+262184|0}l=x[a+16>>2];i=x[a+40>>2];j=x[a+36>>2];b=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=b;m=x[a+32>>2];n=x[a+28>>2];while(1){if(d){b=x[e+8>>2];g=x[e+12>>2]+l|0;b=(b>>>16&65520)+k|0;b=(((((((D(v[g-2|0],w[b+2>>1])+D(v[g-3|0],w[b>>1])|0)+D(v[g-1|0],w[b+4>>1])|0)+D(v[g|0],w[b+6>>1])|0)+D(v[g+1|0],w[b+8>>1])|0)+D(v[g+2|0],w[b+10>>1])|0)+D(v[g+3|0],w[b+12>>1])|0)+D(v[g+4|0],w[b+14>>1])<<8)/32768|0;j=j+n|0;x[c>>2]=x[c>>2]+D(b,j>>12);i=i+m|0;x[c+4>>2]=x[c+4>>2]+D(b,i>>12);Pb(e+8|0,h,f);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+24>>2]=i>>12;fb=e+16|0}function fC(a,b,c){var d=0,e=0;b=b-a>>5;while(1){if((b|0)>0){d=y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24);e=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);v[a|0]=e;v[a+1|0]=e>>>8;v[a+2|0]=e>>>16;v[a+3|0]=e>>>24;v[a+4|0]=d;v[a+5|0]=d>>>8;v[a+6|0]=d>>>16;v[a+7|0]=d>>>24;d=y[c+28|0]|y[c+29|0]<<8|(y[c+30|0]<<16|y[c+31|0]<<24);e=y[c+24|0]|y[c+25|0]<<8|(y[c+26|0]<<16|y[c+27|0]<<24);v[a+24|0]=e;v[a+25|0]=e>>>8;v[a+26|0]=e>>>16;v[a+27|0]=e>>>24;v[a+28|0]=d;v[a+29|0]=d>>>8;v[a+30|0]=d>>>16;v[a+31|0]=d>>>24;d=y[c+20|0]|y[c+21|0]<<8|(y[c+22|0]<<16|y[c+23|0]<<24);e=y[c+16|0]|y[c+17|0]<<8|(y[c+18|0]<<16|y[c+19|0]<<24);v[a+16|0]=e;v[a+17|0]=e>>>8;v[a+18|0]=e>>>16;v[a+19|0]=e>>>24;v[a+20|0]=d;v[a+21|0]=d>>>8;v[a+22|0]=d>>>16;v[a+23|0]=d>>>24;d=y[c+12|0]|y[c+13|0]<<8|(y[c+14|0]<<16|y[c+15|0]<<24);e=y[c+8|0]|y[c+9|0]<<8|(y[c+10|0]<<16|y[c+11|0]<<24);v[a+8|0]=e;v[a+9|0]=e>>>8;v[a+10|0]=e>>>16;v[a+11|0]=e>>>24;v[a+12|0]=d;v[a+13|0]=d>>>8;v[a+14|0]=d>>>16;v[a+15|0]=d>>>24;b=b-1|0;a=a+32|0;continue}break}}function jua(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=fb-32|0;fb=g;i=a+8|0;c=x[a+8>>2];h=nc(a);a:{if((c|0)!=x[h>>2]){break a}k=a+4|0;d=x[a+4>>2];e=x[a>>2];if(d>>>0>e>>>0){f=fb-16|0;fb=f;l=f+8|0;a=fb-32|0;fb=a;Id(a+24|0,d,c);m=a+16|0;c=x[a+24>>2];h=x[a+28>>2];j=((d-e>>1)+1|0)/-2<<1;d=d+j|0;e=fb-16|0;fb=e;while(1){if((c|0)!=(h|0)){d=h0(d,c)+2|0;c=c+2|0;continue}break}x[e+12>>2]=d;Ac(m,h,e+12|0);fb=e+16|0;c=x[a+16>>2];x[a+12>>2]=x[a+20>>2];Ac(l,c,a+12|0);fb=a+32|0;fb=f+16|0;c=x[f+12>>2];x[i>>2]=c;x[k>>2]=x[k>>2]+j;break a}x[g+8>>2]=c-e;x[g+28>>2]=1;d=g+8|0;c=x[ad(d,g+28|0)>>2];c=kk(d,c,c>>>2|0,x[a+16>>2]);d=vb(g+4|0,x[a+4>>2]);e=x[vb(g,x[a+8>>2])>>2];f=fb-16|0;fb=f;d=x[d>>2];x[f+12>>2]=d;e=Gp(f,c+8|0,nE(d,e));d=x[e>>2];while(1){if(x[e+4>>2]!=(d|0)){j=d;d=x[f+12>>2];hj(j,y[d|0]|y[d+1|0]<<8);d=x[e>>2]+2|0;x[e>>2]=d;Md(f+12|0);continue}break}he(e);fb=f+16|0;Tb(a,c);Tb(k,c+4|0);Tb(i,c+8|0);Tb(h,nc(c));jj(c);c=x[a+8>>2]}hj(c,y[b|0]|y[b+1|0]<<8);x[i>>2]=x[i>>2]+2;fb=g+32|0}function ora(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=Jv(c,d);d=b&63;if(e>>>0>d>>>0){c=gZ(c,d);d=0;g=fb-16|0;fb=g;v[a+12|0]=0;Nf(a);e=fb-32|0;fb=e;a:{b:{if(Ug(a)>>>0<=14){if(th(1073741823)>>>0<=14){break b}f=zb(a);f=$f(e+12|0,15,oc(x[a>>2],x[a+4>>2]),f);bs(a,f);_f(f)}fb=e+32|0;break a}dd();p()}h=0-y[c+1|0]|0;while(1){c:{if((d|0)==15){break c}e=c+(d<<1)|0;f=y[e+1|0];if(!f){break c}v[g+11|0]=64;h=f+(h<<16>>16)|0;f=em(g+12|0,h&65535,y[Qb(e+2|0,g+11|0)|0]);d:{if(A[a+4>>2]<A[zb(a)>>2]){cZ(a,f);break d}i=fb-32|0;fb=i;e=zb(a);e=$f(i+12|0,Mf(a,oc(x[a>>2],x[a+4>>2])+1|0),oc(x[a>>2],x[a+4>>2]),e);gp(x[e+8>>2],z[f>>1]|z[f+2>>1]<<16);x[e+8>>2]=x[e+8>>2]+4;bs(a,e);_f(e);fb=i+32|0}d=d+1|0;continue}break}d=y[c+32|0];v[a+14|0]=d>>>4;v[a+13|0]=d&15;c=y[c+31|0];d=c&15;v[a+15|0]=d;v[a+16|0]=d;if(c&16){v[a+12|0]=y[a+12|0]|4}if(c&32){v[a+12|0]=y[a+12|0]|2}fb=g+16|0}e:{f:{if(b<<24>>24>=0){b=a+12|0;break f}b=a+12|0;if(mc(x[a>>2],x[a+4>>2])){break f}a=y[a+12|0]|1;break e}a=y[b|0]&-2}v[b|0]=a}function Qma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0;g=fb-16|0;fb=g;f=x[a+48>>2];o=x[a+24>>2];p=x[a+20>>2];e=x[a+44>>2];q=x[a+16>>2];b=x[a+4>>2];x[g+8>>2]=x[a>>2];x[g+12>>2]=b;r=x[a+72>>2];l=x[a+68>>2];s=l>>31;m=x[a+64>>2];t=m>>31;n=x[a+60>>2];u=n>>31;v=x[a+8>>2];y=x[a+12>>2];while(1){b=e;if(d){e=Yb(e,-16777216,16776704);i=Sua(m,t,e,e>>31);j=hb;e=x[g+8>>2];h=(x[g+12>>2]<<1)+q|0;e=e>>>21&2040;h=(((D(w[h>>1],w[e+38194>>1])+D(w[h-2>>1],w[e+38192>>1])|0)+D(w[h+2>>1],w[e+38196>>1])|0)+D(w[h+4>>1],w[e+38198>>1])|0)/16384<<8;e=h;e=Sua(e,e>>31,n,u);i=e+i|0;k=hb+j|0;k=e>>>0>i>>>0?k+1|0:k;f=Yb(f,-16777216,16776704);e=Sua(l,s,f,f>>31);j=e+i|0;f=hb+k|0;f=e>>>0>j>>>0?f+1|0:f;e=j+8388608|0;f=e>>>0<8388608?f+1|0:f;e=Rc(e,f,24);f=(e|0)/256|0;x[c>>2]=D(f,p)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(f,o);Pb(g+8|0,v,y);e=e-(h&r)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=x[g+12>>2];x[a>>2]=x[g+8>>2];x[a+4>>2]=c;x[a+48>>2]=f;x[a+44>>2]=b;fb=g+16|0}function CD(a,b,c){var d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;v[d+15|0]=c;e=a;a:{b:{c:{switch(b-14|0){case 0:b=14;if(!c){break b}d:{if((c|0)!=15){if((c|0)!=240){break d}v[d+15|0]=239;break b}v[d+15|0]=254;break b}if(c>>>0>=16){v[d+15|0]=c|15;break b}v[d+15|0]=c|240;break b;case 1:v[d+15|0]=c^128;b=15;break b;case 6:case 7:if(c>>>0>=16){v[d+15|0]=c>>>4|240;break b}v[d+15|0]=c|224;break b;case 8:v[d+15|0]=((c^-1)&254)>>>1;b=22;break b;case 9:v[d+15|0]=c&15|128;b=23;break b;case 17:f=d,g=Ch(c<<1),v[f+15|0]=g;b=31;break b;case 19:a=32;b=33;e:{f:{switch(c>>>4|0){default:b=0;break b;case 8:a=64;break e;case 10:a=176;break e;case 11:a=224;break e;case 12:case 13:b=c?33:0;break b;case 14:g:{switch(c&15){case 0:v[d+15|0]=119;break b;case 1:v[d+15|0]=119;break b;case 2:v[d+15|0]=121;break b;case 3:break g;default:break b}}v[d+15|0]=123;break b;case 3:break e;case 5:break f;case 0:break b}}a=48}v[d+15|0]=c&15|a;break b;default:break c}}a=0;if(b>>>0>35){break a}}a=y[b+25024|0]}de(e,a,d+15|0);fb=d+16|0}function pta(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;f=fb-288|0;fb=f;sf(b);a:{if(!Mb(x[a>>2],x[a+8>>2],1)){break a}while(1){j=f+32|0;d=j;wo(f+8|0,d,xr(d));lc(f+20|0,x[a>>2],x[a+8>>2],x[f+8>>2],x[f+12>>2]);x[f+28>>2]=x[f+24>>2];o=f,q=c-Yc(x[b+4>>2],y[b+11|0])|0,x[o+4>>2]=q;d=x[Gb(f+28|0,f+4|0)>>2];if(!d){break a}m=d+j|0;k=Li(j,m,0);d=vb(f,Df(b));l=fb-16|0;fb=l;h=Fk(x[d>>2],zd(b));b:{c:{d=j;e=Vj(d,k);d:{if(!e){zd(b);break d}if(!Lz(b,d)){i=Cb(x[b+4>>2],y[b+11|0]);g=Mc(b);e:{if(e>>>0<=g-i>>>0){g=Jb(b);if((h|0)==(i|0)){break e}n=h+g|0;Ui(e+n|0,n,i-h|0);break e}Wm(b,g,(e+i|0)-g|0,i,h,0,e);g=x[b>>2]}e=e+i|0;ng(b,e);fd(e+g|0,0);e=h+g|0;while(1){if((d|0)!=(k|0)){fd(e,y[d|0]);d=d+1|0;e=e+1|0;continue}break}uf(zd(b),h);break d}d=si(l+4|0,d,k);i=zd(d);g=Df(d);x[31737]=0;ha(365,b|0,e|0,h|0,i|0,g|0)|0;h=x[31737];x[31737]=0;if((h|0)==1){break c}tb(d)}fb=l+16|0;break b}a=N()|0;tb(d);Q(a|0);p()}Vb(a,k-j|0);if(k>>>0>=m>>>0){continue}break}Vb(a,1)}fb=f+288|0}function qua(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=fb-144|0;fb=f;x[31737]=0;l=R(274,a|0)|0;e=x[31737];x[31737]=0;if((e|0)!=1){while(1){a:{if((j&65535)>>>0>=l>>>0){ub(a);fb=f+144|0;return}x[31737]=0;O(293,a|0,f+8|0);e=x[31737];x[31737]=0;if((e|0)!=1){b:{e=Bb(z[f+8>>1]);if((e-1&65535)>>>0>=z[c+480192>>1]){break b}e=x[((e<<2)+c|0)+900380>>2];if(!e){break b}e=Zh(e,b);g=y[f+11|0];c:{if(!g){break c}h=y[f+10|0];if(h&1){v[e+12|0]=y[e+12|0]|1}if(h&2){v[e+12|0]=y[e+12|0]|4}if(!(h&4)){break c}v[e+12|0]=y[e+12|0]|2}v[f+4|0]=g;v[f+7|0]=31;h=y[Qb(f+4|0,f+7|0)|0];x[31737]=0;h=h+1&255;O(294,e|0,h|0);g=x[31737];x[31737]=0;if((g|0)==1){break a}v[e+13|0]=y[f+13|0];v[e+14|0]=y[f+14|0];g=y[f+12|0];v[e+15|0]=g;v[e+16|0]=g;g=x[e>>2];e=0;while(1){if((e|0)==(h|0)){break b}i=(f+8|0)+(e<<2)|0;m=Bb(z[i+8>>1]);k=yb(g,e);w[k>>1]=m;i=Bb(z[i+10>>1]);w[f+4>>1]=d?i+128>>>2|0:i;Gf(f+4|0,64);v[k+2|0]=y[f+4|0];e=e+1|0;continue}}j=j+1|0;continue}}break}}b=N()|0;ub(a);Q(b|0);p()}function sba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if(A[a+4>>2]<A[zb(a)>>2]){d=fb-16|0;fb=d;c=d+4|0;x[c>>2]=a;a=x[a+4>>2];x[c+4>>2]=a;x[c+8>>2]=a+24;iN(x[c+4>>2],b);x[c+4>>2]=x[c+4>>2]+24;hc(c);fb=d+16|0;return}i=fb-32|0;fb=i;c=zb(a);c=SJ(i+12|0,YJ(a,oj(x[a>>2],x[a+4>>2])+1|0),oj(x[a>>2],x[a+4>>2]),c);iN(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+24;g=fb-16|0;fb=g;d=vb(g+12|0,x[a+4>>2]);e=vb(g+8|0,x[a>>2]);f=x[vb(g+4|0,x[c+4>>2])>>2];h=fb-16|0;fb=h;b=fb-32|0;fb=b;Id(b+24|0,x[d>>2],x[e>>2]);k=b+16|0;e=x[b+24>>2];l=x[b+28>>2];d=fb-16|0;fb=d;x[d+8>>2]=f;x[d+12>>2]=e;while(1){if(pd(e,l)){e=ol(e);f=ol(x[d+8>>2]);x[f+16>>2]=x[e+16>>2];j=x[e+12>>2];x[f+8>>2]=x[e+8>>2];x[f+12>>2]=j;j=x[e+4>>2];x[f>>2]=x[e>>2];x[f+4>>2]=j;e=$s(d+12|0);$s(d+8|0);e=x[e>>2];continue}break}Ac(k,e,d+8|0);fb=d+16|0;d=x[b+16>>2];x[b+12>>2]=x[b+20>>2];Ac(h+8|0,d,b+12|0);fb=b+32|0;fb=h+16|0;x[c+4>>2]=x[h+12>>2];Tb(a,c+4|0);Tb(a+4|0,c+8|0);Tb(zb(a),nc(c));x[c>>2]=x[c+4>>2];fb=g+16|0;NJ(c);fb=i+32|0}function Sma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0;h=fb-16|0;fb=h;e=x[a+48>>2];n=x[a+24>>2];o=x[a+20>>2];f=x[a+44>>2];p=x[a+16>>2];b=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=b;q=x[a+72>>2];j=x[a+68>>2];r=j>>31;k=x[a+64>>2];s=k>>31;l=x[a+60>>2];t=l>>31;u=x[a+8>>2];y=x[a+12>>2];while(1){b=f;if(d){f=Yb(f,-16777216,16776704);g=Sua(k,s,f,f>>31);f=hb;e=Yb(e,-16777216,16776704);e=Sua(j,r,e,e>>31);g=e+g|0;f=hb+f|0;f=e>>>0>g>>>0?f+1|0:f;e=x[h+8>>2];i=g;g=x[h+12>>2]+p|0;e=e>>>21&2040;m=(((D(v[g|0],w[e+38194>>1])+D(v[g-1|0],w[e+38192>>1])|0)+D(v[g+1|0],w[e+38196>>1])|0)+D(v[g+2|0],w[e+38198>>1])<<8)/16384<<8;e=m;g=Sua(e,e>>31,l,t);i=i+g|0;e=hb+f|0;e=g>>>0>i>>>0?e+1|0:e;f=i+8388608|0;e=f>>>0<8388608?e+1|0:e;f=Rc(f,e,24);e=(f|0)/256|0;x[c>>2]=D(e,o)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(e,n);Pb(h+8|0,u,y);f=f-(q&m)|0;c=c+8|0;d=d-1|0;e=b;continue}break}c=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=c;x[a+48>>2]=e;x[a+44>>2]=b;fb=h+16|0}function mma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0;e=fb-16|0;fb=e;g=x[a+40>>2];h=x[a+36>>2];k=x[a+16>>2];j=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=j;l=b+24|0;m=x[a+32>>2];n=x[a+28>>2];j=x[a+8>>2];o=x[a+12>>2];while(1){if(d){b=x[e+8>>2];p=((((x[e+12>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+k|0;b=(((b>>>16|0)+4&131064)<<1)+l|0;q=w[b+14>>1];r=w[b+12>>1];s=w[b+10>>1];t=w[b+8>>1];u=w[b+6>>1];v=w[b+4>>1];y=w[b+2>>1];b=w[b>>1];i=0;while(1){if((i|0)!=2){f=(i<<1)+p|0;x[(i<<2)+e>>2]=(((((D(w[f+8>>1],s)+D(w[f+4>>1],t)|0)+D(w[f+12>>1],r)|0)+D(w[f+16>>1],q)|0)/2|0)+((((D(w[f-8>>1],y)+D(w[f-12>>1],b)|0)+D(w[f-4>>1],v)|0)+D(w[f>>1],u)|0)/2|0)|0)/16384;i=i+1|0;continue}break}h=h+n|0;x[c>>2]=x[c>>2]+D(x[e>>2],h>>12);g=g+m|0;x[c+4>>2]=x[c+4>>2]+D(x[e+4>>2],g>>12);Pb(e+8|0,j,o);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;x[a+40>>2]=g;x[a+20>>2]=h>>12;x[a+36>>2]=h;x[a+24>>2]=g>>12;fb=e+16|0}function y8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=fb-32|0;fb=g;x[g+28>>2]=b;a:{b:{if(!(v[d+4|0]&1)){x[g>>2]=-1;b=ib[x[x[a>>2]+16>>2]](a,b,c,d,e,g)|0;c:{switch(x[g>>2]){case 1:v[f|0]=1;break a;case 0:break b;default:break c}}v[f|0]=1;x[e>>2]=4;break a}bd(g,x[d+28>>2]);x[31737]=0;b=R(1211,x[g>>2])|0;a=x[31737];x[31737]=0;d:{e:{f:{g:{if((a|0)!=1){Zb(g);bd(g,x[d+28>>2]);x[31737]=0;a=R(1212,x[g>>2])|0;d=x[31737];x[31737]=0;if((d|0)==1){break g}Zb(g);x[31737]=0;O(1213,g|0,a|0);d=x[31737];x[31737]=0;if((d|0)==1){b=N()|0;break d}x[31737]=0;O(1214,g|12,a|0);a=x[31737];x[31737]=0;if((a|0)==1){break f}x[31737]=0;d=g+24|0;a=sa(1215,g+28|0,c|0,g|0,d|0,b|0,e|0,1)|0;b=x[31737];x[31737]=0;if((b|0)==1){break e}v[f|0]=(a|0)==(g|0);b=x[g+28>>2];while(1){d=Ub(d-12|0);if((g|0)!=(d|0)){continue}break}break a}b=N()|0;Zb(g);break d}b=N()|0;Zb(g);break d}b=N()|0;Ub(g);break d}b=N()|0;while(1){d=Ub(d-12|0);if((g|0)!=(d|0)){continue}break}}Q(b|0);p()}v[f|0]=0}fb=g+32|0;return b|0}function J8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=fb-32|0;fb=g;x[g+28>>2]=b;a:{b:{if(!(v[d+4|0]&1)){x[g>>2]=-1;b=ib[x[x[a>>2]+16>>2]](a,b,c,d,e,g)|0;c:{switch(x[g>>2]){case 1:v[f|0]=1;break a;case 0:break b;default:break c}}v[f|0]=1;x[e>>2]=4;break a}bd(g,x[d+28>>2]);x[31737]=0;b=R(28,x[g>>2])|0;a=x[31737];x[31737]=0;d:{e:{f:{g:{if((a|0)!=1){Zb(g);bd(g,x[d+28>>2]);x[31737]=0;a=R(1195,x[g>>2])|0;d=x[31737];x[31737]=0;if((d|0)==1){break g}Zb(g);x[31737]=0;O(1196,g|0,a|0);d=x[31737];x[31737]=0;if((d|0)==1){b=N()|0;break d}x[31737]=0;O(1197,g|12,a|0);a=x[31737];x[31737]=0;if((a|0)==1){break f}x[31737]=0;d=g+24|0;a=sa(1198,g+28|0,c|0,g|0,d|0,b|0,e|0,1)|0;b=x[31737];x[31737]=0;if((b|0)==1){break e}v[f|0]=(a|0)==(g|0);b=x[g+28>>2];while(1){d=tb(d-12|0);if((g|0)!=(d|0)){continue}break}break a}b=N()|0;Zb(g);break d}b=N()|0;Zb(g);break d}b=N()|0;tb(g);break d}b=N()|0;while(1){d=tb(d-12|0);if((g|0)!=(d|0)){continue}break}}Q(b|0);p()}v[f|0]=0}fb=g+32|0;return b|0}function wk(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0;i=fb-16|0;fb=i;x[i+8>>2]=c;x[i+12>>2]=b;b=i+4|0;bd(b,x[d+28>>2]);c=0;x[31737]=0;j=R(28,x[i+4>>2])|0;k=x[31737];x[31737]=0;if((k|0)!=1){Zb(b);x[e>>2]=0;a:{while(1){if((g|0)==(h|0)|c){break a}b:{if(sh(i+12|0,i+8|0)){break b}c:{if((rl(j,v[g|0])|0)==37){if((g+1|0)==(h|0)){break b}c=rl(j,v[g+1|0]);d:{if(!((c|0)==69|(c&255)==48)){b=0;k=1;break d}if((g+2|0)==(h|0)){break b}b=c;c=rl(j,v[g+2|0]);k=2}l=i,m=ib[x[x[a>>2]+36>>2]](a,x[i+12>>2],x[i+8>>2],d,e,f,c,b)|0,x[l+12>>2]=m;g=(g+k|0)+1|0;break c}b=x[j+8>>2];if(Jf(b,1,v[g|0])){while(1){e:{g=g+1|0;if((h|0)==(g|0)){g=h;break e}if(Jf(b,1,v[g|0])){continue}}break}while(1){b=i+12|0;if(sh(b,i+8|0)){break c}c=Al(x[i+12>>2]);if(!Jf(x[j+8>>2],1,c)){break c}Km(b);continue}}if((yy(j,Al(x[i+12>>2]))|0)==(yy(j,v[g|0])|0)){g=g+1|0;Km(i+12|0);break c}x[e>>2]=4}c=x[e>>2];continue}break}x[e>>2]=4}if(sh(i+12|0,i+8|0)){x[e>>2]=x[e>>2]|2}fb=i+16|0;return x[i+12>>2]}a=N()|0;Zb(i+4|0);Q(a|0);p()}function Xaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c=fb+-64|0;fb=c;f=x[a>>2];a=x[f>>2];g=x[a+4>>2];x[c+40>>2]=x[a+20>>2];d=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=d;Zf(c+48|0,c+32|0,g);a=x[f+4>>2];f=x[a+8>>2];g=x[a+4>>2];d=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=d;d=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=d;x[c+8>>2]=x[a+8>>2];d=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=d;a:{b:{c:{d:{d=x[c+4>>2];if(g>>>0<=d>>>0){if(g>>>0>A[c+20>>2]){break d}if(f>>>0>A[c+8>>2]){break c}h=x[c+28>>2];if(f>>>0>x[c+24>>2]-h>>>0){break b}i=b+12|0;j=x[c+16>>2];k=x[c>>2];b=0;e:while(1){if((b|0)==(f|0)){break a}l=(D(b,d)<<2)+k|0;a=0;while(1)if((a|0)==(g|0)){b=b+1|0;continue e}else{e=a<<2;m=x[e+l>>2];n=Wt(i);o=(x[e+j>>2]+(h<<1)|0)+(b<<1)|0;e=qd((qd(n,21)+m|0)+2048|0,12);e=(e|0)>=32767?32767:e;w[o>>1]=(e|0)<=-32768?-32768:e;a=a+1|0;continue}}}_(7244,9061,33,8774);p()}_(7209,9061,34,8774);p()}_(5897,9061,35,8774);p()}_(5867,9061,36,8774);p()}fb=c- -64|0}function Lla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;g=fb-16|0;fb=g;x[g+12>>2]=1;a:{if(ap(a)){c=x[a>>2];k=Lg(c,x[a+4>>2]);x[g+8>>2]=k;l=x[Gb(g+12|0,g+8|0)>>2];while(1){if(l){l=l-1|0;if((b|0)!=(c|0)){i=wb(x[b>>2]);e=wb(x[b+4>>2]);f=fb-16|0;fb=f;h=nE(i,e);b:{if(h>>>0<=Nn(c)>>>0){x[f+12>>2]=e;m=x[c>>2];d=Zc(m,x[c+4>>2]);n=d>>>0>=h>>>0;if(n){d=e}else{x[f+12>>2]=i;eV(f+12|0,d);d=x[f+12>>2]}j=fb-16|0;fb=j;gV(j+8|0,i,d,m);d=x[j+12>>2];fb=j+16|0;if(!n){iV(c,x[f+12>>2],e,h-Zc(x[c>>2],x[c+4>>2])|0);break b}In(c,d);break b}hV(c);GC(c,lk(c,h));iV(c,i,e,h)}fb=f+16|0;us(c+12|0,b+12|0);w[c+28>>1]=z[b+28>>1]}c=c+32|0;continue}break}if(!k){YB(a,1-k|0,b);break a}_U(a,x[a>>2]+32|0);break a}if(x[a>>2]){aV(a);e=x[a>>2];ap(a);Db(e);o=zb(a),q=0,x[o>>2]=q;x[a>>2]=0;x[a+4>>2]=0}d=_q(a,1);e=fb-16|0;fb=e;if(th(134217727)>>>0<d>>>0){dd();p()}TV(e+8|0,d);d=x[e+8>>2];x[a+4>>2]=d;x[a>>2]=d;o=zb(a),q=d+(x[e+12>>2]<<5)|0,x[o>>2]=q;fb=e+16|0;YB(a,1,b)}fb=g+16|0}function yx(a,b,c,d){var e=0,f=0,g=0,h=0;g=fb-32|0;fb=g;e=d&2147483647;h=e;f=e-1006698496|0;e=e-1140785152|0;a:{if((f|0)==(e|0)&0|e>>>0>f>>>0){e=c<<4|b>>>28;c=d<<4|c>>>28;b=b&268435455;if((b|0)==134217728&(a|0)!=0|b>>>0>134217728){f=c+1073741824|0;e=e+1|0;f=e?f:f+1|0;break a}f=c+1073741824|0;if(a|(b|0)!=134217728){break a}a=e&1;e=a+e|0;f=a>>>0>e>>>0?f+1|0:f;break a}if(!(!c&(h|0)==2147418112?!(a|b):h>>>0<2147418112)){a=d<<4|c>>>28;e=c<<4|b>>>28;f=a&524287|2146959360;break a}e=0;f=2146435072;if(h>>>0>1140785151){break a}f=0;h=h>>>16|0;if(h>>>0<15249){break a}e=d&65535|65536;bg(g+16|0,a,b,c,e,h-15233|0);gn(g,a,b,c,e,15361-h|0);b=x[g+8>>2];e=b<<4;b=x[g+12>>2]<<4|b>>>28;c=x[g>>2];f=x[g+4>>2];h=f;e=f>>>28|e;f=b;a=h&268435455;b=c|(x[g+16>>2]|x[g+24>>2]|(x[g+20>>2]|x[g+28>>2]))!=0;if((a|0)==134217728&(b|0)!=0|a>>>0>134217728){e=e+1|0;f=e?f:f+1|0;break a}if(b|(a|0)!=134217728){break a}a=e;e=e+(e&1)|0;f=a>>>0>e>>>0?f+1|0:f}fb=g+32|0;l(0,e|0);l(1,d&-2147483648|f);return+n()}function IH(a,b,c){var d=0,e=0,f=0;e=fb-32|0;fb=e;a:{f=Ts(e+28|0,b);d=x[f>>2];if(!Dd(d)){x[31737]=0;b=P(36,e+4|0,b|0)|0;a=x[31737];x[31737]=0;b:{c:{d:{if((a|0)!=1){x[31737]=0;a=e+16|0;S(1017,a|0,17727,b|0);c=x[31737];x[31737]=0;if((c|0)==1){break d}x[31737]=0;W(1325,a|0);a=x[31737];x[31737]=0;if((a|0)==1){break c}p()}a=N()|0;break a}a=N()|0;break b}a=N()|0;tb(e+16|0)}tb(b);break a}iq(d);if(!Ss(a+8|0,22303,x[f>>2])){v[a+8|0]=127}if(!Ss(a+9|0,22303,x[f>>2])){v[a+9|0]=127}x[31737]=0;O(273,a+12|0,22303);b=x[31737];x[31737]=0;e:{f:{if((b|0)==1){break f}x[31737]=0;b=a+24|0;O(273,b|0,22303);d=x[31737];x[31737]=0;if((d|0)==1){break f}x[a+60>>2]=0;x[31737]=0;O(273,a+36|0,22303);d=x[31737];x[31737]=0;if((d|0)==1){break f}x[31737]=0;O(273,a+48|0,22303);d=x[31737];x[31737]=0;if((d|0)==1){break f}x[31737]=0;b=P(71,e+16|0,b|0)|0;d=x[31737];x[31737]=0;if((d|0)!=1){break e}a=N()|0;break a}a=N()|0;break a}hi(a- -64|0,c);hi(a+68|0,c);tb(b);nl(f);fb=e+32|0;return}nl(f);Q(a|0);p()}function Hf(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=fb-32|0;fb=d;c=x[a+36>>2];kg(x[x[c>>2]-12>>2]+c|0,0);c=a+32|0;Pc(d+12|0,c,4);if(!Hb(x[x[d+12>>2]>>2],x[d+16>>2])){oy(a)}a:{if(!x[a+8>>2]){break a}Pc(d+12|0,c,6);if(Hb(x[x[d+12>>2]>>2],x[d+16>>2])){break a}Pc(d+24|0,c,7);if(Hb(x[x[d+24>>2]>>2],x[d+28>>2])){break a}f=x[a+36>>2];e=x[a+92>>2];g=D(x[a+28>>2],x[a+8>>2]);h=g;g=g+x[a+88>>2]|0;e=h>>>0>g>>>0?e+1|0:e;Hi(f,g,e,0)}Pc(d+12|0,c,5);c=0;b:{if(!Hb(x[x[d+12>>2]>>2],x[d+16>>2])){break b}e=oj(x[a+52>>2],x[a+56>>2]);while(1){if((e|0)==(i|0)){break b}c:{g=(x[a+108>>2]+i>>>0)%(e>>>0)|0;f=wf(x[a+52>>2],g);h=x[f>>2];j=x[a+40>>2];if(h>>>0>=Vc(j,x[a+44>>2])>>>0){break c}f=yl(d+12|0,xb(j,h),z[f+20>>1]);h=Gy(b,f);Eb(f);if(!h){break c}b=g+1|0;x[a+108>>2]=(b|0)!=(e|0)?b:0;c=wf(x[a+52>>2],g);b=x[c+8>>2];e=x[c+12>>2];if(!(b|e)){break b}f=x[a+16>>2];c=f+b|0;b=x[a+20>>2]+e|0;Hi(x[a+36>>2],c,c>>>0<f>>>0?b+1|0:b,0);c=wf(x[a+52>>2],g);break b}i=i+1|0;continue}}fb=d+32|0;return c}function oq(a,b,c,d,e,f){var g=E(0),h=0,i=E(0),j=0,k=E(0),l=E(0);c=(c<<2)+b|0;d=c+(d<<2)|0;a=a>>2;b=f<<2;while(1){if((a|0)>0){f=d-4|0;i=B[f>>2];k=B[c>>2];l=B[d>>2];B[c>>2]=k+l;h=c-4|0;g=B[h>>2];B[h>>2]=g+B[f>>2];k=E(k-l);g=E(g-i);B[d>>2]=E(k*B[e>>2])-E(B[e+4>>2]*g);B[f>>2]=E(g*B[e>>2])+E(k*B[e+4>>2]);f=d-12|0;k=B[f>>2];h=c-8|0;g=B[h>>2];j=h;h=d-8|0;l=B[h>>2];B[j>>2]=g+l;j=c-12|0;i=B[j>>2];B[j>>2]=i+B[f>>2];g=E(g-l);e=b+e|0;i=E(i-k);B[h>>2]=E(g*B[e>>2])-E(B[e+4>>2]*i);B[f>>2]=E(i*B[e>>2])+E(g*B[e+4>>2]);f=d-20|0;k=B[f>>2];h=c-16|0;g=B[h>>2];j=h;h=d-16|0;l=B[h>>2];B[j>>2]=g+l;j=c-20|0;i=B[j>>2];B[j>>2]=i+B[f>>2];g=E(g-l);e=b+e|0;i=E(i-k);B[h>>2]=E(g*B[e>>2])-E(B[e+4>>2]*i);B[f>>2]=E(i*B[e>>2])+E(g*B[e+4>>2]);f=d-28|0;k=B[f>>2];h=c-24|0;g=B[h>>2];j=h;h=d-24|0;l=B[h>>2];B[j>>2]=g+l;j=c-28|0;i=B[j>>2];B[j>>2]=i+B[f>>2];g=E(g-l);e=b+e|0;i=E(i-k);B[h>>2]=E(g*B[e>>2])-E(B[e+4>>2]*i);B[f>>2]=E(i*B[e>>2])+E(g*B[e+4>>2]);e=b+e|0;a=a-1|0;d=d-32|0;c=c-32|0;continue}break}}function Di(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=xj(a)&2047;c=xj(5551115123125783e-32);a:{if(f-c>>>0>=xj(512)-c>>>0){if(c>>>0>f>>>0){return a+1}o(+a);c=j(1)|0;e=j(0)|0;b:{if(xj(1024)>>>0>f>>>0){break b}b=0;if(!e&(c|0)==-1048576){break a}if(xj(Infinity)>>>0<=f>>>0){return a+1}if((c|0)>0|(c|0)>=0){return Qs(3105036184601418e216)}if(c>>>0<3230714880){break b}return Qs(12882297539194267e-247)}c=c<<1|e>>>31;f=!(e<<1)&(c|0)==-2129002496|c>>>0<2165964800?f:0}b=C[177];g=b+a;a=a-(g-b);b=a*a;h=b*b*(a*C[182]+C[181]);b=b*(a*C[180]+C[179]);a=a*C[178];o(+g);j(1)|0;c=j(0)|0;d=c<<4&2032;a=h+(b+(a+C[d+1464>>3]));d=d+1472|0;e=0+x[d>>2]|0;d=x[d+4>>2]+(c<<13)|0;d=e>>>0<i>>>0?d+1|0:d;if(!f){c:{if(!(c&-2147483648)){l(0,e|0);l(1,d+-1048576|0);b=+n();a=b*a+b;a=a+a;break c}l(0,e|0);l(1,d+1071644672|0);b=+n();g=b*a;a=g+b;if(a<1){KJ(kK()*22250738585072014e-324);h=a+1;a=h+(g+(b-a)+(a+(1-h)))+-1;a=a==0?0:a}a=a*22250738585072014e-324}return a}l(0,e|0);l(1,d|0);b=+n();b=b*a+b}return b}function Oaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;c=fb+-64|0;fb=c;e=x[a>>2];a=x[e>>2];f=x[a+4>>2];x[c+40>>2]=x[a+20>>2];d=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=d;Zf(c+48|0,c+32|0,f);a=x[e+4>>2];e=x[a+8>>2];f=x[a+4>>2];d=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=d;d=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=d;x[c+8>>2]=x[a+8>>2];d=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=d;a:{b:{c:{d:{d=x[c+4>>2];if(f>>>0<=d>>>0){h=x[c+20>>2];if(f>>>0>h>>>0){break d}if(e>>>0>A[c+8>>2]){break c}i=x[c+28>>2];if(e>>>0>x[c+24>>2]-i>>>0){break b}j=b+12|0;k=x[c+16>>2];l=x[c>>2];b=0;e:while(1){if((b|0)==(e|0)){break a}m=(D(b,d)<<2)+l|0;n=(D(b+i|0,h)<<1)+k|0;a=0;while(1)if((a|0)==(f|0)){b=b+1|0;continue e}else{g=qd((x[(a<<2)+m>>2]+qd(Wt(j),21)|0)+2048|0,12);g=(g|0)>=32767?32767:g;w[(a<<1)+n>>1]=(g|0)<=-32768?-32768:g;a=a+1|0;continue}}}_(7244,9061,33,8774);p()}_(7209,9061,34,8774);p()}_(5897,9061,35,8774);p()}_(5867,9061,36,8774);p()}fb=c- -64|0}function vk(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0;i=fb-16|0;fb=i;x[i+8>>2]=c;x[i+12>>2]=b;c=i+4|0;bd(c,x[d+28>>2]);b=0;x[31737]=0;j=R(1211,x[i+4>>2])|0;k=x[31737];x[31737]=0;if((k|0)!=1){Zb(c);x[e>>2]=0;a:{while(1){if((g|0)==(h|0)|b){break a}b:{if(li(i+12|0,i+8|0)){break b}c:{if((uk(j,x[g>>2])|0)==37){if((g+4|0)==(h|0)){break b}b=uk(j,x[g+4>>2]);d:{if(!((b|0)==69|(b&255)==48)){c=0;k=1;break d}if((g+8|0)==(h|0)){break b}c=b;b=uk(j,x[g+8>>2]);k=2}l=i,m=ib[x[x[a>>2]+36>>2]](a,x[i+12>>2],x[i+8>>2],d,e,f,b,c)|0,x[l+12>>2]=m;g=((k<<2)+g|0)+4|0;break c}if(yj(j,1,x[g>>2])){while(1){e:{g=g+4|0;if((h|0)==(g|0)){g=h;break e}if(yj(j,1,x[g>>2])){continue}}break}while(1){b=i+12|0;if(li(b,i+8|0)){break c}if(!yj(j,1,zl(x[i+12>>2]))){break c}lo(b);continue}}if((rm(j,zl(x[i+12>>2]))|0)==(rm(j,x[g>>2])|0)){g=g+4|0;lo(i+12|0);break c}x[e>>2]=4}b=x[e>>2];continue}break}x[e>>2]=4}if(li(i+12|0,i+8|0)){x[e>>2]=x[e>>2]|2}fb=i+16|0;return x[i+12>>2]}a=N()|0;Zb(i+4|0);Q(a|0);p()}function Pta(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=fb-2608|0;fb=f;d=aE(f+4|0,a);x[d+1060>>2]=0;x[d+1064>>2]=0;e=d+2604|0;a=d+1068|0;while(1){v[a+4|0]=0;w[a>>1]=0;w[a+2>>1]=0;a=a+6|0;if((e|0)!=(a|0)){continue}break}x[31737]=0;W(324,d|0);a=x[31737];x[31737]=0;a:{b:{if((a|0)!=1){if((w[d+1068>>1]|w[d+1070>>1])<0){break a}c:{while(1){if((c|0)==(g|0)){break a}x[31737]=0;j=P(159,d|0,1)|0;a=x[31737];x[31737]=0;if((a|0)==1){break c}a=0;d:{while(1){x[31737]=0;k=P(159,d|0,1)|0;e=x[31737];x[31737]=0;if((e|0)==1){break d}a=w[(d+D(a,6)|0)+(k?1070:1068)>>1];e:{if((a|0)>255){break e}e=d+D(a,6)|0;h=y[e+1072|0];if(w[e+1068>>1]<0){break e}if(w[e+1070>>1]>=0){continue}}break}h=(j?-1:0)^h;i=(i&255)+(h&255)|0;v[b+g|0]=i;g=g+1|0;continue}break}a=T(28896)|0;break b}a=T(28896)|0;break b}a=T(28896)|0}if((gb|0)==($(28896)|0)){Y(a|0)|0;x[31737]=0;X(26);a=x[31737];x[31737]=0;if((a|0)!=1){break a}a=N()|0}ub(d);Q(a|0);p()}a=Gr(d);ub(d);fb=f+2608|0;return a|0}function $z(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=E(0);c=fb-48|0;fb=c;a:{b=x[a+20>>2];b:{if(!b){break b}d=x[b+4>>2];b=x[b+8>>2];if(Vc(d,b)>>>0<4){break b}re(c+16|0,d,b);b=Nd(c+8|0);d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;d=m$(c+28|0,x[c+16>>2],x[c+20>>2],c);x[31737]=0;b=R(152,d|0)|0;f=x[31737];x[31737]=0;c:{if((f|0)!=1){if(b){break c}b=x[x[a>>2]+40>>2];x[31737]=0;f=R(b|0,a|0)|0;b=x[31737];x[31737]=0;if((b|0)==1){break a}b=x[a+20>>2];if(Vc(x[b+4>>2],x[b+8>>2])-4>>>0<f<<2>>>0){break c}e=x[x[a>>2]+176>>2];b=0;x[31737]=0;O(e|0,a|0,-1);e=x[31737];x[31737]=0;if((e|0)==1){break a}while(1){if((b|0)==(f|0)){b=x[x[a>>2]+180>>2];x[31737]=0;W(b|0,a|0);a=x[31737];x[31737]=0;if((a|0)!=1){break c}break a}x[31737]=0;g=E(xa(474,d|0));e=x[31737];x[31737]=0;d:{if((e|0)==1){break d}e=x[x[a>>2]+44>>2];x[31737]=0;wa(e|0,a|0,b|0,E(_m(g)?g:E(0)));e=x[31737];x[31737]=0;if((e|0)==1){break d}b=b+1|0;continue}break}break a}break a}ub(d)}fb=c+48|0;return}a=N()|0;ub(d);Q(a|0);p()}function _la(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=fb-16|0;fb=e;p=x[a+16>>2];q=Fg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);j=x[a+8>>2];k=x[a+12>>2];b=x[a>>2];g=x[a+4>>2];l=x[a+128>>2];if(l){m=Gg(j,k,l);n=hb;f=x[a+76>>2];hg(b,g,vf(j,k,d),hb);o=hb>>>0>f>>>0?d:0}f=a+112|0;h=x[a+40>>2];i=x[a+36>>2];x[e>>2]=b;x[e+4>>2]=g;a:while(1){if(d){d=d-1|0;x[e+8>>2]=b;x[e+12>>2]=0;o=o-1|0;b=o;m=b?m:0;n=b?n:0;g=(g<<1)+p|0;b=l;while(1)if((b|0)<=0){Pb(f,x[a+120>>2],x[a+124>>2]);b=x[a+116>>2];if(b){be(f,w[g+(x[e+12>>2]<<1)>>1]/4<<16>>16);ae(f,b);x[f>>2]=x[f>>2];x[f+4>>2]=0}b=Eg(f,q);g=x[a+32>>2];i=x[a+28>>2]+i|0;x[c>>2]=x[c>>2]+D(b,i>>12);h=g+h|0;x[c+4>>2]=x[c+4>>2]+D(b,h>>12);Pb(e,j,k);c=c+8|0;b=x[e>>2];g=x[e+4>>2];continue a}else{be(f,w[g+(x[e+12>>2]<<1)>>1]/4<<16>>16);ae(f,4);Pb(e+8|0,m,n);b=b-1|0;continue}}break}x[a>>2]=b;x[a+4>>2]=g;x[a+40>>2]=h;x[a+20>>2]=i>>12;x[a+36>>2]=i;x[a+24>>2]=h>>12;fb=e+16|0}function Jz(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=fb-16|0;fb=d;a:{b:{c:{d:{e:{f:{g:{e=x[a+36>>2];c=x[a+40>>2];h:{if(Ib(e,c)){sc(d+12|0);break h}zo(d,a);x[31737]=0;c=R(1062,d|0)|0;e=x[31737];x[31737]=0;if((e|0)==1){break g}x[d+12>>2]=c;nf(d);c=x[a+40>>2];e=x[a+36>>2]}e=(h=a+36|0,i=x[d+12>>2],j=Ib(e,c),j?h:i);if((b|0)==-1){f=x[e>>2];c=0;g=4194304;break e}if((b|0)>=0){c=b;f=x[e>>2];if((oj(f,x[e+4>>2])|0)>(b|0)){break e}}b=ac(8);x[31737]=0;c=P(36,d|0,10982)|0;a=x[31737];x[31737]=0;if((a|0)==1){break f}pc(b,c);x[31737]=0;S(98,b|0,48540,1006);a=x[31737];x[31737]=0;if((a|0)!=1){break b}a=N()|0;tb(c);break d}a=N()|0;nf(d);break c}a=N()|0;jc(b);break d}x[a+8>>2]=b;b=x[a+24>>2];x[b+480208>>2]=x[b+480208>>2]&-4194305|g;ak(b+484360|0,y[wf(f,c)+16|0]);b=wf(x[e>>2],c);c=x[b+8>>2];b=x[b+12>>2];x[31737]=0;+oa(1094,a|0,b|0,c|0);b=x[31737];x[31737]=0;if((b|0)!=1){break a}a=N()|0}El(d+12|0)}Q(a|0)}p()}x[a+16>>2]=0;x[a+20>>2]=0;El(d+12|0);fb=d+16|0}function nma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0;e=fb-16|0;fb=e;g=x[a+40>>2];h=x[a+36>>2];k=x[a+16>>2];j=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=j;l=b+24|0;m=x[a+32>>2];n=x[a+28>>2];j=x[a+8>>2];o=x[a+12>>2];while(1){if(d){b=x[e+8>>2];p=(((x[e+12>>2]&2147483647)<<1|b>>>31)&-2)+k|0;b=(((b>>>16|0)+4&131064)<<1)+l|0;q=w[b+14>>1];r=w[b+12>>1];s=w[b+10>>1];t=w[b+8>>1];u=w[b+6>>1];y=w[b+4>>1];z=w[b+2>>1];b=w[b>>1];i=0;while(1){if((i|0)!=2){f=i+p|0;x[(i<<2)+e>>2]=((((D(v[f+4|0],s)+D(v[f+2|0],t)|0)+D(v[f+6|0],r)|0)+D(v[f+8|0],q)<<8>>1)+(((D(v[f-4|0],z)+D(v[f-6|0],b)|0)+D(v[f-2|0],y)|0)+D(v[f|0],u)<<8>>1)|0)/16384;i=i+1|0;continue}break}h=h+n|0;x[c>>2]=x[c>>2]+D(x[e>>2],h>>12);g=g+m|0;x[c+4>>2]=x[c+4>>2]+D(x[e+4>>2],g>>12);Pb(e+8|0,j,o);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;x[a+40>>2]=g;x[a+20>>2]=h>>12;x[a+36>>2]=h;x[a+24>>2]=g>>12;fb=e+16|0}function rV(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=E(0),l=0,m=0,n=0;if(Rj(x[a+656>>2])){e=y[a+797|0];e=(l=e,m=y[a+799|0],n=Sc(e),n?l:m);f=Ob(d+1074312|0,34);d=x[a+656>>2];a:{if(!f){break a}f=e&255;if(!f|f>>>0>120){break a}e=y[xb(d+108|0,f-1|0)|0]}k=E(E(x[a+704>>2])*b);d=x[d+44>>2];g=((e&255)+c|0)-61<<16>>16;b:{c:{c=x[a+852>>2]+w[a+772>>1]|0;if(c){h=x[d+36>>2];if(h){break c}}b=$m(d,c+g<<16>>16);break b}j=h+1|0;i=gA(c,j);e=hA(c,j);b=E(1);f=w[d+28>>1];c=g+i<<16>>16;d:{if((f|0)>(c|0)){break d}g=x[d+4>>2];if((c|0)>(oc(g,x[d+8>>2])+f|0)-1<<16>>16){break d}if(!e){b=B[yb(g,c-f|0)>>2];break b}e:{f:{g:{switch(z[d>>1]-1|0){case 2:h=x[d+16>>2];if(!oc(h,x[d+20>>2])){break f}b=B[yb(h,e-1|0)>>2];break e;case 0:break g;default:break f}}i=x[d+16>>2];if(!oc(i,x[d+20>>2])){break f}b=B[yb(i,(e+D(h,lA(c,z[d+30>>1])<<16>>16)|0)-1|0)>>2];break e}b=Ce(E($m(d,c+1<<16>>16)/$m(d,c)),E(E(e|0)/E(j|0)))}b=E(b*B[yb(g,c-f|0)>>2])}}l=a,m=Gk(E(E(k*b)*E(16))),x[l+700>>2]=m}}function eJ(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;a=fb-16|0;fb=a;x[a+12>>2]=c;x[a+8>>2]=f;x[a+12>>2]=c;x[a+8>>2]=f;b=x[a+12>>2];a:{while(1){if(b>>>0>=d>>>0){c=0;break a}c=2;b=x[b>>2];if(b>>>0>1114111|(b&-2048)==55296){break a}b:{c:{if(b>>>0<=127){c=1;f=x[a+8>>2];if((g-f|0)<=0){break a}x[a+8>>2]=f+1;v[f|0]=b;break c}if(b>>>0<=2047){c=x[a+8>>2];if((g-c|0)<2){break b}x[a+8>>2]=c+1;v[c|0]=b>>>6|192;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b&63|128;break c}c=x[a+8>>2];f=g-c|0;if(b>>>0<=65535){if((f|0)<3){break b}x[a+8>>2]=c+1;v[c|0]=b>>>12|224;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b>>>6&63|128;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b&63|128;break c}if((f|0)<4){break b}x[a+8>>2]=c+1;v[c|0]=b>>>18|240;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b>>>12&63|128;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b>>>6&63|128;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b&63|128}b=x[a+12>>2]+4|0;x[a+12>>2]=b;continue}break}c=1}x[e>>2]=x[a+12>>2];x[h>>2]=x[a+8>>2];fb=a+16|0;return c|0}function tta(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;ld(b,32);g=b,h=$b(y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24)),x[g>>2]=h;f=$b(y[a+10|0]|y[a+11|0]<<8|(y[a+12|0]<<16|y[a+13|0]<<24));x[b+4>>2]=f;g=b,h=$b(y[a+14|0]|y[a+15|0]<<8|(y[a+16|0]<<16|y[a+17|0]<<24))+f|0,x[g+8>>2]=h;if(!(d?0:c)){c=$b(y[a+46|0]|y[a+47|0]<<8|(y[a+48|0]<<16|y[a+49|0]<<24))}x[b+24>>2]=c;c=y[a+8|0]<<28>>24;a:{if((d|0)!=841887798){break a}d=Bb(y[a+42|0]|y[a+43|0]<<8);if(!d|(d|0)==48){break a}c=(c-(d<<7)|0)+6144|0}gm(b,+(c|0)*.0006510416666666666);v[e+15|0]=y[a+9|0];v[e+14|0]=64;g=b,h=y[Qb(e+15|0,e+14|0)|0]<<2,w[g+30>>1]=h;c=x[b+4>>2];d=x[b+8>>2];if(v[a+40|0]&1){d=d>>>1|0;x[b+8>>2]=d;c=c>>>1|0;x[b+4>>2]=c;w[b+34>>1]=z[b+34>>1]|64;x[b>>2]=x[b>>2]>>>1}if(y[a+41|0]>=9){d=d>>>1|0;x[b+8>>2]=d;c=c>>>1|0;x[b+4>>2]=c;w[b+34>>1]=z[b+34>>1]|1;x[b>>2]=x[b>>2]>>>1}b:{if(c+1>>>0<d>>>0){w[b+34>>1]=z[b+34>>1]|2;break b}x[b+4>>2]=0;x[b+8>>2]=0}fb=e+16|0}function py(a,b,c,d,e,f,g,h,i,j,k,l){var m=0,n=0;a:{b:{if((a|0)==(f|0)){if(!y[b|0]){break a}f=0;v[b|0]=0;a=x[e>>2];x[e>>2]=a+1;v[a|0]=46;if(!Cb(x[h+4>>2],y[h+11|0])){break b}a=x[j>>2];if((a-i|0)>159){break b}b=x[k>>2];x[j>>2]=a+4;x[a>>2]=b;return 0}c:{if((a|0)!=(g|0)){break c}if(!Cb(x[h+4>>2],y[h+11|0])){break c}if(!y[b|0]){break a}f=0;a=x[j>>2];if((a-i|0)>159){break b}b=x[k>>2];x[j>>2]=a+4;x[a>>2]=b;x[k>>2]=0;return 0}f=-1;l=ry(l,l+128|0,a)-l|0;g=l>>2;if((g|0)>31){break b}a=v[g+111776|0];d:{e:{f=l&-5;if((f|0)!=88){if((f|0)!=96){break e}b=x[e>>2];if((b|0)!=(d|0)){f=-1;if((xl(v[b-1|0])|0)!=(xl(v[c|0])|0)){break b}}x[e>>2]=b+1;v[b|0]=a;return 0}v[c|0]=80;break d}d=xl(a);if((d|0)!=v[c|0]){break d}m=c,n=yt(d),v[m|0]=n;if(!y[b|0]){break d}v[b|0]=0;if(!Cb(x[h+4>>2],y[h+11|0])){break d}b=x[j>>2];if((b-i|0)>159){break d}c=x[k>>2];x[j>>2]=b+4;x[b>>2]=c}b=x[e>>2];x[e>>2]=b+1;v[b|0]=a;f=0;if((g|0)>21){break b}x[k>>2]=x[k>>2]+1}return f}return-1}function oz(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=E(0);c=fb+-64|0;fb=c;b=x[a>>2];a=x[b>>2];d=x[a+4>>2];x[c+40>>2]=x[a+20>>2];e=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=e;Zf(c+48|0,c+32|0,d);a=x[b+4>>2];d=x[a+8>>2];e=x[a+4>>2];b=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=b;b=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=b;x[c+8>>2]=x[a+8>>2];b=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=b;a:{b:{c:{d:{f=x[c+4>>2];if(f>>>0>=e>>>0){g=x[c+20>>2];if(g>>>0<e>>>0){break d}if(d>>>0>A[c+8>>2]){break c}h=x[c+28>>2];if(d>>>0>x[c+24>>2]-h>>>0){break b}i=x[c+16>>2];j=x[c>>2];b=0;e:while(1){if((b|0)==(d|0)){break a}k=(D(b,f)<<3)+j|0;l=(D(b+h|0,g)<<2)+i|0;a=0;while(1)if((a|0)==(e|0)){b=b+1|0;continue e}else{m=(a<<2)+l|0,n=E(+(Cn(Ee(Ig(C[(a<<3)+k>>3])*134217728))|0)*7.450580596923828e-9),B[m>>2]=n;a=a+1|0;continue}}}_(7244,9061,77,8741);p()}_(7209,9061,78,8741);p()}_(5897,9061,79,8741);p()}_(5867,9061,80,8741);p()}fb=c- -64|0}function vy(a,b,c,d,e,f,g,h,i,j,k,l){var m=0,n=0;a:{b:{if((a|0)==(f|0)){if(!y[b|0]){break a}f=0;v[b|0]=0;a=x[e>>2];x[e>>2]=a+1;v[a|0]=46;if(!Cb(x[h+4>>2],y[h+11|0])){break b}a=x[j>>2];if((a-i|0)>159){break b}b=x[k>>2];x[j>>2]=a+4;x[a>>2]=b;return 0}c:{if((a|0)!=(g|0)){break c}if(!Cb(x[h+4>>2],y[h+11|0])){break c}if(!y[b|0]){break a}f=0;a=x[j>>2];if((a-i|0)>159){break b}b=x[k>>2];x[j>>2]=a+4;x[a>>2]=b;x[k>>2]=0;return 0}f=-1;a=Li(l,l+32|0,a)-l|0;if((a|0)>31){break b}g=v[a+111776|0];d:{e:{switch((a&-2)-22|0){case 2:a=x[e>>2];if((a|0)!=(d|0)){if((xl(v[a-1|0])|0)!=(xl(v[c|0])|0)){break b}}x[e>>2]=a+1;v[a|0]=g;return 0;case 0:v[c|0]=80;break d;default:break e}}d=xl(g);if((d|0)!=v[c|0]){break d}m=c,n=yt(d),v[m|0]=n;if(!y[b|0]){break d}v[b|0]=0;if(!Cb(x[h+4>>2],y[h+11|0])){break d}b=x[j>>2];if((b-i|0)>159){break d}c=x[k>>2];x[j>>2]=b+4;x[b>>2]=c}b=x[e>>2];x[e>>2]=b+1;v[b|0]=g;f=0;if((a|0)>21){break b}x[k>>2]=x[k>>2]+1}return f}return-1}function Paa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c=fb+-64|0;fb=c;b=x[a>>2];a=x[b>>2];d=x[a+4>>2];x[c+40>>2]=x[a+20>>2];e=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=e;Zf(c+48|0,c+32|0,d);a=x[b+4>>2];d=x[a+8>>2];e=x[a+4>>2];b=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=b;b=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=b;x[c+8>>2]=x[a+8>>2];b=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=b;a:{b:{c:{d:{g=x[c+4>>2];if(g>>>0>=e>>>0){h=x[c+20>>2];if(h>>>0<e>>>0){break d}if(d>>>0>A[c+8>>2]){break c}i=x[c+28>>2];if(d>>>0>x[c+24>>2]-i>>>0){break b}j=x[c+16>>2];k=x[c>>2];b=0;e:while(1){if((b|0)==(d|0)){break a}l=(D(b,g)<<2)+k|0;m=(D(b+i|0,h)<<1)+j|0;a=0;while(1)if((a|0)==(e|0)){b=b+1|0;continue e}else{f=qd(x[(a<<2)+l>>2]+2048|0,12);f=(f|0)>=32767?32767:f;w[(a<<1)+m>>1]=(f|0)<=-32768?-32768:f;a=a+1|0;continue}}}_(7244,9061,33,8774);p()}_(7209,9061,34,8774);p()}_(5897,9061,35,8774);p()}_(5867,9061,36,8774);p()}fb=c- -64|0}function qz(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=E(0);c=fb+-64|0;fb=c;b=x[a>>2];a=x[b>>2];d=x[a+4>>2];x[c+40>>2]=x[a+20>>2];e=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=e;Zf(c+48|0,c+32|0,d);a=x[b+4>>2];d=x[a+8>>2];e=x[a+4>>2];b=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=b;b=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=b;x[c+8>>2]=x[a+8>>2];b=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=b;a:{b:{c:{d:{f=x[c+4>>2];if(f>>>0>=e>>>0){if(A[c+20>>2]<e>>>0){break d}if(d>>>0>A[c+8>>2]){break c}g=x[c+28>>2];if(d>>>0>x[c+24>>2]-g>>>0){break b}h=x[c+16>>2];i=x[c>>2];b=0;e:while(1){if((b|0)==(d|0)){break a}j=(D(b,f)<<3)+i|0;a=0;while(1)if((a|0)==(e|0)){b=b+1|0;continue e}else{k=Ee(Ig(C[(a<<3)+j>>3])*134217728);l=(x[(a<<2)+h>>2]+(g<<2)|0)+(b<<2)|0,m=E(+(Cn(k)|0)*7.450580596923828e-9),B[l>>2]=m;a=a+1|0;continue}}}_(7244,9061,77,8741);p()}_(7209,9061,78,8741);p()}_(5897,9061,79,8741);p()}_(5867,9061,80,8741);p()}fb=c- -64|0}function wr(a){var b=0,c=0,d=0,e=0,f=0;e=fb-16|0;fb=e;a:{b:{c:{d:{e:{f:{g:{h:{b=x[a+480180>>2];switch(b-1|0){case 7:break e;case 0:case 1:case 3:break f;case 2:case 4:case 5:case 6:break g;default:break h}}if((b|0)==16){break b}if((b|0)==32){break f}if((b|0)==64|(b|0)==256|((b|0)==512|(b|0)==2048)|(b|0)==8192){break b}if((b|0)==65536){break d}d=1;if((b|0)==2097152){break a}if((b|0)==4194304){break c}if((b|0)==536870912|(b|0)==67108864|(b|0)==134217728){break a}d=b;if((b|0)==16777216){break a}}d=32;break a}d=b;break a}d=4;if(z[a+480192>>1]){break a}c=wb(x[a+484344>>2]);x[e+12>>2]=c;a=wb(x[a+484348>>2]);while(1){if(!Ib(c,a)){d=1;break a}if(!(!Ib(x[c>>2],x[c+4>>2])|x[c+12>>2]==64)){break a}c=x[am(e+12|0)>>2];continue}}d=16777216;break a}d=32;f=z[a+480188>>1];if(f>>>0>16){break a}while(1){if((c|0)==(f|0)){break b}b=(c<<5)+a|0;if(v[b+480281|0]&1){break a}c=c+1|0;if(z[b+480286>>1]==64){continue}break}break a}d=2}fb=e+16|0;return d}function lba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=fb-16|0;fb=g;h=g+4|0;f=fb-160|0;fb=f;d=f+24|0;c=d+56|0;e=Qt(c);x[d>>2]=94204;x[e>>2]=94224;x[d+56>>2]=94264;x[d>>2]=94244;i=c;c=d+4|0;so(i,c);x[d>>2]=94204;x[e>>2]=94224;c=Nt(c);x[c>>2]=93688;Fb(c+32|0);x[c+44>>2]=0;x[c+48>>2]=16;j=x[x[d>>2]-12>>2];x[31737]=0;i=ca(105)|0;c=x[31737];x[31737]=0;a:{b:{c:{d:{e:{f:{if((c|0)==1){break f}x[31737]=0;e=f+20|0;S(106,e|0,d+j|0,i|0);c=x[31737];x[31737]=0;if((c|0)==1){break f}Zb(e);c=fb-16|0;fb=c;x[c+12>>2]=17;fb=c+16|0;Dn(d+x[x[d>>2]-12>>2]|0,x[c+12>>2]);k=C[b>>3];x[31737]=0;e=Sa(1136,d|0,+k)|0;b=x[31737];x[31737]=0;if((b|0)==1){break e}x[31737]=0;c=f+8|0;O(1137,c|0,e|0);b=x[31737];x[31737]=0;if((b|0)==1){break d}x[31737]=0;O(304,h|0,c|0);b=x[31737];x[31737]=0;if((b|0)==1){break c}tb(c);nq(e);fb=f+160|0;break a}a=N()|0;break b}a=N()|0;break b}a=N()|0;break b}a=N()|0;tb(f+8|0)}nq(d);Q(a|0);p()}Sh(a,h);tb(h);fb=g+16|0}function Ria(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=x[a>>2];c=mk(d,x[a+4>>2]);if(c>>>0<b>>>0){h=fb-32|0;fb=h;f=b-c|0;d=x[zb(a)>>2];b=x[a+4>>2];a:{if(f>>>0<=d-b>>11>>>0){c=fb-16|0;fb=c;b=c+4|0;x[b>>2]=a;a=x[a+4>>2];x[b+4>>2]=a;x[b+8>>2]=a+(f<<11);a=x[b+4>>2];d=x[b+8>>2];while(1){if((a|0)==(d|0)){hc(b);fb=c+16|0}else{tu(a);a=a+2048|0;x[b+4>>2]=a;continue}break}break a}g=zb(a);i=h+12|0;e=mk(x[a>>2],b)+f|0;c=fb-16|0;fb=c;x[c+12>>2]=e;d=fb-16|0;fb=d;x[d+12>>2]=2097151;x[d+8>>2]=2147483647;b=x[Gb(d+12|0,d+8|0)>>2];fb=d+16|0;b:{if(b>>>0>=e>>>0){d=cA(a);if(d>>>0<b>>>1>>>0){x[c+8>>2]=d<<1;b=x[ad(c+8|0,c+12|0)>>2]}fb=c+16|0;break b}dd();p()}d=UQ(i,b,mk(x[a>>2],x[a+4>>2]),g);c=d;e=fb-16|0;fb=e;g=x[c+8>>2];b=e+4|0;x[b+8>>2]=c+8;x[b>>2]=g;x[b+4>>2]=g+(f<<11);c=x[b>>2];while(1){if(x[b+4>>2]!=(c|0)){tu(c);c=x[b>>2]+2048|0;x[b>>2]=c;continue}break}he(b);fb=e+16|0;SQ(a,d);RQ(d)}fb=h+32|0;return}if(b>>>0<c>>>0){OQ(a,d+(b<<11)|0)}}function N2(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;c=fb-48|0;fb=c;f=Fb(a);x[31737]=0;a=ca(118)|0;b=x[31737];x[31737]=0;a:{b:{if((b|0)==1){break b}c:{d:{if(!a){break d}x[31737]=0;b=P(1,c+24|0,8979)|0;a=x[31737];x[31737]=0;if((a|0)==1){break c}x[31737]=0;a=ca(118)|0;d=x[31737];x[31737]=0;e:{f:{g:{h:{if((d|0)==1){break h}x[31737]=0;x[c+8>>2]=a;a=c+12|0;O(127,a|0,c+8|0);d=x[31737];x[31737]=0;if((d|0)==1){break h}x[31737]=0;d=c+36|0;S(2,d|0,b|0,a|0);e=x[31737];x[31737]=0;if((e|0)==1){break g}e=Ab(f,d);tb(d);tb(a);tb(b);x[31737]=0;a=ca(120)|0;b=x[31737];x[31737]=0;if((b|0)==1){break b}if(!a){break e}x[31737]=0;P(128,e|0,17561)|0;a=x[31737];x[31737]=0;if((a|0)!=1){break e}break b}a=N()|0;break f}a=N()|0;tb(c+12|0)}tb(b);break a}x[31737]=0;a=ca(119)|0;b=x[31737];x[31737]=0;if((b|0)==1){break b}if(!a){break d}x[31737]=0;P(128,e|0,16847)|0;a=x[31737];x[31737]=0;if((a|0)==1){break b}}fb=c+48|0;return}a=N()|0;break a}a=N()|0}tb(f);Q(a|0);p()}function Cc(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;a:{c=x[b>>2];f=fb-48|0;fb=f;e=x[b+4>>2];b=y[b+8|0];d=e-(((b|0)==1|(b|0)==4)&(e|0)!=0)|0;e=Fb(a);b:{c:{d:{e:{f:{g:{h:{if((b-1&255)>>>0<=1){a=Li(c,c+d|0,0);x[31737]=0;U(70,e|0,c|0,a|0)|0;a=x[31737];x[31737]=0;if((a|0)!=1){break h}a=N()|0;break b}if((b-3&255)>>>0>1){break h}x[31737]=0;b=U(70,e|0,c|0,c+d|0)|0;a=x[31737];x[31737]=0;if((a|0)==1){break g}c=zd(b);d=Df(b);g=zd(b);a=fb-16|0;fb=a;x[a+8>>2]=g;x[a+12>>2]=c;while(1){if(Ib(c,d)){c=v[c|0];v[x[a+8>>2]]=c?c:32;c=le(a+12|0);le(a+8|0);c=x[c>>2];continue}break}fb=a+16|0;x[31737]=0;c=P(71,f+24|0,b|0)|0;a=x[31737];x[31737]=0;if((a|0)==1){break f}x[31737]=0;d=P(36,f+12|0,18465)|0;a=x[31737];x[31737]=0;if((a|0)==1){break e}x[31737]=0;a=f+36|0;S(72,a|0,c|0,d|0);g=x[31737];x[31737]=0;if((g|0)==1){break d}Ab(b,a);tb(a);tb(d);tb(c)}fb=f+48|0;break a}a=N()|0;break b}a=N()|0;break b}a=N()|0;break c}a=N()|0;tb(d)}tb(c)}tb(e);Q(a|0);p()}}function uA(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=fb-16|0;fb=e;d=y[a+2|0];if(!(!d|(d|0)==255)){x[e+12>>2]=d+1;x[e+8>>2]=10;gh(b,x[ud(e+12|0,e+8|0)>>2]);i=y[a+3|0];v[b+15|0]=i;v[b+16|0]=i;j=y[a+4|0];v[b+13|0]=j;l=y[a+5|0];v[b+14|0]=l;g=511;d=0;a:{b:{switch(c-1|0){case 1:d=4096;g=128;break a;case 0:break b;default:break a}}d=32768;g=1024}o=g>>>1|d;c=x[b>>2];k=Sd(c,x[b+4>>2]);d=0;while(1){if((d|0)==(k|0)){c=y[b+12|0]&-2|v[a|0]&1;v[b+12|0]=c;c=c&-5|(y[a|0]|y[a+1|0]<<8)<<1&(k>>>0>=i>>>0)<<2;v[b+12|0]=c;v[b+12|0]=c&253|(y[a|0]|y[a+1|0]<<8)>>>1&(j>>>0<=l>>>0?(k>>>0>=j>>>0)<<1:0)}else{m=yb(c,d);h=(d<<2)+a|0;f=(y[h+6|0]|y[h+7|0]<<8)>>>4|0;w[m>>1]=f;c:{if(d){n=z[yb(c,d-1|0)>>1];if(f>>>0>=n>>>0){break c}f=n+1|0}else{f=0}p=yb(c,d),q=f,w[p>>1]=q}x[e+12>>2]=(((y[h+8|0]|y[h+9|0]<<8)<<16>>16)+o|0)/(g|0);x[e+8>>2]=0;x[e+4>>2]=64;p=m,q=x[dk(e+12|0,e+8|0,e+4|0)>>2],v[p+2|0]=q;d=d+1|0;continue}break}}fb=e+16|0}function Yaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=fb+-64|0;fb=c;b=x[a>>2];a=x[b>>2];e=x[a+4>>2];x[c+40>>2]=x[a+20>>2];f=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=f;Zf(c+48|0,c+32|0,e);a=x[b+4>>2];e=x[a+8>>2];f=x[a+4>>2];b=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=b;b=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=b;x[c+8>>2]=x[a+8>>2];b=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=b;a:{b:{c:{d:{g=x[c+4>>2];if(g>>>0>=f>>>0){if(A[c+20>>2]<f>>>0){break d}if(e>>>0>A[c+8>>2]){break c}h=x[c+28>>2];if(e>>>0>x[c+24>>2]-h>>>0){break b}i=x[c+16>>2];j=x[c>>2];b=0;e:while(1){if((b|0)==(e|0)){break a}k=(D(b,g)<<2)+j|0;a=0;while(1)if((a|0)==(f|0)){b=b+1|0;continue e}else{d=a<<2;l=(x[d+i>>2]+(h<<1)|0)+(b<<1)|0;d=qd(x[d+k>>2]+2048|0,12);d=(d|0)>=32767?32767:d;w[l>>1]=(d|0)<=-32768?-32768:d;a=a+1|0;continue}}}_(7244,9061,33,8774);p()}_(7209,9061,34,8774);p()}_(5897,9061,35,8774);p()}_(5867,9061,36,8774);p()}fb=c- -64|0}function Bf(a,b,c){v[a+5|0]=c;a:{switch(b|0){case 0:v[a+3|0]=(c|0)!=0;return;case 1:v[a+3|0]=2;return;case 2:v[a+3|0]=3;return;case 3:v[a+3|0]=4;return;case 4:v[a+3|0]=5;return;case 5:v[a+3|0]=6;return;case 6:v[a+3|0]=7;return;case 7:v[a+3|0]=8;return;case 8:v[a+3|0]=9;return;case 9:v[a+3|0]=10;return;case 10:v[a+3|0]=11;return;case 11:v[a+3|0]=12;return;case 12:v[a+3|0]=13;return;case 13:v[a+3|0]=14;v[a+5|0]=D(c>>>4|0,10)+(c&15);return;case 14:v[a+3|0]=19;return;case 15:if(c>>>0<=31){v[a+3|0]=16;return}v[a+3|0]=17;return;case 16:v[a+3|0]=23;return;case 17:v[a+3|0]=24;return;case 20:v[a+3|0]=25;return;case 21:v[a+3|0]=30;return;case 25:v[a+3|0]=29;return;case 27:v[a+3|0]=15;return;case 29:v[a+3|0]=18;return;case 32:v[a+3|0]=37;return;case 33:v[a+3|0]=28;return;case 34:v[a+3|0]=27;return;case 35:v[a+3|0]=31;return;case 36:v[a+3|0]=32;return;case 37:v[a+3|0]=32;return;case 38:v[a+3|0]=34;return;default:break a}}v[a+3|0]=0}function $la(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=fb-16|0;fb=e;p=x[a+16>>2];q=Fg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);j=x[a+8>>2];k=x[a+12>>2];b=x[a>>2];g=x[a+4>>2];l=x[a+128>>2];if(l){m=Gg(j,k,l);n=hb;f=x[a+76>>2];hg(b,g,vf(j,k,d),hb);o=hb>>>0>f>>>0?d:0}f=a+112|0;h=x[a+40>>2];i=x[a+36>>2];x[e>>2]=b;x[e+4>>2]=g;a:while(1){if(d){d=d-1|0;x[e+8>>2]=b;x[e+12>>2]=0;o=o-1|0;b=o;m=b?m:0;n=b?n:0;g=g+p|0;b=l;while(1)if((b|0)<=0){Pb(f,x[a+120>>2],x[a+124>>2]);b=x[a+116>>2];if(b){be(f,v[g+x[e+12>>2]|0]<<6);ae(f,b);x[f>>2]=x[f>>2];x[f+4>>2]=0}b=Eg(f,q);g=x[a+32>>2];i=x[a+28>>2]+i|0;x[c>>2]=x[c>>2]+D(b,i>>12);h=g+h|0;x[c+4>>2]=x[c+4>>2]+D(b,h>>12);Pb(e,j,k);c=c+8|0;b=x[e>>2];g=x[e+4>>2];continue a}else{be(f,v[g+x[e+12>>2]|0]<<6);ae(f,4);Pb(e+8|0,m,n);b=b-1|0;continue}}break}x[a>>2]=b;x[a+4>>2]=g;x[a+40>>2]=h;x[a+20>>2]=i>>12;x[a+36>>2]=i;x[a+24>>2]=h>>12;fb=e+16|0}function gna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0;h=fb-16|0;fb=h;f=x[a+48>>2];m=x[a+24>>2];n=x[a+20>>2];e=x[a+44>>2];o=x[a+16>>2];b=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=b;p=x[a+72>>2];j=x[a+68>>2];q=j>>31;k=x[a+64>>2];r=k>>31;l=x[a+60>>2];s=l>>31;t=x[a+8>>2];u=x[a+12>>2];while(1){b=e;if(d){e=Yb(e,-16777216,16776704);e=Sua(k,r,e,e>>31);i=hb;g=e;f=Yb(f,-16777216,16776704);e=Sua(j,q,f,f>>31);g=g+e|0;f=hb+i|0;f=e>>>0>g>>>0?f+1|0:f;w=g;e=x[h+8>>2];i=e>>>10&4194048;e=x[h+12>>2]+o|0;g=v[e|0];i=((D(v[e+1|0]-g|0,i)|0)/16384<<8)+(g<<16)|0;e=i;e=Sua(e,e>>31,l,s);g=e+w|0;f=hb+f|0;f=e>>>0>g>>>0?f+1|0:f;e=g+8388608|0;f=e>>>0<8388608?f+1|0:f;e=Rc(e,f,24);f=(e|0)/256|0;x[c>>2]=D(f,n)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(f,m);Pb(h+8|0,t,u);e=e-(i&p)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=c;x[a+48>>2]=f;x[a+44>>2]=b;fb=h+16|0}function Rsa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;ld(b,32);kp(b);f=b,g=Bb(y[a+40|0]|y[a+41|0]<<8)>>>2|0,w[f+32>>1]=g;d=z[b+34>>1];if((xe((y[a+38|0]|y[a+39|0]<<8)<<16>>16)|0)>0){d=d|32;w[b+34>>1]=d;c=xe((y[a+38|0]|y[a+39|0]<<8)<<16>>16);e=(c<<8&-256)+2047|0;c=c>>>24|0;f=b,g=Bc(Uua(e,e>>>0<2047?c+1|0:c,4095,0),hb),w[f+28>>1]=g}f=b,g=$b(y[a+58|0]|y[a+59|0]<<8|(y[a+60|0]<<16|y[a+61|0]<<24)),x[f>>2]=g;f=b,g=$b(y[a+62|0]|y[a+63|0]<<8|(y[a+64|0]<<16|y[a+65|0]<<24)),x[f+4>>2]=g;f=b,g=$b(y[a+62|0]|y[a+63|0]<<8|(y[a+64|0]<<16|y[a+65|0]<<24))+$b(y[a+66|0]|y[a+67|0]<<8|(y[a+68|0]<<16|y[a+69|0]<<24))|0,x[f+8>>2]=g;c=d&-3|((Bb(y[a+44|0]|y[a+45|0]<<8)|0)!=0)<<1;w[b+34>>1]=c;f=b,g=c&65531|Bb(y[a+44|0]|y[a+45|0]<<8)<<1&4,w[f+34>>1]=g;f=b,g=$b(y[a+54|0]|y[a+55|0]<<8|(y[a+56|0]<<16|y[a+57|0]<<24))<<1,x[f+24>>2]=g;c=xe((y[a+42|0]|y[a+43|0]<<8)<<16>>16);if(c){gm(b,+(c|0)/96);c=xe((y[a+42|0]|y[a+43|0]<<8)<<16>>16)}v[b+37|0]=c<<4}function hha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=E(0),o=0,p=0,q=0,r=0,s=0,t=E(0),u=E(0),v=E(0),w=E(0),z=0,A=0,C=0,D=0,G=0,H=E(0);g=fb-16|0;fb=g;m=x[a+4240>>2];a:{if(!m){break a}if(!zi(a+44|0)){break a}n=B[a+4220>>2];e=x[a+44>>2];D=g,G=Hc(e,0),x[D+8>>2]=G;D=g,G=Hc(e,1),x[D+12>>2]=G;e=x[a+56>>2];o=Hc(e,0);x[g>>2]=o;p=Hc(e,1);x[g+4>>2]=p;w=E(E(1)-n);q=x[a+4208>>2];z=y[a+4264|0];e=d;b:while(1){if(e){k=x[a+4244>>2];A=k<<1;f=0;l=0;while(1)if((f|0)==2){f=k+1|0;x[a+4244>>2]=(f|0)!=(m|0)?f:0;e=e-1|0;continue b}else{h=(z?1-l|0:f)&255;j=x[((h<<2)+a|0)+4248>>2];C=x[a+4240>>2];r=f<<2;s=r+(g+8|0)|0;i=x[s>>2];x[s>>2]=i+4;j=k-j|0;t=B[yb(q,h+((j>>31&C)+j<<1)|0)>>2];u=B[i>>2];v=E(E(t*B[a+4224>>2])+E(u*B[a+4260>>2]));D=yb(q,f+A|0),H=E(F(v))<E(10000000195414814e-40)?E(0):v,B[D>>2]=H;h=g+r|0;i=x[h>>2];x[h>>2]=i+4;B[i>>2]=E(u*w)+E(n*t);l=l+1|0;f=f+1|0;continue}}break}Pi(a,b,c,o,p,d)}fb=g+16|0}function Cq(a){a=a|0;var b=0,c=0,d=0,e=0,f=E(0),g=E(0),h=0,i=0,j=0,k=0,l=0,m=E(0),n=0,o=E(0);b=x[a+36>>2];if(!b){Nf(a+16|0);return}a:{b:{switch(z[a>>1]){case 3:c=a+16|0;if(b>>>0>=1001){Nf(c);return}Jl(c,b);b=x[a+36>>2]+1|0;c=b>>>0<=1?1:b;e=w[a+28>>1];g=Ce(E($m(a,e+1<<16>>16)/$m(a,e)),E(E(1)/E(b>>>0)));a=x[a+16>>2];b=1;while(1){if((b|0)==(c|0)){break a}f=Ce(g,E(b>>>0));n=yb(a,b-1|0),o=f,B[n>>2]=o;b=b+1|0;continue};case 1:c=a+16|0;e=z[a+30>>1];if(e>>>0>1e3/(b>>>0)>>>0){Nf(c);return}Jl(c,D(b,e));h=z[a+30>>1];j=lA(w[a+28>>1],h);i=x[a+36>>2];g=E(E(1)/E(i+1>>>0));c=0;c:while(1){if(e>>>0<=(c&65535)>>>0){break a}b=1;d=lA(c+j<<16>>16,h);f=$m(a,d+1<<16>>16);d=d<<16>>16;f=Ce(E(f/$m(a,d)),g);k=D(d,x[a+36>>2]);l=x[a+16>>2];while(1){d=b&65535;if(d>>>0>i>>>0){c=c+1|0;continue c}else{m=Ce(f,E(d>>>0));n=yb(l,(d+k|0)-1|0),o=m,B[n>>2]=o;b=b+1|0;continue}}};case 0:Nf(a+16|0);return;default:break b}}Nf(a+16|0);x[a+36>>2]=0}}function Ft(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;a:{b:{e=xj(a)&2047;d=xj(5551115123125783e-32);if(e-d>>>0<xj(512)-d>>>0){h=e;break b}if(d>>>0>e>>>0){return a+1}if(xj(1024)>>>0>e>>>0){break b}o(+a);d=j(1)|0;b=0;if(!(j(0)|0)&(d|0)==-1048576){break a}if(xj(Infinity)>>>0<=e>>>0){return a+1}if((d|0)<0){return Qs(12882297539194267e-247)}return Qs(3105036184601418e216)}b=C[170];f=C[169]*a+b;b=f-b;a=b*C[172]+(b*C[171]+a);b=a*a;g=b*b*(a*C[176]+C[175]);b=b*(a*C[174]+C[173]);o(+f);j(1)|0;e=j(0)|0;c=e<<4&2032;a=g+(b+(C[c+1464>>3]+a));c=c+1472|0;d=0+x[c>>2]|0;c=x[c+4>>2]+(e<<13)|0;c=d>>>0<i>>>0?c+1|0:c;if(!h){c:{if(!(e&-2147483648)){l(0,d|0);l(1,c-1058013184|0);b=+n();a=(b*a+b)*5486124068793689e288;break c}l(0,d|0);l(1,c+1071644672|0);b=+n();f=b*a;a=f+b;if(a<1){KJ(kK()*22250738585072014e-324);g=a+1;a=g+(f+(b-a)+(a+(1-g)))+-1;a=a==0?0:a}a=a*22250738585072014e-324}return a}l(0,d|0);l(1,c|0);b=+n();b=b*a+b}return b}function Y2(){var a=0,b=0,c=0,d=0;d=fb-32|0;fb=d;a:{a=Dc(d+20|0,14832);if(!Yc(x[a+4>>2],y[a+11|0])){break a}b:{if((Rg(a,14690)|0)!=-1){b=Rg(a,14690);x[31737]=0;c=d+8|0;V(122,c|0,a|0,b+1|0,-1);b=x[31737];x[31737]=0;if((b|0)==1){break b}Ab(a,c);tb(c)}if((Rg(a,16845)|0)!=-1){b=Rg(a,16845);x[31737]=0;c=d+8|0;V(122,c|0,a|0,b+1|0,-1);b=x[31737];x[31737]=0;if((b|0)==1){break b}Ab(a,c);tb(c)}if((Rg(a,13959)|0)!=-1){b=Rg(a,13959);x[31737]=0;c=d+8|0;V(122,c|0,a|0,0,b|0);b=x[31737];x[31737]=0;if((b|0)==1){break b}Ab(a,c);tb(c)}if((Rg(a,13834)|0)!=-1){b=Rg(a,13834);x[31737]=0;c=d+8|0;V(122,c|0,a|0,0,b|0);b=x[31737];x[31737]=0;if((b|0)==1){break b}Ab(a,c);tb(c)}if((Rg(a,13877)|0)!=-1){b=Rg(a,13877);x[31737]=0;c=d+8|0;V(122,c|0,a|0,0,b|0);b=x[31737];x[31737]=0;if((b|0)==1){break b}Ab(a,c);tb(c)}x[31737]=0;c=R(123,a|0)|0;b=x[31737];x[31737]=0;if((b|0)!=1){break a}}d=N()|0;tb(a);Q(d|0);p()}tb(a);fb=d+32|0;return c|0}function dga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=fb-80|0;fb=e;x[e+76>>2]=c;c=e+76|0;a=qe(a,c);g=sc(a+4|0);h=sc(a+24|0);i=sc(a+32|0);j=Nb(a+36|0);x[a+56>>2]=3;k=Nb(a+68|0);x[31737]=0;O(997,a|0,d|0);f=x[31737];x[31737]=0;a:{b:{c:{d:{if((f|0)!=1){f=x[b>>2];l=x[b+4>>2];m=x[b+12>>2];x[e+48>>2]=x[b+8>>2];x[e+52>>2]=m;x[e+40>>2]=f;x[e+44>>2]=l;b=Nd(e+32|0);f=x[e+52>>2];x[e+24>>2]=x[e+48>>2];x[e+28>>2]=f;x[31737]=0;f=x[e+44>>2];x[e+16>>2]=x[e+40>>2];x[e+20>>2]=f;f=x[b+4>>2];x[e+8>>2]=x[b>>2];x[e+12>>2]=f;b=e+56|0;S(986,b|0,e+16|0,e+8|0);f=x[31737];x[31737]=0;if((f|0)==1){break d}x[31737]=0;S(998,a|0,b|0,d|0);d=x[31737];x[31737]=0;if((d|0)==1){break c}ub(b);x[31737]=0;W(999,a|0);b=x[31737];x[31737]=0;if((b|0)==1){break b}Uc(c);fb=e+80|0;return a|0}d=N()|0;break a}d=N()|0;break a}d=N()|0;ub(e+56|0);break a}d=N()|0}Td(k);nf(j);Hl(i);vh(h);uh(g);Uc(a);Uc(e+76|0);Q(d|0);p()}function _L(a){var b=0,c=0,d=0,e=0,f=0,g=0;b=x[a+32>>2];a:{b:{c:{d=x[a+1380>>2];if((d|0)==-1){c=1;break c}f=x[a+1116>>2];e=(d|0)>(f|0)?d:f;c=d;while(1){d:{if((c|0)!=(e|0)){g=y[(a+c|0)+1120|0];b=g+b|0;if((g|0)==255){break d}e=c}if(A[a+40>>2]<b>>>0){fc(a,1);break b}c=(e|0)==-1|(e|0)==(f|0);break c}c=c+1|0;continue}}d=(d|0)!=-1;while(1){e=1;if(!(c&1)){break a}e=x[a+40>>2];if(e>>>0<=b+26>>>0){fc(a,1);break b}if((y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24))!=(y[125972]|y[125973]<<8|(y[125974]<<16|y[125975]<<24))){fc(a,21);break b}if(y[b+4|0]){fc(a,21);break b}e:{if(!d){if(!x[a+992>>2]|!(v[b+5|0]&1)){break e}fc(a,21);break b}if(v[b+5|0]&1){break e}fc(a,21);break b}c=0;f=b+27|0;d=y[b+26|0];b=f+d|0;if(e>>>0<b>>>0){fc(a,1);break b}while(1){f:{if((c|0)==(d|0)){c=d;break f}g=y[c+f|0];b=g+b|0;if((g|0)!=255){break f}c=c+1|0;continue}break}c=(c|0)==(d|0);d=1;if(b>>>0<=e>>>0){continue}break}fc(a,1)}e=0}return e}function fna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;h=fb-16|0;fb=h;e=x[a+48>>2];n=x[a+24>>2];o=x[a+20>>2];f=x[a+44>>2];p=x[a+16>>2];b=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=b;q=x[a+72>>2];k=x[a+68>>2];r=k>>31;l=x[a+64>>2];s=l>>31;m=x[a+60>>2];t=m>>31;u=x[a+8>>2];v=x[a+12>>2];while(1){b=f;if(d){f=Yb(f,-16777216,16776704);g=Sua(l,s,f,f>>31);f=hb;e=Yb(e,-16777216,16776704);e=Sua(k,r,e,e>>31);g=e+g|0;f=hb+f|0;f=e>>>0>g>>>0?f+1|0:f;j=g;g=(x[h+12>>2]<<1)+p|0;i=w[g>>1];i=i+((D(w[g+2>>1]-i|0,x[h+8>>2]>>>18|0)|0)/16384|0)<<8;e=i;g=Sua(e,e>>31,m,t);j=g+j|0;e=hb+f|0;e=g>>>0>j>>>0?e+1|0:e;f=j+8388608|0;e=f>>>0<8388608?e+1|0:e;f=Rc(f,e,24);e=(f|0)/256|0;x[c>>2]=D(e,o)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(e,n);Pb(h+8|0,u,v);f=f-(i&q)|0;c=c+8|0;d=d-1|0;e=b;continue}break}c=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=c;x[a+48>>2]=e;x[a+44>>2]=b;fb=h+16|0}function Gqa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=fb-16|0;fb=f;w[f+12>>1]=0;x[f+8>>2]=0;j=8;n=D(c,d)<<1;a:while(1){if((d|0)!=(l|0)){i=(l<<1)+b|0;o=n+i|0;while(1){b:{c:{if(i>>>0<o>>>0){w[f+6>>1]=0;wY(a,f+15|0,f+12|0,j,f+6|0);g=z[f+6>>1];e=z[f+12>>1];c=j;while(1){if(c&255){h=e<<1;e=h&254;d:{if(e){h=(h&65534)>>>0>255;break d}if(!Af(a,f+5|0)){break c}e=y[f+5|0];h=e>>>7|0;e=e<<1&254|1}c=c-1|0;g=g<<1|h;continue}break}w[f+12>>1]=e;break b}l=l+1|0;continue a}w[f+12>>1]=0}c=1;h=g&65535;e:{if(h>>>0<4){break e}e=15;while(1){c=e;m=e&255;if(m>>>0<2){break e}e=e-1|0;if(!(h&1<<m)){continue}break}}e=g&1;v[f+15|0]=e;g=e-1^(g&65534)>>>1;e=g+z[f+8>>1]|0;w[f+6>>1]=e;w[i>>1]=e;x[f+8>>2]=((g>>1)-(k<<16>>16)|0)+(e<<16>>16<<1);i=(d<<1)+i|0;j=(c+j&254)>>>1|0;c=-32768;k=x[f+8>>2];f:{if((k|0)>=-32768){c=32767;if((k|0)<32768){break f}}x[f+8>>2]=c}k=e;continue}}break}fb=f+16|0}function W1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=fb-32|0;fb=h;e=Qn(h+12|0,a);i=fb-48|0;fb=i;j=-1;c=i+12|0;a:{if(!$F(e,c)){break a}j=0;if(!eG(c)){break a}k=Cf(13181);if(k){o=x[e+12>>2];b:{if(!cm(e,y[c+16|0]|y[c+17|0]<<8|(y[c+18|0]<<16|y[c+19|0]<<24))){break b}while(1){if((y[c+12|0]|y[c+13|0]<<8|(y[c+14|0]<<16|y[c+15|0]<<24))>>>0<=l>>>0){break b}if(!kh(e,5)){break b}c:{if((y[c+4|0]|y[c+5|0]<<8)>>>0>=64){a=Qr(e);d=a&63;g=a<<24>>24;d:{if(!(a&64)){break d}a=6;while(1){f=Qr(e);d=(f&127)<<a|d;if(f<<24>>24>=0){break d}f=a>>>0<25;a=a+7|0;if(f){continue}break}}if((((g|0)<0?(d|0)<0?-2147483648:0-d|0:d)|0)<=0){break c}}d=0;a=1;while(1){f=Qr(e);if(f){m=d>>>0>=k>>>0;g=m&a;if(!((a^1)&1|m)){g=(Oq(f<<24>>24)&255)==y[d+13181|0]}a=g;d=d+1|0;continue}break}gd(e,4);n=(d|0)==(k|0)&a|n}l=l+1|0;continue}}cm(e,o)}if(!(n&1)){break a}j=ve(e,b,dG(c),0)}fb=i+48|0;fb=h+32|0;return j|0}function Lia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=E(0),j=0,k=0,l=0,m=0,n=E(0),o=E(0),p=E(0),q=E(0),r=0,s=0,t=0,u=E(0),v=E(0),w=E(0),y=E(0),z=0,A=0,C=0,D=E(0);r=x[a+4220>>2];if(r){f=x[a+44>>2];k=Hc(f,0);l=Hc(f,1);g=x[a+56>>2];s=Hc(g,0);j=x[a+4208>>2];z=x[a+4228>>2];f=d;t=Hc(g,1);m=t;g=s;while(1){if(f){h=x[a+4224>>2];e=h-z|0;e=(x[a+4220>>2]&e>>31)+e<<1;A=yb(j,e);n=B[yb(j,e|1)>>2];u=B[a+4244>>2];o=B[A>>2];v=B[a+4252>>2];p=B[l>>2];w=B[a+4248>>2];q=B[k>>2];y=B[a+4256>>2];i=E(E(n*u)+E(E(o*v)+E(E(p*w)+E(q*y))));e=h<<1;C=yb(j,e),D=E(F(i))<E(10000000195414814e-40)?E(0):i,B[C>>2]=D;i=E(E(o*u)+E(E(n*v)+E(E(q*w)+E(p*y))));C=yb(j,e|1),D=E(F(i))<E(10000000195414814e-40)?E(0):i,B[C>>2]=D;h=h+1|0;x[a+4224>>2]=(h|0)!=(r|0)?h:0;B[g>>2]=E(q*B[a+4240>>2])+E(o*B[a+4236>>2]);B[m>>2]=E(p*B[a+4240>>2])+E(n*B[a+4236>>2]);f=f-1|0;m=m+4|0;g=g+4|0;l=l+4|0;k=k+4|0;continue}else{Pi(a,b,c,s,t,d)}break}}}function _M(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;e=fb-16|0;fb=e;x[e+12>>2]=c;a:{b:{if(!b){a=a+120|0;xo(a);c=x[e+12>>2];b=fb-16|0;fb=b;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);Rd(b+8|0,x[vb(b+4|0,a)>>2]);c:{if(c){x[31737]=0;O(1143,a|0,c|0);d=x[31737];x[31737]=0;if((d|0)==1){break a}WM(a,c)}c=b+8|0;Qd(c);cj(c);fb=b+16|0;break c}v[a+20|0]=0;break b}d=fb-16|0;fb=d;x[d+12>>2]=c;d:{if((b|0)==1){b=a+120|0;xo(b);h=uz(b,a,x[d+12>>2]),i=1,v[h+20|0]=i;break d}f=fb-16|0;fb=f;x[f+12>>2]=c;e:{if((b|0)==2){a=a+120|0;xo(a);c=x[f+12>>2];b=fb-16|0;fb=b;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);Rd(b+8|0,x[vb(b+4|0,a)>>2]);f:{if(c){x[31737]=0;O(1142,a|0,c|0);g=x[31737];x[31737]=0;if((g|0)==1){break a}WM(a,c)}c=b+8|0;Qd(c);cj(c);fb=b+16|0;break f}Nd(a+12|0);v[a+20|0]=2;break e}b=fb-16|0;fb=b;x[b+12>>2]=c;c=a+120|0;xo(c);h=uz(c,a,x[b+12>>2]),i=3,v[h+20|0]=i;fb=b+16|0}fb=f+16|0}fb=d+16|0}fb=e+16|0;return}a=N()|0;cj(b+8|0);Q(a|0);p()}function UK(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=fb-32|0;fb=c;a:{if(y[a+52|0]){d=x[a+48>>2];if(!b){break a}v[a+52|0]=0;x[a+48>>2]=-1;break a}x[c+24>>2]=1;e=x[Ye(c+24|0,a+44|0)>>2];g=(e|0)>0?e:0;while(1){if((f|0)!=(g|0)){d=-1;h=vv(x[a+32>>2]);if((h|0)==-1){break a}v[(c+24|0)+f|0]=h;f=f+1|0;continue}break}b:{c:{if(y[a+53|0]){v[c+23|0]=y[c+24|0];break c}h=c+24|0;while(1){d:{f=x[a+40>>2];d=x[f>>2];j=x[f+4>>2];i=c+24|0;g=i+e|0;e:{switch(gL(x[a+36>>2],f,i,g,c+16|0,c+23|0,h,c+12|0)-1|0){case 0:break e;case 1:break b;case 2:break d;default:break c}}f=x[a+40>>2];x[f>>2]=d;x[f+4>>2]=j;if((e|0)==8){break b}d=vv(x[a+32>>2]);if((d|0)==-1){break b}v[g|0]=d;e=e+1|0;continue}break}v[c+23|0]=y[c+24|0]}f:{if(!b){while(1){if((e|0)<=0){break f}d=-1;e=e-1|0;if((zt(Pf(v[e+(c+24|0)|0]),x[a+32>>2])|0)!=-1){continue}break a}}d=Pf(v[c+23|0]);x[a+48>>2]=d;break a}d=Pf(v[c+23|0]);break a}d=-1}fb=c+32|0;return d}function wna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0;g=fb-16|0;fb=g;p=x[a+16>>2];j=mg(1,2);b=hb;q=b;Pb(a,j,b);f=x[a+48>>2];r=x[a+24>>2];s=x[a+20>>2];e=x[a+44>>2];b=x[a+4>>2];x[g+8>>2]=x[a>>2];x[g+12>>2]=b;t=x[a+72>>2];k=x[a+68>>2];u=k>>31;l=x[a+64>>2];v=l>>31;m=x[a+60>>2];y=m>>31;z=x[a+8>>2];A=x[a+12>>2];while(1){b=e;if(d){n=w[(x[g+12>>2]<<1)+p>>1]<<8;e=n;e=Sua(e,e>>31,m,y);i=hb;h=e;e=Yb(b,-16777216,16776704);e=Sua(l,v,e,e>>31);o=h+e|0;h=hb+i|0;h=e>>>0>o>>>0?h+1|0:h;f=Yb(f,-16777216,16776704);e=Sua(k,u,f,f>>31);i=e+o|0;f=hb+h|0;f=e>>>0>i>>>0?f+1|0:f;e=i+8388608|0;f=e>>>0<8388608?f+1|0:f;e=Rc(e,f,24);f=(e|0)/256|0;x[c>>2]=D(f,s)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(f,r);Pb(g+8|0,z,A);e=e-(t&n)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=x[g+12>>2];x[a>>2]=x[g+8>>2];x[a+4>>2]=c;x[a+48>>2]=f;x[a+44>>2]=b;Hg(a,j,q);fb=g+16|0}function sw(a){var b=0,c=0,d=0,e=0;c=fb-16|0;fb=c;a:{if(y[a+3|0]!=19){break a}v[a+3|0]=20;b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{b=y[a+5|0];switch(b>>>4|0){case 4:break j;case 3:break k;case 2:break l;case 1:break m;case 0:break n;case 13:break b;case 12:break c;case 11:break d;case 10:break e;case 9:break f;case 7:break g;case 6:break h;case 5:break i;default:break a}}v[a+3|0]=0;break a}v[a+3|0]=2;v[a+5|0]=b|240;break a}v[a+3|0]=3;v[a+5|0]=b|240;break a}v[a+5|0]=b&15|16;break a}v[a+5|0]=b&3|48;break a}v[a+5|0]=b&223^120;break a}v[a+5|0]=b&15|176;break a}v[a+5|0]=b&3|64;break a}v[a+3|0]=15;v[a+5|0]=b&15;break a}if(b&15){v[a+3|0]=11;v[a+5|0]=b<<4|15;break a}v[a+3|0]=0;break a}b=b&15;if(b){v[a+3|0]=11;x[c+12>>2]=b;x[c+8>>2]=14;d=a,e=y[ud(c+12|0,c+8|0)|0]|240,v[d+5|0]=e;break a}v[a+3|0]=0;break a}if((b|0)!=192){break a}v[a|0]=254;v[a+3|0]=0;break a}if((b|0)!=208){break a}v[a+3|0]=0}fb=c+16|0}function kba(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=fb-16|0;fb=d;x[31737]=0;f=P(21,d+8|0,a|0)|0;c=x[31737];x[31737]=0;a:{b:{c:{if((c|0)!=1){d:{if(!Gd(y[f|0])){break d}c=d+4|0;bd(c,x[(x[x[a>>2]-12>>2]+a|0)+28>>2]);x[31737]=0;g=R(1138,x[d+4>>2])|0;e=x[31737];x[31737]=0;e:{f:{if((e|0)!=1){Zb(c);c=up(d,a);e=x[x[a>>2]-12>>2];x[31737]=0;e=a+e|0;h=R(22,e|0)|0;i=x[31737];x[31737]=0;if((i|0)==1){break f}c=x[c>>2];x[31737]=0;c=Ra(1139,g|0,c|0,e|0,h|0,+b)|0;g=x[31737];x[31737]=0;if((g|0)==1){break f}if(c){break d}c=x[x[a>>2]-12>>2];x[31737]=0;O(24,a+c|0,5);c=x[31737];x[31737]=0;if((c|0)!=1){break d}c=T(0)|0;break e}c=T(0)|0;Zb(d+4|0);break e}c=T(0)|0}nm(f);break c}nm(f);break b}c=T(0)|0}Y(c|0)|0;c=x[x[a>>2]-12>>2];x[31737]=0;W(25,a+c|0);c=x[31737];x[31737]=0;if((c|0)==1){break a}Z()}fb=d+16|0;return a|0}a=N()|0;x[31737]=0;X(26);d=x[31737];x[31737]=0;if((d|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function Tt(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c=fb+-64|0;fb=c;b=x[a>>2];a=x[b>>2];d=x[a+4>>2];x[c+40>>2]=x[a+20>>2];e=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=e;Zf(c+48|0,c+32|0,d);a=x[b+4>>2];d=x[a+8>>2];e=x[a+4>>2];b=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=b;b=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=b;x[c+8>>2]=x[a+8>>2];b=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=b;a:{b:{c:{d:{f=x[c+4>>2];if(f>>>0>=e>>>0){g=x[c+20>>2];if(g>>>0<e>>>0){break d}if(d>>>0>A[c+8>>2]){break c}h=x[c+28>>2];if(d>>>0>x[c+24>>2]-h>>>0){break b}j=x[c+16>>2];k=x[c>>2];b=0;e:while(1){if((b|0)==(d|0)){break a}l=(D(b,f)<<2)+k|0;m=(D(b+h|0,g)<<2)+j|0;a=0;while(1)if((a|0)==(e|0)){b=b+1|0;continue e}else{i=a<<2;B[i+m>>2]=E(x[l+i>>2])*E(7.450580596923828e-9);a=a+1|0;continue}}}_(7244,9061,33,8774);p()}_(7209,9061,34,8774);p()}_(5897,9061,35,8774);p()}_(5867,9061,36,8774);p()}fb=c- -64|0}function Ima(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=fb-16|0;fb=e;a:{b:{c:{f=x[a+12>>2];h=x[a+8>>2];d:{if((f|0)<=1&h>>>0<=805306368|(f|0)<=0){if((f|0)>=-2&h>>>0>=3489660928|(f|0)>-2){break c}if((f|0)==-2&h>>>0>2147483647|(f|0)==-1){break d}break b}if((f|0)==1&h>>>0>2147483648|f>>>0>1){break b}}i=b+196648|0;break a}i=b+131112|0;break a}i=b+262184|0}j=x[a+16>>2];k=x[a+24>>2];l=x[a+20>>2];b=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=b;while(1){if(d){b=x[e+8>>2];g=(x[e+12>>2]<<1)+j|0;b=(b>>>16&65520)+i|0;b=(((((((D(w[g-4>>1],w[b+2>>1])+D(w[g-6>>1],w[b>>1])|0)+D(w[g-2>>1],w[b+4>>1])|0)+D(w[g>>1],w[b+6>>1])|0)+D(w[g+2>>1],w[b+8>>1])|0)+D(w[g+4>>1],w[b+10>>1])|0)+D(w[g+6>>1],w[b+12>>1])|0)+D(w[g+8>>1],w[b+14>>1])|0)/32768|0;x[c>>2]=x[c>>2]+D(b,l);x[c+4>>2]=x[c+4>>2]+D(b,k);Pb(e+8|0,h,f);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;fb=e+16|0}function Zha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{f=b;c=fb-16|0;fb=c;d=Fb(a);while(1){b:{c:{d:{if(Yc(x[f+4>>2],y[f+11|0])>>>0>g>>>0){b=x[Vd(f,g)>>2];if(b>>>0>=2097152){x[31737]=0;O(969,d|0,63);a=x[31737];x[31737]=0;if((a|0)!=1){break c}break b}a=0;while(1){if((a|0)==6){b=7;a=6;break d}e=b&63;v[(c+10|0)+a|0]=e;if(b>>>0>=64){a=a+1|0;b=b>>>6|0;continue}break}if(a){b=a+1|0;if((b|0)!=2){break d}a=1;b=2;if((e|0)!=1){break d}a=y[c+10|0]|64}else{a=y[c+10|0]}x[31737]=0;O(969,d|0,a<<24>>24);a=x[31737];x[31737]=0;if((a|0)!=1){break c}break b}fb=c+16|0;break a}i=(2<<a)+255<<7-a;e=b-1|0;j=e+(c+10|0)|0;a=b;while(1){if(!a){break c}e:{if((a|0)==(b|0)){a=y[j|0];x[31737]=0;O(969,d|0,(a|i)<<24>>24);h=x[31737];x[31737]=0;a=e;break e}x[31737]=0;a=a-1|0;O(969,d|0,v[a+(c+10|0)|0]|-128);h=x[31737];x[31737]=0}if((h|0)!=1){continue}break}break b}g=g+1|0;continue}break}a=N()|0;tb(d);Q(a|0);p()}}function $I(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;b=0;a=c;while(1){a:{if(a>>>0>=d>>>0|b>>>0>=e>>>0){break a}g=1;f=v[a|0];b:{if((f|0)>=0){break b}if(f>>>0<4294967234){break a}if(f>>>0<=4294967263){if((d-a|0)<2){break a}g=2;if((y[a+1|0]&192)!=128){break a}break b}g=f&255;if(f>>>0<=4294967279){if((d-a|0)<3){break a}h=y[a+2|0];f=y[a+1|0];c:{d:{if((g|0)!=237){if((g|0)!=224){break d}if((f&224)==160){break c}break a}if((f&224)!=128){break a}break c}if((f&192)!=128){break a}}g=3;if((h&192)!=128){break a}break b}if((d-a|0)<4|f>>>0>4294967284|e-b>>>0<2){break a}h=y[a+3|0];i=y[a+2|0];f=y[a+1|0];e:{f:{switch(g-240|0){case 0:if((f+112&255)>>>0>=48){break a}break e;case 4:if((f&240)!=128){break a}break e;default:break f}}if((f&192)!=128){break a}}if((i&192)!=128|(h&192)!=128|(g<<18&1835008|(f&48)<<12)>>>0>1114111){break a}b=b+1|0;g=4}b=b+1|0;a=a+g|0;continue}break}return a-c|0}function xna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0,A=0;g=fb-16|0;fb=g;p=x[a+16>>2];j=mg(1,2);b=hb;q=b;Pb(a,j,b);f=x[a+48>>2];r=x[a+24>>2];s=x[a+20>>2];e=x[a+44>>2];b=x[a+4>>2];x[g+8>>2]=x[a>>2];x[g+12>>2]=b;t=x[a+72>>2];k=x[a+68>>2];u=k>>31;l=x[a+64>>2];w=l>>31;m=x[a+60>>2];y=m>>31;z=x[a+8>>2];A=x[a+12>>2];while(1){b=e;if(d){n=v[x[g+12>>2]+p|0]<<16;e=n;e=Sua(e,e>>31,m,y);i=hb;h=e;e=Yb(b,-16777216,16776704);e=Sua(l,w,e,e>>31);o=h+e|0;h=hb+i|0;h=e>>>0>o>>>0?h+1|0:h;f=Yb(f,-16777216,16776704);e=Sua(k,u,f,f>>31);i=e+o|0;f=hb+h|0;f=e>>>0>i>>>0?f+1|0:f;e=i+8388608|0;f=e>>>0<8388608?f+1|0:f;e=Rc(e,f,24);f=(e|0)/256|0;x[c>>2]=D(f,s)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(f,r);Pb(g+8|0,z,A);e=e-(t&n)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=x[g+12>>2];x[a>>2]=x[g+8>>2];x[a+4>>2]=c;x[a+48>>2]=f;x[a+44>>2]=b;Hg(a,j,q);fb=g+16|0}function OV(a,b,c,d){var e=0,f=0;e=fb-16|0;fb=e;v[e+15|0]=c;f=b&15;b=y[f+25488|0];a:{b:{switch(f|0){case 0:b=c?d>>>0>=51?b:0:0;break a;case 5:c:{d:{f=c&15;e:{if(!((f|0)!=2&(c&240)!=32)){c=159;v[e+15|0]=159;b=20;break e}if((f|0)==12){break d}}if(d>>>0<51){break a}if((c&240)==192){break c}break a}if(d>>>0<51){break a}}v[e+15|0]=0;b=25;break a;case 7:b=d>>>0>=52?b:0;break a;case 10:c=c&240;if(!c){break a}v[e+15|0]=c;break a;case 11:v[e+15|0]=D(c&15,17);break a;case 13:v[e+15|0]=D(c>>>4|0,10)+(c&15);break a;case 14:f:{switch((c>>>4|0)-1|0){case 0:v[e+15|0]=c|240;b=2;break a;case 1:v[e+15|0]=c|240;b=3;break a;case 7:if(d>>>0<52){break a}v[e+15|0]=c&15|96;case 11:case 12:b=20;break a;case 8:b=15;v[e+15|0]=c&15;break a;case 9:v[e+15|0]=c<<4|15;b=11;break a;case 10:break f;default:break a}}v[e+15|0]=c|240;b=11;break a;case 15:break b;default:break a}}b=c>>>0>47?17:b}de(a,b,e+15|0);fb=e+16|0}function VK(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=fb-32|0;fb=c;a:{if(y[a+52|0]){d=x[a+48>>2];if(!b){break a}v[a+52|0]=0;x[a+48>>2]=-1;break a}x[c+24>>2]=1;e=x[Ye(c+24|0,a+44|0)>>2];g=(e|0)>0?e:0;while(1){if((f|0)!=(g|0)){d=-1;h=vv(x[a+32>>2]);if((h|0)==-1){break a}v[(c+24|0)+f|0]=h;f=f+1|0;continue}break}b:{c:{if(y[a+53|0]){x[c+20>>2]=v[c+24|0];break c}h=c+24|0;while(1){d:{f=x[a+40>>2];d=x[f>>2];j=x[f+4>>2];i=c+24|0;g=i+e|0;e:{switch(gL(x[a+36>>2],f,i,g,c+16|0,c+20|0,h,c+12|0)-1|0){case 0:break e;case 1:break b;case 2:break d;default:break c}}f=x[a+40>>2];x[f>>2]=d;x[f+4>>2]=j;if((e|0)==8){break b}d=vv(x[a+32>>2]);if((d|0)==-1){break b}v[g|0]=d;e=e+1|0;continue}break}x[c+20>>2]=v[c+24|0]}f:{if(!b){while(1){if((e|0)<=0){break f}d=-1;e=e-1|0;if((zt(v[e+(c+24|0)|0],x[a+32>>2])|0)!=-1){continue}break a}}d=x[c+20>>2];x[a+48>>2]=d;break a}d=x[c+20>>2];break a}d=-1}fb=c+32|0;return d}function cJ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a=c;while(1){a:{if(e>>>0<=i>>>0|a>>>0>=d>>>0){break a}f=1;b=v[a|0];b:{if((b|0)>=0){break b}if(b>>>0<4294967234){break a}if(b>>>0<=4294967263){if((d-a|0)<2){break a}f=2;if((y[a+1|0]&192)!=128){break a}break b}g=b&255;if(b>>>0<=4294967279){if((d-a|0)<3){break a}h=y[a+2|0];b=y[a+1|0];c:{d:{if((g|0)!=237){if((g|0)!=224){break d}if((b&224)==160){break c}break a}if((b&224)!=128){break a}break c}if((b&192)!=128){break a}}f=3;if((h&192)!=128){break a}break b}if((d-a|0)<4|b>>>0>4294967284){break a}f=y[a+3|0];h=y[a+2|0];b=y[a+1|0];e:{f:{switch(g-240|0){case 0:if((b+112&255)>>>0>=48){break a}break e;case 4:if((b&240)!=128){break a}break e;default:break f}}if((b&192)!=128){break a}}if((h&192)!=128|(f&192)!=128){break a}f=4;if((g<<18&1835008|(b&48)<<12)>>>0>1114111){break a}}i=i+1|0;a=a+f|0;continue}break}return a-c|0}function Jma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=fb-16|0;fb=e;a:{b:{c:{f=x[a+12>>2];h=x[a+8>>2];d:{if((f|0)<=1&h>>>0<=805306368|(f|0)<=0){if((f|0)>=-2&h>>>0>=3489660928|(f|0)>-2){break c}if((f|0)==-2&h>>>0>2147483647|(f|0)==-1){break d}break b}if((f|0)==1&h>>>0>2147483648|f>>>0>1){break b}}i=b+196648|0;break a}i=b+131112|0;break a}i=b+262184|0}j=x[a+16>>2];k=x[a+24>>2];l=x[a+20>>2];b=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=b;while(1){if(d){b=x[e+8>>2];g=x[e+12>>2]+j|0;b=(b>>>16&65520)+i|0;b=(((((((D(v[g-2|0],w[b+2>>1])+D(v[g-3|0],w[b>>1])|0)+D(v[g-1|0],w[b+4>>1])|0)+D(v[g|0],w[b+6>>1])|0)+D(v[g+1|0],w[b+8>>1])|0)+D(v[g+2|0],w[b+10>>1])|0)+D(v[g+3|0],w[b+12>>1])|0)+D(v[g+4|0],w[b+14>>1])<<8)/32768|0;x[c>>2]=x[c>>2]+D(b,l);x[c+4>>2]=x[c+4>>2]+D(b,k);Pb(e+8|0,h,f);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;fb=e+16|0}function Ut(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=fb+-64|0;fb=c;b=x[a>>2];a=x[b>>2];d=x[a+4>>2];x[c+40>>2]=x[a+20>>2];e=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=e;Zf(c+48|0,c+32|0,d);a=x[b+4>>2];d=x[a+8>>2];e=x[a+4>>2];b=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=b;b=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=b;x[c+8>>2]=x[a+8>>2];b=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=b;a:{b:{c:{d:{f=x[c+4>>2];if(f>>>0>=e>>>0){if(A[c+20>>2]<e>>>0){break d}if(d>>>0>A[c+8>>2]){break c}g=x[c+28>>2];if(d>>>0>x[c+24>>2]-g>>>0){break b}i=x[c+16>>2];j=x[c>>2];b=0;e:while(1){if((b|0)==(d|0)){break a}k=(D(b,f)<<2)+j|0;a=0;while(1)if((a|0)==(e|0)){b=b+1|0;continue e}else{h=a<<2;B[(x[h+i>>2]+(g<<2)|0)+(b<<2)>>2]=E(x[k+h>>2])*E(7.450580596923828e-9);a=a+1|0;continue}}}_(7244,9061,33,8774);p()}_(7209,9061,34,8774);p()}_(5897,9061,35,8774);p()}_(5867,9061,36,8774);p()}fb=c- -64|0}function BE(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;f=fb-560|0;fb=f;w[f+558>>1]=b;a:{if((b-256&65535)>>>0<65281){break a}e=((b<<2)+a|0)+900380|0;b=x[e>>2];b:{if(b){c=pV(f,c);d=x[c+4>>2];x[b>>2]=x[c>>2];x[b+4>>2]=d;d=y[c+11|0]|y[c+12|0]<<8|(y[c+13|0]<<16|y[c+14|0]<<24);e=y[c+7|0]|y[c+8|0]<<8|(y[c+9|0]<<16|y[c+10|0]<<24);v[b+7|0]=e;v[b+8|0]=e>>>8;v[b+9|0]=e>>>16;v[b+10|0]=e>>>24;v[b+11|0]=d;v[b+12|0]=d>>>8;v[b+13|0]=d>>>16;v[b+14|0]=d>>>24;v[b+15|0]=y[c+15|0];d=x[c+44>>2];x[b+40>>2]=x[c+40>>2];x[b+44>>2]=d;d=x[c+36>>2];x[b+32>>2]=x[c+32>>2];x[b+36>>2]=d;d=x[c+28>>2];x[b+24>>2]=x[c+24>>2];x[b+28>>2]=d;d=x[c+20>>2];x[b+16>>2]=x[c+16>>2];x[b+20>>2]=d;NA(b+48|0,c+48|0);NA(b+68|0,c+68|0);NA(b+88|0,c+88|0);yc(b+108|0,c+108|0,448);d=b;Hv(c);break b}b=yu(556);if(!b){x[e>>2]=0;break a}d=pV(b,c);x[e>>2]=d}g=a,h=z[pe(a+480192|0,f+558|0)>>1],w[g+480192>>1]=h}fb=f+560|0;return d|0}function H1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{f=b;c=fb-16|0;fb=c;d=Fb(a);while(1){b:{c:{d:{if(Yc(x[f+4>>2],y[f+11|0])>>>0>g>>>0){b=x[Vd(f,g)>>2];if(b>>>0>=2097152){x[31737]=0;O(50,d|0,63);a=x[31737];x[31737]=0;if((a|0)!=1){break c}break b}a=0;while(1){if((a|0)==6){b=7;a=6;break d}e=b&63;v[(c+10|0)+a|0]=e;if(b>>>0>=64){a=a+1|0;b=b>>>6|0;continue}break}if(a){b=a+1|0;if((b|0)!=2){break d}a=1;b=2;if((e|0)!=1){break d}a=y[c+10|0]|64}else{a=y[c+10|0]}x[31737]=0;O(50,d|0,a&255);a=x[31737];x[31737]=0;if((a|0)!=1){break c}break b}fb=c+16|0;break a}e=b-1|0;i=e+(c+10|0)|0;j=(2<<a)+255<<7-a&255;a=b;while(1){if(!a){break c}e:{if((a|0)==(b|0)){a=y[i|0];x[31737]=0;O(50,d|0,a|j);h=x[31737];x[31737]=0;a=e;break e}x[31737]=0;a=a-1|0;O(50,d|0,y[a+(c+10|0)|0]|128);h=x[31737];x[31737]=0}if((h|0)!=1){continue}break}break b}g=g+1|0;continue}break}a=N()|0;tb(d);Q(a|0);p()}}function voa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=fb-16|0;fb=e;w[e+12>>1]=c;w[e+14>>1]=b;w[e+10>>1]=d;g=z[x[x[a+24>>2]+8>>2]+12>>1];a:{if(g>>>0<=b>>>0){break a}if(!c|Oj(a)>>>0>=g>>>0){break a}Gf(e+12|0,g-b&65535);k=e,l=km(x[a>>2],x[a+4>>2]),w[k+8>>1]=l;d=z[e+12>>1];NY(a,d+z[pe(e+14|0,e+8|0)>>1]|0);f=e+4|0;c=a;a=x[a>>2];if(Zc(a,x[c+4>>2])>>>0<b>>>0){xg(c,b);a=x[c>>2]}a=vb(f,fV(wb(a),b));h=e+10|0;j=fb-32|0;fb=j;b=x[a>>2];a=x[c>>2];f=(pp(b,wb(a))<<1)+a|0;a=d;b:{if(!a){break b}b=x[zb(c)>>2];i=x[c+4>>2];if(a>>>0<=b-i>>1>>>0){b=a;d=i-f>>1;if(d>>>0<a>>>0){yp(c,a-d|0,h);b=d;if((f|0)==(i|0)){break b}}dV(c,f,i,(a<<1)+f|0);Fv(f,b,((f>>>0<=h>>>0?A[c+4>>2]>h>>>0?a:0:0)<<1)+h|0);break b}b=zb(c);b=kk(j+12|0,lk(c,Zc(x[c>>2],i)+a|0),f-x[c>>2]>>1,b);sF(b,a,h);f=cV(c,b,f);jj(b)}wb(f);fb=j+32|0;if(Zc(x[c>>2],x[c+4>>2])>>>0<=g>>>0){break a}xg(c,g)}fb=e+16|0}function dra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=fb-432|0;fb=d;xc(b);dD(b,d+380|0,d+300|0,d+16|0);k=d,l=Ch((m=y[d+431|0]+1|0,n=1,o=$b(y[d+412|0]|y[d+413|0]<<8|(y[d+414|0]<<16|y[d+415|0]<<24)),o?m:n)),v[k+12|0]=l;i=y[Qb(25216,d+12|0)|0];v[d+15|0]=i;w[d+12>>1]=4;a:{b:{while(1){if((h&255)>>>0>=i>>>0){break b}e=Bb(z[d+16>>1])<<16>>16;if(!((e|0)<0|y[d+299|0]>63)){e=e&65535;f=0;while(1){if((f|0)==(e|0)){c:{e=g;g=$b(x[d+300>>2]);if(e>>>0<g>>>0){if(cd(b,g)){break c}}v[d+15|0]=h+1;break b}}else{d:{if(!cd(b,$b(y[d+396|0]|y[d+397|0]<<8|(y[d+398|0]<<16|y[d+399|0]<<24))+(f<<2)|0)){break d}if(!cd(b,sp(b))){break d}e:{if(!c){j=Zd(b);break e}j=Uk(b)}w[d+10>>1]=j;k=d,l=z[pe(d+12|0,d+10|0)>>1],w[k+12>>1]=l}f=f+1|0;continue}break}g=$b(x[d+300>>2]);dD(b,d+380|0,d+300|0,d+16|0);h=h+1|0;continue}break}Rw(a);break a}JY(a,z[d+12>>1],d+15|0)}fb=d+432|0}function Dra(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;e=fb-16|0;fb=e;b=fb-16|0;fb=b;x[b+4>>2]=1073741824;w[b+10>>1]=12;c=Ec(64);x[31737]=0;d=R(879,c|0)|0;f=x[31737];x[31737]=0;a:{b:{c:{if((f|0)!=1){c=yf(b,d);d=x[c>>2];x[31737]=0;O(880,d|0,a|0);a=x[31737];x[31737]=0;if((a|0)==1){break c}a=x[c>>2];x[31737]=0;a=U(881,a|0,b+10|0,b+4|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break c}d:{if(!a){sc(b+12|0);break d}a=x[c>>2];x[31737]=0;O(882,a|0,15);a=x[31737];x[31737]=0;if((a|0)==1){break c}qe(b+12|0,c)}og(c);fb=b+16|0;b=x[b+12>>2];break a}a=N()|0;Db(c);break b}a=N()|0;og(c)}Q(a|0);p()}x[e+12>>2]=b;a=0;e:{f:{g:{while(1){if((a|0)==12){break e}x[31737]=0;c=P(1,e|0,(a<<2)+30624|0)|0;d=x[31737];x[31737]=0;if((d|0)!=1){x[31737]=0;S(500,b|0,a|0,c|0);d=x[31737];x[31737]=0;if((d|0)==1){break g}tb(c);a=a+1|0;continue}break}a=N()|0;break f}a=N()|0;tb(c)}og(e+12|0);Q(a|0);p()}fb=e+16|0;return b|0}function Laa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=fb+-64|0;fb=c;b=x[a>>2];a=x[b>>2];d=x[a+4>>2];x[c+40>>2]=x[a+20>>2];e=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=e;Zf(c+48|0,c+32|0,d);a=x[b+4>>2];d=x[a+8>>2];e=x[a+4>>2];b=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=b;b=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=b;x[c+8>>2]=x[a+8>>2];b=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=b;a:{b:{c:{d:{f=x[c+4>>2];if(f>>>0>=e>>>0){g=x[c+20>>2];if(g>>>0<e>>>0){break d}if(d>>>0>A[c+8>>2]){break c}h=x[c+28>>2];if(d>>>0>x[c+24>>2]-h>>>0){break b}i=x[c+16>>2];j=x[c>>2];b=0;e:while(1){if((b|0)==(d|0)){break a}k=(D(b,f)<<3)+j|0;l=(D(b+h|0,g)<<2)+i|0;a=0;while(1)if((a|0)==(e|0)){b=b+1|0;continue e}else{B[(a<<2)+l>>2]=C[(a<<3)+k>>3];a=a+1|0;continue}}}_(7244,9061,77,8741);p()}_(7209,9061,78,8741);p()}_(5897,9061,79,8741);p()}_(5867,9061,80,8741);p()}fb=c- -64|0}function Dqa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=fb-16|0;fb=f;w[f+12>>1]=0;x[f+8>>2]=0;n=D(c,d);k=4;a:while(1){if((d|0)!=(l|0)){i=b+l|0;o=n+i|0;while(1){b:{c:{if(i>>>0<o>>>0){v[f+7|0]=0;vY(a,f+15|0,f+12|0,f+7|0);g=y[f+7|0];e=z[f+12>>1];c=k;while(1){if(c&255){h=e<<1;e=h&254;d:{if(e){h=(h&65534)>>>0>255;break d}if(!Af(a,f+6|0)){break c}e=y[f+6|0];h=e>>>7|0;e=e<<1&254|1}c=c-1|0;g=g<<1|h;continue}break}w[f+12>>1]=e;break b}l=l+1|0;continue a}w[f+12>>1]=0}c=1;h=g&255;e:{if(h>>>0<4){break e}e=7;while(1){c=e;m=e&255;if(m>>>0<2){break e}e=e-1|0;if(!(h&1<<m)){continue}break}}e=g&1;v[f+15|0]=e;g=e-1^(g&254)>>>1;e=g+y[f+8|0]|0;v[f+7|0]=e;v[i|0]=e;x[f+8>>2]=((g>>1)-(j<<24>>24)|0)+(e<<24>>24<<1);i=d+i|0;k=(c+k&254)>>>1|0;c=-128;j=x[f+8>>2];f:{if((j|0)>=-128){c=127;if((j|0)<128){break f}}x[f+8>>2]=c}j=e;continue}}break}fb=f+16|0}function UG(a,b,c,d){var e=0,f=0,g=0,h=0;g=fb-32|0;fb=g;f=d&2147483647;e=f-1065418752|0;h=f-1082064896|0;a:{if((e|0)==(h|0)&0|e>>>0<h>>>0){f=(d&33554431)<<7|c>>>25;e=0;h=e;c=c&33554431;if(!(!e&(c|0)==16777216?!(a|b):!e&c>>>0<16777216)){e=f+1073741825|0;break a}e=f+1073741824|0;if(c^16777216|a|(b|h)){break a}e=(f&1)+e|0;break a}if(!(!c&(f|0)==2147418112?!(a|b):f>>>0<2147418112)){e=((d&33554431)<<7|c>>>25)&4194303|2143289344;break a}e=2139095040;if(f>>>0>1082064895){break a}e=0;f=f>>>16|0;if(f>>>0<16145){break a}e=d&65535|65536;bg(g+16|0,a,b,c,e,f-16129|0);gn(g,a,b,c,e,16257-f|0);a=x[g+8>>2];e=(x[g+12>>2]&33554431)<<7|a>>>25;c=x[g>>2]|(x[g+16>>2]|x[g+24>>2]|(x[g+20>>2]|x[g+28>>2]))!=0;f=x[g+4>>2];b=0;a=a&33554431;if(!(!b&(a|0)==16777216?!(c|f):!b&a>>>0<16777216)){e=e+1|0;break a}if(a^16777216|c|(b|f)){break a}e=(e&1)+e|0}fb=g+32|0;return l(2,d&-2147483648|e),r()}function qma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;e=fb-16|0;fb=e;i=x[a+24>>2];j=x[a+20>>2];k=x[a+16>>2];h=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=h;l=b+24|0;h=x[a+8>>2];m=x[a+12>>2];while(1){if(d){b=x[e+8>>2];n=((((x[e+12>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+k|0;b=(((b>>>16|0)+4&131064)<<1)+l|0;o=w[b+14>>1];p=w[b+12>>1];q=w[b+10>>1];r=w[b+8>>1];s=w[b+6>>1];t=w[b+4>>1];u=w[b+2>>1];b=w[b>>1];g=0;while(1){if((g|0)!=2){f=(g<<1)+n|0;x[(g<<2)+e>>2]=(((((D(w[f+8>>1],q)+D(w[f+4>>1],r)|0)+D(w[f+12>>1],p)|0)+D(w[f+16>>1],o)|0)/2|0)+((((D(w[f-8>>1],u)+D(w[f-12>>1],b)|0)+D(w[f-4>>1],t)|0)+D(w[f>>1],s)|0)/2|0)|0)/16384;g=g+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[e>>2],j);x[c+4>>2]=x[c+4>>2]+D(x[e+4>>2],i);Pb(e+8|0,h,m);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;fb=e+16|0}function Aga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=E(0),m=0,n=0,o=E(0),p=E(0),q=E(0),r=E(0),s=E(0),t=E(0),u=E(0),v=E(0),w=E(0);h=fb-16|0;fb=h;if(zi(a+44|0)){f=x[a+44>>2];g=Hc(f,0);x[h+8>>2]=g;f=Hc(f,1);x[h+12>>2]=f;j=x[a+56>>2];m=Hc(j,0);x[h>>2]=m;j=Hc(j,1);x[h+4>>2]=j;a:{if(B[yb(a+4208|0,2)>>2]!=E(.5)){f=d;b:while(1){g=0;if(!f){break a}while(1)if((g|0)==2){f=f-1|0;continue b}else{k=g<<2;e=k+(h+8|0)|0;i=x[e>>2];x[e>>2]=i+4;e=a+k|0;n=e+4248|0;q=B[n>>2];l=B[i>>2];r=B[a+4236>>2];s=B[a+4232>>2];t=B[a+4228>>2];u=B[a+4220>>2];v=B[a+4224>>2];i=e+4240|0;o=B[i>>2];B[n>>2]=o;B[i>>2]=l;i=e+4264|0;w=B[i>>2];e=e+4256|0;p=B[e>>2];B[i>>2]=p;l=E(E(E(E(t*q)+E(E(u*l)+E(v*o)))-E(s*p))-E(r*w));B[e>>2]=l;k=h+k|0;e=x[k>>2];x[k>>2]=e+4;B[e>>2]=l;g=g+1|0;continue}}}e=g;g=d<<2;yc(m,e,g);yc(j,f,g);f=x[a+56>>2];m=Hc(f,0);j=Hc(f,1)}Pi(a,b,c,m,j,d)}fb=h+16|0}function pB(a,b,c,d,e){var f=0,g=0,h=0;g=D(c,872)+b|0;a:{if(d){if(!Ob(a+1074312|0,90)){v[g+1427|0]=d}v[(D(c,872)+b|0)+1428|0]=d;break a}d=y[g+1428|0]}f=x[a+480180>>2];if(!e){h=Iu(f)}g=g+616|0;b:{if((f|0)!=268435456){if((f|0)!=16777216){break b}f=x[(D(c,872)+b|0)+1272>>2];if(!f|!x[f+44>>2]){break b}a=d&255;if(!(a>>>0<240|e)){cT(b,c,240-a|0);return}if(!(a>>>0<224|e)){bT(g,224-a|0);return}aT(g,0-a|0);return}x[(D(c,872)+b|0)+1324>>2]=65535}e=d&255;c:{d:{if(!(e>>>0>223&h)){break d}e:{f=e&15;if(!f){break e}d=d&240;if((d|0)!=224){if((d|0)!=240){break e}mB(a,g,f);return}if(x[a+480180>>2]==524288){break d}lB(a,g,f);return}if(x[a+480180>>2]!=524288){break c}}b=D(c,872)+b|0;f:{if(!(v[b+1467|0]&1)){break f}if(x[a+1074416>>2]==1){if(Ob(a+1074312|0,6)){break f}}c=x[a+480180>>2];if(c&32832){break f}if(!(y[a+480208|0]&2)|(c|0)!=8){break c}}Ck(a,g,b+1316|0,0-(e<<2)|0,0)}}function cma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=fb-16|0;fb=e;n=x[a+16>>2];o=Fg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);i=x[a+8>>2];j=x[a+12>>2];b=x[a>>2];g=x[a+4>>2];k=x[a+128>>2];if(k){l=Gg(i,j,k);m=hb;f=x[a+76>>2];hg(b,g,vf(i,j,d),hb);h=hb>>>0>f>>>0?d:0}f=a+112|0;p=x[a+24>>2];q=x[a+20>>2];x[e>>2]=b;x[e+4>>2]=g;a:while(1){if(d){g=x[e+4>>2];x[e+8>>2]=x[e>>2];x[e+12>>2]=0;h=h-1|0;l=h?l:0;m=h?m:0;d=d-1|0;g=(g<<1)+n|0;b=k;while(1)if((b|0)<=0){Pb(f,x[a+120>>2],x[a+124>>2]);b=x[a+116>>2];if(b){be(f,w[(x[e+12>>2]<<1)+g>>1]/4<<16>>16);ae(f,b);x[f>>2]=x[f>>2];x[f+4>>2]=0}b=Eg(f,o);x[c>>2]=x[c>>2]+D(b,q);x[c+4>>2]=x[c+4>>2]+D(b,p);Pb(e,i,j);c=c+8|0;continue a}else{be(f,w[(x[e+12>>2]<<1)+g>>1]/4<<16>>16);ae(f,4);Pb(e+8|0,l,m);b=b-1|0;continue}}break}b=x[e+4>>2];x[a>>2]=x[e>>2];x[a+4>>2]=b;fb=e+16|0}function UC(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;i=fb-32|0;fb=i;h=fb-16|0;fb=h;ld(b,1);g=Bb(y[a+22|0]|y[a+23|0]<<8)<<1;x[b>>2]=g;v[b+37|0]=y[a+24|0]<<4;v[h+15|0]=y[a+25|0];v[h+14|0]=64;l=b,m=y[Qb(h+15|0,h+14|0)|0]<<2,w[l+30>>1]=m;f=Bb(y[a+26|0]|y[a+27|0]<<8);e=f<<1;k=Bb(y[a+28|0]|y[a+29|0]<<8);j=k<<1;e=k>>>0>=2?e+j>>>0<=g>>>0?e:f+j>>>0>g>>>0?e:f:e;a:{b:{switch(g|0){case 2:x[b>>2]=0;break a;case 0:break a;default:break b}}x[b+4>>2]=e;f=e+j|0;x[b+8>>2]=f;if(e>>>0>=g>>>0){e=g-1|0;x[b+4>>2]=e}if(!(!(f>>>0<4|e>>>0>f>>>0)&f-e>>>0>3)){x[b+4>>2]=0;x[b+8>>2]=0;f=0;e=0}if(!(f>>>0>8|f>>>0>=g>>>0|(!d|e))){x[b+8>>2]=0;break a}if(e>>>0>=f>>>0){break a}w[b+34>>1]=z[b+34>>1]|2}fb=h+16|0;d=i+8|0;Xk(d,3,a);b=i+20|0;Cc(b,d);c=zc(c,b);tb(b);d=0;while(1){if((d|0)!=32){b=c+d|0;if((y[b|0]-1&255)>>>0<=30){v[b|0]=32}d=d+1|0;continue}break}a=WC(a);fb=i+32|0;return a}function Una(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=fb-32|0;fb=g;e=fb-16|0;fb=e;c=a+33|0;x[b>>2]=y[c+206|0]|y[c+207|0]<<8;GR(c,b+48|0,y[c+192|0],y[c+200|0],y[c+194|0],y[c+195|0],y[c+196|0],0);GR(c,b+68|0,y[c+193|0],y[c+201|0],y[c+197|0],y[c+198|0],y[c+199|0],1);f=b+236|0;while(1){if((d|0)==96){if(y[c+208|0]){v[b+31|0]=y[c+209|0]+1;f=y[b+31|0];a:{b:{if(!f){d=1;break b}d=16;if(f>>>0<17){break a}}v[b+31|0]=d}w[e+14>>1]=y[c+210|0]|y[c+211|0]<<8;w[e+12>>1]=127;j=b,k=y[Nc(e+14|0,e+12|0)|0]+1|0,v[j+30|0]=k}v[b+33|0]=y[c+212|0];fb=e+16|0}else{i=y[c+d|0];j=_b(f,d+12|0),k=i,w[j>>1]=k;d=d+1|0;continue}break}e=b+236|0;while(1){if((h|0)!=96){d=y[c+h|0];f=y[a+27|0]|y[a+28|0]<<8;j=_b(e,h+12|0),k=d>>>0<f>>>0?d:0,w[j>>1]=k;h=h+1|0;continue}break}d=g+8|0;Xk(d,3,a+4|0);c=g+20|0;Cc(c,d);zc(b+492|0,c);tb(c);if(!y[a+241|0]){v[b+30|0]=y[a+26|0]}fb=g+32|0}function RH(a,b,c,d,e,f,g,h){var i=0,j=0,k=E(0);i=fb-96|0;fb=i;KA(x[a+24>>2]);v[x[a+24>>2]+1298424|0]=x[a+52>>2]!=0;x[i+92>>2]=f;x[i+88>>2]=e;x[i+84>>2]=d;x[i+80>>2]=c;a:{d=i+80|0;c=0;while(1){b:{if((c|0)!=4){if(x[(c<<2)+d>>2]){break b}}else{c=4}break a}c=c+1|0;continue}}x[i+44>>2]=b;x[i+40>>2]=c;x[i+36>>2]=d;e=x[a+32>>2];k=B[a+48>>2];x[i+8>>2]=b;c=x[i+40>>2];x[i>>2]=x[i+36>>2];x[i+4>>2]=c;d=fb-16|0;fb=d;x[d+8>>2]=x[i+8>>2];c=x[i+4>>2];x[d>>2]=x[i>>2];x[d+4>>2]=c;c=PM(i+48|0);x[c+8>>2]=e;x[c+4>>2]=0;x[c>>2]=h;e=x[d+4>>2];x[c+12>>2]=x[d>>2];x[c+16>>2]=e;x[c+20>>2]=x[d+8>>2];C[c+24>>3]=k;x[c>>2]=g;fb=d+16|0;while(1){if(b){d=x[a+24>>2];x[i+24>>2]=b;x[i+28>>2]=0;x[i+16>>2]=134217727;x[i+20>>2]=0;d=QM(d,x[_r(i+24|0,i+16|0)>>2],c);j=d+j|0;b=b-d|0;if(d){continue}}break}if(!(x[a+52>>2]!=1|j)){a=x[a+24>>2];x[a+480208>>2]=x[a+480208>>2]&-513}fb=i+96|0;return j}function Uaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=fb+-64|0;fb=c;b=x[a>>2];a=x[b>>2];d=x[a+4>>2];x[c+40>>2]=x[a+20>>2];e=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=e;Zf(c+48|0,c+32|0,d);a=x[b+4>>2];d=x[a+8>>2];e=x[a+4>>2];b=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=b;b=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=b;x[c+8>>2]=x[a+8>>2];b=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=b;a:{b:{c:{d:{f=x[c+4>>2];if(f>>>0>=e>>>0){if(A[c+20>>2]<e>>>0){break d}if(d>>>0>A[c+8>>2]){break c}g=x[c+28>>2];if(d>>>0>x[c+24>>2]-g>>>0){break b}h=x[c+16>>2];i=x[c>>2];b=0;e:while(1){if((b|0)==(d|0)){break a}j=(D(b,f)<<3)+i|0;a=0;while(1)if((a|0)==(e|0)){b=b+1|0;continue e}else{B[(x[(a<<2)+h>>2]+(g<<2)|0)+(b<<2)>>2]=C[(a<<3)+j>>3];a=a+1|0;continue}}}_(7244,9061,77,8741);p()}_(7209,9061,78,8741);p()}_(5897,9061,79,8741);p()}_(5867,9061,80,8741);p()}fb=c- -64|0}function oG(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;h=fb-16|0;fb=h;d=zb(a);c=vb(h+12|0,x[a+4>>2]);g=vb(h+8|0,x[a>>2]);f=vb(h+4|0,x[b+4>>2]);e=x[c>>2];g=x[g>>2];c=fb+-64|0;fb=c;f=x[f>>2];x[c+56>>2]=f;x[c+60>>2]=e;x[c+52>>2]=f;d=Re(c+24|0,d,c+52|0,c+56|0);x[c+16>>2]=x[d+8>>2];f=x[d+4>>2];x[c+8>>2]=x[d>>2];x[c+12>>2]=f;Qe(c+36|0,c+8|0);while(1){if(pd(e,g)){bx(lG(x[c+56>>2]),lj(e));e=mG(c+60|0);mG(c+56|0);e=x[e>>2];continue}break}Pe(c+36|0);i=x[c+56>>2];if(!y[c+48|0]){g=fb-16|0;fb=g;d=vb(g+12|0,x[x[c+44>>2]>>2]);j=x[vb(g+8|0,x[x[c+40>>2]>>2])>>2];e=fb-16|0;fb=e;f=x[d>>2];x[e+12>>2]=f;while(1){if(ci(f,j)){d=fb-16|0;fb=d;x[d+12>>2]=f;x[d+12>>2]=x[d+12>>2]+36;fb=d+16|0;Mp(lG(x[d+12>>2]));x[e+12>>2]=x[e+12>>2]+36;f=x[e+12>>2];continue}break}fb=e+16|0;fb=g+16|0}fb=c- -64|0;x[b+4>>2]=i;Tb(a,b+4|0);Tb(a+4|0,b+8|0);Tb(zb(a),nc(b));x[b>>2]=x[b+4>>2];fb=h+16|0}function Tm(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=fb-16|0;fb=e;x[a+4>>2]=0;if(Gd(y[Lm(e+15|0,a,1)|0])){a:{b:{c:{if((b|0)==2147483647){b=a+24|0;while(1){c=x[b+x[x[a>>2]-12>>2]>>2];x[31737]=0;c=R(84,c|0)|0;d=x[31737];x[31737]=0;d:{if((d|0)!=1){if(!mc(c,-1)){break d}break b}break c}x[a+4>>2]=x[a+4>>2]+1;continue}}if(x[a+4>>2]>=(b|0)){break a}c=a+24|0;e:{while(1){d=x[c+x[x[a>>2]-12>>2]>>2];x[31737]=0;d=R(84,d|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break e}if(mc(d,-1)){break b}d=x[a+4>>2]+1|0;x[a+4>>2]=d;if((b|0)>(d|0)){continue}break}c=0;break a}}Y(T(0)|0)|0;c=1;Jm(x[x[a>>2]-12>>2]+a|0,1);f:{g:{if(x[(x[x[a>>2]-12>>2]+a|0)+20>>2]&1){x[31737]=0;X(85);a=x[31737];x[31737]=0;if((a|0)!=1){break f}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)==1){break g}Q(a|0);p()}Z();break a}T(0)|0;Sb()}p()}c=2}bk(x[x[a>>2]-12>>2]+a|0,c)}fb=e+16|0;return a|0}function Nm(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;Cl(a);a:{b:{c:{f=x[b+32>>2];d:{if(!f){e=x[b+2084>>2];if(e){break d}break b}c=x[b+4>>2];if((c|0)<9){break c}e=x[b+2084>>2];if(!e){break c}}h=x[a+1392>>2];j=Mm(h);d=x[b+2092>>2];c=0;while(1){if((d|0)>=2){f=d>>>1|0;i=f+c|0;g=A[(i<<2)+e>>2]>j>>>0;d=g?f:d-f|0;c=g?c:i;continue}break}d=x[a+1396>>2];c=y[b+23|0]?c:x[x[b+2088>>2]+(c<<2)>>2];b=y[c+x[b+8>>2]|0];e:{if((d|0)<(b|0)){c=-1;b=0;break e}x[a+1392>>2]=h>>>b;b=d-b|0}x[a+1396>>2]=b;return c}if(y[b+23|0]){break a}e=(c|0)>0?c:0;while(1){if((d|0)!=(e|0)){f:{c=y[x[b+8>>2]+d|0];if((c|0)==255){break f}g=x[a+1392>>2];if(x[f+(d<<2)>>2]!=(g&(-1<<c^-1))){break f}e=x[a+1396>>2];if((e|0)>=(c|0)){x[a+1392>>2]=g>>>c;x[a+1396>>2]=e-y[x[b+8>>2]+d|0];return d}x[a+1396>>2]=0;break b}d=d+1|0;continue}break}fc(a,21);x[a+1396>>2]=0}return-1}_(11394,13274,1705,5445);p()}function w0(a,b,c){var d=0,e=0;e=fb-16|0;fb=e;v[e+15|0]=c;a:{if(b>>>0>35){break a}b:{c:{d:{e:{f:{g:{h:{d=y[b+24704|0];switch(d-6|0){case 2:case 3:case 4:case 6:case 7:case 9:case 10:case 12:break a;case 11:break c;case 13:break d;case 0:case 1:case 5:break f;case 8:break g;default:break h}}if((d|0)==31){break b}if((d|0)==23){break e}if((d|0)!=1){break a}d=(c|0)!=0;break a}v[e+15|0]=D(c>>>4|0,10)+(c&15);d=14;break a}b=c&240;if(!b|(b|0)==240|(c&15)==15){break a}v[e+15|0]=b;break a}if(c>>>0<=64){v[e+15|0]=c<<1;d=23;break a}v[e+15|0]=128;d=23;break a}d=19;i:{switch(c-48>>>4|0){case 0:v[e+15|0]=159;d=20;break a;case 1:v[e+15|0]=192;d=20;break a;case 2:if(c&14){break a}v[e+15|0]=((c|0)!=80)<<6;d=21;break a;case 4:break i;default:break a}}v[e+15|0]=c&15|160;d=20;break a}d=c>>>0<32?16:17;break a}v[e+15|0]=(b<<5|c>>>3)^128;d=31}de(a,d,e+15|0);fb=e+16|0}function ppa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=fb-16|0;fb=c;d=c+11|0;zX(a,d);if((y[c+11|0]|y[c+12|0]<<8|(y[c+13|0]<<16|y[c+14|0]<<24))==1414807888){zX(a,d);v[b|0]=1;b=0}else{b=1}a=fb-176|0;fb=a;e=a+12|0;Sw(e,(c+11|0)+b|0);x[31737]=0;d=a+24|0;O(125,d|0,e|0);b=x[31737];x[31737]=0;a:{b:{c:{d:{e:{if((b|0)!=1){x[31737]=0;b=P(104,a+36|0,d|0)|0;g=x[31737];x[31737]=0;if((g|0)==1){break e}tb(d);tb(e);e=x[x[b>>2]-12>>2];x[31737]=0;g=ca(105)|0;f=x[31737];x[31737]=0;if((f|0)==1){break c}x[31737]=0;f=a+8|0;S(106,f|0,b+e|0,g|0);e=x[31737];x[31737]=0;if((e|0)==1){break c}Zb(f);x[31737]=0;w[a+24>>1]=0;d=P(688,b|0,d|0)|0;e=x[31737];x[31737]=0;if((e|0)==1){break c}b=tk(x[(d+x[x[d>>2]-12>>2]|0)+16>>2]);e=z[a+24>>1];Ff(d);fb=a+176|0;a=(b?0:e)&65535;break a}c=N()|0;break d}c=N()|0;tb(a+24|0)}tb(a+12|0);break b}c=N()|0;Ff(b)}Q(c|0);p()}fb=c+16|0;return a|0}function qB(a,b,c,d,e){var f=0,g=0,h=0;g=D(c,872)+b|0;a:{if(d){if(!Ob(a+1074312|0,90)){v[g+1428|0]=d}v[(D(c,872)+b|0)+1427|0]=d;break a}d=y[g+1427|0]}f=x[a+480180>>2];if(!e){h=Iu(f)}g=g+616|0;b:{if((f|0)!=268435456){if((f|0)!=16777216){break b}f=x[(D(c,872)+b|0)+1272>>2];if(!f|!x[f+44>>2]){break b}a=d&255;if(!(a>>>0<240|e)){cT(b,c,a-240|0);return}if(!(a>>>0<224|e)){bT(g,a-224|0);return}aT(g,a);return}x[(D(c,872)+b|0)+1324>>2]=1}e=d&255;c:{d:{if(!(e>>>0>223&h)){break d}e:{f=e&15;if(!f){break e}d=d&240;if((d|0)!=224){if((d|0)!=240){break e}nB(a,g,f);return}if(x[a+480180>>2]==524288){break d}oB(a,g,f);return}if(x[a+480180>>2]!=524288){break c}}b=D(c,872)+b|0;f:{if(!(v[b+1467|0]&1)){break f}if(x[a+1074416>>2]==1){if(Ob(a+1074312|0,6)){break f}}c=x[a+480180>>2];if(c&32832){break f}if(!(y[a+480208|0]&2)|(c|0)!=8){break c}}Ck(a,g,b+1316|0,e<<2,0)}}function AP(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;g=fb-16|0;fb=g;b=x[a>>2];vb(g+12|0,b);a:{b:{c:{d:{e:{if(Dd(x[b+16>>2])){while(1){if(c>>>0>31){break e}x[31737]=0;d=ca(69)|0;e=x[31737];x[31737]=0;if((e|0)!=1){f=d|f;c=c+32|0;continue}break}c=T(125632)|0;if((gb|0)!=($(125632)|0)){break c}Y(c|0)|0;v[b+20|0]=0;x[31737]=0;W(57,b|0);c=x[31737];x[31737]=0;if((c|0)==1){break d}Z();break e}v[b+20|0]=0}if(!y[b+20|0]){d=x[b+24>>2];b=0;c=1;while(1){if(c){c=0;b=x[d+2496>>2];e=(b<<2)+d|0;i=x[((b+397>>>0)%624<<2)+d>>2];h=(b+1>>>0)%624|0;b=x[(h<<2)+d>>2];b=i^(b&2147483647|x[e>>2]&-2147483648)>>>1^0-(b&1)&-1727483681;x[e>>2]=b;x[d+2496>>2]=h;b=b^b>>>11;b=b<<7&-1658038656^b;b=b<<15&-272236544^b;b=b>>>18^b;continue}break}f=b^f}fb=g+16|0;break a}c=N()|0;x[31737]=0;X(26);a=x[31737];x[31737]=0;if((a|0)==1){break b}}Q(c|0);p()}T(0)|0;Sb();p()}return x[a+28>>2]&f}function X0(a,b,c){a=a|0;b=b|0;c=c|0;a:{b:{switch(b|0){case 0:se(a,0,c);break a;case 1:se(a,1,c);break a;case 2:se(a,2,c);break a;case 3:se(a,3,c);break a;case 4:se(a,4,c);break a;case 5:se(a,5,c);break a;case 6:se(a,6,c);break a;case 7:se(a,7,c);break a;case 8:se(a,8,c);break a;case 9:se(a,9,c);break a;case 10:se(a,10,c);break a;case 11:se(a,11,c);break a;case 12:se(a,12,c);break a;case 13:se(a,13,c);break a;case 14:se(a,14,c);break a;case 15:se(a,15,c);break a;case 16:se(a,16,c);break a;case 17:se(a,17,c);break a;case 18:se(a,18,c);break a;case 19:se(a,19,c);break a;case 20:W0(a,71504,c);break a;case 21:W0(a,72528,c);break a;case 22:se(a,20,c);break a;case 23:se(a,21,c);break a;case 24:se(a,22,c);break a;case 25:se(a,23,c);break a;case 26:se(a,24,c);break a;case 27:se(a,25,c);break a;case 28:se(a,26,c);break a;default:break b}}Fb(a)}}function WG(a,b,c){a=a|0;b=b|0;c=c|0;a:{b:{switch(b|0){case 0:oe(a,0,c);break a;case 1:oe(a,1,c);break a;case 2:oe(a,2,c);break a;case 3:oe(a,3,c);break a;case 4:oe(a,4,c);break a;case 5:oe(a,5,c);break a;case 6:oe(a,6,c);break a;case 7:oe(a,7,c);break a;case 8:oe(a,8,c);break a;case 9:oe(a,9,c);break a;case 10:oe(a,10,c);break a;case 11:oe(a,11,c);break a;case 12:oe(a,12,c);break a;case 13:oe(a,13,c);break a;case 14:oe(a,14,c);break a;case 15:oe(a,15,c);break a;case 16:oe(a,16,c);break a;case 17:oe(a,17,c);break a;case 18:oe(a,18,c);break a;case 19:oe(a,19,c);break a;case 20:VG(a,71504,c);break a;case 21:VG(a,72528,c);break a;case 22:oe(a,20,c);break a;case 23:oe(a,21,c);break a;case 24:oe(a,22,c);break a;case 25:oe(a,23,c);break a;case 26:oe(a,24,c);break a;case 27:oe(a,25,c);break a;case 28:oe(a,26,c);break a;default:break b}}Fb(a)}}function PD(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;h=fb-16|0;fb=h;e=zb(a);c=vb(h+12|0,x[a+4>>2]);g=vb(h+8|0,x[a>>2]);f=vb(h+4|0,x[b+4>>2]);d=x[c>>2];g=x[g>>2];c=fb+-64|0;fb=c;f=x[f>>2];x[c+56>>2]=f;x[c+60>>2]=d;x[c+52>>2]=f;e=Re(c+24|0,e,c+52|0,c+56|0);x[c+16>>2]=x[e+8>>2];f=x[e+4>>2];x[c+8>>2]=x[e>>2];x[c+12>>2]=f;Qe(c+36|0,c+8|0);while(1){if(pd(d,g)){SD(W_(x[c+56>>2]),d-20|0);d=X_(c+60|0);X_(c+56|0);d=x[d>>2];continue}break}Pe(c+36|0);i=x[c+56>>2];if(!y[c+48|0]){g=fb-16|0;fb=g;d=vb(g+12|0,x[x[c+44>>2]>>2]);j=x[vb(g+8|0,x[x[c+40>>2]>>2])>>2];f=fb-16|0;fb=f;d=x[d>>2];x[f+12>>2]=d;while(1){if(ci(d,j)){e=fb-16|0;fb=e;x[e+12>>2]=d;x[e+12>>2]=x[e+12>>2]+20;fb=e+16|0;ub(W_(x[e+12>>2]));d=x[Sf(f+12|0)>>2];continue}break}fb=f+16|0;fb=g+16|0}fb=c- -64|0;x[b+4>>2]=i;Tb(a,b+4|0);Tb(a+4|0,b+8|0);Tb(zb(a),nc(b));x[b>>2]=x[b+4>>2];fb=h+16|0}function YU(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;h=fb-16|0;fb=h;e=zb(a);c=vb(h+12|0,x[a+4>>2]);g=vb(h+8|0,x[a>>2]);f=vb(h+4|0,x[b+4>>2]);d=x[c>>2];g=x[g>>2];c=fb+-64|0;fb=c;f=x[f>>2];x[c+56>>2]=f;x[c+60>>2]=d;x[c+52>>2]=f;e=Re(c+24|0,e,c+52|0,c+56|0);x[c+16>>2]=x[e+8>>2];f=x[e+4>>2];x[c+8>>2]=x[e>>2];x[c+12>>2]=f;Qe(c+36|0,c+8|0);while(1){if(pd(d,g)){WB(WU(x[c+56>>2]),ln(d));d=Yo(c+60|0);Yo(c+56|0);d=x[d>>2];continue}break}Pe(c+36|0);i=x[c+56>>2];if(!y[c+48|0]){g=fb-16|0;fb=g;d=vb(g+12|0,x[x[c+44>>2]>>2]);j=x[vb(g+8|0,x[x[c+40>>2]>>2])>>2];f=fb-16|0;fb=f;d=x[d>>2];x[f+12>>2]=d;while(1){if(ci(d,j)){e=fb-16|0;fb=e;x[e+12>>2]=d;x[e+12>>2]=x[e+12>>2]+32;fb=e+16|0;Ek(WU(x[e+12>>2]));d=x[br(f+12|0)>>2];continue}break}fb=f+16|0;fb=g+16|0}fb=c- -64|0;x[b+4>>2]=i;Tb(a,b+4|0);Tb(a+4|0,b+8|0);Tb(zb(a),nc(b));x[b>>2]=x[b+4>>2];fb=h+16|0}function z_(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;g=b-1|0;while(1){a:{if(!c){c=0;break a}if(y[c+g|0]){break a}c=c-1|0;continue}break}b:{if((d|0)!=4){break b}g=0;while(1){if((c|0)==(e|0)){if((f|0)==(g|0)){d=2;if((f|0)==(h|0)){break b}}if(f){d=0;if(!g){break b}}d=f?3:g?1:3}else{c:{d:{e:{d=b+e|0;i=y[d|0];switch(i-10|0){case 0:break d;case 3:break e;default:break c}}f=f+1|0;break c}g=g+1|0}if(e){h=((i|0)==10&y[d-1|0]==13)+h|0}e=e+1|0;continue}break}}f=0;g=(d|0)==2;e=0;while(1){if(c>>>0>e>>>0){e=((g&y[b+e|0]==13)+e|0)+1|0;f=f+1|0;continue}break}sf(a);Cs(a,f);g=(d|0)==1?32:13;h=d&-3?13:32;d=(d|0)==2;e=0;while(1){if(c>>>0>e>>>0){f:{g:{h:{i:{f=v[b+e|0];switch(f-10|0){case 1:case 2:break f;case 0:break g;case 3:break h;default:break i}}if(f){break f}f=32;break f}e=d+e|0;f=g;break f}f=h}Xp(a,f);e=e+1|0;continue}break}}function rma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;e=fb-16|0;fb=e;i=x[a+24>>2];j=x[a+20>>2];k=x[a+16>>2];h=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=h;l=b+24|0;h=x[a+8>>2];m=x[a+12>>2];while(1){if(d){b=x[e+8>>2];n=(((x[e+12>>2]&2147483647)<<1|b>>>31)&-2)+k|0;b=(((b>>>16|0)+4&131064)<<1)+l|0;o=w[b+14>>1];p=w[b+12>>1];q=w[b+10>>1];r=w[b+8>>1];s=w[b+6>>1];t=w[b+4>>1];u=w[b+2>>1];b=w[b>>1];g=0;while(1){if((g|0)!=2){f=g+n|0;x[(g<<2)+e>>2]=((((D(v[f+4|0],q)+D(v[f+2|0],r)|0)+D(v[f+6|0],p)|0)+D(v[f+8|0],o)<<8>>1)+(((D(v[f-4|0],u)+D(v[f-6|0],b)|0)+D(v[f-2|0],t)|0)+D(v[f|0],s)<<8>>1)|0)/16384;g=g+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[e>>2],j);x[c+4>>2]=x[c+4>>2]+D(x[e+4>>2],i);Pb(e+8|0,h,m);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;fb=e+16|0}function ZL(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0,p=0,q=0;o(+a);b=j(1)|0;e=j(0)|0;a:{b:{c:{if(!(((b|0)>0|(b|0)>=0)&b>>>0>1048575)){o(+a);c=j(1)|0;if(!(j(0)|c&2147483647)){return-1/(a*a)}if((b|0)>0|(b|0)>=0){break c}return(a-a)/0}if(b>>>0>2146435071){break a}c=1072693248;k=-1023;if((b|0)!=1072693248){c=b;break b}if(e){break b}return 0}o(+(a*0x40000000000000));b=j(1)|0;e=j(0)|0;c=b;k=-1077}l(0,e|0);c=c+614242|0;l(1,(c&1048575)+1072079006|0);d=+n()+-1;f=d*(d*.5);g=d/(d+2);h=g*g;a=h*h;o(+(d-f));b=j(1)|0;j(0)|0;l(0,0);l(1,b|0);i=+n();m=i*1.4426950407214463;p=+((c>>>20|0)+k|0);q=m+p;a=g*(f+(a*(a*(a*.15313837699209373+.22222198432149784)+.3999999999940942)+h*(a*(a*(a*.14798198605116586+.1818357216161805)+.2857142874366239)+.6666666666666735)))+(d-i-f);a=q+(m+(p-q)+((a+i)*1.6751713164886512e-10+a*1.4426950407214463))}return a}function Mka(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=fb-16|0;fb=f;b=x[a+4>>2];if(Gd(y[b+223884|0])){MT(b+223860|0);b=x[a+4>>2]}x[a+24>>2]=0;x[a+28>>2]=0;x[b>>2]=0;c=x[a>>2];x[b+40>>2]=x[c+480196>>2];x[b+44>>2]=x[c+480204>>2];x[b+80>>2]=x[c+480200>>2];c=z[c+480188>>1];x[f+8>>2]=0;x[f+12>>2]=0;d=f+8|0;w[d+4>>1]=65280;x[d>>2]=0;e=fb-16|0;fb=e;x[e+12>>2]=c;b=a+8|0;a:{if(Xn(b)>>>0>=c>>>0){g=x[b>>2];h=jh(g,x[b+4>>2]);x[e+8>>2]=h;i=x[Gb(e+12|0,e+8|0)>>2];while(1){if(i){x[g>>2]=x[d>>2];w[g+4>>1]=z[d+4>>1];i=i-1|0;g=g+8|0;continue}break}if(c>>>0>h>>>0){XS(b,c-h|0,d);break a}uG(b,x[b>>2]+(c<<3)|0);break a}fU(b);tU(b,ns(b,c));XS(b,c,d)}fb=e+16|0;b=0;while(1){c=x[a>>2];if(z[c+480188>>1]<=b>>>0){fb=f+16|0}else{d=D(b,872);Uo((d+x[a+4>>2]|0)+616|0,c,b&65535,67108864);c=d+x[a+4>>2]|0;w[c+1432>>1]=0;v[c+1415|0]=0;b=b+1|0;continue}break}}function bka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=fb-32|0;fb=d;e=Fb(d+20|0);a:{b:{c:{if(c>>>0<=63){break c}x[31737]=0;c=R(185,b|0)|0;f=x[31737];x[31737]=0;d:{if((f|0)!=1){x[d+16>>2]=c;if((c|0)>0){break d}x[31737]=0;P(36,a|0,22303)|0;a=x[31737];x[31737]=0;if((a|0)!=1){break b}}break a}x[31737]=0;c=R(203,b|0)|0;f=x[31737];x[31737]=0;if((f|0)!=1){g=d,h=th(c),x[g+12>>2]=h;c=x[ud(d+16|0,d+12|0)>>2];x[31737]=0;O(115,e|0,c|0);c=x[31737];x[31737]=0;if((c|0)!=1){break c}}break a}e:{while(1){f:{x[31737]=0;c=R(198,b|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break f}if(!c){break e}x[31737]=0;U(894,e|0,1,((c-65&255)>>>0<26?c+32|0:c)<<24>>24)|0;c=x[31737];x[31737]=0;if((c|0)!=1){continue}}break}break a}x[31737]=0;P(184,b|0,4)|0;b=x[31737];x[31737]=0;if((b|0)==1){break a}_c(a,e)}tb(e);fb=d+32|0;return}a=N()|0;tb(e);Q(a|0);p()}function gra(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;if(A[a+4>>2]<A[zb(a)>>2]){c=fb-16|0;fb=c;a=f0(c+4|0,a);gD(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+28;hc(a);fb=c+16|0;return}h=fb-32|0;fb=h;c=zb(a);c=d0(h+12|0,e0(a,Nr(x[a>>2],x[a+4>>2])+1|0),Nr(x[a>>2],x[a+4>>2]),c);gD(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+28;g=fb-16|0;fb=g;e=zb(a);b=vb(g+12|0,x[a+4>>2]);i=vb(g+8|0,x[a>>2]);f=vb(g+4|0,x[c+4>>2]);d=x[b>>2];i=x[i>>2];b=fb+-64|0;fb=b;f=x[f>>2];x[b+56>>2]=f;x[b+60>>2]=d;x[b+52>>2]=f;e=Re(b+24|0,e,b+52|0,b+56|0);x[b+16>>2]=x[e+8>>2];f=x[e+4>>2];x[b+8>>2]=x[e>>2];x[b+12>>2]=f;Qe(b+36|0,b+8|0);while(1){if(pd(d,i)){gD(lE(x[b+56>>2]),Lr(d));d=lw(b+60|0);lw(b+56|0);d=x[d>>2];continue}break}d=b+36|0;Pe(d);e=x[b+56>>2];b0(d);fb=b- -64|0;x[c+4>>2]=e;Tb(a,c+4|0);Tb(a+4|0,c+8|0);Tb(zb(a),nc(c));x[c>>2]=x[c+4>>2];fb=g+16|0;c0(c);fb=h+32|0}function dma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=fb-16|0;fb=e;n=x[a+16>>2];o=Fg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);i=x[a+8>>2];j=x[a+12>>2];b=x[a>>2];g=x[a+4>>2];k=x[a+128>>2];if(k){l=Gg(i,j,k);m=hb;f=x[a+76>>2];hg(b,g,vf(i,j,d),hb);h=hb>>>0>f>>>0?d:0}f=a+112|0;p=x[a+24>>2];q=x[a+20>>2];x[e>>2]=b;x[e+4>>2]=g;a:while(1){if(d){g=x[e+4>>2];x[e+8>>2]=x[e>>2];x[e+12>>2]=0;h=h-1|0;l=h?l:0;m=h?m:0;d=d-1|0;g=g+n|0;b=k;while(1)if((b|0)<=0){Pb(f,x[a+120>>2],x[a+124>>2]);b=x[a+116>>2];if(b){be(f,v[x[e+12>>2]+g|0]<<6);ae(f,b);x[f>>2]=x[f>>2];x[f+4>>2]=0}b=Eg(f,o);x[c>>2]=x[c>>2]+D(b,q);x[c+4>>2]=x[c+4>>2]+D(b,p);Pb(e,i,j);c=c+8|0;continue a}else{be(f,v[x[e+12>>2]+g|0]<<6);ae(f,4);Pb(e+8|0,l,m);b=b-1|0;continue}}break}b=x[e+4>>2];x[a>>2]=x[e>>2];x[a+4>>2]=b;fb=e+16|0}function $j(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;if(A[a+4>>2]<A[zb(a)>>2]){c=fb-16|0;fb=c;a=f0(c+4|0,a);mE(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+28;hc(a);fb=c+16|0;return}h=fb-32|0;fb=h;c=zb(a);c=d0(h+12|0,e0(a,Nr(x[a>>2],x[a+4>>2])+1|0),Nr(x[a>>2],x[a+4>>2]),c);mE(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+28;g=fb-16|0;fb=g;e=zb(a);b=vb(g+12|0,x[a+4>>2]);i=vb(g+8|0,x[a>>2]);f=vb(g+4|0,x[c+4>>2]);d=x[b>>2];i=x[i>>2];b=fb+-64|0;fb=b;f=x[f>>2];x[b+56>>2]=f;x[b+60>>2]=d;x[b+52>>2]=f;e=Re(b+24|0,e,b+52|0,b+56|0);x[b+16>>2]=x[e+8>>2];f=x[e+4>>2];x[b+8>>2]=x[e>>2];x[b+12>>2]=f;Qe(b+36|0,b+8|0);while(1){if(pd(d,i)){mE(lE(x[b+56>>2]),Lr(d));d=lw(b+60|0);lw(b+56|0);d=x[d>>2];continue}break}d=b+36|0;Pe(d);e=x[b+56>>2];b0(d);fb=b- -64|0;x[c+4>>2]=e;Tb(a,c+4|0);Tb(a+4|0,c+8|0);Tb(zb(a),nc(c));x[c>>2]=x[c+4>>2];fb=g+16|0;c0(c);fb=h+32|0}function Qw(a,b,c,d){var e=0,f=0,g=0,h=0;g=fb-16|0;fb=g;a:{if(!c){break a}if(d){b=gc(g+8|0,a,b);a=fb-16|0;fb=a;x[a+12>>2]=c;d=x[b+4>>2];b:{if(!d){d=x[b>>2];break b}c=32-d|0;x[a+8>>2]=c;e=x[b>>2];h=c;c=x[Gb(a+8|0,a+12|0)>>2];x[e>>2]=-1<<d&-1>>>h-c|x[e>>2];c=x[a+12>>2]-c|0;x[a+12>>2]=c;d=e+4|0;x[b>>2]=d}x[a+4>>2]=-1;e=d;d=c>>>5|0;KF(e,d,a+4|0);e=x[a+12>>2];c=c&-32;f=e-c|0;x[a+12>>2]=f;if((c|0)!=(e|0)){c=b;b=x[b>>2]+(d<<2)|0;x[c>>2]=b;x[b>>2]=x[b>>2]|-1>>>32-f}fb=a+16|0;break a}b=gc(g,a,b);a=fb-16|0;fb=a;x[a+12>>2]=c;d=x[b+4>>2];c:{if(!d){d=x[b>>2];break c}e=32-d|0;x[a+8>>2]=e;c=x[b>>2];f=x[c>>2];h=e;e=x[Gb(a+8|0,a+12|0)>>2];x[c>>2]=(-1<<d&-1>>>h-e^-1)&f;f=x[a+12>>2];d=c+4|0;x[b>>2]=d;c=f-e|0}e=d;d=c>>>5|0;JF(e,d);c=c&31;x[a+12>>2]=c;if(c){e=b;b=x[b>>2]+(d<<2)|0;x[e>>2]=b;x[b>>2]=x[b>>2]&(-1>>>32-c^-1)}fb=a+16|0}fb=g+16|0}function Ey(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=a;a:{if(b&3){while(1){c=y[b|0];if(!c|(c|0)==61){break a}b=b+1|0;if(b&3){continue}break}}c=x[b>>2];b:{if((c^-1)&c-16843009&-2139062144){break b}while(1){if((c^1027423549)-16843009&(c^-1)&-2139062144){break b}c=x[b+4>>2];b=b+4|0;if(!(c-16843009&(c^-1)&-2139062144)){continue}break}}while(1){c=b;d=y[b|0];if((d|0)!=61){b=b+1|0;if(d){continue}}break}b=c}if((a|0)==(b|0)){return 0}f=b-a|0;c:{if(y[f+a|0]){break c}e=x[125034];if(!e){break c}b=x[e>>2];if(!b){break c}while(1){d:{g=a;c=b;h=f;d=0;e:{if(!f){break e}d=y[a|0];if(d){f:{while(1){i=y[c|0];if((i|0)!=(d|0)|!i){break f}h=h-1|0;if(!h){break f}c=c+1|0;d=y[g+1|0];g=g+1|0;if(d){continue}break}d=0}}else{d=0}d=d-y[c|0]|0}if(!d){b=b+f|0;if(y[b|0]==61){break d}}b=x[e+4>>2];e=e+4|0;if(b){continue}break c}break}j=b+1|0}return j}function bM(a,b,c,d){var e=0,f=E(0),g=0,h=E(0),i=0,j=0,k=0,l=E(0),m=E(0),n=E(0),o=0;e=fb-96|0;fb=e;o=(d|0)>0?d:0;while(1){if((j|0)!=(o|0)){B[e+48>>2]=-B[a>>2];B[e>>2]=B[a+68>>2];d=0;while(1){if((d|0)!=4){i=(e+48|0)+(d<<3)|0;g=(d<<4)+a|0;h=B[g+4>>2];f=B[g+8>>2];B[i+4>>2]=h+f;k=d<<1;B[(8-k<<2)+e>>2]=h-f;h=B[g+16>>2];f=B[g+12>>2];B[(7-k<<2)+e>>2]=h-f;B[i+8>>2]=-E(h+f);d=d+1|0;continue}break}aM(e+48|0);aM(e);B[e+4>>2]=-B[e+4>>2];B[e+12>>2]=-B[e+12>>2];B[e+20>>2]=-B[e+20>>2];B[e+28>>2]=-B[e+28>>2];g=0;while(1){if((g|0)!=9){d=g<<2;i=d+b|0;h=B[i>>2];f=B[d+(e+48|0)>>2];l=B[d+87648>>2];m=B[d+87684>>2];n=B[d+e>>2];B[i>>2]=E(f*l)-E(m*n);i=a+d|0;d=c+d|0;f=E(E(f*m)+E(n*l));B[i>>2]=E(h*B[d>>2])-E(B[d+36>>2]*f);B[(17-g<<2)+a>>2]=E(h*B[d+36>>2])+E(f*B[d>>2]);g=g+1|0;continue}break}b=b+36|0;a=a+72|0;j=j+1|0;continue}break}fb=e+96|0}function Hua(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;ld(b,0);x[b>>2]=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);c=Sr(a+4|0,a);d=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);x[b+4>>2]=d;c=Sr(a+8|0,a);f=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);x[b+8>>2]=f;c=(y[a+15|0]|y[a+16|0]<<8)<<1;x[b+24>>2]=c;c=y[a+15|0]|y[a+16|0]<<8?c:16726;x[b+24>>2]=c;g=b,h=(D(tw(v[a+17|0],y[a+14|0]<<28>>24),c)>>>0)/8363|0,x[g+24>>2]=h;v[e+15|0]=y[a+18|0];v[e+14|0]=127;g=b,h=(((y[Qb(e+15|0,e+14|0)|0]<<8|64)&65344)>>>0)/127|0,w[g+30>>1]=h;c=y[a+14|0];if(c>>>0>=16){w[b+34>>1]=32;w[b+28>>1]=c&240}c=y[a+19|0];if(c&4){w[b+34>>1]=z[b+34>>1]|1;c=y[a+19|0]}a:{if(!(c&8)|d>>>0>=f>>>0){break a}f=z[b+34>>1];d=f|2;w[b+34>>1]=d;c=y[a+19|0];if(c&16){d=f|6;w[b+34>>1]=d;c=y[a+19|0]}if(!(c&64)){break a}w[b+34>>1]=d|128}fb=e+16|0}function UP(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=E(0),k=0,l=E(0),m=0,n=0,o=E(0);e=a+4208|0;j=E(E(B[yb(e,2)>>2]*E(2999.9990234375))+E(.0010000000474974513));l=E(B[yb(e,3)>>2]*E(.9980000257492065));f=-3e3/(+A[x[a+16>>2]+24620>>2]*+j);e=a+4272|0;c=sk(10,f*+A[yb(e,4)>>2]);g=a+4232|0;n=yb(g,0),o=E(c),B[n>>2]=o;c=sk(10,f*+A[yb(e,5)>>2]);n=yb(g,1),o=E(c),B[n>>2]=o;m=f*(1/+E(l+E(.0010000000474974513))+-1);c=0;while(1){if((d|0)==4){d=a+4208|0;f=sk(10,+RP(B[yb(d,0)>>2])*.05);b=4/M(c)*f;c=sk(10,+RP(B[yb(d,1)>>2])*.1);B[a+4228>>2]=b*M(c);B[a+4224>>2]=f*M(1-c)}else{h=x[yb(e,d)>>2];k=d>>>1|0;i=sk(10,m*+(x[yb(e,d)>>2]+x[yb(e,k+4|0)>>2]>>>0));b=sk(10,f*+(h>>>0));j=B[yb(g,k)>>2];h=d<<1;i=(1-i)*.5;n=yb(g,h+2|0),o=E(b*(1-i)),B[n>>2]=o;n=yb(g,h+3|0),o=E(b*i),B[n>>2]=o;b=b*+j;b=b*(b*(b*(b+1)+1)+1)+1;c=b*b+c;d=d+1|0;continue}break}}function l5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=oJ(a,0);h=fb-32|0;fb=h;c=UI(f+12|0,b);d=c+172|0;i=c+4|0;a=i;while(1){a=Fb(a)+12|0;if((d|0)!=(a|0)){continue}break}e=c+460|0;a=d;while(1){a=Fb(a)+12|0;if((e|0)!=(a|0)){continue}break}g=c+484|0;a=e;while(1){a=Fb(a)+12|0;if((g|0)!=(a|0)){continue}break}g=Fb(g);j=Fb(c+496|0);k=Fb(c+508|0);l=Fb(c+520|0);x[31737]=0;a=P(1334,h+12|0,b|0)|0;b=x[31737];x[31737]=0;a:{b:{c:{if((b|0)!=1){x[31737]=0;O(1335,c|0,a|0);b=x[31737];x[31737]=0;if((b|0)==1){break c}Vs(a);fb=h+32|0;break a}b=N()|0;break b}b=N()|0;Vs(a)}tb(l);tb(k);tb(j);a=tb(g);while(1){a=tb(a-12|0);if((e|0)!=(a|0)){continue}break}while(1){e=tb(e-12|0);if((e|0)!=(d|0)){continue}break}while(1){d=tb(d-12|0);if((i|0)!=(d|0)){continue}break}Xs(c);Q(b|0);p()}x[f+8>>2]=116652;x[f>>2]=116576;return f|0}function j5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=nJ(a,0);h=fb-16|0;fb=h;c=UI(f+12|0,b);d=c+172|0;i=c+4|0;a=i;while(1){a=Fb(a)+12|0;if((d|0)!=(a|0)){continue}break}e=c+460|0;a=d;while(1){a=Fb(a)+12|0;if((e|0)!=(a|0)){continue}break}g=c+484|0;a=e;while(1){a=Fb(a)+12|0;if((g|0)!=(a|0)){continue}break}g=Fb(g);j=Fb(c+496|0);k=Fb(c+508|0);l=Fb(c+520|0);x[31737]=0;a=P(1336,h+4|0,b|0)|0;b=x[31737];x[31737]=0;a:{b:{c:{if((b|0)!=1){x[31737]=0;O(1337,c|0,a|0);b=x[31737];x[31737]=0;if((b|0)==1){break c}Ys(a);fb=h+16|0;break a}b=N()|0;break b}b=N()|0;Ys(a)}Ub(l);Ub(k);Ub(j);a=Ub(g);while(1){a=Ub(a-12|0);if((e|0)!=(a|0)){continue}break}while(1){e=Ub(e-12|0);if((e|0)!=(d|0)){continue}break}while(1){d=Ub(d-12|0);if((i|0)!=(d|0)){continue}break}Xs(c);Q(b|0);p()}x[f+8>>2]=116948;x[f>>2]=116872;return f|0}function yO(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=fb+-64|0;fb=e;a:{b:{if((b|0)>=0){d=x[a+24>>2];if(Oj(Xb(x[d+484360>>2],y[d+484376|0]))>>>0>b>>>0){break b}}a=a+16|0;break a}d=0;c:{f=x[a+24>>2];g=x[f+484344>>2];i=x[f+484348>>2];h=z[_b(x[Xb(x[f+484360>>2],y[f+484376|0])>>2],b)>>1];if(!vp(g,i,h)){break c}if((c|0)>=0){d=c;if((d|0)<x[Wb(g,h)+12>>2]){break c}}a=a+16|0;break a}w[f+1074448>>1]=b;c=f;f=b&65535;hS(c,f);c=x[a+24>>2];x[c+1074392>>2]=-2;x[c+1074428>>2]=d;g=y[a+64|0];b=e+24|0;w[b+4>>1]=0;v[b+6|0]=255;x[b+16>>2]=2;x[b>>2]=0;w[b+12>>1]=f;x[b+8>>2]=d;d=x[b+20>>2];x[e+16>>2]=x[b+16>>2];x[e+20>>2]=d;d=x[b+12>>2];x[e+8>>2]=x[b+8>>2];x[e+12>>2]=d;d=x[b+4>>2];x[e>>2]=x[b>>2];x[e+4>>2]=d;b=e+52|0;Bv(b,c,g?7:1,e);j=a,k=C[ln(x[e+56>>2])>>3],C[j+16>>3]=k;Xi(b);a=a+16|0}fb=e- -64|0;return+C[a>>3]}function zka(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=fb-880|0;fb=b;c=Rb(a,0,76);x[c+84>>2]=0;x[c+88>>2]=0;x[c+80>>2]=256;v[c+78|0]=0;w[c+76>>1]=65535;x[c+92>>2]=0;x[c+96>>2]=0;v[c+100|0]=1;d=c+223848|0;e=c+616|0;a=e;while(1){a=eW(a)+872|0;if((d|0)!=(a|0)){continue}break}d=Nb(d);g=hB(c+223860|0);f=b+8|0;Rb(f,0,108);nC(b+120|0,48e3);Rb(b+664|0,0,72);v[b+754|0]=0;w[b+752>>1]=65535;v[b+746|0]=0;w[b+744>>1]=65535;v[b+738|0]=0;w[b+736>>1]=65535;x[b+748>>2]=0;x[b+740>>2]=0;Rb(b+756|0,0,103);x[b+868>>2]=0;x[b+872>>2]=0;v[b+875|0]=0;v[b+876|0]=0;v[b+877|0]=0;v[b+878|0]=0;x[b+860>>2]=0;x[b+864>>2]=0;v[b+859|0]=y[b+859|0]&128;a=((e+223232|0)-e|0)/872|0;while(1){if((a|0)>0){a=a-1|0;e=Kq(e,f)+872|0;continue}break}x[31737]=0;O(554,d|0,32);a=x[31737];x[31737]=0;if((a|0)!=1){fb=b+880|0;return c|0}a=N()|0;Lq(g);dc(d);Q(a|0);p()}function GR(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;k=fb-16|0;fb=k;v[k+15|0]=c;v[k+14|0]=12;gh(b,y[Qb(k+15|0,k+14|0)|0]);c=0;l=x[b>>2];m=x[b+4>>2];p=Sd(l,m);while(1){if((c|0)==(p|0)){c=0;v[b+12|0]=0;a:{if(!(d&1)){break a}if(mc(l,m)){break a}c=1;v[b+12|0]=1}if(e>>>0<=11){if(d&2){c=c|4;v[b+12|0]=c}v[b+15|0]=e;v[b+16|0]=e}if(!(g>>>0>11|f>>>0>g>>>0)){if(d&4){v[b+12|0]=c|2}v[b+14|0]=g;v[b+13|0]=f}fb=k+16|0}else{b:{c:{d:{switch(h|0){case 0:j=yb(l,c);i=(c<<2)+a|0;w[j>>1]=y[i+96|0]|y[i+97|0]<<8;i=i+98|0;break c;case 1:break d;default:break b}}j=yb(l,c);i=(c<<2)+a|0;w[j>>1]=y[i+144|0]|y[i+145|0]<<8;i=i+146|0}v[j+2|0]=y[i|0]}e:{if(!c){break e}i=yb(l,c);j=z[i>>1];n=yb(l,c-1|0);o=z[n>>1];if(j>>>0>255|j>>>0>=o>>>0){break e}j=j|o&65280;w[i>>1]=j;if(j>>>0>=z[n>>1]){break e}w[i>>1]=j+256}c=c+1|0;continue}break}}function Tma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=fb-16|0;fb=b;f=x[a+40>>2];g=x[a+36>>2];j=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;k=x[a+32>>2];l=x[a+28>>2];m=x[a+8>>2];n=x[a+12>>2];while(1){if(d){e=x[b+8>>2];o=((((x[b+12>>2]&2147483647)<<1|e>>>31)&2147483646)<<1)+j|0;e=e>>>21&2040;p=w[e+38198>>1];q=w[e+38196>>1];r=w[e+38194>>1];e=w[e+38192>>1];h=0;while(1){if((h|0)!=2){i=(h<<1)+o|0;x[(h<<2)+b>>2]=(((D(w[i>>1],r)+D(w[i-4>>1],e)|0)+D(w[i+4>>1],q)|0)+D(w[i+8>>1],p)|0)/16384;h=h+1|0;continue}break}g=g+l|0;x[c>>2]=x[c>>2]+D(x[b>>2],g>>12);f=f+k|0;x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],f>>12);Pb(b+8|0,m,n);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=f;x[a+20>>2]=g>>12;x[a+36>>2]=g;x[a+24>>2]=f>>12;fb=b+16|0}function Jja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;ld(c,0);w[c+28>>1]=y[a+36|0]<<2;d=y[a+37|0];w[c+32>>1]=64;w[c+30>>1]=d<<2;x[c>>2]=y[a+40|0]|y[a+41|0]<<8|(y[a+42|0]<<16|y[a+43|0]<<24);x[c+4>>2]=y[a+44|0]|y[a+45|0]<<8|(y[a+46|0]<<16|y[a+47|0]<<24);x[c+8>>2]=y[a+48|0]|y[a+49|0]<<8|(y[a+50|0]<<16|y[a+51|0]<<24);x[c+24>>2]=y[a+52|0]|y[a+53|0]<<8|(y[a+54|0]<<16|y[a+55|0]<<24);d=y[b+151|0];if(d>>>0<=4){v[c+38|0]=y[d+41226|0]}d=y[b+152|0]|y[b+153|0]<<8;v[c+39|0]=d;e=(y[b+156|0]|y[b+157|0]<<8)>>>4|0;v[c+41|0]=e;b=(y[b+154|0]|y[b+155|0]<<8)>>>2|0;v[c+40|0]=b;if((b|e)&255){v[c+39|0]=d^-1}b=y[a+38|0]|y[a+39|0]<<8;if(b&4){w[c+34>>1]=z[c+34>>1]|1;b=y[a+38|0]|y[a+39|0]<<8}if(b&8){w[c+34>>1]=z[c+34>>1]|2;b=y[a+38|0]|y[a+39|0]<<8}if(b&16){w[c+34>>1]=z[c+34>>1]|4;b=y[a+38|0]|y[a+39|0]<<8}if(b&32){w[c+34>>1]=z[c+34>>1]|32}}function r7(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=fb-16|0;fb=k;a:{if(a){a=MJ(c);b:{if(b){b=k+4|0;ql(b,a);c=x[k+4>>2];v[d|0]=c;v[d+1|0]=c>>>8;v[d+2|0]=c>>>16;v[d+3|0]=c>>>24;pl(b,a);break b}b=k+4|0;bt(b,a);c=x[k+4>>2];v[d|0]=c;v[d+1|0]=c>>>8;v[d+2|0]=c>>>16;v[d+3|0]=c>>>24;ji(b,a)}oh(i,b);Ub(b);l=e,m=tj(a),x[l>>2]=m;l=f,m=uj(a),x[l>>2]=m;b=k+4|0;rh(b,a);Ab(g,b);tb(b);ki(b,a);oh(h,b);Ub(b);a=Ok(a);break a}a=LJ(c);c:{if(b){b=k+4|0;ql(b,a);c=x[k+4>>2];v[d|0]=c;v[d+1|0]=c>>>8;v[d+2|0]=c>>>16;v[d+3|0]=c>>>24;pl(b,a);break c}b=k+4|0;bt(b,a);c=x[k+4>>2];v[d|0]=c;v[d+1|0]=c>>>8;v[d+2|0]=c>>>16;v[d+3|0]=c>>>24;ji(b,a)}oh(i,b);Ub(b);l=e,m=tj(a),x[l>>2]=m;l=f,m=uj(a),x[l>>2]=m;b=k+4|0;rh(b,a);Ab(g,b);tb(b);ki(b,a);oh(h,b);Ub(b);a=Ok(a)}x[j>>2]=a;fb=k+16|0}function Haa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=fb-96|0;fb=d;x[31737]=0;f=x[b+12>>2];x[d+40>>2]=x[b+8>>2];x[d+44>>2]=f;f=x[b+4>>2];x[d+32>>2]=x[b>>2];x[d+36>>2]=f;f=R(1155,d+32|0)|0;e=x[31737];x[31737]=0;if((e|0)!=1){a:{b:{if(f){x[31737]=0;f=d+72|0;O(1156,f|0,b|0);b=x[31737];x[31737]=0;if((b|0)!=1){b=d+80|0;Pp(b,x[d+72>>2],x[d+76>>2]);e=Ef(d+88|0,b);g=Ef(d- -64|0,c);h=x[e+4>>2];x[d+8>>2]=x[e>>2];x[d+12>>2]=h;e=x[g+4>>2];x[d>>2]=x[g>>2];x[d+4>>2]=e;Qp(a,d+8|0,d);break b}break a}x[31737]=0;f=d+72|0;O(1157,f|0,b|0);b=x[31737];x[31737]=0;if((b|0)==1){break a}b=d+80|0;Pp(b,x[d+72>>2],x[d+76>>2]);e=Ef(d+56|0,b);g=Ef(d+48|0,c);h=x[e+4>>2];x[d+24>>2]=x[e>>2];x[d+28>>2]=h;e=x[g+4>>2];x[d+16>>2]=x[g>>2];x[d+20>>2]=e;Qp(a,d+24|0,d+16|0)}ke(b);ke(f);ke(c);fb=d+96|0;return}}a=N()|0;ke(c);Q(a|0);p()}function v7(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=fb-16|0;fb=k;a:{if(a){a=QJ(c);b:{if(b){b=k+4|0;ql(b,a);c=x[k+4>>2];v[d|0]=c;v[d+1|0]=c>>>8;v[d+2|0]=c>>>16;v[d+3|0]=c>>>24;pl(b,a);break b}b=k+4|0;bt(b,a);c=x[k+4>>2];v[d|0]=c;v[d+1|0]=c>>>8;v[d+2|0]=c>>>16;v[d+3|0]=c>>>24;ji(b,a)}Ab(i,b);tb(b);l=e,m=tj(a),v[l|0]=m;l=f,m=uj(a),v[l|0]=m;b=k+4|0;rh(b,a);Ab(g,b);tb(b);ki(b,a);Ab(h,b);tb(b);a=Ok(a);break a}a=PJ(c);c:{if(b){b=k+4|0;ql(b,a);c=x[k+4>>2];v[d|0]=c;v[d+1|0]=c>>>8;v[d+2|0]=c>>>16;v[d+3|0]=c>>>24;pl(b,a);break c}b=k+4|0;bt(b,a);c=x[k+4>>2];v[d|0]=c;v[d+1|0]=c>>>8;v[d+2|0]=c>>>16;v[d+3|0]=c>>>24;ji(b,a)}Ab(i,b);tb(b);l=e,m=tj(a),v[l|0]=m;l=f,m=uj(a),v[l|0]=m;b=k+4|0;rh(b,a);Ab(g,b);tb(b);ki(b,a);Ab(h,b);tb(b);a=Ok(a)}x[j>>2]=a;fb=k+16|0}function pK(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;i=fb-32|0;fb=i;a:{b:{c:{if((b|0)!=(c|0)){k=x[31612];x[31612]=0;g=fb-16|0;fb=g;Od();f=fb-16|0;fb=f;e=fb-16|0;fb=e;By(e,b,i+28|0,2);h=x[e>>2];j=x[e+4>>2];b=f;f=x[e+12>>2];x[b+8>>2]=x[e+8>>2];x[b+12>>2]=f;x[b>>2]=h;x[b+4>>2]=j;fb=e+16|0;f=x[b>>2];h=x[b+4>>2];e=g;g=x[b+12>>2];x[e+8>>2]=x[b+8>>2];x[e+12>>2]=g;x[e>>2]=f;x[e+4>>2]=h;fb=b+16|0;g=x[e>>2];f=x[e+4>>2];h=x[e+12>>2];b=i;x[b+16>>2]=x[e+8>>2];x[b+20>>2]=h;x[b+8>>2]=g;x[b+12>>2]=f;fb=e+16|0;e=x[b+16>>2];f=x[b+20>>2];g=x[b+8>>2];h=x[b+12>>2];j=x[31612];if(!j){break c}if(x[b+28>>2]!=(c|0)){break b}l=g;m=h;n=e;o=f;if((j|0)!=68){break a}break b}x[d>>2]=4;break a}x[31612]=k;if(x[i+28>>2]==(c|0)){break a}}x[d>>2]=4;g=l;h=m;e=n;f=o}x[a>>2]=g;x[a+4>>2]=h;x[a+8>>2]=e;x[a+12>>2]=f;fb=i+32|0}function eka(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0;b=fb-48|0;fb=b;e=30672;a=Nb(a);a:{while(1){b:{if((e|0)==31104){e=31104;break b}c=qc(b+40|0,x[e+4>>2]);f=x[b+44>>2];c:{if(!f){break c}d=x[a+4>>2];if(!mc(x[a>>2],d)){c=x[c>>2];d=qc(b+32|0,x[xf(d)>>2]);g=x[d+4>>2];x[b+8>>2]=x[d>>2];x[b+12>>2]=g;if(Ic(c,f,b+8|0)){break c}}x[31737]=0;O(890,a|0,e+4|0);c=x[31737];x[31737]=0;if((c|0)==1){break a}}e=e+8|0;continue}break}d:{while(1){if((e|0)==31152){break d}c=qc(b+40|0,x[e+8>>2]);e:{f=x[b+44>>2];f:{if(!f){break f}d=x[a+4>>2];if(!mc(x[a>>2],d)){g=x[c>>2];d=qc(b+24|0,x[xf(d)>>2]);h=x[d+4>>2];x[b>>2]=x[d>>2];x[b+4>>2]=h;if(Ic(g,f,b)){break f}}c=x[c>>2];x[31737]=0;x[b+20>>2]=c;O(891,a|0,b+20|0);c=x[31737];x[31737]=0;if((c|0)==1){break e}}e=e+12|0;continue}break}break a}fb=b+48|0;return}b=N()|0;vc(a);Q(b|0);p()}function Gq(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;c=fb-16|0;fb=c;b=x[a+24620>>2];a:{b:{switch(y[a+480224|0]-1|0){default:x[c+8>>2]=1;x[c>>2]=x[a+1074420>>2]<<1;d=Sua(b,b>>31,5e4,0);e=hb;b=x[ad(c+8|0,c)>>2];b=Gc(Tua(d,e,b,b>>31),hb);x[a+1074404>>2]=b;break a;case 1:x[c+8>>2]=1;x[c+12>>2]=0;g=c,h=Sua(x[a+1074420>>2],0,Sua(x[a+1074408>>2],0,x[a+1074416>>2],0),hb),x[g>>2]=h;x[c+4>>2]=hb;b=Sua(b,0,6e5,0);f=c+8|0;e=b;d=hb;b=Nw(x[f>>2],x[f+4>>2],x[c>>2],x[c+4>>2])?c:f;b=Uua(e,d,x[b>>2],x[b+4>>2]);x[a+1074404>>2]=b;break a;case 0:break b}}x[c+8>>2]=1;x[c>>2]=x[a+1074420>>2];d=Sua(b,b>>31,1e4,0);e=hb;b=x[ad(c+8|0,c)>>2];b=Gc(Tua(d,e,b,b>>31),hb);x[a+1074404>>2]=b}f=a+1074404|0;a=x[a+480244>>2];b=Sua(a,a>>31,b,b>>31);a=hb;b=b+32768|0;a=b>>>0<32768?a+1|0:a;a=Gc(Tua(b,a,65536,0),hb);x[f>>2]=a>>>0<=1?1:a;fb=c+16|0}function pW(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=fb-16|0;fb=g;m=x[a+20>>2];h=z[a+34>>1]&65;x[g+12>>2]=h;x[g+8>>2]=h^65;h=b;n=d+1298224|0;e=d+1074992|0;j=Gj(d);o=a+4|0;p=a+12|0;q=a+8|0;r=a+16|0;while(1){if((e|0)!=(n|0)){if(x[e+104>>2]==(a|0)){if(x[e+16>>2]){x[e+16>>2]=h}if(A[e+4>>2]>c>>>0){x[e>>2]=0;x[e+4>>2]=0}b=a;if(x[e+76>>2]){wc(e+76|0,c);b=x[e+104>>2]}f=x[e+88>>2];b=WF(f,b);i=x[(b?p:o)>>2];x[e+84>>2]=x[(b?r:q)>>2];x[e+80>>2]=i;b=f|x[g+12>>2];x[e+88>>2]=b;x[e+88>>2]=b&(x[g+8>>2]^-1);f=x[e+704>>2];b=x[a+24>>2];a:{if(!f|!b){break a}if(En(x[d+480180>>2])){break a}i=Sua(x[e+700>>2],0,j?b:f,0);f=j?f:b;k=i+(f>>>1|0)|0;l=hb;s=e,t=Bc(Uua(k,i>>>0>k>>>0?l+1|0:l,f,0),hb),x[s+700>>2]=t}x[e+704>>2]=b}e=e+872|0;continue}break}x[a>>2]=c;x[a+20>>2]=h;aC(m);fb=g+16|0}function A3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;f=Nb(a);a=0;a:{b:{c:{while(1){if((Kx(b,c,a)|0)==-1){break b}g=Kx(b,c,a);x[31737]=0;e=d+4|0;V(101,e|0,b|0,a|0,g-a|0);g=x[31737];x[31737]=0;if((g|0)!=1){x[31737]=0;O(102,f|0,e|0);g=x[31737];x[31737]=0;if((g|0)==1){break c}tb(e);a=Kx(b,c,a)+Yc(x[c+4>>2],y[c+11|0])|0;continue}break}a=N()|0;break a}a=N()|0;tb(d+4|0);break a}d:{e:{f:{g:{if(mc(x[f>>2],x[f+4>>2])){x[31737]=0;c=d+4|0;V(101,c|0,b|0,a|0,-1);e=x[31737];x[31737]=0;if((e|0)==1){break f}e=Yc(x[d+8>>2],y[d+15|0]);tb(c);if(!e){break g}}x[31737]=0;c=d+4|0;V(101,c|0,b|0,a|0,-1);a=x[31737];x[31737]=0;if((a|0)==1){break e}x[31737]=0;O(102,f|0,c|0);a=x[31737];x[31737]=0;if((a|0)==1){break d}tb(c)}fb=d+16|0;return}a=N()|0;break a}a=N()|0;break a}a=N()|0;tb(d+4|0)}Td(f);Q(a|0);p()}function Xfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=fb-32|0;fb=e;x[31737]=0;W(1002,a|0);d=x[31737];x[31737]=0;a:{b:{c:{d:{e:{f:{g:{if((d|0)==1){break g}x[31737]=0;W(1003,b|0);d=x[31737];x[31737]=0;if((d|0)==1){break g}x[31737]=0;W(1003,c|0);d=x[31737];x[31737]=0;if((d|0)==1){break g}f=x[a+24>>2];x[31737]=0;d=P(36,e+20|0,b|0)|0;b=x[31737];x[31737]=0;if((b|0)==1){break g}x[31737]=0;c=P(36,e+8|0,c|0)|0;b=x[31737];x[31737]=0;if((b|0)==1){break f}x[31737]=0;V(1018,f|0,d|0,c|0,1);b=x[31737];x[31737]=0;if((b|0)==1){break e}tb(c);tb(d);b=1;break b}b=T(0)|0;break c}b=T(0)|0;break d}b=T(0)|0;tb(c)}tb(d)}Y(b|0)|0;b=0;x[31737]=0;V(989,6409,a|0,0,0);a=x[31737];x[31737]=0;if((a|0)==1){break a}Z()}fb=e+32|0;return b|0}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function Lra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=fb-16|0;fb=f;c=Hf(a,c);$d(f,x[a+36>>2]);j=a;a:{if(!c){Pc(f,a+32|0,5);d=0;if(Hb(x[x[f>>2]>>2],x[f+4>>2])){break a}}d=fb-32|0;fb=d;h=x[a+36>>2];e=d+30|0;pg(h,e);b:{c:{d:{e:{a=z[d+30>>1];if(a>>>0>=4001){k=x[b+12>>2];a=fb-16|0;fb=a;g=d+4|0;i=tc(a+4|0,16005);_c(g,i);tb(i);fb=a+16|0;x[31737]=0;a=d+16|0;S(491,a|0,g|0,e|0);e=x[31737];x[31737]=0;if((e|0)==1){break e}e=x[k+1298472>>2];x[31737]=0;S(386,e|0,2,a|0);e=x[31737];x[31737]=0;if((e|0)==1){break d}tb(a);Eb(g);a=4e3}xg(Tj(x[b>>2],0),a);a=Tj(x[b>>2],0);b=wb(x[a>>2]);x[d+16>>2]=b;a=wb(x[a+4>>2]);break b}b=N()|0;break c}b=N()|0;tb(d+16|0)}Eb(d+4|0);Q(b|0);p()}while(1){if(Ib(b,a)){pg(h,d+4|0);w[b>>1]=z[d+4>>1];b=x[Md(d+16|0)>>2];continue}break}fb=d+32|0;d=c}ff(j,d);fb=f+16|0}function $n(a,b,c,d){var e=0,f=0;f=fb-16|0;fb=f;x[31737]=0;W(1002,a|0);e=x[31737];x[31737]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((e|0)!=1){e=x[a+24>>2];x[31737]=0;O(d|0,f+4|0,e|0);d=x[31737];x[31737]=0;if((d|0)==1){break i}d=x[f+4>>2];e=Ud(d,x[f+8>>2]);if(e>>>0<2147483647){break h}d=ac(8);x[31737]=0;b=P(1057,d|0,7429)|0;e=x[31737];x[31737]=0;if((e|0)==1){break g}x[31737]=0;S(98,b|0,125408,163);b=x[31737];x[31737]=0;if((b|0)!=1){break b}b=T(0)|0;break f}b=T(0)|0;break e}b=T(0)|0;break e}j:{if(!((b|0)<(e|0)&(b|0)>=0)){b=Bg(22303);break j}b=Bg(Jb(Hd(d,b)))}Td(f+4|0);break d}b=T(0)|0;jc(d)}Td(f+4|0)}Y(b|0)|0;b=0;x[31737]=0;V(989,c|0,a|0,0,0);a=x[31737];x[31737]=0;if((a|0)==1){break c}Z()}fb=f+16|0;return b}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)!=1){break a}T(0)|0;Sb()}p()}Q(a|0);p()}function Oga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;b=Qi(a,b,c,d);x[b+4260>>2]=0;x[b>>2]=45260;c=b+4960|0;e=b+4504|0;d=e;while(1){d=Nb(d)+24|0;if((d|0)!=(c|0)){continue}break}v[b+5046|0]=1;w[b+5044>>1]=0;a=b+4208|0;f=yb(a,0),g=1063675494,x[f>>2]=g;f=yb(a,1),g=1065185444,x[f>>2]=g;f=yb(a,2),g=0,x[f>>2]=g;f=yb(a,3),g=1032805417,x[f>>2]=g;f=yb(a,4),g=1053079357,x[f>>2]=g;f=yb(a,5),g=1059859440,x[f>>2]=g;f=yb(a,6),g=1047457519,x[f>>2]=g;f=yb(a,7),g=1062836634,x[f>>2]=g;f=yb(a,8),g=1038174126,x[f>>2]=g;f=yb(a,9),g=1065353216,x[f>>2]=g;f=yb(a,10),g=1065353216,x[f>>2]=g;f=yb(a,11),g=1048525618,x[f>>2]=g;f=yb(a,12),g=1059760811,x[f>>2]=g;x[31737]=0;O(947,b+44|0,2);a=x[31737];x[31737]=0;if((a|0)==1){a=N()|0;while(1){c=vc(c-24|0);if((e|0)!=(c|0)){continue}break}ag(b);Q(a|0);p()}return b|0}function Uma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=fb-16|0;fb=b;f=x[a+40>>2];g=x[a+36>>2];j=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;k=x[a+32>>2];l=x[a+28>>2];m=x[a+8>>2];n=x[a+12>>2];while(1){if(d){e=x[b+8>>2];o=(((x[b+12>>2]&2147483647)<<1|e>>>31)&-2)+j|0;e=e>>>21&2040;p=w[e+38198>>1];q=w[e+38196>>1];r=w[e+38194>>1];e=w[e+38192>>1];h=0;while(1){if((h|0)!=2){i=h+o|0;x[(h<<2)+b>>2]=(((D(v[i|0],r)+D(v[i-2|0],e)|0)+D(v[i+2|0],q)|0)+D(v[i+4|0],p)<<8)/16384;h=h+1|0;continue}break}g=g+l|0;x[c>>2]=x[c>>2]+D(x[b>>2],g>>12);f=f+k|0;x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],f>>12);Pb(b+8|0,m,n);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=f;x[a+20>>2]=g>>12;x[a+36>>2]=g;x[a+24>>2]=f>>12;fb=b+16|0}function oma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=fb-16|0;fb=e;g=x[a+40>>2];h=x[a+36>>2];j=x[a+16>>2];i=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=i;k=b+24|0;l=x[a+32>>2];m=x[a+28>>2];i=x[a+8>>2];n=x[a+12>>2];while(1){if(d){b=x[e+8>>2];f=(x[e+12>>2]<<1)+j|0;b=(((b>>>16|0)+4&131064)<<1)+k|0;b=(((((D(w[f+4>>1],w[b+10>>1])+D(w[f+2>>1],w[b+8>>1])|0)+D(w[f+6>>1],w[b+12>>1])|0)+D(w[f+8>>1],w[b+14>>1])|0)/2|0)+((((D(w[f-4>>1],w[b+2>>1])+D(w[f-6>>1],w[b>>1])|0)+D(w[f-2>>1],w[b+4>>1])|0)+D(w[f>>1],w[b+6>>1])|0)/2|0)|0)/16384|0;h=h+m|0;x[c>>2]=x[c>>2]+D(b,h>>12);g=g+l|0;x[c+4>>2]=x[c+4>>2]+D(b,g>>12);Pb(e+8|0,i,n);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;x[a+40>>2]=g;x[a+20>>2]=h>>12;x[a+36>>2]=h;x[a+24>>2]=g>>12;fb=e+16|0}function vr(a,b){var c=0;c=fb-16|0;fb=c;a=hs(a);a:{b:{c:{switch(b-1|0){default:if((b|0)!=16777216){break b}Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(a,7,1),9,1),10,1),13,1),15,1),16,1),17,1),18,1),20,1),21,1),24,1),25,1),26,1),28,1),30,1),31,1),33,1),34,1),39,1),41,1),44,1),46,1),45,1),47,1),48,1),50,1),99,1),102,1),104,1),105,1),115,1);break a;case 1:QA(c,2);b=x[c+12>>2];x[a+8>>2]=x[c+8>>2];x[a+12>>2]=b;b=x[c+4>>2];x[a>>2]=x[c>>2];x[a+4>>2]=b;dg(a,107);break a;case 3:QA(c,4);b=x[c+12>>2];x[a+8>>2]=x[c+8>>2];x[a+12>>2]=b;b=x[c+4>>2];x[a>>2]=x[c>>2];x[a+4>>2]=b;dg(a,4);break a;case 2:break b;case 0:break c}}Lb(a,88,1);break a}QA(c,b);b=x[c+12>>2];x[a+8>>2]=x[c+8>>2];x[a+12>>2]=b;b=x[c+4>>2];x[a>>2]=x[c>>2];x[a+4>>2]=b}fb=c+16|0}function dB(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;d=z[a+480188>>1];h=d>>>0<=256?256:d;f=x[a+1298300>>2];c=d;a:{while(1){if((c|0)!=(h|0)){e=D(c,872)+a|0;if(!x[e+1075068>>2]){if(!Ij(x[e+1075648>>2])|y[e+1075081|0]&24){break a}}if(y[e+1075081|0]&2){if(!Dd(f)){break a}if(!US(f,c&65535)){break a}}c=c+1|0;continue}break}g=8388608;if(b>>>0<=255){b=D(b,872)+a|0;if(!x[b+1075688>>2]){c=65535;if(x[b+1075068>>2]){break a}}g=x[b+1075680>>2]|x[b+1075672>>2]<<9}e=0;c=65535;while(1){if((d|0)==(h|0)){break a}b=D(d,872)+a|0;if(!(x[b+1075688>>2]?0:x[b+1075068>>2])){f=(x[b+1075680>>2]|x[b+1075672>>2]<<9)>>>(x[b+1075080>>2]>>>1&1)|0;b:{c:{if(f>>>0<g>>>0){b=x[b+1075716>>2];break c}if((f|0)!=(g|0)){break b}b=x[b+1075716>>2];if(e>>>0>=b>>>0){break b}}g=f;c=d;e=b}d=d+1|0;continue}break}c=d}return c&65535}function Sia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;a:{b:{if((mk(x[a>>2],x[a+4>>2])|0)==2){if((mk(x[a+12>>2],x[a+16>>2])|0)==(b|0)){break b}}x[31737]=0;O(949,a|0,2);c=x[31737];x[31737]=0;c:{if((c|0)==1){break c}x[31737]=0;O(949,a+12|0,b|0);c=x[31737];x[31737]=0;if((c|0)==1){break c}x[31737]=0;O(950,a+24|0,2);c=x[31737];x[31737]=0;if((c|0)==1){break c}x[31737]=0;O(950,a+36|0,b|0);c=x[31737];x[31737]=0;if((c|0)==1){break c}c=a;while(1)if((d|0)==2){a=0;while(1){if((a|0)==(b|0)){break b}d=es(x[c+12>>2],a);f=yb(x[c+36>>2],a),g=d,x[f>>2]=g;a=a+1|0;continue}}else{e=es(x[a>>2],d);f=yb(x[a+24>>2],d),g=e,x[f>>2]=g;d=d+1|0;continue}}b=T(125048)|0;if((gb|0)!=($(125048)|0)){break a}Y(b|0)|0;dA(a);WQ(a);b=a+12|0;dA(b);WQ(b);b=a+24|0;Nf(b);VQ(b);a=a+36|0;Nf(a);VQ(a);Z()}return}Q(b|0);p()}function sd(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=x[a+112>>2];d=x[a+116>>2];i=!!(b|d);h=b;e=x[a+4>>2];f=x[a+44>>2];b=e-f|0;g=b;c=b+x[a+120>>2]|0;b=x[a+124>>2]+(b>>31)|0;a:{b=c>>>0<g>>>0?b+1|0:b;if(!(((b|0)>=(d|0)&c>>>0>=h>>>0|(b|0)>(d|0))&i)){i=Jy(a);if((i|0)>=0){break a}e=x[a+4>>2];f=x[a+44>>2]}x[a+112>>2]=-1;x[a+116>>2]=-1;x[a+104>>2]=e;g=c;c=f-e|0;d=g+c|0;b=(c>>31)+b|0;x[a+120>>2]=d;x[a+124>>2]=c>>>0>d>>>0?b+1|0:b;return-1}d=c+1|0;b=d?b:b+1|0;h=x[a+4>>2];f=x[a+8>>2];c=x[a+116>>2];g=c;e=x[a+112>>2];b:{if(!(c|e)){break b}c=e-d|0;e=g-(b+(d>>>0>e>>>0)|0)|0;j=f-h|0;g=j>>31;if((e|0)>=(g|0)&c>>>0>=j>>>0|(e|0)>(g|0)){break b}f=c+h|0}x[a+104>>2]=f;c=x[a+44>>2];f=c-h|0;d=f+d|0;b=(f>>31)+b|0;x[a+120>>2]=d;x[a+124>>2]=d>>>0<f>>>0?b+1|0:b;if(c>>>0>=h>>>0){v[h-1|0]=i}return i}function gja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=fb-16|0;fb=f;l=Hf(a,c);$d(f,x[a+36>>2]);m=a;a:{if(!l){Pc(f,a+32|0,5);c=0;if(Hb(x[x[f>>2]>>2],x[f+4>>2])){break a}}e=fb-48|0;fb=e;j=x[a+36>>2];tl(j,e+40|0);h=x[e+44>>2];if(!h&A[e+40>>2]>=257|h){x[e+40>>2]=256;x[e+44>>2]=0}h=x[e+40>>2];n=x[e+44>>2];c=0;b:{c:{d:{e:{while(1){if(!n&c>>>0>=h>>>0){break b}i=e+38|0;pg(j,i);a=Fb(e+24|0);x[31737]=0;P(499,j|0,a|0)|0;g=x[31737];x[31737]=0;if((g|0)!=1){x[31737]=0;g=e+12|0;S(497,g|0,d|0,a|0);k=x[31737];x[31737]=0;if((k|0)==1){break e}x[31737]=0;i=P(937,b|0,i|0)|0;k=x[31737];x[31737]=0;if((k|0)==1){break d}Ab(i,g);tb(g);tb(a);c=c+1|0;continue}break}c=N()|0;break c}c=N()|0;break c}c=N()|0;tb(e+12|0)}tb(a);Q(c|0);p()}fb=e+48|0;c=l}ff(m,c);fb=f+16|0}function gia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=E(0);c=fb-4112|0;fb=c;h=ib[x[x[a>>2]+120>>2]](a)|0;if(!h){ib[x[x[a>>2]+124>>2]](a)}x[c+12>>2]=0;f=fb-16|0;fb=f;while(1){d=x[a+44>>2];if(mk(d,x[a+48>>2])>>>0<=e>>>0){fb=f+16|0}else{x[f+12>>2]=0;d=es(d,e);g=(d+2048|0)-d>>2;while(1){if((g|0)>0){B[d>>2]=B[f+12>>2];g=g-1|0;d=d+4|0;continue}break}e=e+1|0;continue}break}f=c+2064|0;a:while(1){if(b){x[c+8>>2]=b;wc(c+8|0,512);e=c+16|0;VA(e);d=x[c+8>>2];ib[x[x[a>>2]+60>>2]](a,e,f,d);e=0;while(1)if((e|0)==(d|0)){b=b-d|0;continue a}else{g=(c+16|0)+(e<<2)|0;B[c+4>>2]=F(B[g>>2]);i=c,j=B[Wz(c+12|0,c+4|0)>>2],B[i+12>>2]=j;B[c+4>>2]=F(B[g+2048>>2]);i=c,j=B[Wz(c+12|0,c+4|0)>>2],B[i+12>>2]=j;e=e+1|0;continue}}break}if(!h){ib[x[x[a>>2]+128>>2]](a)}fb=c+4112|0;return E(B[c+12>>2])}function Epa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=fb+-64|0;fb=c;i=c,j=kf(a)>>>5|0,w[i+32>>1]=j;w[c+20>>1]=3999;d=z[Nc(c+32|0,c+20|0)>>1];w[b+480190>>1]=d;g=1;while(1){f=g&65535;if(f>>>0<=d>>>0){d=ti(b,f);e=c+32|0;Dr(a,e);ld(d,0);h=c+8|0;vi(h,2,e);e=c+20|0;Cc(e,h);zc(((f<<5)+b|0)+946304|0,e);tb(e);x[d+24>>2]=8287;i=c,j=Bb(y[c+60|0]|y[c+61|0]<<8),w[i+20>>1]=j;w[c+8>>1]=64;i=d,j=z[Nc(e,h)>>1]<<2,w[i+30>>1]=j;i=d,j=$b(y[c+52|0]|y[c+53|0]<<8|(y[c+54|0]<<16|y[c+55|0]<<24))&-2,x[i>>2]=j;e=Bb(y[c+62|0]|y[c+63|0]<<8);i=yb(d+68|0,0),j=e,x[i>>2]=j;e=Bb(y[c+56|0]|y[c+57|0]<<8);f=Bb(y[c+58|0]|y[c+59|0]<<8);a:{if(f>>>0<2){break a}f=e+f<<1;if(f>>>0>A[d>>2]){break a}x[d+16>>2]=f;x[d+12>>2]=e<<1;w[d+34>>1]=z[d+34>>1]|8}g=g+1|0;d=z[b+480190>>1];continue}break}fb=c- -64|0}function VT(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;g=fb-16|0;fb=g;c=vb(g+12|0,x[a+4>>2]);d=vb(g+8|0,x[a>>2]);e=x[vb(g+4|0,x[b+4>>2])>>2];h=fb-16|0;fb=h;j=h+8|0;f=fb-32|0;fb=f;Id(f+24|0,x[c>>2],x[d>>2]);k=f+16|0;c=x[f+24>>2];l=x[f+28>>2];d=fb-16|0;fb=d;x[d+8>>2]=e;x[d+12>>2]=c;while(1){if(pd(c,l)){c=ST(c);e=ST(x[d+8>>2]);i=y[c+3|0]|y[c+4|0]<<8|(y[c+5|0]<<16|y[c+6|0]<<24);v[e+3|0]=i;v[e+4|0]=i>>>8;v[e+5|0]=i>>>16;v[e+6|0]=i>>>24;c=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);v[e|0]=c;v[e+1|0]=c>>>8;v[e+2|0]=c>>>16;v[e+3|0]=c>>>24;c=RT(d+12|0);RT(d+8|0);c=x[c>>2];continue}break}Ac(k,c,d+8|0);fb=d+16|0;c=x[f+16>>2];x[f+12>>2]=x[f+20>>2];Ac(j,c,f+12|0);fb=f+32|0;fb=h+16|0;x[b+4>>2]=x[h+12>>2];Tb(a,b+4|0);Tb(a+4|0,b+8|0);Tb(zb(a),nc(b));x[b>>2]=x[b+4>>2];fb=g+16|0}function pma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=fb-16|0;fb=e;g=x[a+40>>2];h=x[a+36>>2];j=x[a+16>>2];i=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=i;k=b+24|0;l=x[a+32>>2];m=x[a+28>>2];i=x[a+8>>2];n=x[a+12>>2];while(1){if(d){b=x[e+8>>2];f=x[e+12>>2]+j|0;b=(((b>>>16|0)+4&131064)<<1)+k|0;b=((((D(v[f+2|0],w[b+10>>1])+D(v[f+1|0],w[b+8>>1])|0)+D(v[f+3|0],w[b+12>>1])|0)+D(v[f+4|0],w[b+14>>1])<<8>>1)+(((D(v[f-2|0],w[b+2>>1])+D(v[f-3|0],w[b>>1])|0)+D(v[f-1|0],w[b+4>>1])|0)+D(v[f|0],w[b+6>>1])<<8>>1)|0)/16384|0;h=h+m|0;x[c>>2]=x[c>>2]+D(b,h>>12);g=g+l|0;x[c+4>>2]=x[c+4>>2]+D(b,g>>12);Pb(e+8|0,i,n);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;x[a+40>>2]=g;x[a+20>>2]=h>>12;x[a+36>>2]=h;x[a+24>>2]=g>>12;fb=e+16|0}function eda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=fb+-64|0;fb=e;x[e+60>>2]=c;a=qe(a,e+60|0);c=sc(a+4|0);g=sc(a+24|0);h=sc(a+32|0);i=Nb(a+36|0);x[a+56>>2]=3;j=Nb(a+68|0);x[31737]=0;O(997,a|0,d|0);f=x[31737];x[31737]=0;a:{b:{c:{d:{if((f|0)!=1){re(e+24|0,x[b>>2],x[b+4>>2]);lf(e+32|0,x[e+24>>2],x[e+28>>2]);b=Nd(e+16|0);x[31737]=0;f=x[b+4>>2];x[e+8>>2]=x[b>>2];x[e+12>>2]=f;b=e+40|0;Os(1001,b,x[e+32>>2],x[e+36>>2],e+8|0);f=x[31737];x[31737]=0;if((f|0)==1){break d}x[31737]=0;S(998,a|0,b|0,d|0);d=x[31737];x[31737]=0;if((d|0)==1){break c}ub(b);x[31737]=0;W(999,a|0);b=x[31737];x[31737]=0;if((b|0)!=1){break a}}d=N()|0;break b}d=N()|0;break b}d=N()|0;ub(e+40|0)}Td(j);nf(i);Hl(h);vh(g);uh(c);Uc(a);Uc(e+60|0);Q(d|0);p()}Uc(e+60|0);fb=e- -64|0;return a|0}function oha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=E(0),g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=E(0),o=E(0),p=0,q=0,r=0,s=0;h=fb-16|0;fb=h;if(zi(a+44|0)){g=x[a+44>>2];r=h,s=Hc(g,0),x[r+8>>2]=s;r=h,s=Hc(g,1),x[r+12>>2]=s;g=x[a+56>>2];l=Hc(g,0);x[h>>2]=l;m=Hc(g,1);x[h+4>>2]=m;p=y[a+4273|0];q=y[a+4272|0];g=d;while(1){k=0;if(g){while(1){if((k|0)!=2){j=k<<2;i=j+(h+8|0)|0;e=x[i>>2];x[i>>2]=e+4;f=E(B[e>>2]*B[a+4240>>2]);e=a+j|0;i=e+4228|0;f=E(f+E(B[i>>2]*B[a+4236>>2]));B[i>>2]=f;f=kQ(E(f*E(1073741824)),q,p);i=e+4244|0;e=e+4252|0;n=B[e>>2];o=B[a+4264>>2];f=E(E(E(f*B[a+4260>>2])-E(B[a+4268>>2]*B[i>>2]))-E(n*o));B[e>>2]=f;B[i>>2]=n+E(f*o);e=h+j|0;j=x[e>>2];x[e>>2]=j+4;B[j>>2]=f*E(9.313225746154785e-10);k=k+1|0;continue}break}g=g-1|0;continue}else{Pi(a,b,c,l,m,d)}break}}fb=h+16|0}function XQ(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;e=fb-16|0;fb=e;if(!(oc(x[a>>2],x[a+4>>2])>>>0>511|x[(x[x[b>>2]-12>>2]+b|0)+16>>2])){d=fb-16|0;fb=d;f=Ec(64);x[31737]=0;g=R(879,f|0)|0;h=x[31737];x[31737]=0;a:{b:{if((h|0)!=1){f=yf(d+8|0,g);g=x[f>>2];x[31737]=0;g=U(944,g|0,b|0,c|0)|0;h=x[31737];x[31737]=0;c:{d:{if((h|0)!=1){if((g|0)==1){break d}sc(d+12|0);break c}a=N()|0;og(f);break b}qe(d+12|0,f)}og(f);fb=d+16|0;d=x[d+12>>2];break a}a=N()|0;Db(f)}Q(a|0);p()}x[e+12>>2]=d;e:{f:{if(!Dd(d)){x[31737]=0;b=P(942,b|0,c|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break f}x[e+8>>2]=b;b=e+8|0;IZ(e+12|0,me(b));og(b);d=x[e+12>>2]}if(!Dd(d)){break e}x[31737]=0;O(501,a|0,e+12|0);a=x[31737];x[31737]=0;i=d;if((a|0)!=1){break e}}a=N()|0;og(e+12|0);Q(a|0);p()}og(e+12|0)}fb=e+16|0;return i}function Jo(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=x[b+88>>2];d=c|2048;x[b+88>>2]=d;f=x[b+656>>2];if(!(!f|v[b+730|0]&1)){d=c|6144;x[b+88>>2]=d}a:{if(!x[b+76>>2]){break a}b:{if(!(d&8)|c&2048){break b}c=x[b+104>>2];if(!c){break b}e=z[c+34>>1];if(e&2){d=(e&4?d|4:d&-135)|2;x[b+88>>2]=d;e=x[c>>2];x[b+76>>2]=e;g=x[c+4>>2];x[b+80>>2]=g;c=x[c+8>>2];x[b+84>>2]=c;if(c>>>0<e>>>0){x[b+76>>2]=c;h=c}else{h=e}e=x[b+4>>2];if(h>>>0>=e>>>0){break b}x[b>>2]=0;x[b+4>>2]=((e-g>>>0)%(c-g>>>0)|0)+g;break b}d=d&-135;x[b+88>>2]=d;x[b+76>>2]=x[c>>2]}if(!f){break a}if(!(!(y[f+60|0]&2|x[a+480180>>2]&1064964)|!x[f>>2])){x[b+88>>2]=d|4096}if(y[f+65|0]==255|z[b+728>>1]!=65535){break a}i=b,j=ed(Uq(f+48|0,x[b+724>>2],256,64)),w[i+728>>1]=j;i=b,j=z[yb(x[f+48>>2],y[f+65|0])>>1],x[i+724>>2]=j}}function bI(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;d=fb-32|0;fb=d;x[31737]=0;W(1002,a|0);e=x[31737];x[31737]=0;a:{b:{c:{if((e|0)!=1){e=Fb(d+20|0);x[31737]=0;W(c|0,d+8|0);c=x[31737];x[31737]=0;d:{e:{if((c|0)!=1){h=d,i=wb(x[d+8>>2]),x[h+4>>2]=i;f=1;while(1){g=wb(x[d+12>>2]);c=x[d+4>>2];if(!Ib(c,g)){c=Bg(Jb(e));Td(d+8|0);tb(e);break b}if(!f){x[31737]=0;P(991,e|0,14665)|0;c=x[31737];x[31737]=0;if((c|0)==1){break e}c=x[d+4>>2]}x[31737]=0;P(842,e|0,c|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break e}hl(d+4|0);f=0;continue}}c=T(0)|0;break d}c=T(0)|0;Td(d+8|0)}tb(e);break c}c=T(0)|0}Y(c|0)|0;c=0;x[31737]=0;V(989,b|0,a|0,0,0);a=x[31737];x[31737]=0;if((a|0)==1){break a}Z()}fb=d+32|0;return c}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)==1){T(0)|0;Sb();p()}Q(a|0);p()}function Uq(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=fb-16|0;fb=h;a:{e=x[a>>2];f=x[a+4>>2];if(mc(e,f)){break a}i=Sd(e,f)-1|0;while(1){b:{if(Sd(e,f)-1>>>0>g>>>0){j=Oc(e,f,g);f=x[a+4>>2];e=x[a>>2];if(z[j>>1]<(b|0)){break b}i=g}g=z[Oc(e,f,i)>>1];f=0;x[h+12>>2]=0;c:{if((b|0)>=(g|0)){k=h,l=(y[Oc(x[a>>2],x[a+4>>2],i)+2|0]<<16>>>0)/(d>>>0)|0,x[k+12>>2]=l;break c}e=0;if(i){e=i-1|0;f=(y[Oc(x[a>>2],x[a+4>>2],e)+2|0]<<16>>>0)/(d>>>0)|0;x[h+12>>2]=f;e=z[Oc(x[a>>2],x[a+4>>2],e)>>1]}if((b|0)<=(e|0)|e>>>0>=g>>>0){break c}a=((y[Oc(x[a>>2],x[a+4>>2],i)+2|0]<<16>>>0)/(d>>>0)|0)-f|0;d=a;i=a>>31;a=b-e|0;b=Sua(d,i,a,a>>31);a=g-e|0;k=h,l=Gc(Tua(b,hb,a,a>>31),hb)+f|0,x[k+12>>2]=l}Fe(h+12|0,0,65536);g=(D(x[h+12>>2],c)+32768|0)/65536|0;break a}g=g+1|0;continue}}fb=h+16|0;return g}function V2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=fb-32|0;fb=c;x[c+28>>2]=0;if(Gd(y[Lm(c+27|0,a,0)|0])){bd(c+16|0,x[(x[x[a>>2]-12>>2]+a|0)+28>>2]);x[31737]=0;e=R(1181,x[c+16>>2])|0;d=x[31737];x[31737]=0;a:{b:{if((d|0)!=1){d=up(c+12|0,a);f=sc(c+8|0);g=x[x[a>>2]-12>>2];f=x[f>>2];d=x[d>>2];x[31737]=0;ja(1183,e|0,d|0,f|0,a+g|0,c+28|0,c+20|0);e=x[31737];x[31737]=0;if((e|0)!=1){break b}}b=T(0)|0;Zb(c+16|0);Y(b|0)|0;b=x[c+28>>2]|1;x[c+28>>2]=b;Jm(x[x[a>>2]-12>>2]+a|0,b);c:{d:{if(x[(x[x[a>>2]-12>>2]+a|0)+20>>2]&1){x[31737]=0;X(85);a=x[31737];x[31737]=0;if((a|0)!=1){break c}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)==1){break d}Q(a|0);p()}Z();break a}T(0)|0;Sb()}p()}Zb(c+16|0);x[b>>2]=x[c+20>>2]}bk(x[x[a>>2]-12>>2]+a|0,x[c+28>>2])}fb=c+32|0;return a|0}function hda(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=fb+-64|0;fb=f;x[f+60>>2]=d;a=qe(a,f+60|0);d=sc(a+4|0);g=sc(a+24|0);h=sc(a+32|0);i=Nb(a+36|0);x[a+56>>2]=3;j=Nb(a+68|0);x[31737]=0;O(997,a|0,e|0);k=x[31737];x[31737]=0;a:{b:{c:{d:{if((k|0)!=1){bc(f+24|0,b,c);lf(f+32|0,x[f+24>>2],x[f+28>>2]);b=Nd(f+16|0);x[31737]=0;c=x[b+4>>2];x[f+8>>2]=x[b>>2];x[f+12>>2]=c;b=f+40|0;Os(1001,b,x[f+32>>2],x[f+36>>2],f+8|0);c=x[31737];x[31737]=0;if((c|0)==1){break d}x[31737]=0;S(998,a|0,b|0,e|0);c=x[31737];x[31737]=0;if((c|0)==1){break c}ub(b);x[31737]=0;W(999,a|0);b=x[31737];x[31737]=0;if((b|0)!=1){break a}}e=N()|0;break b}e=N()|0;break b}e=N()|0;ub(f+40|0)}Td(j);nf(i);Hl(h);vh(g);uh(d);Uc(a);Uc(f+60|0);Q(e|0);p()}Uc(f+60|0);fb=f- -64|0;return a|0}function BF(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=fb-16|0;fb=e;x[31737]=0;f=P(21,e+8|0,a|0)|0;d=x[31737];x[31737]=0;a:{b:{c:{if((d|0)!=1){d:{e:{if(!Gd(y[f|0])){break e}g=up(e+4|0,a);d=x[x[a>>2]-12>>2]+a|0;h=x[d+4>>2];x[31737]=0;i=R(22,d|0)|0;j=x[31737];x[31737]=0;if((j|0)==1){break d}g=x[g>>2];x[31737]=0;c=b+c|0;b=ea(23,g|0,b|0,((h&176)==32?c:b)|0,c|0,d|0,i|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break d}if(b){break e}b=x[x[a>>2]-12>>2];x[31737]=0;O(24,a+b|0,5);b=x[31737];x[31737]=0;if((b|0)!=1){break e}break d}nm(f);break b}b=T(0)|0;nm(f);break c}b=T(0)|0}Y(b|0)|0;b=x[x[a>>2]-12>>2];x[31737]=0;W(25,a+b|0);b=x[31737];x[31737]=0;if((b|0)==1){break a}Z()}fb=e+16|0;return a}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)==1){T(0)|0;Sb();p()}Q(a|0);p()}function U1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;g=fb-16|0;fb=g;cd(b,y[c+32|0]|y[c+33|0]<<8|(y[c+34|0]<<16|y[c+35|0]<<24));h=Nb(a);a=y[c+28|0]|y[c+29|0]<<8|(y[c+30|0]<<16|y[c+31|0]<<24);x[31737]=0;O(180,h|0,a|0);a=x[31737];x[31737]=0;if((a|0)!=1){a:{a=0;while(1){b:{if((y[c+28|0]|y[c+29|0]<<8|(y[c+30|0]<<16|y[c+31|0]<<24))>>>0<=a>>>0){break b}e=x[b+8>>2];f=x[b>>2];x[31737]=0;e=U(151,f|0,e|0,4)|0;f=x[31737];x[31737]=0;if((f|0)==1){break a}if(!e){break b}e=y[c+4|0]|y[c+5|0]<<8;x[31737]=0;e=P(181,b|0,e|0)|0;f=x[31737];x[31737]=0;c:{if((f|0)!=1){x[g+12>>2]=e;if(Ud(x[d>>2],x[d+4>>2])>>>0<=e>>>0){break c}x[31737]=0;O(182,h|0,g+12|0);e=x[31737];x[31737]=0;if((e|0)!=1){break c}}break a}a=a+1|0;continue}break}fb=g+16|0;return}}a=N()|0;vc(h);Q(a|0);p()}function KP(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=+c;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;j=fb-48|0;fb=j;k=x[a+4>>2];l=x[a>>2];a=x[a+8>>2];x[j+32>>2]=b;x[j+44>>2]=a;x[j+36>>2]=l;x[j+40>>2]=k;x[31737]=0;a=P(982,(d?d:983)|0,e|0)|0;b=x[31737];x[31737]=0;a:{b:{c:{d:{if((b|0)!=1){x[j+24>>2]=a;a=j+24|0;b=x[qe(j+28|0,a)>>2];k=x[j+44>>2];x[j+16>>2]=x[j+40>>2];x[j+20>>2]=k;x[31737]=0;k=x[j+36>>2];x[j+8>>2]=x[j+32>>2];x[j+12>>2]=k;c=+pa(984,j+8|0,+c,b|0);b=x[31737];x[31737]=0;if((b|0)==1){break d}Uc(a);break b}a=T(0)|0;break c}a=T(0)|0;Uc(j+24|0)}Y(a|0)|0;x[31737]=0;ga(985,15153,d|0,e|0,f|0,g|0,h|0,i|0);a=x[31737];x[31737]=0;if((a|0)==1){break a}Z();c=0}fb=j+48|0;return+c}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function HQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=fb-16|0;fb=c;e=x[b+4220>>2];f=x[b+4224>>2];g=x[b+4228>>2];h=x[b+4232>>2];i=x[b+4240>>2];j=x[b+4236>>2];k=y[b+4244|0];Nk(b+4208|0,33);d=x[b+4208>>2];v[d+32|0]=k;v[d+24|0]=j;v[d+25|0]=j>>>8;v[d+26|0]=j>>>16;v[d+27|0]=j>>>24;v[d+28|0]=i;v[d+29|0]=i>>>8;v[d+30|0]=i>>>16;v[d+31|0]=i>>>24;v[d+16|0]=g;v[d+17|0]=g>>>8;v[d+18|0]=g>>>16;v[d+19|0]=g>>>24;v[d+20|0]=h;v[d+21|0]=h>>>8;v[d+22|0]=h>>>16;v[d+23|0]=h>>>24;v[d+8|0]=e;v[d+9|0]=e>>>8;v[d+10|0]=e>>>16;v[d+11|0]=e>>>24;v[d+12|0]=f;v[d+13|0]=f>>>8;v[d+14|0]=f>>>16;v[d+15|0]=f>>>24;v[d|0]=76;v[d+1|0]=70;v[d+2|0]=79;v[d+3|0]=32;v[d+4|0]=0;v[d+5|0]=0;v[d+6|0]=0;v[d+7|0]=0;re(c+8|0,x[b+4208>>2],x[b+4212>>2]);gc(a,x[c+8>>2],x[c+12>>2]);fb=c+16|0}function z4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=fb-160|0;fb=d;Rb(d+116|0,0,44);while(1){if((c|0)==7){a:{c=0;while(1){if((c|0)==12){break a}x[d+132>>2]=c;e=d+16|0;f=d+116|0;fa(e|0,100,14339,f|0,x[a>>2])|0;g=D(c,12)+a|0;id(g+172|0,e);fa(e|0,100,13349,f|0,x[a>>2])|0;id(g+316|0,e);c=c+1|0;continue}}}else{x[d+140>>2]=c;e=d+16|0;f=d+116|0;fa(e|0,100,14352,f|0,x[a>>2])|0;g=D(c,12)+a|0;id(g+4|0,e);fa(e|0,100,13556,f|0,x[a>>2])|0;id(g+88|0,e);c=c+1|0;continue}break}x[d+124>>2]=1;c=d+16|0;e=d+116|0;fa(c|0,100,9278,e|0,x[a>>2])|0;id(a+460|0,c);x[d+124>>2]=13;fa(c|0,100,9278,e|0,x[a>>2])|0;id(a+472|0,c);c=d+4|0;Us(c,a,99,b);Ab(a+484|0,c);tb(c);Us(c,a,114,b);Ab(a+496|0,c);tb(c);Us(c,a,120,b);Ab(a+508|0,c);tb(d+4|0);Us(c,a,88,b);Ab(a+520|0,c);tb(d+4|0);fb=d+160|0}function vx(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;h=fb-16|0;fb=h;e=zb(a);c=vb(h+12|0,x[a+4>>2]);f=vb(h+8|0,x[a>>2]);g=vb(h+4|0,x[b+4>>2]);d=x[c>>2];f=x[f>>2];c=fb+-64|0;fb=c;g=x[g>>2];x[c+56>>2]=g;x[c+60>>2]=d;x[c+52>>2]=g;e=Re(c+24|0,e,c+52|0,c+56|0);x[c+16>>2]=x[e+8>>2];g=x[e+4>>2];x[c+8>>2]=x[e>>2];x[c+12>>2]=g;Qe(c+36|0,c+8|0);while(1){if(pd(d,f)){As(Vp(x[c+56>>2]),il(d));d=qk(c+60|0);qk(c+56|0);d=x[d>>2];continue}break}Pe(c+36|0);g=x[c+56>>2];if(!y[c+48|0]){e=fb-16|0;fb=e;d=vb(e+12|0,x[x[c+44>>2]>>2]);i=x[vb(e+8|0,x[x[c+40>>2]>>2])>>2];f=fb-16|0;fb=f;d=x[d>>2];x[f+12>>2]=d;while(1){if(ci(d,i)){Eb(ux(d));d=x[hl(f+12|0)>>2];continue}break}fb=f+16|0;fb=e+16|0}fb=c- -64|0;x[b+4>>2]=g;Tb(a,b+4|0);Tb(a+4|0,b+8|0);Tb(zb(a),nc(b));x[b>>2]=x[b+4>>2];fb=h+16|0}function zja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=fb-32|0;fb=e;c=z[x[x[a+48>>2]+12>>2]+480188>>1];a:{if(!b){break a}c=D(b,c);b:{if(x[a+12>>2]!=(b|0)){break b}if((Mk(x[a>>2],x[a+4>>2])|0)!=(c|0)){break b}b=fb-16|0;fb=b;d=wb(x[a>>2]);a=wb(x[a+4>>2]);w[b+12>>1]=0;x[b+8>>2]=0;f=wu(a,d);c=fb-16|0;fb=c;x[c+12>>2]=d;while(1){if((f|0)>0){a=x[c+12>>2];d=y[b+8|0]|y[b+9|0]<<8|(y[b+10|0]<<16|y[b+11|0]<<24);v[a|0]=d;v[a+1|0]=d>>>8;v[a+2|0]=d>>>16;v[a+3|0]=d>>>24;d=y[b+12|0]|y[b+13|0]<<8;v[a+4|0]=d;v[a+5|0]=d>>>8;f=f-1|0;vg(c+12|0);continue}break}fb=c+16|0;fb=b+16|0;break a}w[e+16>>1]=0;x[e+12>>2]=0;c=UZ(e+20|0,c,e+12|0);vR(a);x[a>>2]=x[c>>2];x[a+4>>2]=x[c+4>>2];f=zb(c);g=zb(a),h=x[f>>2],x[g>>2]=h;x[f>>2]=0;x[c>>2]=0;x[c+4>>2]=0;Qk(c);x[a+12>>2]=b}fb=e+32|0}function qba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=fb-16|0;fb=d;j=d,k=hN(),x[j+12>>2]=k;h=a+24|0;f=d+12|0;fN(h,me(f));vh(f);w[a+28>>1]=0;aQ();g=fb-16|0;fb=g;i=Ec(144);x[31737]=0;c=P(1134,i|0,4)|0;e=x[31737];x[31737]=0;a:{if((e|0)!=1){e=yf(g+12|0,c);fb=g+16|0;e=x[e>>2];break a}a=N()|0;Db(i);Q(a|0);p()}x[d+12>>2]=e;eN(a+32|0,me(f));Hl(f);j=d,k=gN(x[a>>2]),x[j+12>>2]=k;dN(a+4|0,me(f));uh(f);yo(x[h>>2],x[a+4>>2]);v[a+64|0]=1;x[a+60>>2]=0;x[a+48>>2]=1065353216;x[a+52>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;c=_i(x[b>>2]);x[d+12>>2]=c;e=Rf(b);b:{while(1){if(!Zg(c,e)){break b}b=td(c);c=lg(d,b);x[31737]=0;V(1018,a|0,c|0,b+12|0,0);b=x[31737];x[31737]=0;if((b|0)!=1){tb(c);c=x[ah(d+12|0)>>2];continue}break}a=N()|0;tb(c);Q(a|0);p()}fb=d+16|0}function aM(a){var b=E(0),c=E(0),d=E(0),e=E(0),f=E(0),g=E(0),h=E(0),i=E(0),j=E(0),k=E(0),l=E(0),m=E(0),n=E(0),o=E(0);f=B[a>>2];i=B[a+24>>2];c=E(f-i);d=B[a+16>>2];b=B[a+32>>2];g=B[a+8>>2];e=E(d+E(b-g));B[a+16>>2]=c+e;j=E(c-E(e*E(.5)));c=B[a+4>>2];e=B[a+20>>2];h=B[a+28>>2];k=E(E(E(c-e)-h)*E(.8660253882408142));B[a+4>>2]=j+k;l=E(E(d-b)*E(.1736481785774231));f=E(f+E(i*E(.5)));i=E(E(g+b)*E(.7660444378852844));m=E(l+E(f-i));n=E(E(c+e)*E(.9848077297210693));b=E(B[a+12>>2]*E(.8660253882408142));c=E(E(c+h)*E(.6427876353263855));o=E(E(n-b)-c);B[a+12>>2]=m+o;B[a+20>>2]=m-o;B[a+28>>2]=j-k;d=E(E(g+d)*E(.9396926164627075));g=E(E(f+d)-l);e=E(E(e-h)*E(.3420201539993286));h=E(E(e-b)-n);B[a+32>>2]=g+h;d=E(E(f-d)+i);b=E(E(b+e)-c);B[a+24>>2]=d+b;B[a+8>>2]=d-b;B[a>>2]=g-h}function Fqa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=fb-16|0;fb=e;v[e+15|0]=0;w[e+12>>1]=0;j=8;n=D(c,d)<<1;a:while(1){if((d|0)!=(k|0)){h=(k<<1)+b|0;o=n+h|0;while(1){b:{c:{if(h>>>0<o>>>0){w[e+10>>1]=0;wY(a,e+15|0,e+12|0,j,e+10|0);i=z[e+10>>1];f=z[e+12>>1];c=j;while(1){if(c&255){g=f<<1;f=g&254;d:{if(f){g=(g&65534)>>>0>255;break d}if(!Af(a,e+9|0)){break c}f=y[e+9|0];g=f>>>7|0;f=f<<1&254|1}c=c-1|0;i=i<<1|g;continue}break}w[e+12>>1]=f;break b}k=k+1|0;continue a}w[e+12>>1]=0}c=1;g=i&65535;e:{if(g>>>0<4){break e}f=15;while(1){c=f;m=f&255;if(m>>>0<2){break e}f=f-1|0;if(!(g&1<<m)){continue}break}}f=i&1;v[e+15|0]=f;l=(f-1^(i&65534)>>>1)+l|0;w[e+10>>1]=l;w[h>>1]=l;h=(d<<1)+h|0;j=(c+j&254)>>>1|0;continue}}break}fb=e+16|0}function aoa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=fb-80|0;fb=c;a:{d=x[a+4>>2];b:{if(d>>>0<b>>>0){f=Nd(c+72|0);e=b-d|0;g=ev(a);c:{if(!(e>>>0>g>>>0|d>>>0>g-e>>>0)){dr(c+60|0,x[a>>2],d);gc(f,x[c+60>>2],x[c+64>>2]);x[a+4>>2]=x[a+4>>2]+e;break c}d=Xo(c+60|0);x[31737]=0;b=P(761,a|0,b|0)|0;g=x[31737];x[31737]=0;if((g|0)==1){break a}x[31737]=0;O(762,d|0,b|0);b=x[31737];x[31737]=0;if((b|0)==1){break a}x[d+4>>2]=x[a+4>>2]+e;rn(c+44|0,x[a>>2]);dr(c+32|0,x[a>>2],x[a+4>>2]);rn(c+24|0,x[d>>2]);b=x[c+48>>2];x[c+8>>2]=x[c+44>>2];x[c+12>>2]=b;sX(c+52|0,c+8|0,x[c+32>>2],x[c+36>>2],x[c+24>>2],x[c+28>>2]);gc(f,x[c+52>>2],x[c+56>>2]);iC(a,d);tf(d)}a=gc(c+16|0,x[f>>2],x[f+4>>2]);Qw(x[a>>2],x[a+4>>2],e,0);break b}x[a+4>>2]=b}fb=c+80|0;return}a=N()|0;tf(d);Q(a|0);p()}function Es(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;d=fb-32|0;fb=d;x[d+28>>2]=0;a:{b:{c:{if(Gd(y[Lm(d+27|0,a,0)|0])){g=d+20|0;bd(g,x[(x[x[a>>2]-12>>2]+a|0)+28>>2]);x[31737]=0;h=R(1181,x[d+20>>2])|0;e=x[31737];x[31737]=0;d:{e:{if((e|0)==1){break e}e=up(d+16|0,a);f=sc(d+12|0);i=x[x[a>>2]-12>>2];f=x[f>>2];e=x[e>>2];x[31737]=0;ja(c|0,h|0,e|0,f|0,a+i|0,d+28|0,b|0);b=x[31737];x[31737]=0;if((b|0)==1){break e}Zb(g);break d}b=T(0)|0;Zb(d+20|0);Y(b|0)|0;b=x[d+28>>2]|1;x[d+28>>2]=b;Jm(x[x[a>>2]-12>>2]+a|0,b);if(x[(x[x[a>>2]-12>>2]+a|0)+20>>2]&1){x[31737]=0;X(85);a=x[31737];x[31737]=0;if((a|0)!=1){break b}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)==1){break c}Q(a|0);p()}Z()}bk(x[x[a>>2]-12>>2]+a|0,x[d+28>>2])}fb=d+32|0;break a}T(0)|0;Sb()}p()}return a}function uB(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a:{f=a+1074312|0;if(j=Ob(f,77),k=0,l=x[(D(c,872)+b|0)+704>>2]&67109888,l?j:k){break a}g=x[a+480180>>2]!=2?c:0;e=D(g,872);if(!d){x[(b+e|0)+1380>>2]=x[b+48>>2];return}h=(b+e|0)+1457|0;c=y[h|0];b:{if(c){c=c-1|0;v[h|0]=c;if(c&255){break b}if(!Ob(f,16)&x[a+480180>>2]!=2){break a}x[(D(g,872)+b|0)+1380>>2]=x[b+48>>2]+1;return}c:{if(Ob(f,17)|y[a+480180|0]&3){break c}c=b+616|0;i=e+c|0;e=0;a=z[a+480188>>1];while(1){if(a>>>0<=(e&65535)>>>0){break c}if(y[c+841|0]?(c|0)!=(i|0):0){break a}c=c+872|0;e=e+1|0;continue}}v[h|0]=d}a=x[(D(g,872)+b|0)+1380>>2];x[b+56>>2]=a;if((a|0)==-1){break a}d:{if(x[b+60>>2]==-1){break d}if(!Ob(f,68)){break d}x[b+60>>2]=a}x[b+64>>2]=a;if(!Ob(f,103)){break a}w[b+68>>1]=65535}}function Aq(a){var b=E(0),c=0,d=0,e=0,f=0;f=fb-16|0;fb=f;e=(q(a),j(2));c=e&2147483647;a:{if(c>>>0<=1061752794){b=E(1);if(c>>>0<964689920){break a}b=Ei(+a);break a}if(c>>>0<=1081824209){if(c>>>0>=1075235812){b=E(-Ei(((e|0)<0?3.141592653589793:-3.141592653589793)+ +a));break a}d=+a;if((e|0)<0){b=Fi(d+1.5707963267948966);break a}b=Fi(1.5707963267948966-d);break a}if(c>>>0<=1088565717){if(c>>>0>=1085271520){b=Ei(((e|0)<0?6.283185307179586:-6.283185307179586)+ +a);break a}if((e|0)<0){b=Fi(-4.71238898038469-+a);break a}b=Fi(+a+-4.71238898038469);break a}b=E(a-a);if(c>>>0>=2139095040){break a}c=Wy(a,f+8|0);d=C[f+8>>3];b:{switch(c&3){case 0:b=Ei(d);break a;case 1:b=Fi(-d);break a;case 2:b=E(-Ei(d));break a;default:break b}}b=Fi(d)}a=b;fb=f+16|0;return a}function fY(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;while(1){if((c|0)!=20){g=b;b=v[a+c|0];b=g+((b&255)!=0&(b|0)<32)|0;c=c+1|0;continue}break}d=b;a:{if(b>>>0>5){break a}while(1){if((h|0)!=15){e=D(h,30)+a|0;f=e+20|0;c=0;b=0;while(1){if((c|0)!=22){g=b;b=v[c+f|0];b=g+((b&255)!=0&(b|0)<32)|0;c=c+1|0;continue}break}d=b+d|0;if(d>>>0>48){break a}c=y[e+45|0];if(y[e+44|0]|c>>>0>64){break a}b=Bb(y[e+42|0]|y[e+43|0]<<8);if(b>>>0>32768){break a}h=h+1|0;i=c|i;j=b+j|0;continue}break}if(!j|!(i&255)){break a}d=y[a+470|0];if(d>>>0>128){break a}b=y[a+471|0];if(b>>>0>220){break a}a=a+472|0;f=MC(a);b:{if((a|0)==(f|0)){break b}c=a;while(1){c=c+1|0;if((f|0)==(c|0)){break b}a=Vt(y[a|0],y[c|0])?c:a;continue}}a=y[a|0];if(a>>>0>63){break a}k=(b|(a|d))!=0}return k}function sq(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0;o(+a);b=j(1)|0;f=j(0)|0;a:{b:{c:{if(!(((b|0)>0|(b|0)>=0)&b>>>0>1048575)){o(+a);d=j(1)|0;if(!(j(0)|d&2147483647)){return-1/(a*a)}if((b|0)>0|(b|0)>=0){break c}return(a-a)/0}if(b>>>0>2146435071){break a}d=1072693248;g=-1023;if((b|0)!=1072693248){d=b;break b}if(f){break b}return 0}o(+(a*0x40000000000000));b=j(1)|0;f=j(0)|0;d=b;g=-1077}b=d+614242|0;h=+((b>>>20|0)+g|0);e=h*.6931471803691238;l(0,f|0);l(1,(b&1048575)+1072079006|0);a=+n()+-1;c=a/(a+2);i=e;k=a;m=c;e=a*(a*.5);c=c*c;a=c*c;a=i+(k+(m*(e+(a*(a*(a*.15313837699209373+.22222198432149784)+.3999999999940942)+c*(a*(a*(a*.14798198605116586+.1818357216161805)+.2857142874366239)+.6666666666666735)))+h*1.9082149292705877e-10-e))}return a}function nQ(a){var b=0,c=0,d=0,e=0;e=fb-16|0;fb=e;d=(q(a),j(2));c=d&2147483647;a:{if(c>>>0<=1061752794){if(c>>>0<964689920){break a}a=Fi(+a);break a}if(c>>>0<=1081824209){b=+a;if(c>>>0<=1075235811){if((d|0)<0){a=E(-Ei(b+1.5707963267948966));break a}a=Ei(b+-1.5707963267948966);break a}a=Fi(-(((d|0)>=0?-3.141592653589793:3.141592653589793)+b));break a}if(c>>>0<=1088565717){if(c>>>0<=1085271519){b=+a;if((d|0)<0){a=Ei(b+4.71238898038469);break a}a=E(-Ei(b+-4.71238898038469));break a}a=Fi(((d|0)<0?6.283185307179586:-6.283185307179586)+ +a);break a}if(c>>>0>=2139095040){a=E(a-a);break a}c=Wy(a,e+8|0);b=C[e+8>>3];b:{switch(c&3){case 0:a=Fi(b);break a;case 1:a=Ei(b);break a;case 2:a=Fi(-b);break a;default:break b}}a=E(-Ei(b))}fb=e+16|0;return a}function SB(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=fb-16|0;fb=h;i=Xl(a,b);a:{if((i|0)==255){break a}if(Mj(x[a>>2])){break a}b:{if(c>>>0>6208431){j=7168;c=1023;break b}f=7;c:{if(c>>>0>3104215){break c}f=6;if(c>>>0>1552107){break c}f=5;if(c>>>0>776053){break c}f=4;if(c>>>0>388026){break c}f=3;if(c>>>0>194013){break c}f=2;if(c>>>0>97006){break c}f=c>>>0>48503}j=f<<10;f=20-f|0;g=f&31;if((f&63)>>>0>=32){f=c<<g;c=0}else{f=(1<<g)-1&c>>>32-g;c=c<<g}g=c+24858e3|0;c=f;c=Bc(Uua(g,g>>>0<24858e3?c+1|0:c,49716e3,0),hb)}if(e){w[h+14>>1]=(b&3)+c;w[h+12>>1]=1023;c=z[Nc(h+14|0,h+12|0)>>1]}e=bv(i);f=a+8|0;k=xb(f,i),l=(c|j)>>>8|(d?0:32),v[k|0]=l;yh(x[a>>2],x[a+4>>2],b,e|160,c&255);c=xb(f,i);yh(x[a>>2],x[a+4>>2],b,e|176,y[c|0]);v[a+534|0]=1}fb=h+16|0}function Ko(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0;h=fb-16|0;fb=h;if(e){x[e>>2]=0}a:{i=x[a+484344>>2];if(!He(i,x[a+484348>>2],b)){break a}g=Wb(i,b);k=x[x[g+48>>2]+12>>2];b=jd(x[g>>2],k,c,d);f=y[b+5|0];b:{c:{d:{e:{j=y[b+3|0];switch(j-10|0){case 1:case 3:case 5:case 6:break a;case 0:break c;case 2:case 4:case 7:break d;default:break e}}if(j-35>>>0>=2){break a}}x[h+12>>2]=1;i=0;if((j|0)!=17){break b}i=x[a+480180>>2]==4;break b}x[h+12>>2]=2;i=0}x[h+8>>2]=x[g+12>>2]+(c^-1);d=0;a=x[Gb(h+8|0,h+12|0)>>2];c=a;while(1){f:{if(c){b=D(z[k+480188>>1],6)+b|0;if(y[b+3|0]==34){break f}a=d}f=(j-37&255)>>>0<254?f:a?f:f<<8;if(!e){break a}x[e>>2]=a;break a}g=f<<8;f=y[b+5|0]|(i?f>>>0>31?f>>>0<256?g+-8192|0:g:g:g);d=d+1|0;c=c-1|0;continue}}fb=h+16|0;return f}function K_(a,b){var c=0,d=0,e=0,f=0,g=0;e=fb-16|0;fb=e;d=Fb(a);a=zd(b);x[e+12>>2]=a;f=Df(b);b=0;a:{while(1){b:{if(!Ib(a,f)){if(!b){break b}x[31737]=0;O(35,d|0,65533);a=x[31737];x[31737]=0;if((a|0)!=1){break b}break a}a=y[a|0];c:{d:{if(!b){if(a<<24>>24>=0){b=0;x[31737]=0;O(35,d|0,a|0);a=x[31737];x[31737]=0;if((a|0)!=1){break c}break a}if((a&224)==192){c=a&31;b=1;break c}if((a&240)==224){c=a&15;b=2;break c}c=65533;if((a&248)!=240){break d}c=a&7;b=3;break c}if((a&192)!=128){c=0;x[31737]=0;O(35,d|0,65533);g=x[31737];x[31737]=0;b=0;if((g|0)==1){break a}}c=a&63|c<<6;b=b-1|0;if(b){break c}}b=0;x[31737]=0;O(35,d|0,c|0);a=x[31737];x[31737]=0;c=0;if((a|0)==1){break a}}a=x[le(e+12|0)>>2];continue}break}fb=e+16|0;return}a=N()|0;Ub(d);Q(a|0);p()}function Il(a,b,c){var d=0,e=0,f=0,g=0;e=fb-48|0;fb=e;d=x[a+24>>2];g=x[d+24620>>2];a:{if(!((g|0)!=(b|0)|x[d+24624>>2]!=(c|0))){if(y[a+29|0]){break a}_R(d,1);break a}f=e+8|0;yc(f,d+24604|0,40);x[e+28>>2]=c;x[e+24>>2]=b;c=x[e+44>>2];$t(f,x[e+40>>2]);So(f,c);LA(d,f);if((b|0)==(g|0)){break a}c=x[a+24>>2]+906300|0;d=Ak(c);while(1){if((c|0)!=(d|0)){b=x[c>>2];b:{if(!b){break b}if(!(ib[x[x[b>>2]+120>>2]](b)|0)){break b}ib[x[x[b>>2]+112>>2]](b,0);ib[x[x[b>>2]+100>>2]](b);ib[x[x[b>>2]+128>>2]](b)}c=c+160|0;continue}break}c=x[a+24>>2]+906300|0;d=Ak(c);while(1){if((c|0)!=(d|0)){b=x[c>>2];c:{if(!b){break c}if(ib[x[x[b>>2]+120>>2]](b)|0){break c}ib[x[x[b>>2]+112>>2]](b,1);ib[x[x[b>>2]+124>>2]](b)}c=c+160|0;continue}break}}v[a+29|0]=1;fb=e+48|0}function Eqa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=fb-16|0;fb=e;v[e+15|0]=0;w[e+12>>1]=0;n=D(c,d);j=4;a:while(1){if((d|0)!=(k|0)){h=b+k|0;o=n+h|0;while(1){b:{c:{if(h>>>0<o>>>0){v[e+11|0]=0;vY(a,e+15|0,e+12|0,e+11|0);i=y[e+11|0];f=z[e+12>>1];c=j;while(1){if(c&255){g=f<<1;f=g&254;d:{if(f){g=(g&65534)>>>0>255;break d}if(!Af(a,e+10|0)){break c}f=y[e+10|0];g=f>>>7|0;f=f<<1&254|1}c=c-1|0;i=i<<1|g;continue}break}w[e+12>>1]=f;break b}k=k+1|0;continue a}w[e+12>>1]=0}c=1;g=i&255;e:{if(g>>>0<4){break e}f=7;while(1){c=f;m=f&255;if(m>>>0<2){break e}f=f-1|0;if(!(g&1<<m)){continue}break}}f=i&1;v[e+15|0]=f;l=(f-1^(i&254)>>>1)+l|0;v[e+11|0]=l;v[h|0]=l;h=d+h|0;j=(c+j&254)>>>1|0;continue}}break}fb=e+16|0}function xk(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=fb-32|0;fb=d;a:{b:{while(1){f=d+8|0;e=c<<2;h=f+e|0;g=1<<c&2147483647;if(g|1){e=LK(c,g?a:22303)}else{e=x[e>>2]}x[h>>2]=e;if((e|0)==-1){break b}c=c+1|0;if((c|0)!=6){continue}break}if(!KK(0)){b=121532;if(!kd(f,121532,24)){break a}b=121556;if(!kd(f,121556,24)){break a}c=0;if(!y[500192]){while(1){i=(c<<2)+500144|0,j=LK(c,22303),x[i>>2]=j;c=c+1|0;if((c|0)!=6){continue}break}v[500192]=1;x[125042]=x[125036]}b=500144;a=d+8|0;if(!kd(a,500144,24)){break a}b=500168;if(!kd(a,500168,24)){break a}b=Ed(24);if(!b){break b}}a=x[d+12>>2];x[b>>2]=x[d+8>>2];x[b+4>>2]=a;a=x[d+28>>2];x[b+16>>2]=x[d+24>>2];x[b+20>>2]=a;a=x[d+20>>2];x[b+8>>2]=x[d+16>>2];x[b+12>>2]=a;break a}b=0}fb=d+32|0;return b}function oS(a,b){var c=E(0),d=E(0),e=E(0);a:{b:{c:{switch(b|0){case 0:Fq(a,E(1));zk(a,E(3.725290298461914e-9));Eq(a,E(268435456));Dq(a,0);break b;case 1:Fq(a,E(32));zk(a,E(4.656612873077393e-10));Eq(a,E(2147483648));Dq(a,0);break b;case 2:Fq(a,E(2));zk(a,E(7.450580596923828e-9));Eq(a,E(134217728));Dq(a,1);break b;default:Fq(a,E(1));zk(a,E(7.450580596923828e-9));Eq(a,E(134217728));Dq(a,1);FA(a,0);EA(a,1);DA(a,1);d=E(256);c=E(128);e=E(128);b=0;break a;case 4:case 5:break c}}Fq(a,E(.75));zk(a,E(7.450580596923828e-9));Eq(a,E(134217728));Dq(a,1);FA(a,0);b=(b|0)==4;EA(a,b?2:3);DA(a,1);d=E(256);c=b?E(256):E(192);e=c;b=1;break a}FA(a,1);EA(a,0);DA(a,0);d=E(128);e=E(100);c=E(256);b=4}B[a+16>>2]=c;B[a+20>>2]=e;B[a+24>>2]=d;x[a+28>>2]=b}function nY(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;o=x[b>>2];while(1){if((i|0)==128){xg(b,c);c=x[a+8>>2];d=c+d|0;i=z[e>>1];a:{b:{c:{if(!f){break c}j=f;f=h&65535;if((c+(j+(f<<11)|0)|0)!=(Kh(x[a>>2])&-2)){break c}cd(a,c+(f<<10)|0);if(!SC(a,16,1)){break b}w[e>>1]=8;break b}if((h&65535)==(k&65535)){h=k;break a}f=k<<8&16776960;if(!g){if((Kh(x[a>>2])|0)!=(d+D(f,i)|0)){break a}}cd(a,c+D(f,z[e>>1])|0);h=SC(a,64,1)?h:k}cd(a,c)}c=l&65535;d:{if(c>>>0>(h&65535)>>>0){if((d+(D(c,z[e>>1])<<8)|0)==(Kh(x[a>>2])|0)){break d}}if(c>>>0>=255){RC(b,254,65534);RC(b,255,65535)}l=h}a=l&65535}else{j=z[_b(o,i)>>1];m=j+1|0;n=(h&65535)>>>0>j>>>0|j>>>0>127;k=n?k:c>>>0>i>>>0?m:k;l=(l&65535)>>>0>j>>>0?l:m;h=n?h:m;i=i+1|0;continue}break}return a}function AL(a,b,c,d){a:{switch(b-9|0){case 0:b=x[c>>2];x[c>>2]=b+4;x[a>>2]=x[b>>2];return;case 6:b=x[c>>2];x[c>>2]=b+4;b=w[b>>1];x[a>>2]=b;x[a+4>>2]=b>>31;return;case 7:b=x[c>>2];x[c>>2]=b+4;x[a>>2]=z[b>>1];x[a+4>>2]=0;return;case 8:b=x[c>>2];x[c>>2]=b+4;b=v[b|0];x[a>>2]=b;x[a+4>>2]=b>>31;return;case 9:b=x[c>>2];x[c>>2]=b+4;x[a>>2]=y[b|0];x[a+4>>2]=0;return;case 16:b=x[c>>2]+7&-8;x[c>>2]=b+8;C[a>>3]=C[b>>3];return;case 17:ib[d|0](a,c);default:return;case 1:case 4:case 14:b=x[c>>2];x[c>>2]=b+4;b=x[b>>2];x[a>>2]=b;x[a+4>>2]=b>>31;return;case 2:case 5:case 11:case 15:b=x[c>>2];x[c>>2]=b+4;x[a>>2]=x[b>>2];x[a+4>>2]=0;return;case 3:case 10:case 12:case 13:break a}}b=x[c>>2]+7&-8;x[c>>2]=b+8;c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c}function kT(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=fb-16|0;fb=e;i=-1;a:{if(!GA(a,b,2)){break a}f=x[b+656>>2];d=a+1074312|0;g=Ob(d,31);h=x[b+740>>2];if(h?0:g){break a}h=h-Ob(d,31)|0;g=x[a+480180>>2];d=(g|0)==4096;j=f+88|0;f=d?64:(g|0)==16384?192:512;d=Uq(j,h,f,d?255:64)-(f>>>1|0)|0;if(y[b+746|0]&16){i=Nq(a,b,!(x[b+88>>2]&32768),d);break a}if(Rj(x[b+656>>2])){if((d|0)==w[b+772>>1]){break a}k=b,l=ed(d),w[k+772>>1]=l;v[b+851|0]=y[b+851|0]|64;break a}a=Gj(a);x[e+12>>2]=d;b:{if((d|0)<0){x[e+12>>2]=0-d;Ai(e+12|0,255);a=(x[e+12>>2]<<2)+(a?36640:35616)|0;break b}Ai(e+12|0,255);a=(x[e+12>>2]<<2)+(a?35616:36640)|0}a=x[a>>2];b=a;d=a>>31;a=x[c>>2];k=c,l=Gc(Tua(Sua(b,d,a,a>>31),hb,65536,0),hb),x[k>>2]=l}fb=e+16|0;return i}function Cfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;h=fb-16|0;fb=h;g=Jb(b);e=Cb(x[b+4>>2],y[b+11|0]);i=Jb(c);f=Cb(x[c+4>>2],y[c+11|0]);d=e+g|0;e=-1;a:{while(1){if((d|0)==(g|0)){break a}d=d-1|0;if(yq(i,f,y[d|0])){continue}break}e=d-g|0}b:{c:{if((e|0)!=-1){f=vb(h+12|0,uf(uf(zd(b),e),1));c=vb(h+8|0,Df(b));cs(b,x[f>>2],x[c>>2]);break c}if(!Yc(x[b+4>>2],y[b+11|0])){break c}i=Jb(b);e=Cb(x[b+4>>2],y[b+11|0]);f=Jb(c);d=Cb(x[c+4>>2],y[c+11|0]);if(!e|!d){c=-1}else{c=i;e=e+c|0;j=d+f|0;while(1){d:{d=f;e:{if((c|0)!=(e|0)){while(1){if((d|0)==(j|0)){break e}g=v[d|0];d=d+1|0;if(!mc(v[c|0],g)){continue}break}}else{c=e}break d}c=c+1|0;continue}break}c=(c|0)==(e|0)?-1:c-i|0}if(c){break c}Fb(a);break b}_c(a,b)}fb=h+16|0}function x2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;h=fb-16|0;fb=h;g=Jb(b);e=Cb(x[b+4>>2],y[b+11|0]);i=Jb(c);f=Cb(x[c+4>>2],y[c+11|0]);d=e+g|0;e=-1;a:{while(1){if((d|0)==(g|0)){break a}d=d-1|0;if(Fu(i,f,y[d|0])){continue}break}e=d-g|0}b:{c:{if((e|0)!=-1){f=vb(h+12|0,uf(uf(zd(b),e),1));c=vb(h+8|0,Df(b));cs(b,x[f>>2],x[c>>2]);break c}if(!Yc(x[b+4>>2],y[b+11|0])){break c}i=Jb(b);e=Cb(x[b+4>>2],y[b+11|0]);f=Jb(c);d=Cb(x[c+4>>2],y[c+11|0]);if(!e|!d){c=-1}else{c=i;e=e+c|0;j=d+f|0;while(1){d:{d=f;e:{if((c|0)!=(e|0)){while(1){if((d|0)==(j|0)){break e}g=y[d|0];d=d+1|0;if(!mc(y[c|0],g)){continue}break}}else{c=e}break d}c=c+1|0;continue}break}c=(c|0)==(e|0)?-1:c-i|0}if(c){break c}Fb(a);break b}_c(a,b)}fb=h+16|0}function j3(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;d=fb-176|0;fb=d;b=d+12|0;Zk(b,a);x[31737]=0;c=d+24|0;O(103,c|0,b|0);a=x[31737];x[31737]=0;a:{b:{c:{d:{if((a|0)!=1){x[31737]=0;a=P(104,d+36|0,c|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break d}tb(c);tb(b);b=x[x[a>>2]-12>>2];x[31737]=0;f=ca(105)|0;e=x[31737];x[31737]=0;if((e|0)==1){break b}x[31737]=0;e=d+8|0;S(106,e|0,a+b|0,f|0);b=x[31737];x[31737]=0;if((b|0)==1){break b}Zb(e);b=a+x[x[a>>2]-12>>2]|0;x[b+4>>2]=x[b+4>>2]&-75;x[b+4>>2]=x[b+4>>2]|8;x[31737]=0;c=P(107,a|0,c|0)|0;b=x[31737];x[31737]=0;if((b|0)==1){break b}a=tk(x[(c+x[x[c>>2]-12>>2]|0)+16>>2]);b=x[d+24>>2];Ff(c);fb=d+176|0;return(a?0:b)|0}c=N()|0;break c}c=N()|0;tb(d+24|0)}tb(d+12|0);break a}c=N()|0;Ff(a)}Q(c|0);p()}function Pla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=fb-32|0;fb=g;h=a+8|0;c=x[a+8>>2];j=nc(a);a:{if((c|0)!=x[j>>2]){break a}i=a+4|0;d=x[a+4>>2];e=x[a>>2];if(d>>>0>e>>>0){a=((d-e>>2)+1|0)/-2<<2;c=Wg(d,c,a+d|0);x[h>>2]=c;x[i>>2]=a+x[i>>2];break a}x[g+8>>2]=c-e>>1;x[g+28>>2]=1;d=g+8|0;c=x[ad(d,g+28|0)>>2];c=$f(d,c,c>>>2|0,x[a+16>>2]);e=vb(g+4|0,x[a+4>>2]);f=x[vb(g,x[a+8>>2])>>2];d=fb-16|0;fb=d;e=x[e>>2];x[d+12>>2]=e;e=Ln(d,c+8|0,Gv(f,e));f=x[e>>2];while(1){if(x[e+4>>2]!=(f|0)){k=f;f=x[d+12>>2];gp(k,z[f>>1]|z[f+2>>1]<<16);f=x[e>>2]+4|0;x[e>>2]=f;Je(d+12|0);continue}break}he(e);fb=d+16|0;Tb(a,c);Tb(i,c+4|0);Tb(h,c+8|0);Tb(j,nc(c));_f(c);c=x[a+8>>2]}gp(c,z[b>>1]|z[b+2>>1]<<16);x[h>>2]=x[h>>2]+4;fb=g+32|0}function RK(a,b,c,d,e,f){var g=0;g=fb-80|0;fb=g;a:{if((f|0)>=16384){Wd(g+32|0,b,c,d,e,0,0,0,2147352576);d=x[g+40>>2];e=x[g+44>>2];b=x[g+32>>2];c=x[g+36>>2];if(f>>>0<32767){f=f-16383|0;break a}Wd(g+16|0,b,c,d,e,0,0,0,2147352576);f=((f|0)>=49149?49149:f)-32766|0;d=x[g+24>>2];e=x[g+28>>2];b=x[g+16>>2];c=x[g+20>>2];break a}if((f|0)>-16383){break a}Wd(g- -64|0,b,c,d,e,0,0,0,7471104);d=x[g+72>>2];e=x[g+76>>2];b=x[g+64>>2];c=x[g+68>>2];if(f>>>0>4294934644){f=f+16269|0;break a}Wd(g+48|0,b,c,d,e,0,0,0,7471104);f=((f|0)<=-48920?-48920:f)+32538|0;d=x[g+56>>2];e=x[g+60>>2];b=x[g+48>>2];c=x[g+52>>2]}Wd(g,b,c,d,e,0,0,0,f+16383<<16);b=x[g+12>>2];x[a+8>>2]=x[g+8>>2];x[a+12>>2]=b;b=x[g+4>>2];x[a>>2]=x[g>>2];x[a+4>>2]=b;fb=g+80|0}function saa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=fb-80|0;fb=d;x[31737]=0;f=R(1159,b|0)|0;e=x[31737];x[31737]=0;if((e|0)!=1){a:{b:{if(f){x[31737]=0;f=d+56|0;O(1160,f|0,b|0);b=x[31737];x[31737]=0;if((b|0)!=1){b=d- -64|0;Pp(b,x[d+56>>2],x[d+60>>2]);e=Ef(d+72|0,b);g=Ef(d+48|0,c);h=x[e+4>>2];x[d+8>>2]=x[e>>2];x[d+12>>2]=h;e=x[g+4>>2];x[d>>2]=x[g>>2];x[d+4>>2]=e;Qp(a,d+8|0,d);break b}break a}x[31737]=0;f=d+56|0;O(1161,f|0,b|0);b=x[31737];x[31737]=0;if((b|0)==1){break a}b=d- -64|0;Pp(b,x[d+56>>2],x[d+60>>2]);e=Ef(d+40|0,b);g=Ef(d+32|0,c);h=x[e+4>>2];x[d+24>>2]=x[e>>2];x[d+28>>2]=h;e=x[g+4>>2];x[d+16>>2]=x[g>>2];x[d+20>>2]=e;Qp(a,d+24|0,d+16|0)}ke(b);ke(f);ke(c);fb=d+80|0;return}}a=N()|0;ke(c);Q(a|0);p()}function hna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=fb-16|0;fb=b;f=x[a+40>>2];g=x[a+36>>2];k=x[a+16>>2];h=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=h;l=x[a+32>>2];m=x[a+28>>2];h=x[a+8>>2];n=x[a+12>>2];while(1){if(d){e=x[b+8>>2];o=e>>>18|0;p=((((x[b+12>>2]&2147483647)<<1|e>>>31)&2147483646)<<1)+k|0;e=0;while(1){if((e|0)!=2){i=(e<<1)+p|0;j=w[i>>1];x[(e<<2)+b>>2]=j+((D(w[i+4>>1]-j|0,o)|0)/16384|0);e=e+1|0;continue}break}g=g+m|0;x[c>>2]=x[c>>2]+D(x[b>>2],g>>12);f=f+l|0;x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],f>>12);Pb(b+8|0,h,n);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=f;x[a+20>>2]=g>>12;x[a+36>>2]=g;x[a+24>>2]=f>>12;fb=b+16|0}function Wy(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=fb-16|0;fb=e;g=(q(a),j(2));c=g&2147483647;a:{if(c>>>0<=1305022426){h=+a;f=h*.6366197723675814+6755399441055744+-6755399441055744;d=h+f*-1.5707963109016418+f*-1.5893254773528196e-8;C[b>>3]=d;g=d<-.7853981852531433;if(F(f)<2147483648){c=~~f}else{c=-2147483648}if(g){d=f+-1;C[b>>3]=h+d*-1.5707963109016418+d*-1.5893254773528196e-8;c=c-1|0;break a}if(!(d>.7853981852531433)){break a}d=f+1;C[b>>3]=h+d*-1.5707963109016418+d*-1.5893254773528196e-8;c=c+1|0;break a}if(c>>>0>=2139095040){C[b>>3]=E(a-a);c=0;break a}i=c;c=(c>>>23|0)-150|0;C[e+8>>3]=(l(2,i-(c<<23)|0),r());c=FL(e+8|0,e,c,1,0);d=C[e>>3];if((g|0)<0){C[b>>3]=-d;c=0-c|0;break a}C[b>>3]=d}fb=e+16|0;return c}function Fla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=fb-16|0;fb=f;c=Hf(a,c);$d(f,x[a+36>>2]);i=a;a:{if(!c){Pc(f,a+32|0,5);d=0;if(Hb(x[x[f>>2]>>2],x[f+4>>2])){break a}}g=x[a+36>>2];a=fb-16|0;fb=a;x[a+12>>2]=0;KN(g,a+12|0,1);e=x[a+12>>2];d=e>>>2&3;v[a+11|0]=d;if(d){v[a+4|0]=3;h=a+4|0;d=y[Qb(h,a+11|0)|0];v[a+4|0]=0;v[a|0]=0;v[a+10|0]=0;b:{if(!d){break b}Ki(g,h);if((d|0)==1){break b}Ki(g,a);if(d>>>0<3){break b}Ki(g,a+10|0);j=y[a+10|0]<<24}e=e&255|(y[a+4|0]<<8|y[a|0]<<16|j)}d=e>>>4|0;x[a+4>>2]=d;x[a>>2]=1e6;eC(b,x[Gb(a+4|0,a)>>2]);e=0;while(1){h=Cb(x[b+4>>2],y[b+11|0]);if(h>>>0<=e>>>0){if((d|0)!=(h|0)){Tm(g,d-h|0)}fb=a+16|0}else{Dj(g,cc(b,e),1);e=e+1|0;continue}break}d=c}ff(i,d);fb=f+16|0}function gba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=fb+-64|0;fb=d;a=x[a+4>>2];g=d+16|0;ox(g,b);x[31737]=0;b=P(1,d+4|0,18418)|0;e=x[31737];x[31737]=0;a:{b:{c:{d:{e:{f:{g:{h:{if((e|0)!=1){x[31737]=0;e=d+28|0;S(2,e|0,g|0,b|0);f=x[31737];x[31737]=0;if((f|0)==1){break h}x[31737]=0;f=d+40|0;S(490,f|0,e|0,c|0);c=x[31737];x[31737]=0;if((c|0)==1){break g}x[31737]=0;c=d+52|0;O(1065,c|0,f|0);h=x[31737];x[31737]=0;if((h|0)==1){break f}h=x[x[a>>2]+8>>2];x[31737]=0;O(h|0,a|0,c|0);a=x[31737];x[31737]=0;if((a|0)==1){break e}tb(c);tb(f);tb(e);tb(b);tb(g);fb=d- -64|0;return}a=N()|0;break a}a=N()|0;break b}a=N()|0;break c}a=N()|0;break d}a=N()|0;tb(d+52|0)}tb(d+40|0)}tb(d+28|0)}tb(b)}tb(d+16|0);Q(a|0);p()}function XC(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=fb-16|0;fb=f;e=y[a|0];if(e&1){v[b+12|0]=y[b+12|0]|1;e=y[a|0]}if(e&2){v[b+12|0]=y[b+12|0]|4;e=y[a|0]}if(e&4){v[b+12|0]=y[b+12|0]|2;e=y[a|0]}if(e&16){v[b+12|0]=y[b+12|0]|16;e=y[a|0]}if(e&32){v[b+12|0]=y[b+12|0]|8}v[f+15|0]=y[a+1|0];v[f+14|0]=25;gh(b,y[Qb(f+15|0,f+14|0)|0]);e=y[a+2|0];v[b+15|0]=e;v[b+16|0]=(d|0)==4?e:y[a+3|0];v[b+13|0]=y[a+4|0];v[b+14|0]=y[a+5|0];h=x[b>>2];e=Sd(h,x[b+4>>2]);b=0;while(1){if((b|0)!=(e|0)){i=yb(h,b);g=(b<<2)+a|0;d=y[g+6|0]|y[g+7|0]<<8;w[i>>1]=d;a:{if(!b){break a}j=d;d=z[yb(h,b-1|0)>>1];if(j>>>0>=d>>>0){break a}w[i>>1]=d+1}k=i,l=Yb((y[g+8|0]|y[g+9|0]<<8)<<16>>16>>c,0,64),v[k+2|0]=l;b=b+1|0;continue}break}fb=f+16|0}function bY(a,b){var c=0,d=0,e=0;c=fb-32|0;fb=c;a:{if(!Mb(x[a>>2],x[a+8>>2],1024)){x[c+24>>2]=0;x[c+28>>2]=0;x[c+16>>2]=0;x[c+20>>2]=0;a=64;while(1){if(a){d=y[c+20|0]|y[c+21|0]<<8|(y[c+22|0]<<16|y[c+23|0]<<24);e=y[c+16|0]|y[c+17|0]<<8|(y[c+18|0]<<16|y[c+19|0]<<24);v[b|0]=e;v[b+1|0]=e>>>8;v[b+2|0]=e>>>16;v[b+3|0]=e>>>24;v[b+4|0]=d;v[b+5|0]=d>>>8;v[b+6|0]=d>>>16;v[b+7|0]=d>>>24;d=y[c+28|0]|y[c+29|0]<<8|(y[c+30|0]<<16|y[c+31|0]<<24);e=y[c+24|0]|y[c+25|0]<<8|(y[c+26|0]<<16|y[c+27|0]<<24);v[b+8|0]=e;v[b+9|0]=e>>>8;v[b+10|0]=e>>>16;v[b+11|0]=e>>>24;v[b+12|0]=d;v[b+13|0]=d>>>8;v[b+14|0]=d>>>16;v[b+15|0]=d>>>24;a=a-1|0;b=b+16|0;continue}break}break a}PC(c+8|0,b);rd(c+16|0,a,x[c+8>>2],x[c+12>>2])}fb=c+32|0}function QH(a,b,c,d,e,f){var g=0,h=0,i=E(0),j=0;g=fb-80|0;fb=g;KA(x[a+24>>2]);v[x[a+24>>2]+1298424|0]=x[a+52>>2]!=0;x[g+44>>2]=b;x[g+40>>2]=c;x[g+36>>2]=d;i=B[a+48>>2];j=x[a+32>>2];x[g+8>>2]=b;c=x[g+40>>2];x[g>>2]=x[g+36>>2];x[g+4>>2]=c;d=fb-16|0;fb=d;x[d+8>>2]=x[g+8>>2];c=x[g+4>>2];x[d>>2]=x[g>>2];x[d+4>>2]=c;c=PM(g+48|0);x[c+8>>2]=j;x[c+4>>2]=0;x[c>>2]=f;f=x[d+4>>2];x[c+12>>2]=x[d>>2];x[c+16>>2]=f;x[c+20>>2]=x[d+8>>2];C[c+24>>3]=i;x[c>>2]=e;fb=d+16|0;while(1){if(b){d=x[a+24>>2];x[g+24>>2]=b;x[g+28>>2]=0;x[g+16>>2]=134217727;x[g+20>>2]=0;d=QM(d,x[_r(g+24|0,g+16|0)>>2],c);h=d+h|0;b=b-d|0;if(d){continue}}break}if(!(x[a+52>>2]!=1|h)){a=x[a+24>>2];x[a+480208>>2]=x[a+480208>>2]&-513}fb=g+80|0;return h}function $ka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;g=fb-80|0;fb=g;e=Tf(g+52|0);x[31737]=0;d=P(835,b|0,e|0)|0;c=x[31737];x[31737]=0;a:{b:{c:{if((c|0)!=1){if(d){break c}x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[31737]=0;R(836,a|0)|0;a=x[31737];x[31737]=0;if((a|0)!=1){break b}}break a}c=x[e+4>>2];f=x[e>>2];x[31737]=0;d=g+12|0;c=$b(c);d:{if(!c){h=-1;if(($b(f)|0)==1112491097){break d}}h=c}c=h;S(186,d|0,b|0,c|0);f=x[31737];x[31737]=0;if((f|0)==1){break a}f=ic(g+32|0,d);hd(e+8|0,f);ub(f);ub(d);e:{d=c&1;if(!d){break e}x[31737]=0;P(184,b|0,2-d|0)|0;b=x[31737];x[31737]=0;if((b|0)!=1){break e}break a}Sk(a,e)}Fd(e);fb=g+80|0;return}a=N()|0;Fd(e);Q(a|0);p()}function xoa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=fb-16|0;fb=e;i=e,j=Xj(b),x[i+4>>2]=j;d=fb-16|0;fb=d;h=a;c=ce(a);a:{if(c){f=ec(a);while(1){a=c;c=a+13|0;if(lv(b,c)){f=a;c=x[a>>2];if(c){continue}break a}if(!lv(c,b)){break a}f=a+4|0;c=x[a+4>>2];if(c){continue}break}break a}a=ec(h);f=a}x[d+12>>2]=a;b=x[f>>2];if(!b){c=fb-16|0;fb=c;a=ec(h);g=Bh(d,Ec(20),Mg(c+8|0,a));b=x[g>>2];a=x[e+4>>2];a=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);v[b+17|0]=0;v[b+13|0]=a;v[b+14|0]=a>>>8;v[b+15|0]=a>>>16;v[b+16|0]=a>>>24;i=ec(g),j=1,v[i+4|0]=j;fb=c+16|0;$g(h,x[d+12>>2],f,x[d>>2]);b=me(d);a=x[d>>2];x[d>>2]=0;if(a){ec(d);Db(a)}g=1}_g(e+8|0,x[vb(d,b)>>2],g);fb=d+16|0;fb=e+16|0;return x[e+8>>2]+17|0}function dpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=fb-32|0;fb=f;ld(c,2);v[f+20|0]=y[b+13|0];v[f+8|0]=64;d=f+20|0;e=f+8|0;i=c,j=y[Qb(d,e)|0]<<2,w[i+30>>1]=j;x[c+24>>2]=(y[b+14|0]|y[b+15|0]<<8)<<1;Pk(e,2,b+1|0);Cc(d,e);ze(c+43|0,d);tb(d);d=Xc(a,8,1,0,2);a:{if((y[b|0]&3)!=1){break a}g=y[b+22|0]|y[b+23|0]<<8|(y[b+24|0]<<16|y[b+25|0]<<24);x[c>>2]=g;e=y[b+26|0]|y[b+27|0]<<8|(y[b+28|0]<<16|y[b+29|0]<<24);x[c+4>>2]=e;a=y[b+30|0]|y[b+31|0]<<8|(y[b+32|0]<<16|y[b+33|0]<<24);h=a-(a>>>0>e>>>0)|0;x[c+8>>2]=h;a=y[b|0];if(a&4){w[c+34>>1]=z[c+34>>1]|2;a=y[b|0]}if(a&8){w[c+34>>1]=z[c+34>>1]|4;a=y[b|0]}if(!(a&16)){break a}fd(d,16);yg(d,9);x[c+8>>2]=h>>>1;x[c+4>>2]=e>>>1;x[c>>2]=g>>>1}fb=f+32|0}function xx(a,b,c){var d=0,e=0,f=0,g=0;d=Fb(a);a=y[b+11|0];e=x[b+4>>2];x[31737]=0;O(115,d|0,Yc(e,a)|0);a=x[31737];x[31737]=0;if((a|0)!=1){a:{while(1){if(Yc(x[b+4>>2],y[b+11|0])>>>0>f>>>0){a=32;e=x[Vd(b,f)>>2];g=(e&-32)==128;b:{while(1){c:{if((a|0)==256){a=0;break c}if((e|0)!=x[(a<<2)+c>>2]|g){a=a+1|0;continue}else{x[31737]=0;O(116,d|0,a<<24>>24);a=x[31737];x[31737]=0;if((a|0)!=1){break b}break a}}break}d:{while(1){if((a|0)==32){break d}if((e|0)!=x[(a<<2)+c>>2]){a=a+1|0;continue}break}x[31737]=0;O(116,d|0,a<<24>>24);a=x[31737];x[31737]=0;if((a|0)!=1){break b}break a}x[31737]=0;O(116,d|0,63);a=x[31737];x[31737]=0;if((a|0)!=1){break b}break a}f=f+1|0;continue}break}return}}a=N()|0;tb(d);Q(a|0);p()}function UH(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0;f=fb-48|0;fb=f;x[f+44>>2]=c;a=qe(a,f+44|0);c=sc(a+4|0);h=sc(a+24|0);i=sc(a+32|0);j=Nb(a+36|0);x[a+56>>2]=3;k=Nb(a+68|0);x[31737]=0;O(997,a|0,d|0);g=x[31737];x[31737]=0;a:{b:{c:{d:{if((g|0)!=1){re(f+16|0,x[b>>2],x[b+4>>2]);b=Nd(f+8|0);x[31737]=0;g=x[b+4>>2];x[f>>2]=x[b>>2];x[f+4>>2]=g;b=f+24|0;Os(e,b,x[f+16>>2],x[f+20>>2],f);e=x[31737];x[31737]=0;if((e|0)==1){break d}x[31737]=0;S(998,a|0,b|0,d|0);d=x[31737];x[31737]=0;if((d|0)==1){break c}ub(b);x[31737]=0;W(999,a|0);b=x[31737];x[31737]=0;if((b|0)!=1){break a}}d=N()|0;break b}d=N()|0;break b}d=N()|0;ub(f+24|0)}Td(k);nf(j);Hl(i);vh(h);uh(c);Uc(a);Uc(f+44|0);Q(d|0);p()}Uc(f+44|0);fb=f+48|0;return a}function ina(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=fb-16|0;fb=b;f=x[a+40>>2];g=x[a+36>>2];k=x[a+16>>2];h=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=h;l=x[a+32>>2];m=x[a+28>>2];h=x[a+8>>2];n=x[a+12>>2];while(1){if(d){e=x[b+8>>2];o=e>>>10&4194048;p=(((x[b+12>>2]&2147483647)<<1|e>>>31)&-2)+k|0;e=0;while(1){if((e|0)!=2){i=e+p|0;j=v[i|0];x[(e<<2)+b>>2]=((D(v[i+2|0]-j|0,o)|0)/16384|0)+(j<<8);e=e+1|0;continue}break}g=g+m|0;x[c>>2]=x[c>>2]+D(x[b>>2],g>>12);f=f+l|0;x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],f>>12);Pb(b+8|0,h,n);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=f;x[a+20>>2]=g>>12;x[a+36>>2]=g;x[a+24>>2]=f>>12;fb=b+16|0}function Zm(a,b){var c=0,d=0,e=0,f=0;c=fb+-64|0;fb=c;d=x[x[a>>2]-12>>2]+a|0;e=x[d+16>>2]&-3;kg(d,e);a:{b:{if(Gd(y[Lm(c+63|0,a,1)|0])){d=x[(x[x[a>>2]-12>>2]+a|0)+24>>2];x[31737]=0;f=x[b+12>>2];x[c+16>>2]=x[b+8>>2];x[c+20>>2]=f;f=x[b+4>>2];x[c+8>>2]=x[b>>2];x[c+12>>2]=f;S(943,c+40|0,d|0,c+8|0);b=x[31737];x[31737]=0;c:{if((b|0)!=1){b=gi(c+24|0,-1,-1);b=eo(x[c+48>>2],x[c+52>>2],x[b+8>>2],x[b+12>>2])?e|4:e;break c}Y(T(0)|0)|0;b=e|1;Jm(x[x[a>>2]-12>>2]+a|0,b);if(x[(x[x[a>>2]-12>>2]+a|0)+20>>2]&1){x[31737]=0;X(85);a=x[31737];x[31737]=0;if((a|0)!=1){break a}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)==1){break b}Q(a|0);p()}Z()}bk(x[x[a>>2]-12>>2]+a|0,b)}fb=c- -64|0;return}T(0)|0;Sb()}p()}function p_(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;c=fb-176|0;fb=c;d=c+12|0;Wf(d,a);x[31737]=0;b=c+24|0;O(125,b|0,d|0);a=x[31737];x[31737]=0;a:{b:{c:{d:{e:{if((a|0)!=1){x[31737]=0;a=P(104,c+36|0,b|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break e}tb(b);tb(d);d=x[x[a>>2]-12>>2];x[31737]=0;f=ca(105)|0;e=x[31737];x[31737]=0;if((e|0)==1){break c}x[31737]=0;e=c+8|0;S(106,e|0,a+d|0,f|0);d=x[31737];x[31737]=0;if((d|0)==1){break c}Zb(e);x[31737]=0;x[c+24>>2]=0;x[c+28>>2]=0;b=P(410,a|0,b|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break c}a=tk(x[(b+x[x[b>>2]-12>>2]|0)+16>>2]);g=C[c+24>>3];Ff(b);fb=c+176|0;g=a?0:g;break a}b=N()|0;break d}b=N()|0;tb(c+24|0)}tb(c+12|0);break b}b=N()|0;Ff(a)}Q(b|0);p()}return+g}function hqa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;b=fb-528|0;fb=b;e=-1;a:{if(!kh(a,1468)){break a}cm(a,1464);c=b+524|0;rY(a,c);if(!ne(c,25300)){e=0;if(!ne(c,15623)){break a}}cm(a,20);c=1;b:{while(1){if((c&65535)>>>0>31){break b}e=oY(a,b);if(!e){aY(b)}if(e){c=c+1|0;d=WC(b)+d|0;continue}break}e=-1;break a}e=0;if(d>>>0>40){break a}d=b+522|0;c=fb-16|0;fb=c;c:{if(!kh(a,2)){v[c|0]=0;tF(d,c);break c}Hp(c+8|0,d);VC(c,a,x[c+8>>2],x[c+12>>2])}fb=c+16|0;if(y[b+522|0]>128){break a}d=Jc(d);c=fb-16|0;fb=c;d:{if(!kh(a,512)){$X(b);break d}xE(c+8|0,b);VC(c,a,x[c+8>>2],x[c+12>>2])}fb=c+16|0;c=0;e=1;a=y[d|0];while(1){if((c|0)==512){break a}d=b+c|0;c=c+1|0;if(a>>>0>=y[d|0]){continue}break}e=0}fb=b+528|0;return e|0}function Xma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=fb-16|0;fb=b;h=x[a+24>>2];i=x[a+20>>2];j=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;k=x[a+8>>2];l=x[a+12>>2];while(1){if(d){e=x[b+8>>2];m=((((x[b+12>>2]&2147483647)<<1|e>>>31)&2147483646)<<1)+j|0;e=e>>>21&2040;n=w[e+38198>>1];o=w[e+38196>>1];p=w[e+38194>>1];e=w[e+38192>>1];f=0;while(1){if((f|0)!=2){g=(f<<1)+m|0;x[(f<<2)+b>>2]=(((D(w[g>>1],p)+D(w[g-4>>1],e)|0)+D(w[g+4>>1],o)|0)+D(w[g+8>>1],n)|0)/16384;f=f+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[b>>2],i);x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],h);Pb(b+8|0,k,l);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;fb=b+16|0}function Rh(a,b){var c=E(0),d=E(0),e=E(0),f=E(0),g=E(0),h=0;f=YP(a);h=a+4208|0;c=E(E(B[yb(h,4)>>2]*E(1.899999976158142))+E(.10000000149011612));g=B[a+4268>>2];d=Ce(E(10),E(E(E(E(E(x[((b<<2)+a|0)+4292>>2])/g)*E(-60))/E(E(B[yb(h,3)>>2]*E(19.899999618530273))+E(.10000000149011612)))/E(20)));c=E(E(Ce(d,E(E(2)-E(E(2)/c)))+E(-1))/E(E(1)-Aq(c>E(1)?E(3.1415927410125732):E(f*E(E(6.2831854820251465)/g)))));a:{if(c==E(0)){break a}if(!_m(c)){break a}g=E(c+c);f=E(E(-2)-g);c=E(E(f*f)+E(E(c*c)*E(-4)));if(c>E(0)){e=E(M(c))}c=E(E(e-f)/g);if(E(F(c))>E(1)){c=E(E(E(-f)-e)/g)}e=cg(c)}b=(b<<3)+a|0;B[b+4404>>2]=e;B[b+4400>>2]=d;c=B[a+4272>>2];c=E(c*c);e=E(E(1)-c);d=E(d*d);return E(E(E(e*E(d/E(E(1)-E(c*d))))*e)+c)}function cda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=fb-48|0;fb=e;x[e+44>>2]=c;a=qe(a,e+44|0);f=sc(a+4|0);g=sc(a+24|0);h=sc(a+32|0);i=Nb(a+36|0);x[a+56>>2]=3;j=Nb(a+68|0);x[31737]=0;O(997,a|0,d|0);c=x[31737];x[31737]=0;a:{b:{c:{d:{if((c|0)!=1){c=Nd(e+16|0);x[31737]=0;k=x[c+4>>2];x[e+8>>2]=x[c>>2];x[e+12>>2]=k;c=e+24|0;S(1121,c|0,b|0,e+8|0);b=x[31737];x[31737]=0;if((b|0)==1){break d}x[31737]=0;S(998,a|0,c|0,d|0);b=x[31737];x[31737]=0;if((b|0)==1){break c}ub(c);x[31737]=0;W(999,a|0);b=x[31737];x[31737]=0;if((b|0)!=1){break a}}d=N()|0;break b}d=N()|0;break b}d=N()|0;ub(e+24|0)}Td(j);nf(i);Hl(h);vh(g);uh(f);Uc(a);Uc(e+44|0);Q(d|0);p()}Uc(e+44|0);fb=e+48|0;return a|0}function hga(){var a=0,b=0,c=0,d=0,e=0,f=0,g=0;b=fb-32|0;fb=b;c=Fb(b+20|0);x[31737]=0;W(990,b+8|0);a=x[31737];x[31737]=0;a:{b:{c:{d:{if((a|0)!=1){f=b,g=wb(x[b+8>>2]),x[f+4>>2]=g;d=1;while(1){e=wb(x[b+12>>2]);a=x[b+4>>2];if(!Ib(a,e)){a=Bg(Jb(c));Td(b+8|0);tb(c);break b}if(!d){x[31737]=0;P(991,c|0,14665)|0;a=x[31737];x[31737]=0;if((a|0)==1){break d}a=x[b+4>>2]}x[31737]=0;P(842,c|0,a|0)|0;a=x[31737];x[31737]=0;if((a|0)==1){break d}hl(b+4|0);d=0;continue}}a=T(0)|0;break c}a=T(0)|0;Td(b+8|0)}tb(c);Y(a|0)|0;a=0;x[31737]=0;V(989,7040,0,0,0);c=x[31737];x[31737]=0;if((c|0)==1){break a}Z()}fb=b+32|0;return a|0}b=N()|0;x[31737]=0;X(26);a=x[31737];x[31737]=0;if((a|0)==1){T(0)|0;Sb();p()}Q(b|0);p()}function LK(a,b){var c=0,d=0,e=0;a:{if(y[b|0]){break a}b=Ey(13961);if(y[b|0]?b:0){break a}b=Ey(D(a,12)+95824|0);if(y[b|0]?b:0){break a}b=Ey(14217);if(y[b|0]?b:0){break a}b=14798}b:{while(1){d=y[b+c|0];if(!(!d|(d|0)==47)){d=23;c=c+1|0;if((c|0)!=23){continue}break b}break}d=c}e=14798;c:{d:{c=y[b|0];e:{f:{if(!(y[b+d|0]|(c|0)==46)){e=b;if((c|0)!=67){break f}}if(!y[e+1|0]){break e}}if(!ni(e,14798)){break e}if(ni(e,13654)){break d}}if(!a){c=95896;if(y[e+1|0]==46){break c}}return 0}c=x[125035];if(c){while(1){if(!ni(e,c+8|0)){break c}c=x[c+32>>2];if(c){continue}break}}c=Ed(36);if(c){x[c+4>>2]=20;x[c>>2]=95792;b=c+8|0;yc(b,e,d);v[b+d|0]=0;x[c+32>>2]=x[125035];x[125035]=c}c=a|c?c:95896}return c}function yna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=fb-16|0;fb=b;k=x[a+16>>2];j=mg(1,2);e=hb;l=e;Pb(a,j,e);f=x[a+40>>2];g=x[a+36>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;m=x[a+32>>2];n=x[a+28>>2];e=x[a+8>>2];o=x[a+12>>2];while(1){if(d){d=d-1|0;i=x[b+8>>2];i=((((x[b+12>>2]&2147483647)<<1|i>>>31)&2147483646)<<1)+k|0;h=0;while(1){if((h|0)!=2){x[(h<<2)+b>>2]=w[(h<<1)+i>>1];h=h+1|0;continue}break}g=g+n|0;x[c>>2]=x[c>>2]+D(x[b>>2],g>>12);f=f+m|0;x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],f>>12);Pb(b+8|0,e,o);c=c+8|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=f;x[a+20>>2]=g>>12;x[a+36>>2]=g;x[a+24>>2]=f>>12;Hg(a,j,l);fb=b+16|0}function sU(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;g=fb-16|0;fb=g;d=ks(g+4|0,a,d);e=zb(a);a=fb-48|0;fb=a;f=x[d+4>>2];x[a+44>>2]=f;x[a+40>>2]=f;e=Re(a+12|0,e,a+40|0,a+44|0);x[a+8>>2]=x[e+8>>2];f=x[e+4>>2];x[a>>2]=x[e>>2];x[a+4>>2]=f;Qe(a+24|0,a);while(1){if((b|0)!=(c|0)){C[x[a+44>>2]>>3]=C[b>>3];x[a+44>>2]=x[a+44>>2]+8;b=b+8|0;continue}break}Pe(a+24|0);h=x[a+44>>2];if(!y[a+36|0]){e=fb-16|0;fb=e;b=vb(e+12|0,x[x[a+32>>2]>>2]);i=x[vb(e+8|0,x[x[a+28>>2]>>2])>>2];f=fb-16|0;fb=f;b=x[b>>2];x[f+12>>2]=b;while(1){if(pd(b,i)){c=fb-16|0;fb=c;x[c+12>>2]=b;x[c+12>>2]=x[c+12>>2]-8;fb=c+16|0;b=x[Np(f+12|0)>>2];continue}break}fb=f+16|0;fb=e+16|0}fb=a+48|0;x[d+4>>2]=h;hc(d);fb=g+16|0}function No(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;a:{if(c){v[b+809|0]=c;break a}c=y[b+809|0]}e=x[a+480180>>2];d=e&202376205?(c&240?-16:15)&c:c;c=x[b+688>>2];b:{if(e&69206029){break b}g=d&255;f=d&15;if((f|0)==15){if(g>>>0>=16){Mo(a,b,(d&240)>>>4|0,0);return}if(!(v[b+851|0]&1)){break b}c=y[a+480208|0]&2?c:c-60|0;break b}if((g&240)!=240){break b}if(f){Lo(a,b,f,0);return}if(!(v[b+851|0]&1)){break b}c=y[a+480208|0]&2?c:c+60|0}c:{if(!(!(v[b+851|0]&1)|y[a+480208|0]&2)){if(x[a+1074416>>2]!=1|(e|0)!=524288){break c}}a=d&15;d:{if(a){if((d&255)>>>0>15?e&16777248:0){break c}c=c-(a<<2)|0;break d}c=((d&255)>>>2&60)+c|0}if((e|0)!=1){break c}x[b+88>>2]=x[b+88>>2]|2097152}h=b,i=Yb(c,0,256),x[h+688>>2]=i}function q9(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=x[b+44>>2];i=x[b+24>>2];if(h>>>0<i>>>0){x[b+44>>2]=i;h=i}m=-1;n=-1;o=f&24;a:{if(!o|(e|0)==1&(o|0)==24){break a}if(h){j=h-Jb(b+32|0)|0;k=j>>31}b:{c:{switch(e|0){case 1:if(f&8){g=x[b+12>>2]-x[b+8>>2]|0;l=g>>31;break b}g=i-x[b+20>>2]|0;l=g>>31;break b;case 0:break b;case 2:break c;default:break a}}g=j;l=k}d=d+l|0;c=c+g|0;d=g>>>0>c>>>0?d+1|0:d;if((d|0)<0|(c>>>0>j>>>0&(d|0)>=(k|0)|(d|0)>(k|0))){break a}e=f&8;d:{if(!(c|d)){break d}if(x[b+12>>2]?0:e){break a}if(!(f&16)){break d}if(!i){break a}}if(e){e=x[b+8>>2];ko(b,e,c+e|0,h)}if(f&16){My(b,x[b+20>>2],x[b+28>>2]);Bt(b,c)}m=c;n=d}gi(a,m,n)}function gI(a,b,c,d,e,f){var g=0,h=0,i=0,j=0,k=0,l=0;g=fb-48|0;fb=g;x[g+44>>2]=d;a=qe(a,g+44|0);d=sc(a+4|0);h=sc(a+24|0);i=sc(a+32|0);j=Nb(a+36|0);x[a+56>>2]=3;k=Nb(a+68|0);x[31737]=0;O(997,a|0,e|0);l=x[31737];x[31737]=0;a:{b:{c:{d:{if((l|0)!=1){bc(g+16|0,b,c);b=Nd(g+8|0);x[31737]=0;c=x[b+4>>2];x[g>>2]=x[b>>2];x[g+4>>2]=c;b=g+24|0;Os(f,b,x[g+16>>2],x[g+20>>2],g);c=x[31737];x[31737]=0;if((c|0)==1){break d}x[31737]=0;S(998,a|0,b|0,e|0);c=x[31737];x[31737]=0;if((c|0)==1){break c}ub(b);x[31737]=0;W(999,a|0);b=x[31737];x[31737]=0;if((b|0)!=1){break a}}e=N()|0;break b}e=N()|0;break b}e=N()|0;ub(g+24|0)}Td(k);nf(j);Hl(i);vh(h);uh(d);Uc(a);Uc(g+44|0);Q(e|0);p()}Uc(g+44|0);fb=g+48|0;return a}function zoa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=fb-16|0;fb=e;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);Rd(e+8|0,x[vb(e+4|0,a)>>2]);a:{if(b){x[31737]=0;O(741,a|0,b|0);c=x[31737];x[31737]=0;if((c|0)==1){break a}f=fb-16|0;fb=f;d=f+4|0;x[d>>2]=a;c=x[a+4>>2];x[d+4>>2]=c;x[d+8>>2]=c+D(b,36);b=x[d+4>>2];g=x[d+8>>2];while(1){if((b|0)==(g|0)){hc(d);fb=f+16|0}else{c=Rb(b,0,36);x[c>>2]=0;x[c+4>>2]=0;w[c+22>>1]=0;w[c+24>>1]=0;w[c+26>>1]=0;w[c+28>>1]=0;v[c+21|0]=64;v[c+19|0]=64;v[c+20|0]=100;v[c+15|0]=0;v[c+16|0]=0;v[c+17|0]=0;v[c+18|0]=0;x[c+8>>2]=0;x[c+12>>2]=0;w[c+30>>1]=0;w[c+32>>1]=0;b=b+36|0;x[d+4>>2]=b;continue}break}}b=e+8|0;Qd(b);nW(b);fb=e+16|0;return a|0}a=N()|0;nW(e+8|0);Q(a|0);p()}function Z0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;ld(b,0);x[b>>2]=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);c=Sr(a+4|0,a);f=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);x[b+4>>2]=f;c=Sr(a+8|0,a);c=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);x[b+8>>2]=c;v[e+15|0]=127;v[e+14|0]=y[a+15|0];g=b,h=(((y[Qb(e+15|0,e+14|0)|0]<<8|64)&65344)>>>0)/127|0,w[g+30>>1]=h;d=y[a+12|0];if(d>>>0>=16){w[b+34>>1]=32;w[b+28>>1]=d&240}d=(y[a+13|0]|y[a+14|0]<<8)<<1;x[b+24>>2]=d;d=y[a+13|0]|y[a+14|0]<<8?d:16726;x[b+24>>2]=d;g=b,h=(D(tw(0,y[a+12|0]<<28>>24),d)>>>0)/8363|0,x[g+24>>2]=h;if(c>>>0>f>>>0){w[b+34>>1]=z[b+34>>1]|2}if(y[a+16|0]&132){w[b+34>>1]=z[b+34>>1]|1}fb=e+16|0}function W2(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;d=fb-176|0;fb=d;c=d+12|0;Wf(c,a);x[31737]=0;b=d+24|0;O(125,b|0,c|0);a=x[31737];x[31737]=0;a:{b:{c:{d:{e:{if((a|0)!=1){x[31737]=0;a=P(104,d+36|0,b|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break e}tb(b);tb(c);c=x[x[a>>2]-12>>2];x[31737]=0;f=ca(105)|0;e=x[31737];x[31737]=0;if((e|0)==1){break c}x[31737]=0;e=d+8|0;S(106,e|0,a+c|0,f|0);c=x[31737];x[31737]=0;if((c|0)==1){break c}Zb(e);x[31737]=0;x[d+24>>2]=0;b=P(126,a|0,b|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break c}a=tk(x[(b+x[x[b>>2]-12>>2]|0)+16>>2]);c=x[d+24>>2];Ff(b);fb=d+176|0;a=a?0:c;break a}b=N()|0;break d}b=N()|0;tb(d+24|0)}tb(d+12|0);break b}b=N()|0;Ff(a)}Q(b|0);p()}return a|0}function Cs(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=fb-16|0;fb=d;x[d+12>>2]=b;if(b>>>0<2147483632){a:{if(Mc(a)>>>0>=b>>>0){break a}k=d,l=Cb(x[a+4>>2],y[a+11|0]),x[k+8>>2]=l;b=Dh(x[ad(d+12|0,d+8|0)>>2]);if((Mc(a)|0)==(b|0)){break a}e=fb-16|0;fb=e;f=Cb(x[a+4>>2],y[a+11|0]);b:{c:{h=Rk(b);d:{if(h){i=1;j=b+1|0;g=x[a>>2];b=a;c=f;break d}c=b+1|0;e:{if(Mc(a)>>>0<b>>>0){sg(e+8|0,c);break e}x[31737]=0;O(117,e+8|0,c|0);b=x[31737];x[31737]=0;if((b|0)==1){break c}}j=x[e+12>>2];b=x[e+8>>2];c=y[a+11|0];i=Cd(c);g=Jb(a);c=Cb(x[a+4>>2],c)}b=Cg(b,g,c+1|0);if(i){Db(g)}if(!h){of(a,j);Yd(a,f);yd(a,b);break b}Me(a,f);break b}Y(T(0)|0)|0;Z()}fb=e+16|0}fb=d+16|0;return}pf();p()}function Qi(a,b,c,d){var e=0,f=0,g=0;x[a+20>>2]=d;x[a+16>>2]=c;x[a+12>>2]=b;x[a+4>>2]=0;x[a+8>>2]=0;x[a>>2]=42824;c=a+24|0;x[c>>2]=0;x[c+4>>2]=0;x[c+16>>2]=0;x[c+8>>2]=0;x[c+12>>2]=0;b=Nb(a+44|0);d=Nb(b+12|0);e=Nb(b+24|0);f=Nb(b+36|0);x[31737]=0;O(947,b|0,0);g=x[31737];x[31737]=0;if((g|0)==1){a=N()|0;vc(f);vc(e);mu(d);mu(b);Q(a|0);p()}w[a+4204>>1]=0;x[a+4196>>2]=1065353216;x[a+4200>>2]=0;d=x[a+16>>2];x[d+946300>>2]=x[d+946300>>2]+1;x[31737]=0;d=R(948,a+92|0)|0;e=x[31737];x[31737]=0;a:{if((e|0)!=1){b=a+4200|0;x[c>>2]=d;c=x[a+16>>2]+906300|0;d=y[a+4200|0];e=x[a+20>>2];while(1){if((vd(c,d)|0)==(e|0)|d>>>0>248){break a}d=d+1|0;v[b|0]=d;continue}}a=N()|0;DQ(b);Q(a|0);p()}return a}function MU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=fb-16|0;fb=d;x[d+12>>2]=b;if(b>>>0<2147483632){a:{if(Mc(a)>>>0>=b>>>0){break a}k=d,l=Cb(x[a+4>>2],y[a+11|0]),x[k+8>>2]=l;b=Dh(x[ad(d+12|0,d+8|0)>>2]);if((Mc(a)|0)==(b|0)){break a}e=fb-16|0;fb=e;f=Cb(x[a+4>>2],y[a+11|0]);b:{c:{h=Rk(b);d:{if(h){i=1;j=b+1|0;g=x[a>>2];b=a;c=f;break d}c=b+1|0;e:{if(Mc(a)>>>0<b>>>0){sg(e+8|0,c);break e}x[31737]=0;O(52,e+8|0,c|0);b=x[31737];x[31737]=0;if((b|0)==1){break c}}j=x[e+12>>2];b=x[e+8>>2];c=y[a+11|0];i=Cd(c);g=Jb(a);c=Cb(x[a+4>>2],c)}b=Xg(b,g,c+1|0);if(i){Db(g)}if(!h){of(a,j);Yd(a,f);yd(a,b);break b}Me(a,f);break b}Y(T(0)|0)|0;Z()}fb=e+16|0}fb=d+16|0;return}pf();p()}function gB(a,b,c){var d=0,e=0,f=0,g=0;d=fb+-64|0;fb=d;e=x[a>>2];f=x[e-4>>2];g=x[e-8>>2];x[d+28>>2]=0;x[d+32>>2]=0;x[d+36>>2]=0;x[d+40>>2]=0;x[d+44>>2]=0;x[d+48>>2]=0;x[d+52>>2]=0;x[d+56>>2]=0;e=0;v[d+59|0]=0;v[d+60|0]=0;v[d+61|0]=0;v[d+62|0]=0;x[d+20>>2]=0;x[d+24>>2]=0;x[d+16>>2]=b;x[d+12>>2]=a;x[d+8>>2]=c;a=a+g|0;a:{if(mh(f,c,0)){x[d+56>>2]=1;ib[x[x[f>>2]+20>>2]](f,d+8|0,a,a,1,0);e=x[d+32>>2]==1?a:0;break a}ib[x[x[f>>2]+24>>2]](f,d+8|0,a,1,0);b:{switch(x[d+44>>2]){case 0:e=x[d+48>>2]==1?x[d+36>>2]==1?x[d+40>>2]==1?x[d+28>>2]:0:0:0;break a;case 1:break b;default:break a}}if(x[d+32>>2]!=1){if(x[d+48>>2]|x[d+36>>2]!=1|x[d+40>>2]!=1){break a}}e=x[d+24>>2]}fb=d- -64|0;return e}function ef(a,b,c){var d=0,e=0,f=0;d=Fb(a);a=y[b+11|0];e=x[b+4>>2];x[31737]=0;O(115,d|0,Yc(e,a)|0);a=x[31737];x[31737]=0;if((a|0)!=1){a:{while(1){if(Yc(x[b+4>>2],y[b+11|0])>>>0>f>>>0){e=x[Vd(b,f)>>2];a=32;b:{while(1){c:{if((a|0)==256){a=0;break c}if((e|0)==x[(a<<2)+c>>2]){x[31737]=0;O(116,d|0,a<<24>>24);a=x[31737];x[31737]=0;if((a|0)!=1){break b}break a}else{a=a+1|0;continue}}break}d:{while(1){if((a|0)==32){break d}if((e|0)!=x[(a<<2)+c>>2]){a=a+1|0;continue}break}x[31737]=0;O(116,d|0,a<<24>>24);a=x[31737];x[31737]=0;if((a|0)!=1){break b}break a}x[31737]=0;O(116,d|0,63);a=x[31737];x[31737]=0;if((a|0)!=1){break b}break a}f=f+1|0;continue}break}return}}a=N()|0;tb(d);Q(a|0);p()}function zN(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=fb-16|0;fb=f;a:{b:{c:{d:{e:{if((b|0)>=0){e=x[a+32>>2];if((Ao(e)|0)>(b|0)){break e}}a=ac(8);x[31737]=0;b=P(36,f+4|0,10751)|0;c=x[31737];x[31737]=0;if((c|0)==1){break d}pc(a,b);x[31737]=0;S(98,a|0,48540,1006);a=x[31737];x[31737]=0;if((a|0)!=1){break b}c=N()|0;tb(b);break c}d=(e+(b<<5)|0)+480280|0;g=c?67109888:0;x[d>>2]=g|x[d>>2]&-67109889;c=(e+D(b,872)|0)+1075080|0;x[c>>2]=x[c>>2]&-67109889|g;c=z[e+480188>>1];e=c>>>0<=256?256:c;b=b+1|0;a=x[a+32>>2];while(1){if((c|0)==(e|0)){break a}d=a+D(c,872)|0;if((b|0)==z[d+1075778>>1]){d=d+1075080|0;x[d>>2]=x[d>>2]&-67109889|g}c=c+1|0;continue}}c=N()|0;jc(a)}Q(c|0)}p()}fb=f+16|0}function Ona(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;g=fb-16|0;fb=g;ld(b,4);w[b+30>>1]=y[a+12|0]<<2;Gf(b+30|0,256);e=y[a+15|0];w[b+34>>1]=32;w[b+28>>1]=e;v[b+37|0]=y[a+13|0];v[b+36|0]=y[a+16|0];f=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);x[b>>2]=f;c=y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24);x[b+4>>2]=c;d=(y[a+8|0]|y[a+9|0]<<8|(y[a+10|0]<<16|y[a+11|0]<<24))+c|0;x[b+8>>2]=d;e=y[a+14|0];if(e&16){d=d>>>1|0;x[b+8>>2]=d;c=c>>>1|0;x[b+4>>2]=c;f=f>>>1|0;x[b>>2]=f;e=y[a+14|0]}if(e&32){d=d>>>1|0;x[b+8>>2]=d;c=c>>>1|0;x[b+4>>2]=c;x[b>>2]=f>>>1;e=y[a+14|0]}if(!(!(e&3)|c>>>0>=d>>>0)){w[b+34>>1]=34;w[b+34>>1]=y[a+14|0]&2?38:34}a=Dc(g+4|0,22303);ze(b+43|0,a);tb(a);fb=g+16|0}function Hka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=fb-16|0;fb=d;x[d+12>>2]=b;if(b>>>0<1073741808){a:{if(zn(a)>>>0>=b>>>0){break a}k=d,l=Cb(x[a+4>>2],y[a+11|0]),x[k+8>>2]=l;b=yn(x[ad(d+12|0,d+8|0)>>2]);if((zn(a)|0)==(b|0)){break a}e=fb-16|0;fb=e;i=1;f=b+1|0;c=zn(a);g=Cb(x[a+4>>2],y[a+11|0]);b:{c:{j=jr(b);d:{if(j){h=x[a>>2];b=a;c=g;break d}e:{if(b>>>0>c>>>0){Uj(e+8|0,f);break e}x[31737]=0;O(54,e+8|0,f|0);b=x[31737];x[31737]=0;if((b|0)==1){break c}}f=x[e+12>>2];b=x[e+8>>2];c=y[a+11|0];i=Cd(c);h=Jb(a);c=Cb(x[a+4>>2],c)}b=Yi(b,h,c+1|0);if(i){Db(h)}if(!j){of(a,f);Yd(a,g);yd(a,b);break b}Me(a,g);break b}Y(T(0)|0)|0;Z()}fb=e+16|0}fb=d+16|0;return}pf();p()}function qja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;a:{d=fb-16|0;fb=d;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);Rd(d+8|0,x[vb(d+4|0,a)>>2]);b:{c=Mk(x[b>>2],x[b+4>>2]);if(!c){break b}x[31737]=0;O(461,a|0,c|0);e=x[31737];x[31737]=0;if((e|0)!=1){e=x[b+4>>2];f=x[b>>2];x[31737]=0;uu(a,f,e,c);c=x[31737];x[31737]=0;if((c|0)!=1){break b}}a=N()|0;im(d+8|0);Q(a|0);p()}c=d+8|0;Qd(c);im(c);fb=d+16|0;x[a+20>>2]=x[b+20>>2];d=x[b+16>>2];x[a+12>>2]=x[b+12>>2];x[a+16>>2]=d;x[31737]=0;d=P(925,a+24|0,b+24|0)|0;c=x[31737];x[31737]=0;c:{d:{if((c|0)!=1){x[31737]=0;P(71,a+36|0,b+36|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break d}x[a+48>>2]=x[b+48>>2];break a}b=N()|0;break c}b=N()|0;vc(d)}Qk(a);Q(b|0);p()}}function mba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=fb-16|0;fb=g;h=g+4|0;e=fb-32|0;fb=e;d=rf(e+20|0,1,0);a:{b:{c:{while(1){c=Jb(d);j=Cb(x[d+4>>2],y[d+11|0])+c|0;i=x[b>>2];k=e+12|0;f=x[b+4>>2];if(!((c|0)==(j|0)|((f|0)>=0|(f|0)>0))){v[c|0]=45;i=_N(i,f);f=hb;c=c+1|0}TN(k,c,j,i,f);if(!x[e+16>>2]){break c}c=qi(Cb(x[d+4>>2],y[d+11|0]));x[31737]=0;O(45,d|0,c|0);c=x[31737];x[31737]=0;if((c|0)!=1){continue}break}break b}b=x[e+12>>2];c=Jb(d);x[31737]=0;O(46,d|0,b-c|0);b=x[31737];x[31737]=0;d:{if((b|0)!=1){x[31737]=0;O(304,h|0,d|0);b=x[31737];x[31737]=0;if((b|0)!=1){break d}break b}break b}tb(d);fb=e+32|0;break a}a=N()|0;tb(d);Q(a|0);p()}Sh(a,h);tb(h);fb=g+16|0}function _Q(a,b,c){var d=0,e=0,f=0,g=0,h=0;a:{f=fb-48|0;fb=f;d=Fb(f+36|0);x[31737]=0;O(938,b|0,f+24|0);g=x[31737];x[31737]=0;if((g|0)!=1){b:{g=x[f+28>>2];e=x[f+24>>2];sf(d);x[31737]=0;g=!g&e>>>0>=255|g?255:e;O(46,d|0,g|0);e=x[31737];x[31737]=0;if((e|0)==1){break b}c:{while(1){if((g|0)==(h|0)){b=m0(Jb(d),Cb(x[d+4>>2],y[d+11|0]));if((b|0)==-1){break c}x[31737]=0;O(46,d|0,b|0);b=x[31737];x[31737]=0;if((b|0)!=1){break c}break b}e=cc(d,h);x[31737]=0;P(939,b|0,e|0)|0;e=x[31737];x[31737]=0;if((e|0)!=1){h=h+1|0;continue}break}break b}x[31737]=0;b=f+12|0;S(497,b|0,a|0,d|0);a=x[31737];x[31737]=0;if((a|0)==1){break b}Ab(c,b);tb(b);tb(d);fb=f+48|0;break a}}a=N()|0;tb(d);Q(a|0);p()}}function Yma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=fb-16|0;fb=b;h=x[a+24>>2];i=x[a+20>>2];j=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;k=x[a+8>>2];l=x[a+12>>2];while(1){if(d){e=x[b+8>>2];m=(((x[b+12>>2]&2147483647)<<1|e>>>31)&-2)+j|0;e=e>>>21&2040;n=w[e+38198>>1];o=w[e+38196>>1];p=w[e+38194>>1];e=w[e+38192>>1];f=0;while(1){if((f|0)!=2){g=f+m|0;x[(f<<2)+b>>2]=(((D(v[g|0],p)+D(v[g-2|0],e)|0)+D(v[g+2|0],o)|0)+D(v[g+4|0],n)<<8)/16384;f=f+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[b>>2],i);x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],h);Pb(b+8|0,k,l);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;fb=b+16|0}function Ng(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=fb+-64|0;fb=f;a:{b:{if((b|0)==65535|c-1025>>>0<4294966272){break b}d=x[a>>2];e=x[a+4>>2];if(He(d,e,b)){break b}c:{d:{if(pm(d,e)>>>0<=b>>>0){d=pA(f+12|0,a);x[31737]=0;S(200,a|0,b+1|0,d|0);e=x[31737];x[31737]=0;if((e|0)==1){break d}Bk(d);d=x[a>>2]}x[31737]=0;O(201,gj(d,b)|0,c|0);c=x[31737];x[31737]=0;e:{if((c|0)!=1){c=gj(x[a>>2],b);x[c+16>>2]=0;x[c+20>>2]=0;c=x[a>>2];x[31737]=0;W(202,gj(c,b)|0);c=x[31737];x[31737]=0;if((c|0)!=1){break e}}b=T(125048)|0;a=gb;break c}a=gj(x[a>>2],b);g=Ib(x[a>>2],x[a+4>>2]);break b}b=T(125048)|0;a=gb;Bk(d)}if(($(125048)|0)!=(a|0)){break a}Y(b|0)|0;Z()}fb=f- -64|0;return g|0}Q(b|0);p()}function DT(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=fb-112|0;fb=f;x[f+108>>2]=0;e=Ko(a,e&65535,d,c,f+108|0);c=y[b+790|0];if(!x[f+108>>2]){d=(c|0)==15;h=d&!y[b+792|0];e=e<<8;a:{if(e){x[b+664>>2]=e;break a}e=0;if(d){break a}e=x[b+664>>2]}h=h?0:y[b+836|0]<<16}if((c|0)==15){c=y[b+792|0];b:{if(!c){c=x[b+76>>2];x[f+4>>2]=1;g=x[ad(f+4|0,f+108|0)>>2]<<3;e=Sua(c,0,e,0);d=(256<<g>>>1|0)+e|0;c=hb;c=d>>>0<e>>>0?c+1|0:c;e=g+8|0;g=d;d=e&31;if((e&63)>>>0>=32){e=0;c=c>>>d|0}else{e=c>>>d|0;c=((1<<d)-1&c)<<32-d|g>>>d}e=Bc(c,e);break b}Vv(f+4|0);if(c>>>0>9){break b}c=x[b+104>>2];if(!c){break b}e=x[yb(c+68|0,y[b+792|0]-1|0)>>2]+e|0}x[b+664>>2]=e}Oo(a,b,e+h|0);fb=f+112|0}function zna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=fb-16|0;fb=b;k=x[a+16>>2];j=mg(1,2);e=hb;l=e;Pb(a,j,e);f=x[a+40>>2];g=x[a+36>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;m=x[a+32>>2];n=x[a+28>>2];e=x[a+8>>2];o=x[a+12>>2];while(1){if(d){d=d-1|0;i=x[b+8>>2];i=(((x[b+12>>2]&2147483647)<<1|i>>>31)&-2)+k|0;h=0;while(1){if((h|0)!=2){x[(h<<2)+b>>2]=v[h+i|0]<<8;h=h+1|0;continue}break}g=g+n|0;x[c>>2]=x[c>>2]+D(x[b>>2],g>>12);f=f+m|0;x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],f>>12);Pb(b+8|0,e,o);c=c+8|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=f;x[a+20>>2]=g>>12;x[a+36>>2]=g;x[a+24>>2]=f>>12;Hg(a,j,l);fb=b+16|0}function R9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=fb-32|0;fb=d;e=x[a+28>>2];x[d+16>>2]=e;f=x[a+20>>2];x[d+28>>2]=c;x[d+24>>2]=b;b=f-e|0;x[d+20>>2]=b;f=b+c|0;i=2;b=d+16|0;a:{while(1){b:{c:{d:{if(!Yy(Aa(x[a+60>>2],b|0,i|0,d+12|0)|0)){g=x[d+12>>2];if((g|0)==(f|0)){break d}if((g|0)>=0){break c}break b}if((f|0)!=-1){break b}}b=x[a+44>>2];x[a+28>>2]=b;x[a+20>>2]=b;x[a+16>>2]=b+x[a+48>>2];a=c;break a}h=x[b+4>>2];j=h>>>0<g>>>0;e=(j<<3)+b|0;h=g-(j?h:0)|0;x[e>>2]=h+x[e>>2];b=(j?12:4)+b|0;x[b>>2]=x[b>>2]-h;f=f-g|0;i=i-j|0;b=e;continue}break}x[a+28>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a>>2]=x[a>>2]|32;a=0;if((i|0)==2){break a}a=c-x[b+4>>2]|0}fb=d+32|0;return a|0}function sma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=fb-16|0;fb=e;h=x[a+24>>2];i=x[a+20>>2];j=x[a+16>>2];g=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=g;k=b+24|0;g=x[a+8>>2];l=x[a+12>>2];while(1){if(d){b=x[e+8>>2];f=(x[e+12>>2]<<1)+j|0;b=(((b>>>16|0)+4&131064)<<1)+k|0;b=(((((D(w[f+4>>1],w[b+10>>1])+D(w[f+2>>1],w[b+8>>1])|0)+D(w[f+6>>1],w[b+12>>1])|0)+D(w[f+8>>1],w[b+14>>1])|0)/2|0)+((((D(w[f-4>>1],w[b+2>>1])+D(w[f-6>>1],w[b>>1])|0)+D(w[f-2>>1],w[b+4>>1])|0)+D(w[f>>1],w[b+6>>1])|0)/2|0)|0)/16384|0;x[c>>2]=x[c>>2]+D(b,i);x[c+4>>2]=x[c+4>>2]+D(b,h);Pb(e+8|0,g,l);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;fb=e+16|0}function eG(a){var b=0,c=0,d=0,e=0,f=0,g=0;a:{if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=-1641380927){break a}b=y[a+16|0]|y[a+17|0]<<8|(y[a+18|0]<<16|y[a+19|0]<<24);if(b>>>0<36){break a}c=y[a+24|0]|y[a+25|0]<<8|(y[a+26|0]<<16|y[a+27|0]<<24);if(c>>>0<36){break a}d=y[a+32|0]|y[a+33|0]<<8|(y[a+34|0]<<16|y[a+35|0]<<24);if(d>>>0<36){break a}e=y[a+12|0]|y[a+13|0]<<8|(y[a+14|0]<<16|y[a+15|0]<<24);if(e-1>>>0>858993458){break a}f=y[a+20|0]|y[a+21|0]<<8|(y[a+22|0]<<16|y[a+23|0]<<24);if(f-1>>>0>536870910){break a}a=y[a+28|0]|y[a+29|0]<<8|(y[a+30|0]<<16|y[a+31|0]<<24);if(D(e,-5)-1>>>0<b>>>0|a-1>>>0>1073741822|(f<<3^-1)>>>0<c>>>0){break a}g=(a<<2^-1)>>>0>=d>>>0}return g}function Tfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=fb-32|0;fb=d;x[31737]=0;W(1002,a|0);e=x[31737];x[31737]=0;a:{b:{c:{if((e|0)==1){break c}x[31737]=0;W(1003,b|0);e=x[31737];x[31737]=0;if((e|0)==1){break c}x[31737]=0;W(1003,c|0);f=x[31737];x[31737]=0;e=1;if((f|0)==1){break c}f=x[a+24>>2];b=qc(d+24|0,b);c=qc(d+16|0,c);g=x[c>>2];c=x[c+4>>2];x[31737]=0;h=x[b+4>>2];x[d+8>>2]=x[b>>2];x[d+12>>2]=h;Ps(1024,f,d+8|0,g,c,1);b=x[31737];x[31737]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31737]=0;V(989,5507,a|0,0,0);a=x[31737];x[31737]=0;if((a|0)==1){break a}Z();e=0}fb=d+32|0;return e|0}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function uu(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;g=fb-16|0;fb=g;d=Ir(g+4|0,a,d);e=zb(a);a=fb-48|0;fb=a;f=x[d+4>>2];x[a+44>>2]=f;x[a+40>>2]=f;e=Re(a+12|0,e,a+40|0,a+44|0);x[a+8>>2]=x[e+8>>2];f=x[e+4>>2];x[a>>2]=x[e>>2];x[a+4>>2]=f;Qe(a+24|0,a);while(1){if((b|0)!=(c|0)){Ov(x[a+44>>2],b);x[a+44>>2]=x[a+44>>2]+6;b=b+6|0;continue}break}Pe(a+24|0);h=x[a+44>>2];if(!y[a+36|0]){c=fb-16|0;fb=c;b=vb(c+12|0,x[x[a+32>>2]>>2]);i=x[vb(c+8|0,x[x[a+28>>2]>>2])>>2];e=fb-16|0;fb=e;b=x[b>>2];x[e+12>>2]=b;while(1){if(pd(b,i)){f=fb-16|0;fb=f;x[f+12>>2]=b;rR(f+12|0,-1);fb=f+16|0;b=x[nD(e+12|0)>>2];continue}break}fb=e+16|0;fb=c+16|0}fb=a+48|0;x[d+4>>2]=h;hc(d);fb=g+16|0}function eR(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=E(0),j=E(0),k=0,l=E(0);g=fb-16|0;fb=g;e=w[d>>1];f=w[d+2>>1];if(!(!z[b>>1]|(e|0)>(f|0)|(!(B[c>>2]>E(0))|(f-e|0)>32766))){w[a>>1]=3;f=a+4|0;Nf(f);w[a+28>>1]=65472;x[g+12>>2]=1065353216;hR(f,g+12|0);x[a+32>>2]=0;w[a+30>>1]=0;Nf(a+16|0);h=w[d>>1];w[a+28>>1]=h;e=fb-16|0;fb=e;w[e+14>>1]=z[b>>1];w[e+12>>1]=32767;b=w[Nc(e+14|0,e+12|0)>>1];fb=e+16|0;w[a+30>>1]=b;i=E(F(B[c>>2]));B[a+32>>2]=i;i=Ce(i,E(E(1)/E(b|0)));Jl(f,(w[d+2>>1]-h|0)+1|0);b=x[a+4>>2];c=w[a+28>>1];e=w[d+2>>1];d=w[d>>1];while(1){if((d|0)>(e|0)){Cq(a)}else{j=Ce(i,E(d|0));k=yb(b,d-c|0),l=j,B[k>>2]=l;d=d+1|0;continue}break}h=1}fb=g+16|0;return h|0}function RO(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=fb-32|0;fb=e;g=Nb(a);a=0;c=x[b+24>>2];c=Xu(x[c+484344>>2],x[c+484348>>2]);x[31737]=0;O(177,g|0,c|0);c=x[31737];x[31737]=0;a:{if((c|0)!=1){b:{c:{d:{e:{while(1){c=x[b+24>>2];d=x[c+484344>>2];if(Xu(d,x[c+484348>>2])>>>0<=a>>>0){break b}x[31737]=0;c=e+8|0;O(1072,c|0,Wb(d,a)|0);d=x[31737];x[31737]=0;if((d|0)!=1){f=x[b+24>>2];x[31737]=0;d=e+20|0;S(1059,d|0,f|0,c|0);f=x[31737];x[31737]=0;if((f|0)==1){break e}x[31737]=0;O(179,g|0,d|0);f=x[31737];x[31737]=0;if((f|0)==1){break d}a=a+1|0;tb(d);tb(c);continue}break}a=N()|0;break a}a=N()|0;break c}a=N()|0;tb(e+20|0)}tb(e+8|0);break a}fb=e+32|0;return}a=N()|0}Td(g);Q(a|0);p()}function DU(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;j=$u(b);e=fb-16|0;fb=e;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);h=e+8|0;Rd(h,x[vb(e+4|0,a)>>2]);x[31737]=0;O(802,a|0,2048);d=x[31737];x[31737]=0;a:{if((d|0)!=1){i=fb-16|0;fb=i;g=ks(i+4|0,a,2048);d=x[g+4>>2];k=x[g+8>>2];while(1){if((d|0)==(k|0)){hc(g);fb=i+16|0}else{x[d>>2]=0;x[d+4>>2]=0;d=d+8|0;x[g+4>>2]=d;continue}break}Qd(h);Zu(h);fb=e+16|0;break a}a=N()|0;Zu(e+8|0);Q(a|0);p()}while(1){b:{c=1;if((f|0)!=1024){if((f|0)==2048){break b}c=+(f-1024|0);l=$u(M(c*c*-9.5367431640625e-7+1)*b);c=c*.0372006759294457;c=l*Wi(c)/(j*c)}m=Ue(x[a>>2],f),n=c*.011841342921061943,C[m>>3]=n;f=f+1|0;continue}break}}function Rz(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;d=fb-16|0;fb=d;x[d>>2]=a;x[d+4>>2]=b;x[d+8>>2]=a;x[d+12>>2]=b;b=fb+-64|0;fb=b;a:{if(!x[d+4>>2]){break a}a=x[d>>2];h=x[d+4>>2];c=30672;while(1){if((c|0)==31104){c=31104;while(1){f=(c|0)!=31152;if((c|0)==31152){break a}x[b+40>>2]=a;x[b+44>>2]=h;e=qc(b+32|0,x[c+8>>2]);g=x[b+44>>2];x[b+8>>2]=x[b+40>>2];x[b+12>>2]=g;g=x[e+4>>2];x[b>>2]=x[e>>2];x[b+4>>2]=g;c=c+12|0;if(!PR(b+8|0,b)){continue}break}break a}x[b+56>>2]=a;x[b+60>>2]=h;f=qc(b+48|0,x[c+4>>2]);e=x[b+60>>2];x[b+24>>2]=x[b+56>>2];x[b+28>>2]=e;e=x[f+4>>2];x[b+16>>2]=x[f>>2];x[b+20>>2]=e;c=c+8|0;if(!PR(b+24|0,b+16|0)){continue}break}f=1}fb=b- -64|0;fb=d+16|0;return f}function kZ(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=fb-16|0;fb=g;d=vb(g+12|0,x[a+4>>2]);c=vb(g+8|0,x[a>>2]);f=x[vb(g+4|0,x[b+4>>2])>>2];h=fb-16|0;fb=h;i=h+8|0;e=fb-32|0;fb=e;Id(e+24|0,x[d>>2],x[c>>2]);j=e+16|0;c=x[e+24>>2];k=x[e+28>>2];d=fb-16|0;fb=d;x[d+8>>2]=f;x[d+12>>2]=c;while(1){if(pd(c,k)){c=xf(c);f=xf(x[d+8>>2]);c=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);v[f|0]=c;v[f+1|0]=c>>>8;v[f+2|0]=c>>>16;v[f+3|0]=c>>>24;c=Mi(d+12|0);Mi(d+8|0);c=x[c>>2];continue}break}Ac(j,c,d+8|0);fb=d+16|0;d=x[e+16>>2];x[e+12>>2]=x[e+20>>2];Ac(i,d,e+12|0);fb=e+32|0;fb=h+16|0;x[b+4>>2]=x[h+12>>2];Tb(a,b+4|0);Tb(a+4|0,b+8|0);Tb(zb(a),nc(b));x[b>>2]=x[b+4>>2];fb=g+16|0}function jv(a,b){var c=0,d=0,e=0;e=fb-48|0;fb=e;d=e+28|0;iW(d,a+8|0,a+10|0,a+12|0,a+16|0,a+14|0);a=e+8|0;iW(a,b+8|0,b+10|0,b+12|0,b+16|0,b+14|0);b=x[d>>2];c=y[b|0]|y[b+1|0]<<8;b=x[a>>2];b=iv(c,y[b|0]|y[b+1|0]<<8);a:{if(!Sj(b)){break a}b=x[d+4>>2];c=y[b|0]|y[b+1|0]<<8;b=x[a+4>>2];b=iv(c,y[b|0]|y[b+1|0]<<8);if(!Sj(b)){break a}b=x[d+8>>2];c=y[b|0]|y[b+1|0]<<8;b=x[a+8>>2];b=iv(c,y[b|0]|y[b+1|0]<<8);if(!Sj(b)){break a}b=x[a+12>>2];b=(y[b|0]|y[b+1|0]<<8)<<16>>16;c=x[d+12>>2];c=xe((y[c|0]|y[c+1|0]<<8)<<16>>16);b=xe(b);b=(b|0)!=(c|0)?(c|0)<(b|0)?-1:1:0;if(!Sj(b)){break a}b=x[d+16>>2];a=x[a+16>>2];b=iv(y[b|0]|y[b+1|0]<<8,y[a|0]|y[a+1|0]<<8)}a=Cd(b);fb=e+48|0;return a}function aB(a,b,c,d){var e=0,f=0,g=0;a:{if(!d){break a}if(c){v[b+815|0]=c;break a}c=y[b+815|0]}e=x[a+480180>>2];d=e&1048580;c=d?(c&240?-16:15)&c:c;b:{c:{d:{if(!d){d=c&240;e:{f:{g:{h:{c=c&15;if((c|0)==15){a=x[a+480208>>2]&4096;if(!d){break h}if(!a){break b}c=0-(d>>>2|0)|0;break d}a=x[a+480208>>2]&4096;if(!c|(d|0)!=240){break g}if(!a){break b}c=c<<2;break c}d=0;if(!a){break f}break b}if(a){break b}if(!c){break e}}c=c<<2;if(!d|!(e&16777248)){break c}break b}c=0-(d>>>2|0)|0;break d}if(y[a+480209|0]&16){break b}d=c&240;c=d?d>>>2|0:0-(c<<2&60)|0;if(!Ob(a+1074312|0,56)){break d}c=c>>2}if(!c){break b}}a=x[b+692>>2];w[b+784>>1]=0;f=b,g=Yb(a+c|0,0,256),x[f+692>>2]=g}}function K7(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;h=fb-416|0;fb=h;d=h+416|0;x[h+12>>2]=d;c=fb-144|0;fb=c;x[c+28>>2]=c+132;i=c+32|0;dK(x[a+8>>2],i,c+28|0,e,f,g);x[c+16>>2]=0;x[c+20>>2]=0;x[c+12>>2]=i;e=h+16|0;f=oc(e,x[h+12>>2]);a=Gi(e,c+12|0,f,c+16|0,x[a+8>>2]);if((a|0)==-1){io(12677);p()}x[h+12>>2]=e+(a<<2);fb=c+144|0;f=fb-16|0;fb=f;i=f+8|0;a=fb-32|0;fb=a;Id(a+24|0,e,x[h+12>>2]);h=a+16|0;e=x[a+24>>2];g=x[a+28>>2];c=fb-16|0;fb=c;x[c+12>>2]=b;while(1){if((e|0)!=(g|0)){hL(c+12|0,x[e>>2]);e=e+4|0;continue}break}Ac(h,g,c+12|0);fb=c+16|0;b=x[a+16>>2];x[a+12>>2]=x[a+20>>2];Ac(i,b,a+12|0);fb=a+32|0;fb=f+16|0;fb=d;return x[f+12>>2]}function tma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=fb-16|0;fb=e;h=x[a+24>>2];i=x[a+20>>2];j=x[a+16>>2];g=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=g;k=b+24|0;g=x[a+8>>2];l=x[a+12>>2];while(1){if(d){b=x[e+8>>2];f=x[e+12>>2]+j|0;b=(((b>>>16|0)+4&131064)<<1)+k|0;b=((((D(v[f+2|0],w[b+10>>1])+D(v[f+1|0],w[b+8>>1])|0)+D(v[f+3|0],w[b+12>>1])|0)+D(v[f+4|0],w[b+14>>1])<<8>>1)+(((D(v[f-2|0],w[b+2>>1])+D(v[f-3|0],w[b>>1])|0)+D(v[f-1|0],w[b+4>>1])|0)+D(v[f|0],w[b+6>>1])<<8>>1)|0)/16384|0;x[c>>2]=x[c>>2]+D(b,i);x[c+4>>2]=x[c+4>>2]+D(b,h);Pb(e+8|0,g,l);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;fb=e+16|0}function r9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=fb-16|0;fb=f;a:{b:{if(!mc(b,-1)){i=x[a+8>>2];j=x[a+12>>2];d=x[a+24>>2];if((d|0)==x[a+28>>2]){c=-1;if(!(y[a+48|0]&16)){break a}k=x[a+44>>2];h=x[a+20>>2];x[31737]=0;g=a+32|0;O(116,g|0,0);e=x[31737];x[31737]=0;if((e|0)==1){break b}e=Mc(g);x[31737]=0;O(46,g|0,e|0);e=x[31737];x[31737]=0;if((e|0)==1){break b}c=Jb(g);My(a,c,Cb(x[a+36>>2],y[a+43|0])+c|0);Bt(a,d-h|0);x[a+44>>2]=x[a+20>>2]+(k-h|0);d=x[a+24>>2]}x[f+12>>2]=d+1;d=x[ad(f+12|0,a+44|0)>>2];x[a+44>>2]=d;if(y[a+48|0]&8){c=Jb(a+32|0);ko(a,c,c+(j-i|0)|0,d)}c=oL(a,b<<24>>24);break a}c=Ly(b);break a}Y(T(0)|0)|0;Z()}fb=f+16|0;return c|0}function go(a,b,c,d,e,f,g,h,i,j,k){var l=0,m=0,n=0;a:{b:{l=x[d>>2];if((l|0)!=(c|0)){break b}m=43;n=a&255;if((n|0)!=y[k+24|0]){m=45;if(y[k+25|0]!=(n|0)){break b}}x[d>>2]=c+1;v[c|0]=m;break a}c:{if(!(!Cb(g,h)|(a|0)!=(f|0))){h=0;a=x[j>>2];if((a-i|0)>159){break c}b=x[e>>2];x[j>>2]=a+4;x[a>>2]=b;break a}h=-1;a=Li(k,k+26|0,a)-k|0;if((a|0)>23){break c}d:{e:{switch(b-8|0){case 0:case 2:if((a|0)<(b|0)){break d}break c;case 1:break d;default:break e}}if((b|0)!=16|(a|0)<22){break d}if((c|0)==(l|0)|(l-c|0)>2|y[l-1|0]!=48){break c}x[e>>2]=0;x[d>>2]=l+1;v[l|0]=y[a+111776|0];return 0}x[d>>2]=l+1;v[l|0]=y[a+111776|0];x[e>>2]=x[e>>2]+1;h=0}return h}x[e>>2]=0;return 0}function Zoa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=fb-160|0;fb=e;b=-1;a:{if(!Cm(a,80)){break a}b:{c:{if(!cm(a,60)){break c}d=e+140|0;if(!cX(a,d)){break c}c=15;if(tv(d,15)){break b}}if(!Cm(a,144)){break a}b=0;if(!cm(a,124)){break a}d=e+140|0;if(!cX(a,d)){break a}c=31;if(!tv(d,31)){break a}}tE(a);b=0;d:{while(1){if((b&65535)>>>0>=c>>>0){break d}b=b+1|0;if(aX(a)>>>0<=131072){continue}break}b=0;break a}b=-1;if(!gd(a,D(c,30)|20)){break a}c=fb-16|0;fb=c;f=e+10|0;TC(c+8|0,f);d=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((d|0)==(g|0)){gd(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(g|0);if(!a){JC(f)}if(!a){break a}b=bX(y[e+10|0])}fb=e+160|0;return b|0}function Vma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=fb-16|0;fb=b;f=x[a+40>>2];g=x[a+36>>2];i=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;j=x[a+32>>2];k=x[a+28>>2];l=x[a+8>>2];m=x[a+12>>2];while(1){if(d){e=x[b+8>>2];h=(x[b+12>>2]<<1)+i|0;e=e>>>21&2040;e=(((D(w[h>>1],w[e+38194>>1])+D(w[h-2>>1],w[e+38192>>1])|0)+D(w[h+2>>1],w[e+38196>>1])|0)+D(w[h+4>>1],w[e+38198>>1])|0)/16384|0;g=g+k|0;x[c>>2]=x[c>>2]+D(e,g>>12);f=f+j|0;x[c+4>>2]=x[c+4>>2]+D(e,f>>12);Pb(b+8|0,l,m);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=f;x[a+20>>2]=g>>12;x[a+36>>2]=g;x[a+24>>2]=f>>12;fb=b+16|0}function xs(a){var b=0,c=0,d=0,e=0;b=fb-32|0;fb=b;c=b+8|0;Dc(c,13707);x[31737]=0;d=b+20|0;S(124,d|0,1,c|0);e=x[31737];x[31737]=0;a:{b:{c:{if((e|0)!=1){x[31737]=0;O(12,a|0,d|0);e=x[31737];x[31737]=0;if((e|0)==1){break c}Ub(d);tb(c);fb=b+32|0;break a}a=N()|0;break b}a=N()|0;Ub(b+20|0)}tb(b+8|0);Q(a|0);p()}x[31737]=0;b=ca(118)|0;c=x[31737];x[31737]=0;d:{if((c|0)==1){break d}x[a+12>>2]=b;x[31737]=0;b=ca(119)|0;c=x[31737];x[31737]=0;if((c|0)==1){break d}v[a+16|0]=b;x[31737]=0;b=ca(120)|0;c=x[31737];x[31737]=0;if((c|0)==1){break d}v[a+18|0]=0;v[a+17|0]=b;x[31737]=0;W(121,a+20|0);b=x[31737];x[31737]=0;if((b|0)==1){break d}return}b=N()|0;tb(a);Q(b|0);p()}function Zka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=fb-80|0;fb=e;d=Tf(e+52|0);x[31737]=0;g=P(839,b|0,d|0)|0;f=x[31737];x[31737]=0;a:{b:{c:{if((f|0)!=1){if(g){break c}x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[31737]=0;R(840,a|0)|0;a=x[31737];x[31737]=0;if((a|0)!=1){break b}}break a}g=x[d+4>>2];x[31737]=0;f=e+12|0;S(186,f|0,b|0,g|0);h=x[31737];x[31737]=0;if((h|0)==1){break a}h=ic(e+32|0,f);hd(d+8|0,h);ub(h);ub(f);d:{if(c>>>0<2){break d}c=g&1;if(!c){break d}x[31737]=0;P(184,b|0,2-c|0)|0;b=x[31737];x[31737]=0;if((b|0)!=1){break d}break a}Sk(a,d)}Fd(d);fb=e+80|0;return}a=N()|0;Fd(d);Q(a|0);p()}function Gra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=fb-32|0;fb=d;x[d+28>>2]=0;Lk(a,d+28|0);a:{b:{i=x[d+28>>2];c:{if(i>>>0>500){break c}d:{e:{while(1){if((f|0)==(i|0)){break c}h=Fb(d+16|0);x[31737]=0;w[d+14>>1]=0;g=U(496,a|0,h|0,255)|0;e=x[31737];x[31737]=0;if((e|0)==1){break b}if(!g){break d}x[31737]=0;g=d+14|0;O(485,a|0,g|0);e=x[31737];x[31737]=0;if((e|0)==1){break b}x[31737]=0;S(497,d|0,c|0,h|0);e=x[31737];x[31737]=0;if((e|0)!=1){x[31737]=0;g=P(498,b|0,g|0)|0;e=x[31737];x[31737]=0;if((e|0)==1){break e}Ab(g,d);tb(d);tb(h);f=f+1|0;continue}break}f=N()|0;break a}f=N()|0;tb(d);break a}tb(h)}fb=d+32|0;return}f=N()|0}tb(h);Q(f|0);p()}function gsa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=b;c=fb-48|0;fb=c;d=a;a:{if(Mv(x[d>>2],x[d+8>>2])){x[g>>2]=0;break a}rZ(c+16|0,c+32|0);lc(c+24|0,x[d>>2],x[d+8>>2],x[c+16>>2],x[c+20>>2]);h=x[c+28>>2];i=y[c+32|0];f=i&127;x[g>>2]=f;a=f;b=0;while(1){if(a){b=b+1|0;a=a>>>1|0;continue}break}a=b;e=1;while(1){b=(D(h,7)+a|0)+D(e,-7)|0;b:{while(1){if(i<<24>>24>=0|e>>>0>=h>>>0){break b}j=c+32|0;i=y[j+e|0];f=i&127|f<<7;x[g>>2]=f;a=a+7|0;e=e+1|0;if((h|0)!=(e|0)){continue}break}Vb(d,h);rZ(c+8|0,j);lc(c+24|0,x[d>>2],x[d+8>>2],x[c+8>>2],x[c+12>>2]);h=x[c+28>>2];f=x[g>>2];e=0;a=b;continue}break}Vb(d,e);if(a>>>0<33){break a}x[g>>2]=-1}fb=c+48|0}function nG(a){a=a|0;var b=0,c=0,d=0,e=0;b=nF(x[(x[x[a>>2]-12>>2]+a|0)+28>>2],10);d=fb-16|0;fb=d;x[31737]=0;c=P(21,d+8|0,a|0)|0;e=x[31737];x[31737]=0;a:{b:{c:{d:{if((e|0)!=1){e:{if(!Gd(y[c|0])){break e}e=up(d+4|0,a);x[31737]=0;b=P(30,e|0,b|0)|0;e=x[31737];x[31737]=0;if((e|0)!=1){if(x[b>>2]){break e}b=x[x[a>>2]-12>>2];x[31737]=0;O(24,a+b|0,1);b=x[31737];x[31737]=0;if((b|0)!=1){break e}}b=T(0)|0;nm(c);break d}nm(c);break c}b=T(0)|0}Y(b|0)|0;c=x[x[a>>2]-12>>2];x[31737]=0;W(25,a+c|0);c=x[31737];x[31737]=0;if((c|0)==1){break b}Z()}fb=d+16|0;break a}a=N()|0;x[31737]=0;X(26);d=x[31737];x[31737]=0;if((d|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}return xp(a)|0}function lT(a,b,c,d,e){var f=0,g=0,h=0,i=0;a:{b:{c:{if(v[b+851|0]&1){f=y[b+848|0];g=c&240;if(g){f=f&15|g;v[b+848|0]=f}c=c&15;if(c){f=c|f&-16;v[b+848|0]=f}v[b+849|0]=(f&240)>>>4;if(x[a+480180>>2]!=32768){break a}break c}if(x[a+480180>>2]==32768){break c}c=y[b+849|0]-1|0;v[b+849|0]=c;if(c&255){break a}f=y[b+848|0];break b}f=y[b+848|0];if((f&240)==16){break b}if(!(y[a+480209|0]&16)){break a}}v[b+849|0]=(f&240)>>>4;c=f&15;c=d?c:0-c|0;d=x[b+656>>2];d:{if(Rj(d)){x[b+852>>2]=x[b+852>>2]+D(c,x[x[d+44>>2]+36>>2]);break d}h=b,i=wh(a,Ju(a,x[b+700>>2],w[b+772>>1],x[b+704>>2])+c|0,w[b+772>>1],x[b+704>>2]),x[h+700>>2]=i}if(!e){break a}x[b>>2]=0;x[b+4>>2]=0}}function fo(a,b,c,d,e,f,g,h,i,j,k){var l=0,m=0;a:{b:{l=x[d>>2];if((l|0)!=(c|0)){break b}m=43;if(x[k+96>>2]!=(a|0)){m=45;if(x[k+100>>2]!=(a|0)){break b}}x[d>>2]=c+1;v[c|0]=m;break a}c:{if(!(!Cb(g,h)|(a|0)!=(f|0))){h=0;a=x[j>>2];if((a-i|0)>159){break c}b=x[e>>2];x[j>>2]=a+4;x[a>>2]=b;break a}h=-1;a=ry(k,k+104|0,a)-k>>2;if((a|0)>23){break c}d:{e:{switch(b-8|0){case 0:case 2:if((a|0)<(b|0)){break d}break c;case 1:break d;default:break e}}if((b|0)!=16|(a|0)<22){break d}if((c|0)==(l|0)|(l-c|0)>2|y[l-1|0]!=48){break c}x[e>>2]=0;x[d>>2]=l+1;v[l|0]=y[a+111776|0];return 0}x[d>>2]=l+1;v[l|0]=y[a+111776|0];x[e>>2]=x[e>>2]+1;h=0}return h}x[e>>2]=0;return 0}function fI(a,b,c,d){var e=0,f=0,g=0;f=fb-32|0;fb=f;x[31737]=0;W(1002,a|0);e=x[31737];x[31737]=0;a:{b:{c:{d:{e:{f:{if((e|0)==1){break f}x[31737]=0;W(1003,b|0);e=x[31737];x[31737]=0;if((e|0)==1){break f}g=x[a+24>>2];x[31737]=0;e=P(36,f+8|0,b|0)|0;b=x[31737];x[31737]=0;if((b|0)==1){break e}x[31737]=0;b=d;d=f+20|0;S(b|0,d|0,g|0,e|0);b=x[31737];x[31737]=0;if((b|0)==1){break d}b=Bg(Jb(d));tb(d);tb(e);break b}b=T(0)|0;break c}b=T(0)|0;break c}b=T(0)|0;tb(e)}Y(b|0)|0;b=0;x[31737]=0;V(989,c|0,a|0,0,0);a=x[31737];x[31737]=0;if((a|0)==1){break a}Z()}fb=f+32|0;return b}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function xp(a){var b=0,c=0,d=0,e=0;d=fb-16|0;fb=d;a:{b:{if(!x[(x[x[a>>2]-12>>2]+a|0)+24>>2]){break b}x[31737]=0;c=P(21,d+8|0,a|0)|0;b=x[31737];x[31737]=0;c:{if((b|0)!=1){d:{if(!Gd(y[c|0])){break d}b=x[(x[x[a>>2]-12>>2]+a|0)+24>>2];x[31737]=0;b=R(31,b|0)|0;e=x[31737];x[31737]=0;if((e|0)!=1){if((b|0)!=-1){break d}b=x[x[a>>2]-12>>2];x[31737]=0;O(24,a+b|0,1);b=x[31737];x[31737]=0;if((b|0)!=1){break d}}b=T(0)|0;nm(c);break c}nm(c);break b}b=T(0)|0}Y(b|0)|0;c=x[x[a>>2]-12>>2];x[31737]=0;W(25,a+c|0);c=x[31737];x[31737]=0;if((c|0)==1){break a}Z()}fb=d+16|0;return a}a=N()|0;x[31737]=0;X(26);c=x[31737];x[31737]=0;if((c|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function Rra(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=fb-32|0;fb=c;e=c+12|0;g=Nb(e+8|0);x[31737]=0;d=R(203,b|0)|0;f=x[31737];x[31737]=0;a:{b:{if((f|0)==1){break b}c:{if(!BZ(d)){x[31737]=0;X(508);a=x[31737];x[31737]=0;if((a|0)!=1){break c}break b}x[31737]=0;d=R(203,b|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break b}x[31737]=0;S(170,e|0,b|0,d|0);d=x[31737];x[31737]=0;if((d|0)==1){break b}d=x[e>>2];x[31737]=0;P(184,b|0,d|0)|0;b=x[31737];x[31737]=0;if((b|0)==1){break b}break a}p()}a=N()|0;dc(g);Q(a|0);p()}Rn(c+4|0,e);x[31737]=0;S(476,a|0,x[c+4>>2],x[c+8>>2]);a=x[31737];x[31737]=0;if((a|0)!=1){Kc(e);fb=c+32|0;return}a=N()|0;Kc(c+12|0);Q(a|0);p()}function Fra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=fb-32|0;fb=d;w[d+30>>1]=0;pg(a,d+30|0);a:{b:{i=z[d+30>>1];c:{if(i>>>0>500){break c}d:{e:{while(1){if((f|0)==(i|0)){break c}h=Fb(d+16|0);x[31737]=0;w[d+14>>1]=0;g=P(499,a|0,h|0)|0;e=x[31737];x[31737]=0;if((e|0)==1){break b}if(!g){break d}x[31737]=0;g=d+14|0;O(485,a|0,g|0);e=x[31737];x[31737]=0;if((e|0)==1){break b}x[31737]=0;S(497,d|0,c|0,h|0);e=x[31737];x[31737]=0;if((e|0)!=1){x[31737]=0;g=P(498,b|0,g|0)|0;e=x[31737];x[31737]=0;if((e|0)==1){break e}Ab(g,d);tb(d);tb(h);f=f+1|0;continue}break}f=N()|0;break a}f=N()|0;tb(d);break a}tb(h)}fb=d+32|0;return}f=N()|0}tb(h);Q(f|0);p()}function caa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=fb-32|0;fb=d;h=Fb(a);f=Fb(d+20|0);a=1;a:{b:{c:{while(1){e=a&65535;c=x[b+24>>2];if(e>>>0>z[c+480192>>1]){if(!(i&1)){break c}x[31737]=0;O(248,h|0,f|0);a=x[31737];x[31737]=0;if((a|0)!=1){break c}a=N()|0;break a}c=eS(c,e);x[31737]=0;c=P(36,d+8|0,c|0)|0;e=x[31737];x[31737]=0;if((e|0)==1){break b}e=Ad(x[d+12>>2],y[d+19|0]);x[31737]=0;g=P(842,f|0,c|0)|0;j=x[31737];x[31737]=0;d:{if((j|0)==1){break d}x[31737]=0;P(991,g|0,22278)|0;g=x[31737];x[31737]=0;if((g|0)==1){break d}i=e^1|i;tb(c);a=a+1|0;continue}break}a=N()|0;tb(c);break a}tb(f);fb=d+32|0;return}a=N()|0}tb(f);tb(h);Q(a|0);p()}function Wma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=fb-16|0;fb=b;f=x[a+40>>2];g=x[a+36>>2];i=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;j=x[a+32>>2];k=x[a+28>>2];l=x[a+8>>2];m=x[a+12>>2];while(1){if(d){e=x[b+8>>2];h=x[b+12>>2]+i|0;e=e>>>21&2040;e=(((D(v[h|0],w[e+38194>>1])+D(v[h-1|0],w[e+38192>>1])|0)+D(v[h+1|0],w[e+38196>>1])|0)+D(v[h+2|0],w[e+38198>>1])<<8)/16384|0;g=g+k|0;x[c>>2]=x[c>>2]+D(e,g>>12);f=f+j|0;x[c+4>>2]=x[c+4>>2]+D(e,f>>12);Pb(b+8|0,l,m);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=f;x[a+20>>2]=g>>12;x[a+36>>2]=g;x[a+24>>2]=f>>12;fb=b+16|0}function o1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=fb-32|0;fb=c;ld(b,0);e=c+16|0;f=rf(e,1,v[a+1|0]);ze(b+43|0,f);tb(f);x[b>>2]=y[a+6|0]|y[a+7|0]<<8|(y[a+8|0]<<16|y[a+9|0]<<24);x[b+24>>2]=y[a+10|0]|y[a+11|0]<<8;v[c+16|0]=y[a+12|0];v[c+12|0]=64;g=b,h=y[Qb(e,c+12|0)|0]<<2,w[g+30>>1]=h;x[b+4>>2]=y[a+13|0]|y[a+14|0]<<8|(y[a+15|0]<<16|y[a+16|0]<<24);e=y[a+19|0];f=y[a+17|0]|y[a+18|0]<<8;v[c+14|0]=0;v[c+18|0]=e;w[c+16>>1]=f;w[c+12>>1]=0;while(1){if((d|0)!=3){e=y[xb(c+16|0,d)|0];g=xb(c+12|0,d),h=e,v[g|0]=h;d=d+1|0;continue}break}d=eg(c+12|0);x[b+8>>2]=d;if(!(!y[a|0]|d>>>0<=x[b+4>>2]+2>>>0|d>>>0>A[b>>2])){w[b+34>>1]=z[b+34>>1]|2}fb=c+32|0}function baa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=fb-32|0;fb=c;h=Fb(a);f=Fb(c+20|0);a=1;a:{b:{c:{while(1){d=a&65535;e=x[b+24>>2];if(d>>>0>z[e+480190>>1]){if(!(i&1)){break c}x[31737]=0;O(248,h|0,f|0);a=x[31737];x[31737]=0;if((a|0)!=1){break c}a=N()|0;break a}x[31737]=0;e=P(36,c+8|0,fS(e,d)|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break b}d=Ad(x[c+12>>2],y[c+19|0]);x[31737]=0;g=P(842,f|0,e|0)|0;j=x[31737];x[31737]=0;d:{if((j|0)==1){break d}x[31737]=0;P(991,g|0,22278)|0;g=x[31737];x[31737]=0;if((g|0)==1){break d}i=d^1|i;tb(e);a=a+1|0;continue}break}a=N()|0;tb(e);break a}tb(f);fb=c+32|0;return}a=N()|0}tb(f);tb(h);Q(a|0);p()}function H7(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0;k=fb-16|0;fb=k;l=j;a:{if(a){a=k+4|0;b=QJ(b);ql(a,b);j=x[k+4>>2];v[c|0]=j;v[c+1|0]=j>>>8;v[c+2|0]=j>>>16;v[c+3|0]=j>>>24;pl(a,b);Ab(i,a);tb(a);ji(a,b);Ab(h,a);tb(a);m=d,n=tj(b),v[m|0]=n;m=e,n=uj(b),v[m|0]=n;rh(a,b);Ab(f,a);tb(k+4|0);ki(a,b);Ab(g,a);tb(k+4|0);a=Ok(b);break a}a=k+4|0;b=PJ(b);ql(a,b);j=x[k+4>>2];v[c|0]=j;v[c+1|0]=j>>>8;v[c+2|0]=j>>>16;v[c+3|0]=j>>>24;pl(a,b);Ab(i,a);tb(a);ji(a,b);Ab(h,a);tb(a);m=d,n=tj(b),v[m|0]=n;m=e,n=uj(b),v[m|0]=n;rh(a,b);Ab(f,a);tb(k+4|0);ki(a,b);Ab(g,a);tb(k+4|0);a=Ok(b)}x[l>>2]=a;fb=k+16|0}function lsa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=x[a>>2];d=Hr(c,x[a+4>>2]);if(d>>>0<b>>>0){f=fb-32|0;fb=f;c=b-d|0;b=x[zb(a)>>2];e=x[a+4>>2];a:{if(c>>>0<=(b-e|0)/40>>>0){d=fb-16|0;fb=d;b=I$(d+4|0,a,c);a=x[b+4>>2];c=x[b+8>>2];while(1){if((a|0)==(c|0)){hc(b);fb=d+16|0}else{nZ(a);a=a+40|0;x[b+4>>2]=a;continue}break}break a}b=zb(a);d=F$(f+12|0,G$(a,Hr(x[a>>2],e)+c|0),Hr(x[a>>2],x[a+4>>2]),b);e=fb-16|0;fb=e;g=x[d+8>>2];b=e+4|0;x[b+8>>2]=d+8;x[b>>2]=g;x[b+4>>2]=D(c,40)+g;c=x[b>>2];while(1){if(x[b+4>>2]!=(c|0)){nZ(c);c=x[b>>2]+40|0;x[b>>2]=c;continue}break}he(b);fb=e+16|0;E$(a,d);D$(d)}fb=f+32|0;return}if(b>>>0<d>>>0){A$(a,c+D(b,40)|0)}}function Wka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=fb-16|0;fb=g;e=Jb(b);d=Cb(x[b+4>>2],y[b+11|0]);i=Jb(c);j=Cb(x[c+4>>2],y[c+11|0]);f=-1;a:{if(!d){break a}h=d+e|0;d=e;while(1){if((d|0)==(h|0)){break a}if(yq(i,j,y[d|0])){d=d+1|0;continue}break}f=d-e|0}b:{c:{if((f|0)!=-1){c=vb(g+12|0,zd(b));d=vb(g+8|0,uf(zd(b),f));cs(b,x[c>>2],x[d>>2]);break c}f=Yc(x[b+4>>2],y[b+11|0]);if(!f){break c}e=Jb(b);i=Cb(x[b+4>>2],y[b+11|0]);j=Jb(c);d=-1;h=Cb(x[c+4>>2],y[c+11|0]);if(h){c=e+i|0;d:{while(1){if((c|0)==(e|0)){break d}c=c-1|0;if(!yq(j,h,y[c|0])){continue}break}d=c-e|0}}if((f-1|0)!=(d|0)){break c}Fb(a);break b}_c(a,b)}fb=g+16|0}function DC(a,b,c,d,e,f){var g=0,h=0,i=0,j=0;g=fb-16|0;fb=g;h=x[a>>2];a:{if(Vc(h,x[a+4>>2])>>>0<=b>>>0){break a}b:{c:{switch(c|0){case 0:if((d|0)>=0){i=xb(h,b),j=d^128,v[i|0]=j}c=g+8|0;Kb(c,x[a+24>>2],b);If(c,0);break b;case 2:i=xb(h,b),j=128,v[i|0]=j;c=g+8|0;Kb(c,x[a+24>>2],b);If(c,1);break b;case 4:break c;default:break b}}i=xb(h,b),j=128,v[i|0]=j;c=g+8|0;Kb(c,x[a+24>>2],b);If(c,0)}if(y[e|0]){break a}c=x[f+4>>2];if(mc(x[f>>2],c)){break a}c=yX(c);if(y[xb(x[c>>2],b)|0]==y[xb(x[a>>2],b)|0]){Kb(g+8|0,x[c+24>>2],b);c=Hb(x[x[g+8>>2]>>2],x[g+12>>2]);Kb(g,x[a+24>>2],b);if((Hb(x[x[g>>2]>>2],x[g+4>>2])|0)==(c|0)){break a}}v[e|0]=1}fb=g+16|0}function A7(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0;k=fb-16|0;fb=k;l=j;a:{if(a){a=k+4|0;b=MJ(b);ql(a,b);j=x[k+4>>2];v[c|0]=j;v[c+1|0]=j>>>8;v[c+2|0]=j>>>16;v[c+3|0]=j>>>24;pl(a,b);oh(i,a);Ub(a);ji(a,b);oh(h,a);Ub(a);m=d,n=tj(b),x[m>>2]=n;m=e,n=uj(b),x[m>>2]=n;rh(a,b);Ab(f,a);tb(a);ki(a,b);oh(g,a);Ub(k+4|0);a=Ok(b);break a}a=k+4|0;b=LJ(b);ql(a,b);j=x[k+4>>2];v[c|0]=j;v[c+1|0]=j>>>8;v[c+2|0]=j>>>16;v[c+3|0]=j>>>24;pl(a,b);oh(i,a);Ub(a);ji(a,b);oh(h,a);Ub(a);m=d,n=tj(b),x[m>>2]=n;m=e,n=uj(b),x[m>>2]=n;rh(a,b);Ab(f,a);tb(a);ki(a,b);oh(g,a);Ub(k+4|0);a=Ok(b)}x[l>>2]=a;fb=k+16|0}function G2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=fb-16|0;fb=g;e=Jb(b);d=Cb(x[b+4>>2],y[b+11|0]);i=Jb(c);j=Cb(x[c+4>>2],y[c+11|0]);f=-1;a:{if(!d){break a}h=d+e|0;d=e;while(1){if((d|0)==(h|0)){break a}if(Fu(i,j,y[d|0])){d=d+1|0;continue}break}f=d-e|0}b:{c:{if((f|0)!=-1){c=vb(g+12|0,zd(b));d=vb(g+8|0,uf(zd(b),f));cs(b,x[c>>2],x[d>>2]);break c}f=Yc(x[b+4>>2],y[b+11|0]);if(!f){break c}e=Jb(b);i=Cb(x[b+4>>2],y[b+11|0]);j=Jb(c);d=-1;h=Cb(x[c+4>>2],y[c+11|0]);if(h){c=e+i|0;d:{while(1){if((c|0)==(e|0)){break d}c=c-1|0;if(!Fu(j,h,y[c|0])){continue}break}d=c-e|0}}if((f-1|0)!=(d|0)){break c}Fb(a);break b}_c(a,b)}fb=g+16|0}function Aqa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=E(0),g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;c=fb-16|0;fb=c;a:{b:{d=x[b+8>>2];if((d|0)==x[a+8>>2]){e=x[b+4>>2];if((e|0)!=x[a+4>>2]){break b}x[c+12>>2]=d;x[c+8>>2]=d;d=x[Gb(c+12|0,c+8|0)>>2];x[c+12>>2]=e;x[c+8>>2]=e;h=x[Gb(c+12|0,c+8|0)>>2];i=x[a>>2];j=x[b>>2];b=0;c:while(1){if((b|0)==(d|0)){break a}k=(D(b,e)<<1)+i|0;a=0;while(1)if((a|0)==(h|0)){b=b+1|0;continue c}else{l=(a<<1)+k|0;f=ri(E(Pd(B[x[(a<<2)+j>>2]+(b<<2)>>2],E(-1))*E(32768)));d:{if(E(F(f))<E(2147483648)){g=~~f;break d}g=-2147483648}m=l,n=ed(g),w[m>>1]=n;a=a+1|0;continue}}}_(17398,8999,27,9541);p()}_(17348,8999,28,9541);p()}fb=c+16|0}function Eja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=fb-80|0;fb=e;d=Tf(e+52|0);x[31737]=0;g=P(915,b|0,d|0)|0;f=x[31737];x[31737]=0;a:{b:{c:{if((f|0)!=1){if(g){break c}x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[31737]=0;R(916,a|0)|0;a=x[31737];x[31737]=0;if((a|0)!=1){break b}}break a}g=x[d+4>>2];x[31737]=0;f=e+12|0;S(186,f|0,b|0,g|0);h=x[31737];x[31737]=0;if((h|0)==1){break a}h=ic(e+32|0,f);hd(d+8|0,h);ub(h);ub(f);d:{if(!(g&1)|c>>>0<2){break d}x[31737]=0;P(184,b|0,1)|0;b=x[31737];x[31737]=0;if((b|0)!=1){break d}break a}Sk(a,d)}Fd(d);fb=e+80|0;return}a=N()|0;Fd(d);Q(a|0);p()}function k4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;a:{b:{c:{if(ni(b,14337)){d=Ts(c+28|0,b);e=x[d>>2];if(!Dd(e)){x[31737]=0;b=P(36,c+4|0,b|0)|0;a=x[31737];x[31737]=0;if((a|0)==1){break c}x[31737]=0;a=c+16|0;S(1017,a|0,17837,b|0);e=x[31737];x[31737]=0;d:{e:{if((e|0)!=1){x[31737]=0;W(1325,a|0);a=x[31737];x[31737]=0;if((a|0)==1){break e}p()}a=N()|0;break d}a=N()|0;tb(c+16|0)}tb(b);break a}iq(e);if(!Ss(a+8|0,16817,x[d>>2])){v[a+8|0]=v[a+8|0]}if(!Ss(a+9|0,22303,x[d>>2])){v[a+9|0]=v[a+9|0]}x[31737]=0;O(273,a+12|0,22303);a=x[31737];x[31737]=0;if((a|0)==1){break b}nl(d)}fb=c+32|0;return}a=N()|0;break a}a=N()|0}nl(d);Q(a|0);p()}function sla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=fb+-64|0;fb=c;f=AU(a,1<<b-1);x[f+12>>2]=b;l(0,1413754136-0|0);l(1,-1072094725-((b<<20)+(d>>>0>1413754136)|0)|0);h=+n();a=1;g=1<<b>>>2|0;b=g;while(1){if(b){e=x[10085];d=c+32|0;x[d+8>>2]=x[10084];x[d+12>>2]=e;e=x[10083];x[d>>2]=x[10082];x[d+4>>2]=e;PB(d,h*+(b>>>0));vU(c+48|0,C[c+32>>3],C[c+40>>3]);d=Xd(x[f>>2],a);e=x[c+60>>2];x[d+8>>2]=x[c+56>>2];x[d+12>>2]=e;e=x[c+52>>2];x[d>>2]=x[c+48>>2];x[d+4>>2]=e;b=b>>>1|0;a=a<<1;continue}break}a=Wl(c+16|0,1,0);b=x[a+12>>2];x[c+8>>2]=x[a+8>>2];x[c+12>>2]=b;b=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=b;yA(f,0,g,c);fb=c- -64|0;return f|0}function bla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;f=fb-80|0;fb=f;d=Tf(f+52|0);x[31737]=0;c=P(831,b|0,d|0)|0;e=x[31737];x[31737]=0;a:{b:{c:{if((e|0)!=1){if(c){break c}x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[31737]=0;R(832,a|0)|0;a=x[31737];x[31737]=0;if((a|0)!=1){break b}}break a}e=x[d+4>>2];x[31737]=0;c=f+12|0;e=$b(e);S(186,c|0,b|0,e|0);g=x[31737];x[31737]=0;if((g|0)==1){break a}g=ic(f+32|0,c);hd(d+8|0,g);ub(g);ub(c);d:{c=e&1;if(!c){break d}x[31737]=0;P(184,b|0,2-c|0)|0;b=x[31737];x[31737]=0;if((b|0)!=1){break d}break a}Sk(a,d)}Fd(d);fb=f+80|0;return}a=N()|0;Fd(d);Q(a|0);p()}function pba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=fb+-64|0;fb=f;d=f+16|0;h=fb-16|0;fb=h;i=JP(h+8|0);l=f+4|0;while(1){if((j|0)==12){fb=h+16|0}else{g=fb+-64|0;fb=g;c=x[i+4>>2];e=x[i>>2];a:{if((c|0)==(e|0)){break a}c=(c-e|0)+1|0;if(!c){c=RM(SM(g+8|0,32));break a}e=G(c);e=SM(g+8|0,(c<<e&2147483647?32:31)-e|0);while(1){k=RM(e);if(c>>>0<=k>>>0){continue}break}c=x[i>>2]+k|0}fb=g- -64|0;m=yb(d,j),n=c,x[m>>2]=n;j=j+1|0;continue}break}d=WP(l,d,_P(d));TP(a,d);an(d);fb=f- -64|0;d=uz(a+120|0,a,b);v[d+20|0]=1;x[31737]=0;O(1144,a|0,b|0);b=x[31737];x[31737]=0;if((b|0)==1){a=N()|0;xo(d);Q(a|0);p()}return a|0}function _O(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=fb-32|0;fb=e;g=Nb(a);a=z[x[b+24>>2]+480192>>1];x[31737]=0;O(177,g|0,a|0);c=x[31737];x[31737]=0;a=1;a:{if((c|0)!=1){b:{c:{d:{e:{while(1){d=a&65535;c=x[b+24>>2];if(d>>>0>z[c+480192>>1]){break b}c=eS(c,d);x[31737]=0;c=P(36,e+8|0,c|0)|0;d=x[31737];x[31737]=0;if((d|0)!=1){f=x[b+24>>2];x[31737]=0;d=e+20|0;S(1059,d|0,f|0,c|0);f=x[31737];x[31737]=0;if((f|0)==1){break e}x[31737]=0;O(179,g|0,d|0);f=x[31737];x[31737]=0;if((f|0)==1){break d}tb(d);tb(c);a=a+1|0;continue}break}a=N()|0;break a}a=N()|0;break c}a=N()|0;tb(e+20|0)}tb(c);break a}fb=e+32|0;return}a=N()|0}Td(g);Q(a|0);p()}function Tw(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=fb-16|0;fb=f;v[f+15|0]=d;v[b+12|0]=y[b+12|0]&240|y[a|0]&15;i=a+1|0;e=f+15|0;gh(b,y[Qb(i,e)|0]);g=y[Qb(a+2|0,e)|0];v[b+13|0]=g;k=b,l=Kd(y[a+3|0],g,d),v[k+14|0]=l;e=y[Qb(a+4|0,e)|0];v[b+15|0]=e;k=b,l=Kd(y[a+5|0],e,d),v[k+16|0]=l;g=x[b>>2];b=0;while(1){v[f+14|0]=25;if(b>>>0<y[Qb(f+14|0,i)|0]){e=D(b,3)+a|0;h=Yb(y[e+6|0]+c<<24>>24,0,64);d=yb(g,b);v[d+2|0]=h;e=y[e+7|0]|y[e+8|0]<<8;w[d>>1]=e;a:{if(!b){break a}h=yb(g,b-1|0);j=z[h>>1];if(e>>>0>255|e>>>0>=j>>>0){break a}e=e|j&65280;w[d>>1]=e;if(z[h>>1]<=(e&65535)>>>0){break a}w[d>>1]=e+256}b=b+1|0;continue}break}fb=f+16|0}function BN(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;d=fb-16|0;fb=d;a:{b:{c:{d:{if((b|0)>=0){a=x[a+32>>2];if((Ao(a)|0)>(b|0)){break d}}a=ac(8);x[31737]=0;d=P(36,d+4|0,10751)|0;b=x[31737];x[31737]=0;if((b|0)==1){break c}pc(a,d);x[31737]=0;S(98,a|0,48540,1006);a=x[31737];x[31737]=0;if((a|0)!=1){break a}b=N()|0;tb(d);break b}if(c<0|c>1){a=ac(8);x[31737]=0;d=P(36,d+4|0,11768)|0;b=x[31737];x[31737]=0;if((b|0)!=1){pc(a,d);x[31737]=0;S(98,a|0,48540,1006);a=x[31737];x[31737]=0;if((a|0)!=1){break a}b=N()|0;tb(d);break b}b=N()|0;jc(a);break b}e=(a+D(b,872)|0)+1075740|0,f=Zi(c*64),x[e>>2]=f;fb=d+16|0;return}b=N()|0;jc(a)}Q(b|0)}p()}function zqa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=E(0),g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;c=fb-16|0;fb=c;a:{b:{d=x[b+8>>2];if((d|0)==x[a+8>>2]){e=x[b+4>>2];if((e|0)!=x[a+4>>2]){break b}x[c+12>>2]=d;x[c+8>>2]=d;d=x[Gb(c+12|0,c+8|0)>>2];x[c+12>>2]=e;x[c+8>>2]=e;h=x[Gb(c+12|0,c+8|0)>>2];i=x[a>>2];j=x[b>>2];b=0;c:while(1){if((b|0)==(d|0)){break a}k=D(b,e)+i|0;a=0;while(1)if((a|0)==(h|0)){b=b+1|0;continue c}else{l=a+k|0;f=ri(E(Pd(B[x[(a<<2)+j>>2]+(b<<2)>>2],E(-1))*E(128)));d:{if(E(F(f))<E(2147483648)){g=~~f;break d}g=-2147483648}m=l,n=uY(g),v[m|0]=n;a=a+1|0;continue}}}_(17398,8999,27,9541);p()}_(17348,8999,28,9541);p()}fb=c+16|0}function JW(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=fb-16|0;fb=f;d=vb(f+12|0,x[a+4>>2]);c=vb(f+8|0,x[a>>2]);g=x[vb(f+4|0,x[b+4>>2])>>2];h=fb-16|0;fb=h;i=h+8|0;e=fb-32|0;fb=e;Id(e+24|0,x[d>>2],x[c>>2]);j=e+16|0;c=x[e+24>>2];k=x[e+28>>2];d=fb-16|0;fb=d;x[d+8>>2]=g;x[d+12>>2]=c;while(1){if(pd(c,k)){c=il(c);g=il(x[d+8>>2]);x[g+8>>2]=x[c+8>>2];l=x[c+4>>2];x[g>>2]=x[c>>2];x[g+4>>2]=l;c=qk(d+12|0);qk(d+8|0);c=x[c>>2];continue}break}Ac(j,c,d+8|0);fb=d+16|0;d=x[e+16>>2];x[e+12>>2]=x[e+20>>2];Ac(i,d,e+12|0);fb=e+32|0;fb=h+16|0;x[b+4>>2]=x[h+12>>2];Tb(a,b+4|0);Tb(a+4|0,b+8|0);Tb(zb(a),nc(b));x[b>>2]=x[b+4>>2];fb=f+16|0}function ega(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=fb-16|0;fb=e;i=e,j=Xj(b),x[i+4>>2]=j;c=fb-16|0;fb=c;g=a;d=ce(a);a:{if(d){f=ec(a);while(1){a=d;d=a+16|0;if(Tu(b,d)){f=a;d=x[a>>2];if(d){continue}break a}if(!Tu(d,b)){break a}f=a+4|0;d=x[a+4>>2];if(d){continue}break}break a}a=ec(g);f=a}x[c+12>>2]=a;b=x[f>>2];if(!b){a=fb-16|0;fb=a;b=ec(g);b=Bh(c,Ec(40),Mg(a+8|0,b));Fb(_c(x[b>>2]+16|0,x[e+4>>2])+12|0);i=ec(b),j=1,v[i+4|0]=j;fb=a+16|0;$g(g,x[c+12>>2],f,x[c>>2]);b=me(c);a=x[c>>2];x[c>>2]=0;if(a){if(y[ec(c)+4|0]){en(a+16|0)}Db(a)}h=1}_g(e+8|0,x[vb(c,b)>>2],h);fb=c+16|0;a=td(x[e+8>>2]);fb=e+16|0;return a+12|0}function MO(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=fb-32|0;fb=e;g=Nb(a);a=z[x[b+24>>2]+480190>>1];x[31737]=0;O(177,g|0,a|0);c=x[31737];x[31737]=0;a=1;a:{if((c|0)!=1){b:{c:{d:{e:{while(1){d=a&65535;c=x[b+24>>2];if(d>>>0>z[c+480190>>1]){break b}x[31737]=0;c=P(36,e+8|0,fS(c,d)|0)|0;d=x[31737];x[31737]=0;if((d|0)!=1){f=x[b+24>>2];x[31737]=0;d=e+20|0;S(1059,d|0,f|0,c|0);f=x[31737];x[31737]=0;if((f|0)==1){break e}x[31737]=0;O(179,g|0,d|0);f=x[31737];x[31737]=0;if((f|0)==1){break d}tb(d);tb(c);a=a+1|0;continue}break}a=N()|0;break a}a=N()|0;break c}a=N()|0;tb(e+20|0)}tb(c);break a}fb=e+32|0;return}a=N()|0}Td(g);Q(a|0);p()}function J3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;if(mh(a,x[b+8>>2],f)){Px(b,c,d,e);return}g=y[b+53|0];i=x[a+12>>2];v[b+53|0]=0;h=y[b+52|0];v[b+52|0]=0;Lx(x[a+16>>2],x[a+20>>2],b,c,d,e,f);j=y[b+52|0];h=(h|j)!=0;k=y[b+53|0];l=(g|k)!=0;g=a+24|0;i=(a+16|0)+(i<<3)|0;a:{if(g>>>0>=i>>>0){break a}while(1){if(y[b+54|0]){break a}b:{if(j){if(x[b+24>>2]==1){break a}if(y[a+8|0]&2){break b}break a}if(!k){break b}if(!(v[a+8|0]&1)){break a}}w[b+52>>1]=0;Lx(x[g>>2],x[g+4>>2],b,c,d,e,f);k=y[b+53|0];l=(k|l)!=0;j=y[b+52|0];h=(j|h)!=0;g=g+8|0;if(i>>>0>g>>>0){continue}break}}v[b+53|0]=l;v[b+52|0]=h}function VY(a){var b=0,c=0,d=0,e=0,f=0;b=fb-32|0;fb=b;e=b,f=$b(y[a+8|0]|y[a+9|0]<<8|(y[a+10|0]<<16|y[a+11|0]<<24))+788|0,x[e>>2]=f;x[b+4>>2]=0;e=b,f=$b(y[a+16|0]|y[a+17|0]<<8|(y[a+18|0]<<16|y[a+19|0]<<24)),x[e+8>>2]=f;x[b+12>>2]=0;c=$b(y[a+24|0]|y[a+25|0]<<8|(y[a+26|0]<<16|y[a+27|0]<<24));x[b+16>>2]=c?c:52;x[b+20>>2]=0;e=b,f=$b(y[a+32|0]|y[a+33|0]<<8|(y[a+34|0]<<16|y[a+35|0]<<24))+80|0,x[e+24>>2]=f;x[b+28>>2]=0;a=b;d=Ue(a,4);a:{if((a|0)==(d|0)){break a}c=a;while(1){c=c+8|0;if((d|0)==(c|0)){break a}a=Nw(x[a>>2],x[a+4>>2],x[c>>2],x[c+4>>2])?c:a;continue}}fb=b+32|0;c=x[a>>2];b=c-52|0;hb=x[a+4>>2]-(c>>>0<52)|0;return b}function hpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=fb-32|0;fb=d;ld(b,0);f=d+8|0;jk(f,1,a);c=d+20|0;Cc(c,f);ze(b+43|0,c);tb(c);x[b>>2]=y[a+48|0]|y[a+49|0]<<8|(y[a+50|0]<<16|y[a+51|0]<<24);x[b+4>>2]=y[a+52|0]|y[a+53|0]<<8|(y[a+54|0]<<16|y[a+55|0]<<24);x[b+8>>2]=y[a+56|0]|y[a+57|0]<<8|(y[a+58|0]<<16|y[a+59|0]<<24);x[b+24>>2]=y[a+62|0]|y[a+63|0]<<8;gm(b,+((y[a+60|0]^8)-120|0)/192);v[d+20|0]=y[a+61|0];v[d+8|0]=64;g=b,h=y[Qb(c,f)|0]<<2,w[g+30>>1]=h;w[b+34>>1]=0;c=y[a+47|0];if(c&4){w[b+34>>1]=1;x[b>>2]=x[b>>2]>>>1;e=1;c=y[a+47|0]}if(c&32){e=e|4;w[b+34>>1]=e;c=y[a+47|0]}if(c<<24>>24<0){w[b+34>>1]=e|2}fb=d+32|0}
function goa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;g=fb-16|0;fb=g;a:{if(!(c&1024)){break a}i=g,j=zd(b),x[i+12>>2]=j;c=Yc(x[b+4>>2],y[b+11|0]);b:{if(!c){break b}if(y[cc(b,0)|0]!=43){if(y[cc(b,0)|0]!=45){break b}}d=d+1|0;vV(g+12|0)}if(c>>>0>=d>>>0){break a}e=x[vb(g+8|0,x[g+12>>2])>>2];c=d-Yc(x[b+4>>2],y[b+11|0])|0;c:{e=Fk(e,zd(b));d=Cb(x[b+4>>2],y[b+11|0]);if(e>>>0<=d>>>0){if(c){f=Mc(b);d:{if(c>>>0<=f-d>>>0){f=Jb(b);if((d|0)==(e|0)){break d}h=e+f|0;Ui(c+h|0,h,d-e|0);break d}ZB(b,f,(c+d|0)-f|0,d,e,c);f=x[b>>2]}hm(e+f|0,c,48);c=c+d|0;ng(b,c);fd(c+f|0,0)}break c}jn();p()}zd(b)}_c(a,b);fb=g+16|0}function qV(a,b,c){a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{b=b&15;switch(b-3|0){case 2:break j;case 1:break k;case 0:break l;case 10:case 11:break b;case 9:break c;case 8:break d;case 7:break e;case 6:break f;case 5:break g;case 4:break h;case 3:break i;default:break a}}v[a+798|0]=0;return}v[a+798|0]=1;return}v[a+798|0]=2;return}v[a+798|0]=3;return}v[a+730|0]=y[a+730|0]&254;return}v[a+730|0]=y[a+730|0]|1;return}v[a+738|0]=y[a+738|0]&254;return}v[a+738|0]=y[a+738|0]|1;return}v[a+746|0]=y[a+746|0]&254;return}v[a+746|0]=y[a+746|0]|1;return}if((c|0)!=16777216){break a}c=a;a=y[a+746|0];v[c+746|0]=(b|0)==13?a&238|1:a|17}}function kn(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0;j=1;i=d&2147483647;k=i;l=(i|0)==2147418112;a:{if(l&!c?a|b:l&(c|0)!=0|i>>>0>2147418112){break a}i=h&2147483647;if(!g&(i|0)==2147418112?e|f:(i|0)==2147418112&(g|0)!=0|i>>>0>2147418112){break a}if(!(a|e|(c|g)|(b|f|(i|k)))){return 0}j=d&h;if((j|0)>0){k=1}else{k=(j|0)>=0}if(k){j=-1;if((c|0)==(g|0)&(d|0)==(h|0)?(b|0)==(f|0)&a>>>0<e>>>0|b>>>0<f>>>0:c>>>0<g>>>0&(d|0)<=(h|0)|(d|0)<(h|0)){break a}return(a^e|c^g|(b^f|d^h))!=0}j=-1;if((c|0)==(g|0)&(d|0)==(h|0)?(b|0)==(f|0)&a>>>0>e>>>0|b>>>0>f>>>0:c>>>0>g>>>0&(d|0)>=(h|0)|(d|0)>(h|0)){break a}j=(a^e|c^g|(b^f|d^h))!=0}return j}function Jua(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=fb-208|0;fb=d;L0(c,a);K0(c,d+16|0,D(y[a+4|0],3));a:{if(y[a+4|0]<2){break a}c=fb-16|0;fb=c;x[c+12>>2]=64;x[c+8>>2]=255;e=y[Gb(c+12|0,c+8|0)|0];fb=c+16|0;v[d+12|0]=e;gh(b,y[Qb(a+4|0,d+12|0)|0]);v[b+13|0]=y[a+2|0];v[b+14|0]=y[a+3|0];a=y[a+1|0];v[b+15|0]=a;v[b+16|0]=a;e=x[b>>2];f=Sd(e,x[b+4>>2]);a=0;while(1){if((a|0)==(f|0)){break a}b:{if(!a){b=y[d+18|0];c=yb(e,0);break b}g=z[yb(e,a-1|0)>>1];x[d+12>>2]=1;b=(d+16|0)+D(a,3)|0;x[d+8>>2]=(v[b+1|0]&1)<<8|y[b|0];h=Ye(d+12|0,d+8|0);c=yb(e,a);w[c>>1]=z[h>>1]+g;b=y[b+2|0]}v[c+2|0]=b;a=a+1|0;continue}}fb=d+208|0}function BD(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=fb-16|0;fb=e;d=(c<<3)+a|0;f=y[d+356|0];v[b+12|0]=y[b+12|0]&248|f&1|f<<1&4|f>>>1&2;gh(b,Kd(y[d+352|0],2,16));v[b+13|0]=y[d+354|0];v[b+14|0]=y[d+355|0];d=y[d+353|0];v[b+15|0]=d;v[b+16|0]=d;d=0;w[e+14>>1]=0;f=((c|0)!=0)<<1;h=x[b>>2];j=Sd(h,x[b+4>>2]);k=(c<<6)+a|0;c=((c|0)==2?-1:0)&255;while(1){if((d|0)==(j|0)){AD(b,32);fb=e+16|0}else{a=k+(d<<2)|0;w[e+12>>1]=y[a+160|0]|y[a+161|0]<<8;g=pe(e+14|0,e+12|0);i=yb(h,d);g=z[g>>1];w[i>>1]=g;w[e+14>>1]=g+1;v[e+11|0]=(c^y[a+162|0])>>>f;v[e+10|0]=64;l=i,m=y[Qb(e+11|0,e+10|0)|0],v[l+2|0]=m;d=d+1|0;continue}break}}function dka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=fb-16|0;fb=g;f=c;e=fb-16|0;fb=e;h=b;d=ce(b);a:{if(d){c=ec(b);while(1){b=d;d=b+16|0;if(MR(f,d)){c=b;d=x[b>>2];if(d){continue}break a}if(!MR(d,f)){break a}c=b+4|0;d=x[b+4>>2];if(d){continue}break}break a}b=ec(h);c=b}x[e+12>>2]=b;b=x[c>>2];if(!b){b=fb-16|0;fb=b;d=ec(h);d=Bh(e,Ec(28),Mg(b+8|0,d));i=x[d>>2];x[31737]=0;O(893,i+16|0,f|0);f=x[31737];x[31737]=0;b:{if((f|0)!=1){j=ec(d),k=1,v[j+4|0]=k;fb=b+16|0;break b}a=N()|0;LR(d);Q(a|0);p()}$g(h,x[e+12>>2],c,x[e>>2]);b=me(e);LR(e);i=1}c=g+8|0;_g(c,x[vb(e,b)>>2],i);fb=e+16|0;oV(a,c);fb=g+16|0}function Bsa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=fb-80|0;fb=d;e=Tf(d+52|0);x[31737]=0;c=P(411,b|0,e|0)|0;f=x[31737];x[31737]=0;a:{b:{c:{d:{if((f|0)!=1){if(c){break d}x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[31737]=0;R(412,a|0)|0;a=x[31737];x[31737]=0;if((a|0)!=1){break a}}break c}c=fb-16|0;fb=c;g=c,h=$b(x[e+4>>2]),x[g+12>>2]=h;x[c+8>>2]=8;f=ad(c+12|0,c+8|0);fb=c+16|0;c=x[f>>2]-8|0;x[31737]=0;S(186,d+12|0,b|0,c|0);b=x[31737];x[31737]=0;if((b|0)!=1){break b}}a=N()|0;Fd(e);Q(a|0);p()}b=d+12|0;c=ic(d+32|0,b);hd(e+8|0,c);ub(c);ub(b);Sk(a,e)}Fd(e);fb=d+80|0}function vka(a){a=a|0;var b=0,c=0,d=0;c=a+1298224|0;b=a+1074992|0;while(1){if((b|0)==(c|0)){Cu(a+484344|0);sf(a+1298308|0);sf(a+1298320|0);sf(a+1298332|0);gw(a+1298412|0);b=a+900380|0;c=a+484380|0;while(1){if((b|0)==(c|0)){a:{c=a+901404|0;while(1){if((b|0)==(c|0)){b=a+906300|0;c=Ak(b);while(1){if((b|0)==(c|0)){break a}t0(b);b=b+160|0;continue}}d=x[b>>2];if(d){Db(Hv(d))}x[b>>2]=0;b=b+4|0;continue}}}else{sn(c);c=c+104|0;continue}break}x[a+480180>>2]=0;x[a+480184>>2]=0;a=a+480186|0;w[a>>1]=0;w[a+2>>1]=0;w[a+4>>1]=0;w[a+6>>1]=0}else{x[b+104>>2]=0;x[b+656>>2]=0;x[b+76>>2]=0;x[b+16>>2]=0;b=b+872|0;continue}break}}function xt(a,b,c,d){var e=0,f=0,g=0,h=0;g=d?d:500132;d=x[g>>2];a:{b:{c:{if(!b){if(d){break c}return 0}e=-2;if(!c){break b}d:{if(d){e=c;break d}d=y[b|0];f=d<<24>>24;if((f|0)>=0){if(a){x[a>>2]=d}return(f|0)!=0}if(!x[x[124243]>>2]){e=1;if(!a){break b}x[a>>2]=f&57343;return 1}d=d-194|0;if(d>>>0>50){break c}d=x[(d<<2)+111568>>2];e=c-1|0;if(!e){break a}b=b+1|0}f=y[b|0];h=f>>>3|0;if((h-16|(d>>26)+h)>>>0>7){break c}while(1){e=e-1|0;d=f-128|d<<6;if((d|0)>=0){x[g>>2]=0;if(a){x[a>>2]=d}return c-e|0}if(!e){break a}b=b+1|0;f=y[b|0];if((f&192)==128){continue}break}}x[g>>2]=0;x[31612]=25;e=-1}return e}x[g>>2]=d;return-2}function Gta(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;f=fb-32|0;fb=f;e=b;b=x[a>>2];b=Fk(e,wb(b))+b|0;e=YD(c,d);a:{if((e|0)<=0){break a}g=x[zb(a)>>2];h=x[a+4>>2];if((e|0)<=(g-h|0)){x[f+12>>2]=d;g=h-b|0;if((g|0)<(e|0)){x[f+12>>2]=c;j$(f+12|0,g);XD(a,x[f+12>>2],d,e-g|0);if((g|0)<=0){break a}}i$(a,b,h,b+e|0);Br(c,x[f+12>>2],b);break a}g=zb(a);h=un(f+12|0,bm(a,Vc(x[a>>2],h)+e|0),b-x[a>>2]|0,g);e=fb-16|0;fb=e;x[e+12>>2]=c;c=yC(e,h+8|0,YD(c,d));d=x[c>>2];while(1){if(x[c+4>>2]!=(d|0)){Dl(d,y[x[e+12>>2]]);d=x[c>>2]+1|0;x[c>>2]=d;le(e+12|0);continue}break}he(c);fb=e+16|0;b=h$(a,h,b);tn(h)}wb(b);fb=f+32|0}function PA(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=fb-16|0;fb=e;b=x[a>>2];if(!mc(b,x[a+4>>2])){b=wb(b);x[e+12>>2]=b;f=wb(x[a+4>>2]);while(1){if(Ib(b,f)){Kp(b,4194304,67108864);b=x[b>>2];d=b+d|0;c=b>>>0>d>>>0?c+1|0:c;b=x[Je(e+12|0)>>2];continue}else{b=x[a>>2];f=oc(b,x[a+4>>2]);b=wb(b);x[e+8>>2]=b;g=f<<24;d=Uua(d,c,f,0);h=((hb&1)<<31|d>>>1)&2147483647;i=wb(x[a+4>>2]);while(1){if(Ib(b,i)){f=b;b=x[b>>2];c=b>>>8|0;b=h+(b<<24)|0;c=c+j|0;c=Bc(Uua(b,b>>>0<h>>>0?c+1|0:c,d,j),hb);x[f>>2]=c;g=g-c|0;b=x[Je(e+8|0)>>2];continue}else{c=x[a>>2];if(!oc(c,x[a+4>>2])){Ew();p()}x[c>>2]=x[c>>2]+g}break}}break}}fb=e+16|0}function CQ(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=fb-16|0;fb=e;nh(e+8|0,b);f=fb-16|0;fb=f;lf(f+8|0,x[e+8>>2],x[e+12>>2]);g=x[f+8>>2];b=x[f+12>>2];h=fb-16|0;fb=h;l=h,m=wb(a),x[l+12>>2]=m;a=b;b=fb-16|0;fb=b;i=x[h+12>>2];c=i;d=x[c+8>>2];c=x[c+12>>2];a:{if((c|0)<0){break a}j=x[i+4>>2];k=d>>>0>j>>>0;if(k&!c|c){break a}x[b+8>>2]=j-d;x[b+12>>2]=0-(c+k|0);x[b>>2]=a;x[b+4>>2]=0;c=J0(b+8|0,b);if((Su(x[c>>2],x[c+4>>2])|0)!=(a|0)){break a}Wg(g,a+g|0,d+x[i>>2]|0);d=x[h+12>>2];g=d;c=x[d+8>>2];d=x[d+12>>2];i=a;a=a+c|0;d=i>>>0>a>>>0?d+1|0:d;x[g+8>>2]=a;x[g+12>>2]=d}fb=b+16|0;fb=h+16|0;fb=f+16|0;fb=e+16|0}function Si(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;j=c*d;k=b*e;h=j+k;l=b*d;m=c*e;i=l-m;a:{if(!Vi(i)){break a}if(!Vi(h)){break a}f=zf(b);g=zf(c);n=f|g;b:{if((n|0)!=1){break b}b=pi(f?1:0,b);c=pi(g?1:0,c);if(Vi(d)){d=pi(0,d)}if(!Vi(e)){break b}e=pi(0,e)}f=zf(d);g=zf(e);c:{if(f|g){d=pi(f?1:0,d);e=pi(g?1:0,e);if(Vi(b)){b=pi(0,b)}if(!Vi(c)){break c}c=pi(0,c);break c}if(n){break c}d:{if(zf(l)){break d}if(zf(m)){break d}if(zf(k)){break d}if(!zf(j)){break a}}if(Vi(b)){b=pi(0,b)}if(Vi(c)){c=pi(0,c)}if(Vi(d)){d=pi(0,d)}if(!Vi(e)){break c}e=pi(0,e)}h=(b*e+d*c)*Infinity;i=(b*d-e*c)*Infinity}Wl(a,i,h)}function NB(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=fb-16|0;fb=f;c=vb(f+12|0,x[a+4>>2]);d=vb(f+8|0,x[a>>2]);g=x[vb(f+4|0,x[b+4>>2])>>2];h=fb-16|0;fb=h;i=h+8|0;e=fb-32|0;fb=e;Id(e+24|0,x[c>>2],x[d>>2]);j=e+16|0;d=x[e+24>>2];k=x[e+28>>2];c=fb-16|0;fb=c;x[c+8>>2]=g;x[c+12>>2]=d;while(1){if(pd(d,k)){d=Op(d);g=Op(x[c+8>>2]);l=x[d+4>>2];x[g>>2]=x[d>>2];x[g+4>>2]=l;d=Np(c+12|0);Np(c+8|0);d=x[d>>2];continue}break}Ac(j,d,c+8|0);fb=c+16|0;c=x[e+16>>2];x[e+12>>2]=x[e+20>>2];Ac(i,c,e+12|0);fb=e+32|0;fb=h+16|0;x[b+4>>2]=x[h+12>>2];Tb(a,b+4|0);Tb(a+4|0,b+8|0);Tb(zb(a),nc(b));x[b>>2]=x[b+4>>2];fb=f+16|0}function Hi(a,b,c,d){var e=0,f=0,g=0;e=fb-48|0;fb=e;f=x[x[a>>2]-12>>2]+a|0;g=x[f+16>>2]&-3;kg(f,g);a:{b:{if(Gd(y[Lm(e+47|0,a,1)|0])){f=x[(x[x[a>>2]-12>>2]+a|0)+24>>2];x[31737]=0;Ps(87,e+24|0,f,b,c,d);b=x[31737];x[31737]=0;c:{if((b|0)!=1){b=gi(e+8|0,-1,-1);d=eo(x[e+32>>2],x[e+36>>2],x[b+8>>2],x[b+12>>2])?g|4:g;break c}Y(T(0)|0)|0;d=g|1;Jm(x[x[a>>2]-12>>2]+a|0,d);if(x[(x[x[a>>2]-12>>2]+a|0)+20>>2]&1){x[31737]=0;X(85);a=x[31737];x[31737]=0;if((a|0)!=1){break a}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)==1){break b}Q(a|0);p()}Z()}bk(x[x[a>>2]-12>>2]+a|0,d)}fb=e+48|0;return a}T(0)|0;Sb()}p()}function Xqa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=fb-16|0;fb=e;i=e,j=Xj(b),x[i+4>>2]=j;f=z[b>>1];d=fb-16|0;fb=d;g=a;c=ce(a);a:{if(c){b=ec(a);while(1){a=c;c=z[a+14>>1];if(cp(f,c)){b=a;c=x[a>>2];if(c){continue}break a}if(!cp(c,f)){break a}b=a+4|0;c=x[a+4>>2];if(c){continue}break}break a}a=ec(g);b=a}x[d+12>>2]=a;a=x[b>>2];if(!a){a=fb-16|0;fb=a;c=ec(g);f=Bh(d,Ec(20),Mg(a+8|0,c));c=x[f>>2];h=z[x[e+4>>2]>>1];w[c+16>>1]=0;w[c+14>>1]=h;i=ec(f),j=1,v[i+4|0]=j;fb=a+16|0;$g(g,x[d+12>>2],b,x[d>>2]);a=me(d);dm(d);h=1}_g(e+8|0,x[vb(d,a)>>2],h);fb=d+16|0;a=hp(x[e+8>>2]);fb=e+16|0;return a+2|0}function n_(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=fb-16|0;fb=e;i=e,j=Xj(b),x[i+4>>2]=j;f=x[b>>2];d=fb-16|0;fb=d;g=a;c=ce(a);a:{if(c){b=ec(a);while(1){a=c;c=x[a+16>>2];if(qE(f,c)){b=a;c=x[a>>2];if(c){continue}break a}if(!qE(c,f)){break a}b=a+4|0;c=x[a+4>>2];if(c){continue}break}break a}a=ec(g);b=a}x[d+12>>2]=a;a=x[b>>2];if(!a){a=fb-16|0;fb=a;c=ec(g);f=Bh(d,Ec(24),Mg(a+8|0,c));c=x[f>>2];h=x[x[e+4>>2]>>2];x[c+20>>2]=0;x[c+16>>2]=h;i=ec(f),j=1,v[i+4|0]=j;fb=a+16|0;$g(g,x[d+12>>2],b,x[d>>2]);a=me(d);dm(d);h=1}_g(e+8|0,x[vb(d,a)>>2],h);fb=d+16|0;a=td(x[e+8>>2]);fb=e+16|0;return a+4|0}function DL(a,b,c,d,e){var f=0,g=0,h=0,i=0;f=fb-208|0;fb=f;x[f+204>>2]=c;c=f+160|0;Rb(c,0,40);x[f+200>>2]=x[f+204>>2];a:{if((CL(0,b,f+200|0,f+80|0,c,d,e)|0)<0){e=-1;break a}i=x[a+76>>2]<0;g=x[a>>2];x[a>>2]=g&-33;b:{c:{d:{if(!x[a+48>>2]){x[a+48>>2]=80;x[a+28>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;h=x[a+44>>2];x[a+44>>2]=f;break d}if(x[a+16>>2]){break c}}c=-1;if(lF(a)){break b}}c=CL(a,b,f+200|0,f+80|0,f+160|0,d,e)}if(h){ib[x[a+36>>2]](a,0,0)|0;x[a+48>>2]=0;x[a+44>>2]=h;x[a+28>>2]=0;b=x[a+20>>2];x[a+16>>2]=0;x[a+20>>2]=0;c=b?c:-1}b=a;a=x[a>>2];x[b>>2]=a|g&32;e=a&32?-1:c;if(i){break a}}fb=f+208|0;return e}function SS(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;d=fb-16|0;fb=d;a:{if(x[a+480180>>2]!=1){break a}c=y[b+846|0];if(!c){break a}e=x[b+104>>2];if(!e){break a}if(!je(x[e>>2],x[e+20>>2])){break a}f=z[e+34>>1];if(!(f&10)){break a}c=y[b+847|0]+y[(c&15)+31712|0]|0;v[b+847|0]=c;if(c<<24>>24>=0){break a}v[b+847|0]=0;h=f&2;c=x[(h?4:12)+e>>2];g=b;b=x[b+760>>2]+1|0;b=b>>>0<x[(h?8:16)+e>>2]-c>>>0?b:0;x[g+760>>2]=b;g=x[e+20>>2];c=b+c|0;b=cl(f);bc(d+8|0,g+D(c,b)|0,b);b=wb(x[d+8>>2]);x[d+4>>2]=b;f=Wk(x[d+8>>2],x[d+12>>2]);while(1){if(Ib(b,f)){v[b|0]=y[b|0]^-1;b=x[le(d+4|0)>>2];continue}else{Pj(e,a)}break}}fb=d+16|0}function Rt(a,b,c){var d=0,e=0;d=a,e=Bj(E(E(B[c+1792>>2]*E(75038))+E(E(E(B[c+2048>>2]-B[c+1536>>2])*E(37489))+E(E(E(B[c+1280>>2]+B[c+2304>>2])*E(6574))+E(E(E(B[c+2560>>2]-B[c+1024>>2])*E(5153))+E(E(E(B[c+768>>2]+B[c+2816>>2])*E(2037))+E(E(E(B[c+3072>>2]-B[c+512>>2])*E(459))+E(E(E(B[c+256>>2]+B[c+3328>>2])*E(213))+E(E(B[c+3584>>2]-B[c>>2])*E(29)))))))))),w[d>>1]=e;d=(b<<5)+a|0,e=Bj(E(E(B[c+8>>2]*E(-5))+E(E(B[c+520>>2]*E(146))+E(E(B[c+1032>>2]*E(-45))+E(E(B[c+1544>>2]*E(-9975))+E(E(B[c+2056>>2]*E(64019))+E(E(B[c+2568>>2]*E(9727))+E(E(B[c+3080>>2]*E(1567))+E(B[c+3592>>2]*E(104)))))))))),w[d>>1]=e}function rga(a,b,c){a=a|0;b=+b;c=c|0;var d=0,e=0,f=0;d=fb-80|0;fb=d;x[d+76>>2]=c;c=x[a>>2];e=x[a+4>>2];f=x[a+12>>2];x[d+48>>2]=x[a+8>>2];x[d+52>>2]=f;x[d+40>>2]=c;x[d+44>>2]=e;a=Nd(d+32|0);c=x[d+52>>2];x[d+16>>2]=x[d+48>>2];x[d+20>>2]=c;x[31737]=0;c=x[d+44>>2];x[d+8>>2]=x[d+40>>2];x[d+12>>2]=c;c=x[a+4>>2];x[d>>2]=x[a>>2];x[d+4>>2]=c;a=d+56|0;S(986,a|0,d+8|0,d|0);c=x[31737];x[31737]=0;a:{b:{if((c|0)!=1){c=d+76|0;e=x[qe(d+28|0,c)>>2];x[31737]=0;b=+pa(987,a|0,+b,e|0);e=x[31737];x[31737]=0;if((e|0)==1){break b}ub(a);Uc(c);fb=d+80|0;return+b}a=N()|0;break a}a=N()|0;ub(d+56|0)}Uc(d+76|0);Q(a|0);p()}function tX(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=fb-16|0;fb=c;x[a>>2]=0;x[a+4>>2]=0;Fc(a+8|0,0);d=x[b+4>>2];if(d){$r(a,d);rn(c+8|0,x[b>>2]);dr(c,x[b>>2],x[b+4>>2]);b=fb-32|0;fb=b;d=x[c+8>>2];j=x[c>>2];e=x[a+4>>2];g=x[c+12>>2];k=x[c+4>>2];f=e+rX(d,g,j,k)|0;x[a+4>>2]=f;a:{b:{if(!e){h=f-1|0;break b}h=f-1|0;if((h^e-1)>>>0>31){break b}x[b+24>>2]=d;x[b+28>>2]=g;i=x[a>>2];break a}i=x[a>>2];x[i+((f>>>0>=33?h>>>5|0:0)<<2)>>2]=0;x[b+24>>2]=d;x[b+28>>2]=g}Dp(b+16|0,i,e);d=x[b+28>>2];x[b>>2]=x[b+24>>2];x[b+4>>2]=d;sX(b+8|0,b,j,k,x[b+16>>2],x[b+20>>2]);fb=b+32|0}fb=c+16|0;return a|0}function ypa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=fb-32|0;fb=e;a:{c=x[a+12>>2];b:{if((c|0)==(b|0)){break b}f=b>>>0>c>>>0;c=D(z[x[x[a+48>>2]+12>>2]+480188>>1],f?b-c|0:c-b|0);d=wb(x[a+4>>2]);c:{if(f){d=vb(e+28|0,d);w[e+24>>1]=0;x[e+20>>2]=0;d=x[d>>2];x[31737]=0;V(664,a|0,d|0,c|0,e+20|0);c=x[31737];x[31737]=0;if((c|0)!=1){break c}a=T(125048)|0;if((gb|0)!=($(125048)|0)){break a}Y(a|0)|0;Z();break b}c=vb(e+16|0,MD(d,c));d=x[vb(e+12|0,wb(x[a+4>>2]))>>2];f=x[c>>2];c=x[a>>2];c=D(wu(f,wb(c)),6)+c|0;if(Ib(f,d)){sD(a,tA(c+D(wu(d,f),6)|0,x[a+4>>2],c))}wb(c)}x[a+12>>2]=b}fb=e+32|0;return}Q(a|0);p()}function qy(a,b,c,d,e){var f=0,g=0,h=0;f=fb-16|0;fb=f;h=f+12|0;bd(h,b);x[31737]=0;b=R(1211,x[f+12>>2])|0;g=x[31737];x[31737]=0;a:{if((g|0)==1){break a}x[31737]=0;V(1222,b|0,111776,111808,c|0);b=x[31737];x[31737]=0;if((b|0)==1){break a}x[31737]=0;b=R(1212,x[f+12>>2])|0;c=x[31737];x[31737]=0;if((c|0)==1){break a}x[31737]=0;c=R(1223,b|0)|0;g=x[31737];x[31737]=0;if((g|0)==1){break a}x[d>>2]=c;x[31737]=0;c=R(1220,b|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break a}x[e>>2]=c;x[31737]=0;O(1221,a|0,b|0);a=x[31737];x[31737]=0;if((a|0)==1){break a}Zb(h);fb=f+16|0;return}a=N()|0;Zb(f+12|0);Q(a|0);p()}function mA(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=E(0);f=fb-16|0;fb=f;c=vb(f+12|0,x[a+4>>2]);d=vb(f+8|0,x[a>>2]);h=x[vb(f+4|0,x[b+4>>2])>>2];g=fb-16|0;fb=g;i=g+8|0;e=fb-32|0;fb=e;Id(e+24|0,x[c>>2],x[d>>2]);j=e+16|0;d=x[e+24>>2];k=x[e+28>>2];c=fb-16|0;fb=c;x[c+8>>2]=h;x[c+12>>2]=d;while(1){if(pd(d,k)){d=xf(d);l=xf(x[c+8>>2]),m=B[d>>2],B[l>>2]=m;d=Mi(c+12|0);Mi(c+8|0);d=x[d>>2];continue}break}Ac(j,d,c+8|0);fb=c+16|0;c=x[e+16>>2];x[e+12>>2]=x[e+20>>2];Ac(i,c,e+12|0);fb=e+32|0;fb=g+16|0;x[b+4>>2]=x[g+12>>2];Tb(a,b+4|0);Tb(a+4|0,b+8|0);Tb(zb(a),nc(b));x[b>>2]=x[b+4>>2];fb=f+16|0}function lna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=fb-16|0;fb=b;i=x[a+24>>2];j=x[a+20>>2];k=x[a+16>>2];f=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=f;f=x[a+8>>2];l=x[a+12>>2];while(1){if(d){e=x[b+8>>2];m=e>>>18|0;n=((((x[b+12>>2]&2147483647)<<1|e>>>31)&2147483646)<<1)+k|0;e=0;while(1){if((e|0)!=2){g=(e<<1)+n|0;h=w[g>>1];x[(e<<2)+b>>2]=h+((D(w[g+4>>1]-h|0,m)|0)/16384|0);e=e+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[b>>2],j);x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],i);Pb(b+8|0,f,l);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;fb=b+16|0}function f8(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=fb-32|0;fb=f;x[f+28>>2]=b;a:{if(!(v[c+4|0]&1)){c=ib[x[x[a>>2]+24>>2]](a,b,c,d,e)|0;break a}a=f+16|0;bd(a,x[c+28>>2]);x[31737]=0;b=R(1212,x[f+16>>2])|0;c=x[31737];x[31737]=0;b:{if((c|0)!=1){Zb(a);c:{if(e){ki(a,b);break c}ji(f+16|0,b)}g=f,h=zd(f+16|0),x[g+12>>2]=h;while(1){a=f+16|0;b=sl(a);c=x[f+12>>2];if(!Ib(c,b)){c=x[f+28>>2];Ub(a);break a}a=x[c>>2];x[31737]=0;P(1226,f+28|0,a|0)|0;a=x[31737];x[31737]=0;if((a|0)!=1){Je(f+12|0);continue}break}c=N()|0;Ub(f+16|0);break b}c=N()|0;Zb(f+16|0)}Q(c|0);p()}fb=f+32|0;return c|0}function wH(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=fb-16|0;fb=g;e=g+4|0;v[e+8|0]=1;x[e+4>>2]=c;x[e>>2]=a;h=y[e+8|0];a=x[e>>2];i=x[e+4>>2];j=Jb(b);b=Cb(x[b+4>>2],y[b+11|0]);d=fb-16|0;fb=d;x[d+8>>2]=b;x[d+12>>2]=i;b=a;e=x[Gb(d+12|0,d+8|0)>>2];f=e;while(1){a:{if(!f){f=0;break a}c=y[j|0];v[b|0]=c;if(!c){break a}j=j+1|0;b=b+1|0;f=f-1|0;continue}break}b:{if((h-1&255)>>>0<=1){v[d+7|0]=0;Vm(b,((b+i|0)-e|0)+f|0,d+7|0);break b}if((h-3&255)>>>0>1){break b}v[d+6|0]=32;Vm(b,((b+i|0)-e|0)+f|0,d+6|0)}c:{switch(h-1|0){case 0:case 3:v[(x[d+12>>2]+a|0)-1|0]=0;break;default:break c}}fb=d+16|0;fb=g+16|0}function wy(a,b,c,d,e){var f=0,g=0,h=0;f=fb-16|0;fb=f;h=f+12|0;bd(h,b);x[31737]=0;b=R(28,x[f+12>>2])|0;g=x[31737];x[31737]=0;a:{if((g|0)==1){break a}x[31737]=0;V(1209,b|0,111776,111808,c|0);b=x[31737];x[31737]=0;if((b|0)==1){break a}x[31737]=0;b=R(1195,x[f+12>>2])|0;c=x[31737];x[31737]=0;if((c|0)==1){break a}x[31737]=0;c=R(1210,b|0)|0;g=x[31737];x[31737]=0;if((g|0)==1){break a}v[d|0]=c;x[31737]=0;c=R(1207,b|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break a}v[e|0]=c;x[31737]=0;O(1208,a|0,b|0);a=x[31737];x[31737]=0;if((a|0)==1){break a}Zb(h);fb=f+16|0;return}a=N()|0;Zb(f+12|0);Q(a|0);p()}function p8(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=fb-32|0;fb=f;x[f+28>>2]=b;a:{if(!(v[c+4|0]&1)){c=ib[x[x[a>>2]+24>>2]](a,b,c,d,e)|0;break a}a=f+16|0;bd(a,x[c+28>>2]);x[31737]=0;b=R(1195,x[f+16>>2])|0;c=x[31737];x[31737]=0;b:{if((c|0)!=1){Zb(a);c:{if(e){ki(a,b);break c}ji(f+16|0,b)}g=f,h=zd(f+16|0),x[g+12>>2]=h;while(1){a=f+16|0;b=Df(a);c=x[f+12>>2];if(!Ib(c,b)){c=x[f+28>>2];tb(a);break a}a=v[c|0];x[31737]=0;P(30,f+28|0,a|0)|0;a=x[31737];x[31737]=0;if((a|0)!=1){le(f+12|0);continue}break}c=N()|0;tb(f+16|0);break b}c=N()|0;Zb(f+16|0)}Q(c|0);p()}fb=f+32|0;return c|0}function Ym(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=fb-16|0;fb=f;c=vb(f+12|0,x[a+4>>2]);d=vb(f+8|0,x[a>>2]);h=x[vb(f+4|0,x[b+4>>2])>>2];g=fb-16|0;fb=g;i=g+8|0;e=fb-32|0;fb=e;Id(e+24|0,x[c>>2],x[d>>2]);j=e+16|0;d=x[e+24>>2];k=x[e+28>>2];c=fb-16|0;fb=c;x[c+8>>2]=h;x[c+12>>2]=d;while(1){if(pd(d,k)){d=xf(d);l=xf(x[c+8>>2]),m=x[d>>2],x[l>>2]=m;d=Mi(c+12|0);Mi(c+8|0);d=x[d>>2];continue}break}Ac(j,d,c+8|0);fb=c+16|0;c=x[e+16>>2];x[e+12>>2]=x[e+20>>2];Ac(i,c,e+12|0);fb=e+32|0;fb=g+16|0;x[b+4>>2]=x[g+12>>2];Tb(a,b+4|0);Tb(a+4|0,b+8|0);Tb(zb(a),nc(b));x[b>>2]=x[b+4>>2];fb=f+16|0}function $g(a,b,c,d){var e=0,f=0;x[d+8>>2]=b;x[d>>2]=0;x[d+4>>2]=0;x[c>>2]=d;b=x[x[a>>2]>>2];if(b){x[a>>2]=b;d=x[c>>2]}f=x[ec(a)>>2];v[d+12|0]=(f|0)==(d|0);while(1){a:{if((d|0)==(f|0)){break a}c=x[d+8>>2];if(y[c+12|0]){break a}b:{if(Uh(c)){b=x[c+8>>2];e=x[b+4>>2];if(!(!e|y[e+12|0])){break b}if(!Uh(d)){sr(c);c=x[c+8>>2]}v[c+12|0]=1;b=x[c+8>>2];v[b+12|0]=0;qr(b);break a}b=x[c+8>>2];e=x[b>>2];if(!(!e|y[e+12|0])){break b}if(Uh(d)){qr(c);c=x[c+8>>2]}v[c+12|0]=1;b=x[c+8>>2];v[b+12|0]=0;sr(b);break a}v[c+12|0]=1;d=b;v[d+12|0]=(d|0)==(f|0);v[e+12|0]=1;continue}break}a=zb(a);x[a>>2]=x[a>>2]+1}function l4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;a:{b:{if(ni(b,14337)){d=Ts(c+28|0,b);e=x[d>>2];if(!Dd(e)){x[31737]=0;b=P(36,c+4|0,b|0)|0;a=x[31737];x[31737]=0;c:{d:{e:{if((a|0)!=1){x[31737]=0;a=c+16|0;S(1017,a|0,17770,b|0);e=x[31737];x[31737]=0;if((e|0)==1){break e}x[31737]=0;W(1325,a|0);a=x[31737];x[31737]=0;if((a|0)==1){break d}p()}a=N()|0;break a}a=N()|0;break c}a=N()|0;tb(c+16|0)}tb(b);break a}iq(e);eq(a+8|0,16817,x[d>>2]);eq(a+12|0,22303,x[d>>2]);x[31737]=0;O(273,a+16|0,22303);a=x[31737];x[31737]=0;if((a|0)==1){break b}nl(d)}fb=c+32|0;return}a=N()|0}nl(d);Q(a|0);p()}function gh(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=x[a>>2];c=oc(d,x[a+4>>2]);if(c>>>0<b>>>0){e=fb-32|0;fb=e;b=b-c|0;c=x[zb(a)>>2];d=x[a+4>>2];a:{if(b>>>0<=c-d>>2>>>0){c=fb-16|0;fb=c;b=Tg(c+4|0,a,b);a=x[b+4>>2];d=x[b+8>>2];while(1){if((a|0)==(d|0)){hc(b);fb=c+16|0}else{Rw(a);a=a+4|0;x[b+4>>2]=a;continue}break}break a}c=zb(a);c=$f(e+12|0,Mf(a,oc(x[a>>2],d)+b|0),oc(x[a>>2],x[a+4>>2]),c);f=fb-16|0;fb=f;b=Ln(f+4|0,c+8|0,b);d=x[b>>2];while(1){if(x[b+4>>2]!=(d|0)){Rw(d);d=x[b>>2]+4|0;x[b>>2]=d;continue}break}he(b);fb=f+16|0;bs(a,c);_f(c)}fb=e+32|0;return}if(b>>>0<c>>>0){Ih(a,d+(b<<2)|0)}}function x3(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=fb-32|0;fb=k;m=x[c>>2];l=x[c+8>>2];c=x[c+4>>2];x[k+8>>2]=c;x[k+12>>2]=l;x[k+24>>2]=c;x[k+28>>2]=l;x[k+20>>2]=m;x[k+16>>2]=d;x[31737]=0;c=x[k+20>>2];x[k>>2]=x[k+16>>2];x[k+4>>2]=c;a=Ia(1100,a|0,b|0,k|0)|0;b=x[31737];x[31737]=0;a:{b:{if((b|0)==1){Y(T(0)|0)|0;x[31737]=0;ga(985,10431,e|0,f|0,g|0,h|0,i|0,j|0);a=x[31737];x[31737]=0;if((a|0)==1){break b}Z();a=-255}fb=k+32|0;break a}b=N()|0;x[31737]=0;X(26);a=x[31737];x[31737]=0;if((a|0)!=1){Q(b|0);p()}T(0)|0;Sb();p()}return a|0}function XL(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;if(gf(a)){fc(a,31);return 0}g=a,h=gf(a),v[g+1375|0]=h;d=Aj(a);b=Aj(a);Aj(a);g=a,h=Aj(a),x[g+1112>>2]=h;Aj(a);c=gf(a);x[a+1116>>2]=c;if(!cz(a,a+1120|0,c)){fc(a,10);return 0}x[a+1404>>2]=-2;a:{if((b&d)==-1){break a}b=x[a+1116>>2];while(1){if((b|0)<=0){break a}b=b-1|0;if(y[(b+a|0)+1120|0]==255){continue}break}x[a+1408>>2]=d;x[a+1404>>2]=b}if(y[a+1377|0]){b=0;e=x[a+1116>>2];f=(e|0)>0?e:0;c=0;while(1){if((b|0)!=(f|0)){c=y[(a+b|0)+1120|0]+c|0;b=b+1|0;continue}break}x[a- -64>>2]=d;x[a+60>>2]=(x[a+56>>2]+(c+e|0)|0)+27}x[a+1380>>2]=0;return 1}function Lm(a,b,c){var d=0,e=0,f=0,g=0;f=fb-16|0;fb=f;v[a|0]=0;a:{d=x[b>>2];e=x[d-12>>2]+b|0;b:{if(!x[e+16>>2]){e=x[e+72>>2];if(e){xp(e);d=x[b>>2]}c:{if(c){break c}c=x[d-12>>2]+b|0;if(!(y[c+5|0]&16)){break c}d=f+12|0;bd(d,x[c+28>>2]);x[31737]=0;e=R(28,x[f+12>>2])|0;c=x[31737];x[31737]=0;if((c|0)==1){break a}Zb(d);c=up(f+8|0,b);d=sc(f+4|0);while(1){d:{if(sh(c,d)){break d}g=Al(x[c>>2]);if(!Jf(x[e+8>>2],1,g)){break d}Km(c);continue}break}if(sh(c,d)){bk(x[x[b>>2]-12>>2]+b|0,6)}d=x[b>>2]}v[a|0]=!x[(x[d-12>>2]+b|0)+16>>2];break b}bk(e,4)}fb=f+16|0;return a}a=N()|0;Zb(f+12|0);Q(a|0);p()}function gl(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=fb-16|0;fb=e;f=a+36|0;c=x[a+32>>2];a:{b:{while(1){if((b|0)<=(c|0)){break b}c:{d=x[a+20>>2];if(d>>>0>=A[a+24>>2]){wo(e,f,CG(f));rd(e+8|0,a,x[e>>2],x[e+4>>2]);c=x[e+12>>2];x[a+24>>2]=c;x[a+20>>2]=0;if(!c){break c}d=0;c=x[a+32>>2]}x[a+20>>2]=d+1;g=y[(a+d|0)+36|0];d=c+8|0;x[a+32>>2]=d;x[a+28>>2]=x[a+28>>2]|g<<c;c=d;continue}break}a=ac(8);x[31737]=0;b=R(162,a|0)|0;c=x[31737];x[31737]=0;if((c|0)!=1){break a}b=N()|0;jc(a);Q(b|0);p()}x[a+32>>2]=c-b;d=a;a=x[a+28>>2];x[d+28>>2]=a>>>b;fb=e+16|0;return a&(-1<<b^-1)}da(b|0,28896,163);p()}function LL(a,b){var c=0,d=0,e=0,f=0,g=0;if(!y[496864]){f=496865,g=Qa()|0,v[f|0]=g;v[496864]=1}a:{b:{c:{d:{switch(a|0){case 0:break b;case 1:case 4:break d;default:break c}}if(!y[496865]){break c}d=+Ga();break a}x[31612]=28;return-1}d=+Xa()}c=d/1e3;e:{if(F(c)<0x8000000000000000){e=~~c>>>0;if(F(c)>=1){a=~~(c>0?H(J(c*2.3283064365386963e-10),4294967295):K((c-+(~~c>>>0>>>0))*2.3283064365386963e-10))>>>0}else{a=0}break e}a=-2147483648}x[b>>2]=e;x[b+4>>2]=a;c=(d-(+(Sua(e,a,1e3,0)>>>0)+ +(hb|0)*4294967296))*1e3*1e3;f:{if(F(c)<2147483648){a=~~c;break f}a=-2147483648}x[b+8>>2]=a;return 0}function mna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=fb-16|0;fb=b;i=x[a+24>>2];j=x[a+20>>2];k=x[a+16>>2];f=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=f;f=x[a+8>>2];l=x[a+12>>2];while(1){if(d){e=x[b+8>>2];m=e>>>10&4194048;n=(((x[b+12>>2]&2147483647)<<1|e>>>31)&-2)+k|0;e=0;while(1){if((e|0)!=2){g=e+n|0;h=v[g|0];x[(e<<2)+b>>2]=((D(v[g+2|0]-h|0,m)|0)/16384|0)+(h<<8);e=e+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[b>>2],j);x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],i);Pb(b+8|0,f,l);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;fb=b+16|0}function Uta(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);Rd(c+8|0,x[vb(c+4|0,a)>>2]);a:{b:{if(b){x[31737]=0;O(322,a|0,b|0);d=x[31737];x[31737]=0;if((d|0)==1){break b}e=fb-16|0;fb=e;d=Ir(e+4|0,a,b);b=x[d+4>>2];f=x[d+8>>2];while(1){if((b|0)==(f|0)){hc(d);fb=e+16|0}else{v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b+4|0]=6;v[b+5|0]=0;v[b|0]=0;v[b+1|0]=0;v[b+2|0]=8;v[b+3|0]=4;b=b+6|0;x[d+4>>2]=b;continue}break}}b=c+8|0;Qd(b);im(b);fb=c+16|0;break a}a=N()|0;im(c+8|0);Q(a|0);p()}v[a+16|0]=6;x[a+12>>2]=2015363072;return a|0}function Yfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-32|0;fb=d;x[31737]=0;W(1002,a|0);c=x[31737];x[31737]=0;a:{b:{c:{if((c|0)==1){break c}x[31737]=0;W(1003,b|0);c=x[31737];x[31737]=0;if((c|0)==1){break c}e=x[a+24>>2];b=qc(d+12|0,b);x[31737]=0;c=x[b+4>>2];x[d>>2]=x[b>>2];x[d+4>>2]=c;c=d+20|0;V(1015,c|0,e|0,d|0,1);b=x[31737];x[31737]=0;if((b|0)==1){break c}b=Bg(Jb(c));tb(c);break b}Y(T(0)|0)|0;b=0;x[31737]=0;V(989,5535,a|0,0,0);a=x[31737];x[31737]=0;if((a|0)==1){break a}Z()}fb=d+32|0;return b|0}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function P$(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0;a:{if(!d){break a}i=y[e|0];if(!i){break a}j=2240>>>d&d>>>0<12;g=D(c,-6);k=(d-2&255)>>>0>2;while(1){if(!b){break a}c=a;a=c+g|0;f=y[a+3|0];b:{c:{if(!((f-2&255)>>>0>2|k)){f=1;if(y[(c+g|0)+5|0]<224){break c}break a}f=!(1<<f&2240)|(!j|f>>>0>11)?(d|0)==(f|0):1;if(k){break b}}h=c+g|0;if((y[h+2|0]-11&255)>>>0>2){break b}if(y[h+4|0]){break a}}d:{if(!j){break d}h=c+g|0;if((y[h+2|0]-3&255)>>>0>3){break d}if(y[h+4|0]){break a}}b=b-1|0;if(!f){continue}c=y[(c+g|0)+5|0];if(c?(c|0)!=(i|0):0){break a}if((c|0)!=(i|0)){continue}break}v[e|0]=0}}function $d(a,b){var c=0,d=0,e=0;c=fb-32|0;fb=c;a=gi(a,-1,-1);a:{b:{if(Gd(y[Lm(c+31|0,b,1)|0])){d=x[(x[x[b>>2]-12>>2]+b|0)+24>>2];x[31737]=0;Ps(87,c+8|0,d,0,0,1);d=x[31737];x[31737]=0;c:{if((d|0)!=1){d=x[c+12>>2];x[a>>2]=x[c+8>>2];x[a+4>>2]=d;d=x[c+20>>2];x[a+8>>2]=x[c+16>>2];x[a+12>>2]=d;break c}Y(T(0)|0)|0;e=1;Jm(x[x[b>>2]-12>>2]+b|0,1);if(x[(x[x[b>>2]-12>>2]+b|0)+20>>2]&1){x[31737]=0;X(85);a=x[31737];x[31737]=0;if((a|0)!=1){break a}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)==1){break b}Q(a|0);p()}Z()}bk(x[x[b>>2]-12>>2]+b|0,e)}fb=c+32|0;return}T(0)|0;Sb()}p()}function fN(a,b){var c=0,d=0,e=0,f=0,g=0;c=x[a>>2];x[a>>2]=b;if(c){x[31737]=0;W(857,c|0);a=x[31737];x[31737]=0;a:{if((a|0)!=1){d=x[c+4>>2];if(d){e=fb-16|0;fb=e;f=vb(e+12|0,d);a=x[f>>2];if(x[a>>2]){g=x[a>>2];b=x[a+4>>2];while(1){if((b|0)!=(g|0)){b=b-4|0;og(b);continue}break}x[a+4>>2]=g;a=x[f>>2];b=x[a>>2];Ug(a);Db(b)}fb=e+16|0;Db(d)}x[c+4>>2]=0;CS(c+1298412|0);YA(c+1298344|0);tb(c+1298332|0);tb(c+1298320|0);tb(c+1298308|0);XA(c+1298304|0);WA(c+1298300|0);Pu(c+1298264|0);jB(c+1074376|0);BS(c+906300|0);_B(c+484360|0);tS(c+484344|0);vc(c+480248|0);break a}T(0)|0;Sb();p()}Db(c)}}function gta(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=fb-16|0;fb=g;c=65535;e=x[a>>2];a:{if(Zc(e,x[a+4>>2])>>>0<=b>>>0){break a}e=z[_b(e,b)>>1];b:{if(!bj(a,b)){break b}c=x[a+24>>2];d=wb(x[c+484360>>2]);x[g+12>>2]=d;h=wb(x[c+484364>>2]);while(1){if(!Ib(d,h)){break b}f=0;i=km(x[d>>2],x[d+4>>2]);while(1){if((f|0)!=(i|0)){c:{if(!((a|0)!=(d|0)|(b|0)!=(f|0))|(e|0)!=z[_b(x[d>>2],f)>>1]){break c}c=VX(x[a+24>>2]+484344|0,e);if((c|0)==65535){break c}j=_b(x[a>>2],b),k=c,w[j>>1]=k;break a}f=f+1|0;continue}break}d=x[br(g+12|0)>>2];continue}}c=e}fb=g+16|0;return c&65535}function R4(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a:{g=fb+-64|0;fb=g;h=g+16|0;co(h,c);x[31737]=0;c=g+28|0;O(92,c|0,d|0);d=x[31737];x[31737]=0;b:{c:{d:{if((d|0)==1){break d}x[31737]=0;c=g+40|0;O(92,c|0,e|0);d=x[31737];x[31737]=0;if((d|0)==1){break d}x[31737]=0;c=g+52|0;O(92,c|0,f|0);d=x[31737];x[31737]=0;if((d|0)==1){break d}Ux(g+8|0,h);x[31737]=0;V(93,a|0,b|0,x[g+8>>2],x[g+12>>2]);a=x[31737];x[31737]=0;if((a|0)==1){break c}GI(h);fb=g- -64|0;break a}a=N()|0;while(1){c=tb(c-12|0);if((c|0)!=(g+16|0)){continue}break}break b}a=N()|0;GI(g+16|0)}Q(a|0);p()}}function v3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;f=c;c=fb-16|0;fb=c;x[31737]=0;W(1002,a|0);e=x[31737];x[31737]=0;a:{b:{c:{d:{if((e|0)==1){break d}x[31737]=0;W(1003,b|0);e=x[31737];x[31737]=0;if((e|0)==1){break d}e=x[a+24>>2];b=qc(c+8|0,b);x[31737]=0;g=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=g;Ps(1023,e,c,f,d,1);d=x[31737];x[31737]=0;b=1;if((d|0)!=1){break c}}Y(T(0)|0)|0;x[31737]=0;V(989,8658,a|0,0,0);a=x[31737];x[31737]=0;if((a|0)==1){break b}Z();b=0}fb=c+16|0;break a}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}return b|0}function dG(a){var b=0,c=0,d=0;b=fb-16|0;fb=b;x[b+4>>2]=D(y[a+12|0]|y[a+13|0]<<8|(y[a+14|0]<<16|y[a+15|0]<<24),5)+(y[a+16|0]|y[a+17|0]<<8|(y[a+18|0]<<16|y[a+19|0]<<24));x[b+8>>2]=(y[a+24|0]|y[a+25|0]<<8|(y[a+26|0]<<16|y[a+27|0]<<24))+((y[a+20|0]|y[a+21|0]<<8|(y[a+22|0]<<16|y[a+23|0]<<24))<<3);x[b+12>>2]=(y[a+32|0]|y[a+33|0]<<8|(y[a+34|0]<<16|y[a+35|0]<<24))+((y[a+28|0]|y[a+29|0]<<8|(y[a+30|0]<<16|y[a+31|0]<<24))<<2);a=b+4|0;d=yb(a,3);a:{if((a|0)==(d|0)){break a}c=a;while(1){c=c+4|0;if((d|0)==(c|0)){break a}a=xn(x[a>>2],x[c>>2])?c:a;continue}}fb=b+16|0;return x[a>>2]-36|0}function Dr(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;PE(c+8|0,b);d=x[c+12>>2];lc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;if((d|0)!=(e|0)){v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b+6|0]=0;v[b+7|0]=0;v[b+24|0]=0;v[b+25|0]=0;v[b+26|0]=0;v[b+27|0]=0;v[b+28|0]=0;v[b+29|0]=0;v[b+30|0]=0;v[b+31|0]=0;v[b+16|0]=0;v[b+17|0]=0;v[b+18|0]=0;v[b+19|0]=0;v[b+20|0]=0;v[b+21|0]=0;v[b+22|0]=0;v[b+23|0]=0;v[b+8|0]=0;v[b+9|0]=0;v[b+10|0]=0;v[b+11|0]=0;v[b+12|0]=0;v[b+13|0]=0;v[b+14|0]=0;v[b+15|0]=0}}function Cna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=fb-16|0;fb=b;i=x[a+16>>2];h=mg(1,2);e=hb;j=e;Pb(a,h,e);k=x[a+24>>2];l=x[a+20>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;e=x[a+8>>2];m=x[a+12>>2];while(1){if(d){d=d-1|0;g=x[b+8>>2];g=((((x[b+12>>2]&2147483647)<<1|g>>>31)&2147483646)<<1)+i|0;f=0;while(1){if((f|0)!=2){x[(f<<2)+b>>2]=w[(f<<1)+g>>1];f=f+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[b>>2],l);x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],k);Pb(b+8|0,e,m);c=c+8|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;Hg(a,h,j);fb=b+16|0}function Hha(a){a=a|0;var b=0,c=0,d=0;c=fb-16|0;fb=c;b=x[x[a+16>>2]+24620>>2];b=Gc(Tua(Sua(b,b>>31,3840,0),hb,1e3,0),hb);x[a+4316>>2]=b;x[31737]=0;x[c+12>>2]=0;d=b;b=c+12|0;S(953,a+4264|0,d|0,b|0);d=x[31737];x[31737]=0;a:{b:{c:{if((d|0)!=1){d:{if(!y[a+4260|0]){break d}d=x[a+4316>>2];x[31737]=0;x[c+12>>2]=0;S(953,a+4276|0,d|0,b|0);b=x[31737];x[31737]=0;if((b|0)!=1){break d}b=T(125048)|0;break c}x[c+12>>2]=0;b=c+12|0;tQ(a+4288|0,b);x[c+12>>2]=0;tQ(a+4300|0,b);break b}b=T(125048)|0}if((gb|0)!=($(125048)|0)){break a}Y(b|0)|0;x[a+4316>>2]=0;Z()}fb=c+16|0;return}Q(b|0);p()}function SQ(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=fb-16|0;fb=f;c=vb(f+12|0,x[a+4>>2]);d=vb(f+8|0,x[a>>2]);h=x[vb(f+4|0,x[b+4>>2])>>2];g=fb-16|0;fb=g;i=g+8|0;e=fb-32|0;fb=e;Id(e+24|0,x[c>>2],x[d>>2]);j=e+16|0;d=x[e+24>>2];k=x[e+28>>2];c=fb-16|0;fb=c;x[c+8>>2]=h;x[c+12>>2]=d;while(1){if(pd(d,k)){d=QQ(d);yc(QQ(x[c+8>>2]),d,2048);d=PQ(c+12|0);PQ(c+8|0);d=x[d>>2];continue}break}Ac(j,d,c+8|0);fb=c+16|0;c=x[e+16>>2];x[e+12>>2]=x[e+20>>2];Ac(i,c,e+12|0);fb=e+32|0;fb=g+16|0;x[b+4>>2]=x[g+12>>2];Tb(a,b+4|0);Tb(a+4|0,b+8|0);Tb(zb(a),nc(b));x[b>>2]=x[b+4>>2];fb=f+16|0}function kna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=fb-16|0;fb=b;e=x[a+40>>2];f=x[a+36>>2];j=x[a+16>>2];h=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=h;k=x[a+32>>2];l=x[a+28>>2];h=x[a+8>>2];m=x[a+12>>2];while(1){if(d){i=x[b+12>>2]+j|0;g=v[i|0];g=((D(v[i+1|0]-g|0,x[b+8>>2]>>>10&4194048)|0)/16384|0)+(g<<8)|0;f=f+l|0;x[c>>2]=x[c>>2]+D(g,f>>12);e=e+k|0;x[c+4>>2]=x[c+4>>2]+D(g,e>>12);Pb(b+8|0,h,m);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=e;x[a+20>>2]=f>>12;x[a+36>>2]=f;x[a+24>>2]=e>>12;fb=b+16|0}function E$(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=fb-16|0;fb=f;c=vb(f+12|0,x[a+4>>2]);d=vb(f+8|0,x[a>>2]);h=x[vb(f+4|0,x[b+4>>2])>>2];g=fb-16|0;fb=g;i=g+8|0;e=fb-32|0;fb=e;Id(e+24|0,x[c>>2],x[d>>2]);j=e+16|0;d=x[e+24>>2];k=x[e+28>>2];c=fb-16|0;fb=c;x[c+8>>2]=h;x[c+12>>2]=d;while(1){if(pd(d,k)){d=bw(d);yc(bw(x[c+8>>2]),d,36);d=B$(c+12|0);B$(c+8|0);d=x[d>>2];continue}break}Ac(j,d,c+8|0);fb=c+16|0;c=x[e+16>>2];x[e+12>>2]=x[e+20>>2];Ac(i,c,e+12|0);fb=e+32|0;fb=g+16|0;x[b+4>>2]=x[g+12>>2];Tb(a,b+4|0);Tb(a+4|0,b+8|0);Tb(zb(a),nc(b));x[b>>2]=x[b+4>>2];fb=f+16|0}function A6(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=x[a>>2];d=oc(c,x[a+4>>2]);if(d>>>0<b>>>0){h=fb-32|0;fb=h;e=b-d|0;b=x[zb(a)>>2];c=x[a+4>>2];a:{if(e>>>0<=b-c>>2>>>0){Zq(a,e);break a}f=hq(a);d=Mf(a,oc(x[a>>2],c)+e|0);g=oc(x[a>>2],x[a+4>>2]);c=fb-16|0;fb=c;b=h+12|0;Kg(b+12|0,f);b:{if(!d){f=0;d=0;break b}iJ(c+8|0,x[b+16>>2],d);f=x[c+12>>2];d=x[c+8>>2]}x[b>>2]=d;g=d+(g<<2)|0;x[b+8>>2]=g;x[b+4>>2]=g;i=nc(b),j=d+(f<<2)|0,x[i>>2]=j;fb=c+16|0;jA(b,e);Ym(a,b);oQ(b);a=x[b>>2];if(a){cy(x[b+16>>2],a,Uz(b))}}fb=h+32|0;return}if(b>>>0<d>>>0){Ih(a,c+(b<<2)|0)}}function rja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;f=fb-16|0;fb=f;x[f+12>>2]=b;a:{if(Bu(a)>>>0>=b>>>0){e=x[a>>2];g=pm(e,x[a+4>>2]);x[f+8>>2]=g;d=x[Gb(f+12|0,f+8|0)>>2];while(1){if(d){d=d-1|0;e=uR(e,c)+52|0;continue}break}if(b>>>0>g>>>0){oA(a,b-g|0,c);break a}qR(a,x[a>>2]+D(b,52)|0);break a}if(x[a>>2]){Cu(a);d=x[a>>2];Bu(a);Db(d);h=zb(a),i=0,x[h>>2]=i;x[a>>2]=0;x[a+4>>2]=0}e=nR(a,b);d=fb-16|0;fb=d;if(th(82595524)>>>0<e>>>0){dd();p()}mR(d+8|0,e);e=x[d+8>>2];x[a+4>>2]=e;x[a>>2]=e;h=zb(a),i=e+D(x[d+12>>2],52)|0,x[h>>2]=i;fb=d+16|0;oA(a,b,c)}fb=f+16|0}function mm(a,b,c,d,e,f){var g=0;g=fb-16|0;fb=g;v[g+14|0]=d;v[g+15|0]=c;v[g+13|0]=e;v[g+12|0]=f;d=0;a:{b:{while(1){c=d&255;if(c>>>0>3){break b}e=y[g+15|0];rw(g+10|0,e,y[g+14|0],c>>>0>1);if(!(y[g+10|0]|!e)){d=d+1|0;tg(g+15|0,g+13|0);tg(g+14|0,g+12|0);continue}break}c=z[g+10>>1];v[b+2|0]=c;v[b+4|0]=c>>>8;c=y[g+13|0];v[b+5|0]=y[g+12|0];v[b+3|0]=c;v[g+9|0]=0;de(a,0,g+9|0);break a}d=y[g+15|0];e=xi(d);c=y[g+13|0];if(e>>>0>xi(c)>>>0){tg(g+15|0,g+13|0);tg(g+14|0,g+12|0);d=y[g+15|0];c=y[g+13|0]}v[b+4|0]=0;v[b+2|0]=0;v[b+5|0]=y[g+12|0];v[b+3|0]=c;de(a,d,g+14|0)}fb=g+16|0}function kga(a){a=a|0;var b=0;b=8016;a:{b:{c:{switch(a-277|0){default:if((a|0)==357){break b}d:{if((a|0)!=257){if((a|0)==267){break d}if(a){break a}b=22303;break a}b=8049;break a}b=18213;break a;case 0:b=5011;break a;case 9:b=8072;break a;case 10:b=8086;break a;case 11:b=5388;break a;case 12:b=5408;break a;case 19:b=8098;break a;case 20:b=8030;break a;case 21:b=12914;break a;case 22:b=12237;break a;case 1:case 2:case 3:case 4:case 5:case 6:case 7:case 8:case 13:case 14:case 15:case 16:case 17:case 18:break a;case 23:break c}}b=6019;break a}b=7983}return Bg(b)|0}function Vfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-16|0;fb=d;x[31737]=0;W(1002,a|0);e=x[31737];x[31737]=0;a:{b:{c:{if((e|0)==1){break c}x[31737]=0;W(1003,b|0);e=x[31737];x[31737]=0;if((e|0)==1){break c}e=x[a+24>>2];b=qc(d+8|0,b);x[31737]=0;f=x[b+4>>2];x[d>>2]=x[b>>2];x[d+4>>2]=f;V(1020,e|0,d|0,(c|0)!=0|0,1);c=x[31737];x[31737]=0;b=1;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[31737]=0;V(989,10021,a|0,0,0);a=x[31737];x[31737]=0;if((a|0)==1){break a}Z();b=0}fb=d+16|0;return b|0}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function xQ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;a=Qi(a,b,c,d);v[a+4260|0]=e;x[a>>2]=44796;c=Nb(a+4264|0);d=Nb(a+4276|0);x[a+4328>>2]=0;b=a+4320|0;x[b>>2]=0;x[b+4>>2]=0;x[a+4312>>2]=0;x[a+4316>>2]=0;b=a+4208|0;f=yb(b,0),g=1056964608,x[f>>2]=g;f=yb(b,1),g=1036831949,x[f>>2]=g;f=yb(b,2),g=1038174126,x[f>>2]=g;f=yb(b,3),g=1065353216,x[f>>2]=g;f=yb(b,4),g=1061158912,x[f>>2]=g;f=yb(b,5),g=1059082943,x[f>>2]=g;f=yb(b,6),g=1061997773,x[f>>2]=g;x[31737]=0;O(947,a+44|0,2);b=x[31737];x[31737]=0;if((b|0)!=1){return a|0}b=N()|0;vc(d);vc(c);ag(a);Q(b|0);p()}function jna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=fb-16|0;fb=b;f=x[a+40>>2];g=x[a+36>>2];i=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;j=x[a+32>>2];k=x[a+28>>2];l=x[a+8>>2];m=x[a+12>>2];while(1){if(d){e=(x[b+12>>2]<<1)+i|0;h=w[e>>1];e=h+((D(w[e+2>>1]-h|0,x[b+8>>2]>>>18|0)|0)/16384|0)|0;g=g+k|0;x[c>>2]=x[c>>2]+D(e,g>>12);f=f+j|0;x[c+4>>2]=x[c+4>>2]+D(e,f>>12);Pb(b+8|0,l,m);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=f;x[a+20>>2]=g>>12;x[a+36>>2]=g;x[a+24>>2]=f>>12;fb=b+16|0}function w3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-16|0;fb=d;x[31737]=0;W(1002,a|0);c=x[31737];x[31737]=0;a:{b:{c:{d:{if((c|0)==1){break d}x[31737]=0;W(1003,b|0);c=x[31737];x[31737]=0;if((c|0)==1){break d}c=x[a+24>>2];b=qc(d+8|0,b);x[31737]=0;e=x[b+4>>2];x[d>>2]=x[b>>2];x[d+4>>2]=e;b=lI(c,d,1);e=x[31737];x[31737]=0;c=hb;if((e|0)!=1){break c}}Y(T(0)|0)|0;x[31737]=0;V(989,8689,a|0,0,0);a=x[31737];x[31737]=0;if((a|0)==1){break b}Z();b=0;c=0}fb=d+16|0;a=c;break a}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}gb=a;return b|0}function S8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-32|0;fb=c;d=y[a+52|0];a:{if(mc(b,-1)){if(d){break a}b=x[a+48>>2];e=a,f=mc(b,-1)^1,v[e+52|0]=f;break a}b:{if(!d){break b}v[c+19|0]=x[a+48>>2]<<24>>24;c:{d:{e:{d=c+20|0;switch(rr(x[a+36>>2],x[a+40>>2],c+19|0,d,c+12|0,c+24|0,c+32|0,d)-1|0){case 0:case 1:break c;case 2:break e;default:break d}}d=x[a+48>>2];x[c+20>>2]=c+25;v[c+24|0]=d}while(1){d=x[c+20>>2];if(d>>>0<=c+24>>>0){break b}d=d-1|0;x[c+20>>2]=d;if((zt(v[d|0],x[a+32>>2])|0)!=-1){continue}break}}b=-1;break a}v[a+52|0]=1;x[a+48>>2]=b}fb=c+32|0;return b|0}function qra(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=fb-48|0;fb=e;c=x[a+8>>2];d=x[a>>2];x[31737]=0;c=U(151,d|0,c|0,1)|0;d=x[31737];x[31737]=0;a:{if((d|0)==1){break a}b:{if(!c){break b}x[31737]=0;W(518,b|0);c=x[31737];x[31737]=0;if((c|0)==1){break a}x[31737]=0;c=R(198,a|0)|0;d=x[31737];x[31737]=0;c:{if((d|0)!=1){while(1){if(!(c&255)){break b}x[31737]=0;d=e+15|0;f=P(519,a|0,d|0)|0;g=x[31737];x[31737]=0;if((g|0)==1){break c}g=f;f=y[e+15|0];if(g&f>>>0<64){yc(gZ(x[b>>2],f),d,33)}c=c-1|0;continue}}break a}break a}ub(a);fb=e+48|0;return}b=N()|0;ub(a);Q(b|0);p()}function nba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;f=fb-16|0;fb=f;g=f+4|0;e=fb-32|0;fb=e;c=rf(e+20|0,1,0);a:{b:{c:{while(1){d=Jb(c);ws(e+12|0,d,Cb(x[c+4>>2],y[c+11|0])+d|0,y[b|0]);if(!x[e+16>>2]){break c}d=qi(Cb(x[c+4>>2],y[c+11|0]));x[31737]=0;O(45,c|0,d|0);d=x[31737];x[31737]=0;if((d|0)!=1){continue}break}break b}b=x[e+12>>2];d=Jb(c);x[31737]=0;O(46,c|0,b-d|0);b=x[31737];x[31737]=0;d:{if((b|0)!=1){x[31737]=0;O(304,g|0,c|0);b=x[31737];x[31737]=0;if((b|0)!=1){break d}break b}break b}tb(c);fb=e+32|0;break a}a=N()|0;tb(c);Q(a|0);p()}Sh(a,g);tb(g);fb=f+16|0}function fr(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;f=fb-16|0;fb=f;g=f+4|0;e=fb-32|0;fb=e;c=rf(e+20|0,1,0);a:{b:{c:{while(1){d=Jb(c);ws(e+12|0,d,Cb(x[c+4>>2],y[c+11|0])+d|0,x[b>>2]);if(!x[e+16>>2]){break c}d=qi(Cb(x[c+4>>2],y[c+11|0]));x[31737]=0;O(45,c|0,d|0);d=x[31737];x[31737]=0;if((d|0)!=1){continue}break}break b}b=x[e+12>>2];d=Jb(c);x[31737]=0;O(46,c|0,b-d|0);b=x[31737];x[31737]=0;d:{if((b|0)!=1){x[31737]=0;O(304,g|0,c|0);b=x[31737];x[31737]=0;if((b|0)!=1){break d}break b}break b}tb(c);fb=e+32|0;break a}a=N()|0;tb(c);Q(a|0);p()}Sh(a,g);tb(g);fb=f+16|0}function Y_(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;f=fb-16|0;fb=f;g=f+4|0;e=fb-32|0;fb=e;c=rf(e+20|0,1,0);a:{b:{c:{while(1){d=Jb(c);ww(e+12|0,d,Cb(x[c+4>>2],y[c+11|0])+d|0,x[b>>2]);if(!x[e+16>>2]){break c}d=qi(Cb(x[c+4>>2],y[c+11|0]));x[31737]=0;O(45,c|0,d|0);d=x[31737];x[31737]=0;if((d|0)!=1){continue}break}break b}b=x[e+12>>2];d=Jb(c);x[31737]=0;O(46,c|0,b-d|0);b=x[31737];x[31737]=0;d:{if((b|0)!=1){x[31737]=0;O(47,g|0,c|0);b=x[31737];x[31737]=0;if((b|0)!=1){break d}break b}break b}tb(c);fb=e+32|0;break a}a=N()|0;tb(c);Q(a|0);p()}Sh(a,g);tb(g);fb=f+16|0}function W8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=fb-32|0;fb=c;a:{b:{c:{if(mc(b,-1)){break c}v[c+23|0]=b<<24>>24;if(y[a+44|0]){d=-1;if((Tk(c+23|0,1,1,x[a+32>>2])|0)==1){break c}break a}f=c+24|0;x[c+16>>2]=f;h=c+32|0;d=c+23|0;while(1){e=rr(x[a+36>>2],x[a+40>>2],d,f,c+12|0,c+24|0,h,c+16|0);if(x[c+12>>2]==(d|0)){break b}if((e|0)==3){if((Tk(d,1,1,x[a+32>>2])|0)==1){break c}break b}if(e>>>0>1){break b}g=c+24|0;d=x[c+16>>2]-g|0;if((Tk(g,1,d,x[a+32>>2])|0)!=(d|0)){break b}d=x[c+12>>2];if((e|0)==1){continue}break}}d=Ly(b);break a}d=-1}fb=c+32|0;return d|0}function Up(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;f=fb-16|0;fb=f;g=f+4|0;e=fb-32|0;fb=e;c=rf(e+20|0,1,0);a:{b:{c:{while(1){d=Jb(c);ws(e+12|0,d,Cb(x[c+4>>2],y[c+11|0])+d|0,x[b>>2]);if(!x[e+16>>2]){break c}d=qi(Cb(x[c+4>>2],y[c+11|0]));x[31737]=0;O(45,c|0,d|0);d=x[31737];x[31737]=0;if((d|0)!=1){continue}break}break b}b=x[e+12>>2];d=Jb(c);x[31737]=0;O(46,c|0,b-d|0);b=x[31737];x[31737]=0;d:{if((b|0)!=1){x[31737]=0;O(47,g|0,c|0);b=x[31737];x[31737]=0;if((b|0)!=1){break d}break b}break b}tb(c);fb=e+32|0;break a}a=N()|0;tb(c);Q(a|0);p()}Sh(a,g);tb(g);fb=f+16|0}function Rv(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;f=fb-16|0;fb=f;g=f+4|0;e=fb-32|0;fb=e;c=rf(e+20|0,1,0);a:{b:{c:{while(1){d=Jb(c);ww(e+12|0,d,Cb(x[c+4>>2],y[c+11|0])+d|0,z[b>>1]);if(!x[e+16>>2]){break c}d=qi(Cb(x[c+4>>2],y[c+11|0]));x[31737]=0;O(45,c|0,d|0);d=x[31737];x[31737]=0;if((d|0)!=1){continue}break}break b}b=x[e+12>>2];d=Jb(c);x[31737]=0;O(46,c|0,b-d|0);b=x[31737];x[31737]=0;d:{if((b|0)!=1){x[31737]=0;O(47,g|0,c|0);b=x[31737];x[31737]=0;if((b|0)!=1){break d}break b}break b}tb(c);fb=e+32|0;break a}a=N()|0;tb(c);Q(a|0);p()}Sh(a,g);tb(g);fb=f+16|0}function BR(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;h=fb-16|0;fb=h;v[h+15|0]=b;v[h+14|0]=10;gh(g,y[Qb(h+15|0,h+14|0)|0]);v[g+15|0]=c;v[g+16|0]=c;v[g+14|0]=e;v[g+13|0]=d;j=x[g>>2];k=Sd(j,x[g+4>>2]);b=0;while(1){if((b|0)!=(k|0)){m=yb(j,b);l=D(b,3)+f|0;i=(y[l|0]|y[l+1|0]<<8)>>>4|0;w[m>>1]=i;a:{if(b){n=z[yb(j,b-1|0)>>1];if(i>>>0>=n>>>0){break a}i=n+1|0}else{i=0}o=yb(j,b),p=i,w[o>>1]=p}o=m,p=Kd(y[l+2|0],0,64),v[o+2|0]=p;b=b+1|0;continue}break}v[g+12|0]=a>>>1&(d>>>0<=e>>>0?(d>>>0<=k>>>0)<<1:0)|(a<<1&(c>>>0<=k>>>0)<<2|(y[g+12|0]&248|a&1));fb=h+16|0}function Lt(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0;h=fb-240|0;fb=h;x[h+236>>2]=d;x[h+232>>2]=c;x[h>>2]=a;m=!f;a:{b:{c:{d:{if((c|0)!=1){i=a;j=1;break d}i=a;j=1;if(d){break d}f=a;break c}while(1){k=(e<<2)+g|0;f=i-x[k>>2]|0;if((qo(f,a,b)|0)<=0){f=i;break c}l=m^-1;m=1;e:{if(!((l|(e|0)<2)&1)){k=x[k-8>>2];l=i-4|0;if((qo(l,f,b)|0)>=0){break e}if((qo(l-k|0,f,b)|0)>=0){break e}}x[(j<<2)+h>>2]=f;c=JL(c,d);Mt(h+232|0,c);j=j+1|0;e=c+e|0;i=f;d=x[h+236>>2];c=x[h+232>>2];if(d|(c|0)!=1){continue}break b}break}f=i;break b}if(!m){break a}}IL(h,j);_y(f,b,e,g)}fb=h+240|0}function uz(a,b,c){var d=0,e=0,f=0,g=0;e=fb-16|0;fb=e;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);Rd(e+8|0,x[vb(e+4|0,a)>>2]);a:{b:{if(c){x[31737]=0;O(1141,a|0,c|0);d=x[31737];x[31737]=0;if((d|0)==1){break b}f=fb-16|0;fb=f;d=Tg(f+4|0,a,c);c=x[d+4>>2];g=x[d+8>>2];while(1){if((c|0)==(g|0)){hc(d);fb=f+16|0}else{x[c>>2]=0;sc(c);c=c+4|0;x[d+4>>2]=c;continue}break}}c=e+8|0;Qd(c);ch(c);fb=e+16|0;break a}a=N()|0;ch(e+8|0);Q(a|0);p()}e=a;a=0;c=0;d=fb-16|0;fb=d;f=d+12|0;while(1){if(a>>>0<32){a=a+48|0;c=rS(b);continue}break}x[f>>2]=c;Ho(f);fb=d+16|0;x[e+12>>2]=x[f>>2];return e}function GK(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;a:{if(a>>>0>131071){break a}f=a&255;c=(f>>>0)/3|0;g=x[((D(c,-3)+a&255)<<2)+99096>>2];e=c;c=a>>>8|0;d=x[(((D(g,y[(e+D(y[c+100480|0],86)|0)+100480|0])>>>11>>>0)%6|0)+y[c+103152|0]<<2)+99120>>2];c=d>>8;d=d&255;if(d>>>0<=1){return(c&0-(b^d))+a|0}d=c&255;if(!d){break a}c=c>>>8|0;while(1){h=d>>>1|0;e=h+c|0;i=y[(e<<1)+100080|0];if((i|0)==(f|0)){c=x[(y[(e<<1)+100081|0]<<2)+99120>>2];d=c&255;if(d>>>0<=1){return(0-(b^d)&c>>8)+a|0}return(b?-1:1)+a|0}g=e;e=f>>>0<i>>>0;c=e?c:g;d=e?h:d-h|0;if(d){continue}break}}return a}function ts(a,b){a=a|0;b=b|0;var c=0,d=0;d=fb-16|0;fb=d;a=Fb(a);a:{b:{c:{switch(b|0){case 0:x[31737]=0;b=P(1,d+4|0,15935)|0;c=x[31737];x[31737]=0;if((c|0)==1){break a}Ab(a,b);tb(b);break b;case 1:x[31737]=0;b=P(1,d+4|0,15960)|0;c=x[31737];x[31737]=0;if((c|0)!=1){Ab(a,b);tb(b);break b}break a;case 2:x[31737]=0;b=P(1,d+4|0,15908)|0;c=x[31737];x[31737]=0;if((c|0)!=1){Ab(a,b);tb(b);break b}break a;case 3:break c;default:break b}}x[31737]=0;b=P(1,d+4|0,15882)|0;c=x[31737];x[31737]=0;if((c|0)==1){break a}Ab(a,b);tb(b)}fb=d+16|0;return}b=N()|0;tb(a);Q(b|0);p()}function pV(a,b){var c=0,d=0;v[a+15|0]=0;v[a+16|0]=0;v[a+17|0]=0;v[a+18|0]=0;v[a+19|0]=0;v[a+20|0]=0;v[a+21|0]=0;v[a+22|0]=0;v[a+14|0]=5;w[a+12>>1]=0;x[a+8>>2]=128;x[a>>2]=256;x[a+4>>2]=64;x[a+28>>2]=0;v[a+27|0]=60;x[a+40>>2]=0;x[a+44>>2]=0;v[a+33|0]=2;v[a+34|0]=0;v[a+35|0]=0;v[a+36|0]=2;v[a+23|0]=0;v[a+24|0]=0;v[a+25|0]=255;v[a+26|0]=0;v[a+32|0]=0;cC(a+48|0);cC(a+68|0);cC(a+88|0);cv(a+492|0);cv(a+524|0);ik(a,0,0);hk(a,0,0);x[a+40>>2]=0;x[a+44>>2]=0;Iv(a,b);b=a+108|0;d=MC(b);c=1;while(1){if((b|0)!=(d|0)){v[b|0]=c;c=c+1|0;b=b+1|0;continue}break}return a}function Ufa(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;e=fb-16|0;fb=e;x[31737]=0;W(1002,a|0);d=x[31737];x[31737]=0;a:{b:{c:{if((d|0)==1){break c}x[31737]=0;W(1003,b|0);d=x[31737];x[31737]=0;if((d|0)==1){break c}d=x[a+24>>2];b=qc(e+8|0,b);x[31737]=0;f=x[b+4>>2];x[e>>2]=x[b>>2];x[e+4>>2]=f;Za(1022,d|0,e|0,+c,1);d=x[31737];x[31737]=0;b=1;if((d|0)!=1){break b}}Y(T(0)|0)|0;x[31737]=0;V(989,5926,a|0,0,0);a=x[31737];x[31737]=0;if((a|0)==1){break a}Z();b=0}fb=e+16|0;return b|0}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function Dna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=fb-16|0;fb=b;i=x[a+16>>2];h=mg(1,2);e=hb;j=e;Pb(a,h,e);k=x[a+24>>2];l=x[a+20>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;e=x[a+8>>2];m=x[a+12>>2];while(1){if(d){d=d-1|0;g=x[b+8>>2];g=(((x[b+12>>2]&2147483647)<<1|g>>>31)&-2)+i|0;f=0;while(1){if((f|0)!=2){x[(f<<2)+b>>2]=v[f+g|0]<<8;f=f+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[b>>2],l);x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],k);Pb(b+8|0,e,m);c=c+8|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;Hg(a,h,j);fb=b+16|0}function b9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=fb-32|0;fb=c;a:{b:{c:{if(mo(b)){break c}x[c+20>>2]=b;if(y[a+44|0]){d=-1;if((Tk(c+20|0,4,1,x[a+32>>2])|0)==1){break c}break a}f=c+24|0;x[c+16>>2]=f;h=c+32|0;d=c+20|0;while(1){e=rr(x[a+36>>2],x[a+40>>2],d,f,c+12|0,c+24|0,h,c+16|0);if(x[c+12>>2]==(d|0)){break b}if((e|0)==3){if((Tk(d,1,1,x[a+32>>2])|0)==1){break c}break b}if(e>>>0>1){break b}g=c+24|0;d=x[c+16>>2]-g|0;if((Tk(g,1,d,x[a+32>>2])|0)!=(d|0)){break b}d=x[c+12>>2];if((e|0)==1){continue}break}}d=mo(b)?0:b;break a}d=-1}fb=c+32|0;return d|0}function y6(a){a=a|0;if(y[500560]){return x[125139]}if(!y[501664]){v[501664]=1}wd(501376,120540);wd(501388,120572);wd(501400,120608);wd(501412,120632);wd(501424,120656);wd(501436,120672);wd(501448,120692);wd(501460,120712);wd(501472,120740);wd(501484,120780);wd(501496,120812);wd(501508,120848);wd(501520,120884);wd(501532,120900);wd(501544,120916);wd(501556,120932);wd(501568,120656);wd(501580,120948);wd(501592,120964);wd(501604,120980);wd(501616,120996);wd(501628,121012);wd(501640,121028);wd(501652,121044);v[500560]=1;x[125139]=501376;return 501376}function Z8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-32|0;fb=c;d=y[a+52|0];a:{if(mo(b)){if(d){break a}b=x[a+48>>2];e=a,f=mo(b)^1,v[e+52|0]=f;break a}b:{if(!d){break b}x[c+16>>2]=x[a+48>>2];c:{d:{e:{d=c+20|0;switch(rr(x[a+36>>2],x[a+40>>2],c+16|0,d,c+12|0,c+24|0,c+32|0,d)-1|0){case 0:case 1:break c;case 2:break e;default:break d}}d=x[a+48>>2];x[c+20>>2]=c+25;v[c+24|0]=d}while(1){d=x[c+20>>2];if(d>>>0<=c+24>>>0){break b}d=d-1|0;x[c+20>>2]=d;if((zt(v[d|0],x[a+32>>2])|0)!=-1){continue}break}}b=-1;break a}v[a+52|0]=1;x[a+48>>2]=b}fb=c+32|0;return b|0}function RX(a){var b=0,c=0,d=0;a:{if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=1196314451){break a}c=y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24);if(c>>>0<1108){break a}b=a+1104|0;if((c-1108|0)!=(y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24))|c>>>0>262144){break a}c=a+1094|0;if(y[c|0]|y[c+1|0]<<8){break a}b=a+1096|0;if((y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24))-5>>>0<4294967292){break a}if(!Av(a+8|0)){break a}a=a+40|0;while(1){d=(a|0)==(c|0);if(d|y[a+32|0]>15|y[a+33|0]>64){break a}b=Av(a);a=a+34|0;if(b){continue}break}}return d}function Moa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=fb-16|0;fb=d;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);Rd(d+8|0,x[vb(d+4|0,a)>>2]);a:{if(b){x[31737]=0;O(712,a|0,b|0);c=x[31737];x[31737]=0;if((c|0)==1){break a}f=fb-16|0;fb=f;c=f+4|0;x[c>>2]=a;e=x[a+4>>2];x[c+4>>2]=e;x[c+8>>2]=e+D(b,9);b=x[c+4>>2];e=x[c+8>>2];while(1){if((b|0)==(e|0)){hc(c);fb=f+16|0}else{v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b+6|0]=0;v[b+7|0]=0;v[b+8|0]=0;b=b+9|0;x[c+4>>2]=b;continue}break}}b=d+8|0;Qd(b);HW(b);fb=d+16|0;return a|0}a=N()|0;HW(d+8|0);Q(a|0);p()}function wD(a,b){var c=0,d=0;a:{b:{c:{d:{e:{f:{g:{h:{d=y[a+3|0];switch(d|0){case 9:break d;case 10:break e;case 16:case 17:break g;case 0:case 1:case 2:case 3:case 11:case 12:case 13:case 14:case 15:break h;default:break a}}if(!y[a|0]){break a}switch(d|0){case 9:break d;case 10:break e;case 0:case 1:case 2:case 3:case 11:case 12:case 13:case 14:case 15:break f;case 16:case 17:break g;default:break c}}c=8;break c}c=y[a|0];if(!(c&7)){break c}}c=b+1>>>1|0;b=((d|0)==10)<<4;break b}c=16}c=D(c>>>3|0,b);b=((d|0)==10)<<4}c=b+D(mr(y[a+1|0]),c)|0}return c}function dja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=fb-16|0;fb=e;h=Hf(a,c);$d(e,x[a+36>>2]);a:{b:{if(!h){Pc(e,a+32|0,5);c=-1;if(!Hb(x[x[e>>2]>>2],x[e+4>>2])){break b}break a}c=x[h+16>>2]}f=x[a+36>>2];c:{if(!((c|0)!=4&(c|0)!=-1)){d=fb-16|0;fb=d;x[d+12>>2]=0;Bq(f,d+12|0);B[b>>2]=B[d+12>>2];break c}d=fb-16|0;fb=d;x[d+12>>2]=c;x[d+8>>2]=4;c=x[Gb(d+12|0,d+8|0)>>2];g=fb-16|0;fb=g;vz(g+8|0,f);f=x[g+12>>2];if(gq(-1,2147483647,c,0)^1){i=gq(c,0,0,-2147483648)^1}else{i=0}if(i){Hi(f,c,0,1)}fb=g+16|0;x[b>>2]=0}fb=d+16|0;d=h}ff(a,d);fb=e+16|0}function Yja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=fb-48|0;fb=d;c=d+28|0;_j(c,b,1819307379);hd(a+40|0,c);ub(c);_j(c,b,1953721961);hd(a+60|0,c);ub(c);_j(c,b,543520099);hd(a+120|0,c);ub(c);_j(c,b,1414744396);x[31737]=0;e=P(413,c|0,13891)|0;f=x[31737];x[31737]=0;a:{if((f|0)!=1){b:{if(e){x[31737]=0;e=d+8|0;S(811,e|0,c|0,2);c=x[31737];x[31737]=0;if((c|0)==1){break b}yv(a+140|0,e);ie(e)}x[31737]=0;S(812,d+8|0,b|0,1634890872);b=x[31737];x[31737]=0;if((b|0)!=1){break a}}}a=N()|0;ub(d+28|0);Q(a|0);p()}b=a+80|0;a=d+8|0;hd(b,a);ub(a);ub(d+28|0);fb=d+48|0}function xw(a,b){var c=0,d=0,e=0,f=0,g=0;f=fb-16|0;fb=f;g=f+4|0;e=fb-32|0;fb=e;c=rf(e+20|0,1,0);a:{b:{c:{while(1){d=Jb(c);ww(e+12|0,d,Cb(x[c+4>>2],y[c+11|0])+d|0,y[b|0]);if(!x[e+16>>2]){break c}d=qi(Cb(x[c+4>>2],y[c+11|0]));x[31737]=0;O(45,c|0,d|0);d=x[31737];x[31737]=0;if((d|0)!=1){continue}break}break b}b=x[e+12>>2];d=Jb(c);x[31737]=0;O(46,c|0,b-d|0);b=x[31737];x[31737]=0;d:{if((b|0)!=1){x[31737]=0;O(47,g|0,c|0);b=x[31737];x[31737]=0;if((b|0)!=1){break d}break b}break b}tb(c);fb=e+32|0;break a}a=N()|0;tb(c);Q(a|0);p()}Sh(a,g);tb(g);fb=f+16|0}function Zfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;x[31737]=0;W(1002,a|0);d=x[31737];x[31737]=0;a:{b:{c:{if((d|0)==1){break c}x[31737]=0;W(1003,b|0);d=x[31737];x[31737]=0;if((d|0)==1){break c}d=x[a+24>>2];b=qc(c+8|0,b);x[31737]=0;f=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=f;e=+oa(1013,d|0,c|0,1);b=x[31737];x[31737]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31737]=0;V(989,5963,a|0,0,0);a=x[31737];x[31737]=0;if((a|0)==1){break a}Z();e=0}fb=c+16|0;return+e}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function Ana(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=fb-16|0;fb=b;j=x[a+16>>2];h=mg(1,2);e=hb;k=e;Pb(a,h,e);f=x[a+40>>2];g=x[a+36>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;l=x[a+32>>2];m=x[a+28>>2];e=x[a+8>>2];n=x[a+12>>2];while(1){if(d){i=w[(x[b+12>>2]<<1)+j>>1];g=g+m|0;x[c>>2]=x[c>>2]+D(i,g>>12);f=f+l|0;x[c+4>>2]=x[c+4>>2]+D(f>>12,i);Pb(b+8|0,e,n);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=f;x[a+20>>2]=g>>12;x[a+36>>2]=g;x[a+24>>2]=f>>12;Hg(a,h,k);fb=b+16|0}function _fa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-16|0;fb=d;x[31737]=0;W(1002,a|0);c=x[31737];x[31737]=0;a:{b:{c:{if((c|0)==1){break c}x[31737]=0;W(1003,b|0);c=x[31737];x[31737]=0;if((c|0)==1){break c}c=x[a+24>>2];b=qc(d+8|0,b);x[31737]=0;e=x[b+4>>2];x[d>>2]=x[b>>2];x[d+4>>2]=e;b=U(1009,c|0,d|0,1)|0;c=x[31737];x[31737]=0;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[31737]=0;V(989,10052,a|0,0,0);a=x[31737];x[31737]=0;if((a|0)==1){break a}Z();b=0}fb=d+16|0;return b|0}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function Ola(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=fb-16|0;fb=f;h=z[c>>1];i=c;e=fb-16|0;fb=e;g=b;d=ce(b);a:{if(d){c=ec(b);while(1){b=d;d=z[b+14>>1];if(bl(h,d)){c=b;d=x[b>>2];if(d){continue}break a}if(!bl(d,h)){break a}c=b+4|0;d=x[b+4>>2];if(d){continue}break}break a}b=ec(g);c=b}x[e+12>>2]=b;b=x[c>>2];if(!b){b=fb-16|0;fb=b;d=ec(g);d=Bh(e,Ec(16),Mg(b+8|0,d));fj(x[d>>2]+14|0,z[i>>1]);k=ec(d),l=1,v[k+4|0]=l;fb=b+16|0;$g(g,x[e+12>>2],c,x[e>>2]);b=me(e);dm(e);j=1}c=f+8|0;_g(c,x[vb(e,b)>>2],j);fb=e+16|0;oV(a,c);fb=f+16|0}function mF(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=fb-16|0;fb=f;x[f+8>>2]=e;x[f+12>>2]=d;sf(a);Cs(a,c);d=0;e=0;a:while(1){if(c>>>0>d>>>0){i=c-d|0;x[f+4>>2]=i;g=x[Gb(f+12|0,f+4|0)>>2];h=g+e|0;l=e>>>0>h>>>0?e:h;j=Bs(Jt(a,b+d|0,g),1,13);while(1)if((e|0)==(l|0)){x[f+4>>2]=i-g;e=h+1|0;d=x[Gb(f+8|0,f+4|0)>>2]+(d+g|0)|0;continue a}else{b:{c:{d:{k=v[cc(j,e)|0];switch(k-10|0){case 1:case 2:break b;case 0:case 3:break c;default:break d}}if(k){break b}}m=cc(j,e),n=32,v[m|0]=n}e=e+1|0;continue}}break}fb=f+16|0}function Bna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=fb-16|0;fb=b;j=x[a+16>>2];h=mg(1,2);e=hb;k=e;Pb(a,h,e);f=x[a+40>>2];g=x[a+36>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;l=x[a+32>>2];m=x[a+28>>2];e=x[a+8>>2];n=x[a+12>>2];while(1){if(d){i=v[x[b+12>>2]+j|0]<<8;g=g+m|0;x[c>>2]=x[c>>2]+D(i,g>>12);f=f+l|0;x[c+4>>2]=x[c+4>>2]+D(f>>12,i);Pb(b+8|0,e,n);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=f;x[a+20>>2]=g>>12;x[a+36>>2]=g;x[a+24>>2]=f>>12;Hg(a,h,k);fb=b+16|0}function tka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=fb-208|0;fb=e;w[a+480212>>1]=0;x[a+480240>>2]=65536;x[a+480244>>2]=65536;wS(a+946304|0);f=a+906300|0;g=Ak(f);d=e+48|0;Rb(d,0,160);d=yS(d);x[31737]=0;S(864,f|0,g|0,d|0);f=x[31737];x[31737]=0;a:{if((f|0)!=1){UA(d);d=Ge(e+28|0,b);x[31737]=0;f=x[d+12>>2];x[e+16>>2]=x[d+8>>2];x[e+20>>2]=f;x[e+24>>2]=x[d+16>>2];f=x[d+4>>2];x[e+8>>2]=x[d>>2];x[e+12>>2]=f;a=U(865,a|0,e+8|0,c|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){a=N()|0;break a}ub(b);fb=e+208|0;return a|0}a=N()|0;UA(d)}ub(b);Q(a|0);p()}function FT(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;f=-1;a:{if(!(y[b+851|0]&2)){break a}d=!(y[a+480209|0]&32);b:{c:{d:{c=x[b+656>>2];e:{if(c){e=y[c+22|0];if(Cd(e)){g=b,h=Fh(e),v[g+838|0]=h;d=1}e=y[c+21|0];f:{if(Cd(e)){g=b,h=Fh(e),v[g+837|0]=h;break f}if(!d){break d}}d=1;c=y[c+25|0];if((c|0)==255){break e}v[b+845|0]=c;break e}x[b+776>>2]=0;x[b+780>>2]=0}c=b+837|0;if(y[b+837|0]>=127){break c}if(d){break b}break a}if(y[b+837|0]<127){break a}d=0;c=b+837|0}if(!d|!Ob(a+1074312|0,36)){break a}}f=Nq(a,b,1,256);if((f|0)<0){break a}f=y[c|0]>>>1|0}return f}function gz(a,b,c){var d=0,e=0,f=E(0),g=E(0),h=E(0),i=E(0),j=0,k=E(0),l=E(0),m=E(0);e=fb-32|0;fb=e;g=B[a+24>>2];f=B[a+12>>2];h=B[a+48>>2];i=B[a+36>>2];$L(E(-B[a>>2]),E(g+f),E(h+i),e+20|0);$L(B[a+60>>2],E(h-i),E(g-f),e+8|0);B[e+12>>2]=-B[e+12>>2];a=0;while(1){if((a|0)!=3){d=a<<2;j=d+c|0;g=B[j>>2];f=B[d+(e+20|0)>>2];h=B[d+87728>>2];i=B[d+87740>>2];k=B[d+(e+8|0)>>2];B[j>>2]=E(f*h)-E(i*k);j=b+d|0;l=B[(0-a<<2)+87736>>2];d=5-a<<2;m=B[d+87728>>2];f=E(E(f*i)+E(k*h));B[j>>2]=E(g*l)-E(m*f);B[b+d>>2]=E(g*m)+E(f*l);a=a+1|0;continue}break}fb=e+32|0}function kx(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-48|0;fb=e;f=x[b>>2];g=ib[x[x[f>>2]+36>>2]](f,c,d)|0;a:{if(!g){ai(a);break a}wm(e+32|0,x[b>>2],x[b+4>>2]);b=x[e+36>>2];x[e+16>>2]=x[e+32>>2];x[e+20>>2]=b;b=fb-16|0;fb=b;d=e+16|0;f=wm(b+8|0,x[d>>2],x[d+4>>2]);x[31737]=0;h=x[f+4>>2];x[b>>2]=x[f>>2];x[b+4>>2]=h;V(167,e+40|0,b|0,c|0,g|0);c=x[31737];x[31737]=0;b:{if((c|0)!=1){ke(d);fb=b+16|0;break b}a=N()|0;ke(d);Q(a|0);p()}b=Nd(e+24|0);c=x[e+44>>2];x[e+8>>2]=x[e+40>>2];x[e+12>>2]=c;c=x[b+4>>2];x[e>>2]=x[b>>2];x[e+4>>2]=c;Qp(a,e+8|0,e)}fb=e+48|0}function dC(a,b){var c=0,d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;c=x[a>>2];a:{if(!mc(c,x[a+4>>2])){w[c>>1]=0;Qf(c+2|0,b);f=d,g=Jk(wb(x[a>>2]),1),x[f+12>>2]=g;while(1){e=wb(x[a+4>>2]);c=x[d+12>>2];if(Ib(c,e)){f=c,g=z[pe(c,Jk(c,-1))>>1],w[f>>1]=g;Qf(c+2|0,b);yW(d+12|0);continue}else{Qf(a+14|0,Sd(x[a>>2],x[a+4>>2])-1&255);Qf(a+13|0,y[a+14|0]);Qf(a+16|0,Sd(x[a>>2],x[a+4>>2])-1&255);Qf(a+15|0,y[a+16|0]);if(y[a+17|0]==255){break a}Qf(a+17|0,Sd(x[a>>2],x[a+4>>2])-1&255);break a}}}v[a+17|0]=255;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0;v[a+16|0]=0}fb=d+16|0}function Fs(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-80|0;fb=e;f=x[c>>2];g=e+52|0;qH(g,c,71);x[31737]=0;c=e+4|0;S(d|0,c|0,b|0,(f&2?16:10)|0);b=x[31737];x[31737]=0;a:{b:{c:{d:{if((b|0)!=1){b=e+16|0;WV(b,c,x[e+52>>2]);x[31737]=0;d=e+28|0;V(300,d|0,b|0,x[e+52>>2],x[e+56>>2]);f=x[31737];x[31737]=0;if((f|0)==1){break d}x[31737]=0;f=e+40|0;S(301,f|0,d|0,g|0);h=x[31737];x[31737]=0;if((h|0)==1){break c}Sh(a,f);tb(f);tb(d);tb(b);tb(c);Hh(g);fb=e+80|0;return}c=N()|0;break a}c=N()|0;break b}c=N()|0;tb(e+28|0)}tb(e+16|0);tb(e+4|0)}Hh(e+52|0);Q(c|0);p()}function Eo(a,b,c,d){var e=0,f=0;e=fb-16|0;fb=e;a:{b:{c:{if(!d){break c}f=c>>31;d=f;d=(d^c)-d|0;if(d>>>0<224){break c}Kb(e+8|0,a+1074312|0,3);if(Hb(x[x[e+8>>2]>>2],x[e+12>>2])){break c}if(!(v[(D(b,872)+a|0)+1075843|0]&1)){break a}c=D(d&15,(c|0)!=0|f);c=d>>>0>239?c<<2:c;break b}if(v[(D(b,872)+a|0)+1075843|0]&1){Kb(e+8|0,a+1074312|0,3);if(!Hb(x[x[e+8>>2]>>2],x[e+12>>2])){break a}}c=c<<2}if(!c){break a}f=D(b,872)+a|0;d=x[f+1075648>>2];a=Iq(a,x[f+1075080>>2],d);if(!a){break a}ib[x[x[a>>2]+84>>2]](a,c,(d?y[d+33|0]:13)<<24>>24,b)}fb=e+16|0}function Zra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=x[a>>2];d=Mk(e,x[a+4>>2]);if(d>>>0<b>>>0){e=fb-32|0;fb=e;d=b-d|0;b=x[zb(a)>>2];f=x[a+4>>2];a:{if(d>>>0<=(b-f|0)/6>>>0){tD(a,d,c);break a}b=zb(a);b=yZ(e+12|0,oD(a,Mk(x[a>>2],f)+d|0),Mk(x[a>>2],x[a+4>>2]),b);xZ(b,d,c);c=fb-16|0;fb=c;d=vb(c+12|0,x[a+4>>2]);f=vb(c+8|0,x[a>>2]);g=vb(c+4|0,x[b+4>>2]);h=b,i=uZ(x[d>>2],x[f>>2],x[g>>2]),x[h+4>>2]=i;Tb(a,b+4|0);Tb(a+4|0,b+8|0);Tb(zb(a),nc(b));x[b>>2]=x[b+4>>2];fb=c+16|0;wZ(b)}fb=e+32|0;return}if(b>>>0<d>>>0){sD(a,e+D(b,6)|0)}}function Zma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=fb-16|0;fb=b;g=x[a+24>>2];h=x[a+20>>2];i=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;j=x[a+8>>2];k=x[a+12>>2];while(1){if(d){e=x[b+8>>2];f=(x[b+12>>2]<<1)+i|0;e=e>>>21&2040;e=(((D(w[f>>1],w[e+38194>>1])+D(w[f-2>>1],w[e+38192>>1])|0)+D(w[f+2>>1],w[e+38196>>1])|0)+D(w[f+4>>1],w[e+38198>>1])|0)/16384|0;x[c>>2]=x[c>>2]+D(e,h);x[c+4>>2]=x[c+4>>2]+D(e,g);Pb(b+8|0,j,k);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;fb=b+16|0}function aq(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-80|0;fb=e;f=x[c>>2];g=e+52|0;qH(g,c,3);x[31737]=0;c=e+4|0;S(d|0,c|0,b|0,(f&2?16:10)|0);b=x[31737];x[31737]=0;a:{b:{c:{d:{if((b|0)!=1){b=e+16|0;WV(b,c,x[e+52>>2]);x[31737]=0;d=e+28|0;V(19,d|0,b|0,x[e+52>>2],x[e+56>>2]);f=x[31737];x[31737]=0;if((f|0)==1){break d}x[31737]=0;f=e+40|0;S(20,f|0,d|0,g|0);h=x[31737];x[31737]=0;if((h|0)==1){break c}Sh(a,f);tb(f);tb(d);tb(b);tb(c);Hh(g);fb=e+80|0;return}c=N()|0;break a}c=N()|0;break b}c=N()|0;tb(e+28|0)}tb(e+16|0);tb(e+4|0)}Hh(e+52|0);Q(c|0);p()}function mS(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;x[e+12>>2]=16777216;h=e+12|0;d=x[a>>2];c=oc(d,x[a+4>>2]);a:{if(c>>>0<b>>>0){f=fb-32|0;fb=f;b=b-c|0;c=x[zb(a)>>2];d=x[a+4>>2];b:{if(b>>>0<=c-d>>2>>>0){XE(a,b,h);break b}c=zb(a);c=$f(f+12|0,Mf(a,oc(x[a>>2],d)+b|0),oc(x[a>>2],x[a+4>>2]),c);g=fb-16|0;fb=g;b=Ln(g+4|0,c+8|0,b);d=x[b>>2];while(1){if(x[b+4>>2]!=(d|0)){Co(d,x[h>>2]);d=x[b>>2]+4|0;x[b>>2]=d;continue}break}he(b);fb=g+16|0;Ym(a,c);_f(c)}fb=f+32|0;break a}if(b>>>0<c>>>0){Ih(a,d+(b<<2)|0)}}PA(a);fb=e+16|0}function m1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=fb-32|0;fb=e;ld(b,0);f=e+8|0;jk(f,1,a+33|0);d=e+20|0;Cc(d,f);ze(b+43|0,d);tb(d);g=y[a+50|0]|y[a+51|0]<<8|(y[a+52|0]<<16|y[a+53|0]<<24);x[b>>2]=g;x[b+24>>2]=y[a+54|0]|y[a+55|0]<<8;v[e+20|0]=y[a+56|0];v[e+8|0]=64;h=b,i=y[Qb(d,f)|0]<<2,w[h+30>>1]=i;d=y[a+57|0]|y[a+58|0]<<8|(y[a+59|0]<<16|y[a+60|0]<<24);x[b+4>>2]=d;f=y[a+61|0]|y[a+62|0]<<8|(y[a+63|0]<<16|y[a+64|0]<<24);c=c?d?g:f:f;x[b+8>>2]=c;if(!(!y[a|0]|c>>>0<=d+2>>>0|c>>>0>g>>>0)){w[b+34>>1]=z[b+34>>1]|2}fb=e+32|0}function Pja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;a:{g=fb-32|0;fb=g;a=Nb(a);b:{c:{d:{e:{while(1){e=x[b+8>>2];f=x[b>>2];x[31737]=0;e=U(151,f|0,e|0,8)|0;f=x[31737];x[31737]=0;if((f|0)==1){break c}if(e){x[31737]=0;e=g+4|0;S(913,e|0,b|0,c|0);f=x[31737];x[31737]=0;if((f|0)==1){break e}x[31737]=0;O(914,a|0,e|0);f=x[31737];x[31737]=0;if((f|0)==1){break d}Fd(e);f=e;e=Lr(x[a+4>>2]);wi(f,x[e>>2],x[e+4>>2]);if(x[g+4>>2]!=(d|0)){continue}}break}fb=g+32|0;break a}b=N()|0;break b}b=N()|0;Fd(g+4|0);break b}b=N()|0}ie(a);Q(b|0);p()}}function Dj(a,b,c){var d=0,e=0;e=fb-16|0;fb=e;x[a+4>>2]=0;d=4;a:{b:{c:{if(!Gd(y[Lm(e+15|0,a,1)|0])){break c}d=x[(x[x[a>>2]-12>>2]+a|0)+24>>2];x[31737]=0;b=U(86,d|0,b|0,c|0)|0;d=x[31737];x[31737]=0;if((d|0)!=1){x[a+4>>2]=b;d=(b|0)!=(c|0)?6:0;break c}Y(T(0)|0)|0;d=1;Jm(x[x[a>>2]-12>>2]+a|0,1);if(x[(x[x[a>>2]-12>>2]+a|0)+20>>2]&1){x[31737]=0;X(85);a=x[31737];x[31737]=0;if((a|0)!=1){break a}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)==1){break b}Q(a|0);p()}Z()}bk(x[x[a>>2]-12>>2]+a|0,d);fb=e+16|0;return a}T(0)|0;Sb()}p()}function uZ(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;e=fb-16|0;fb=e;g=e+8|0;d=fb-32|0;fb=d;Id(d+24|0,a,b);h=d+16|0;b=x[d+24>>2];i=x[d+28>>2];a=fb-16|0;fb=a;x[a+8>>2]=c;x[a+12>>2]=b;while(1){if(pd(b,i)){b=tZ(b);c=tZ(x[a+8>>2]);f=y[b+4|0]|y[b+5|0]<<8;v[c+4|0]=f;v[c+5|0]=f>>>8;b=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);v[c|0]=b;v[c+1|0]=b>>>8;v[c+2|0]=b>>>16;v[c+3|0]=b>>>24;b=nD(a+12|0);nD(a+8|0);b=x[b>>2];continue}break}Ac(h,b,a+8|0);fb=a+16|0;a=x[d+16>>2];x[d+12>>2]=x[d+20>>2];Ac(g,a,d+12|0);fb=d+32|0;fb=e+16|0;return x[e+12>>2]}function Ipa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=fb-80|0;fb=d;e=Tf(d+52|0);x[31737]=0;c=P(651,b|0,e|0)|0;f=x[31737];x[31737]=0;a:{b:{c:{d:{if((f|0)!=1){if(c){break d}x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[31737]=0;R(652,a|0)|0;a=x[31737];x[31737]=0;if((a|0)!=1){break a}}break c}c=x[e+4>>2];x[31737]=0;S(186,d+12|0,b|0,(c>>>0>=9?c-8|0:0)|0);b=x[31737];x[31737]=0;if((b|0)!=1){break b}}a=N()|0;Fd(e);Q(a|0);p()}b=d+12|0;c=ic(d+32|0,b);hd(e+8|0,c);ub(c);ub(b);Sk(a,e)}Fd(e);fb=d+80|0}function IQ(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=0,f=0;Yz(a);c=Pd(c,E(0));a:{switch(b|0){case 0:B[a+4220>>2]=c;return;case 1:B[a+4224>>2]=c;return;case 2:B[a+4228>>2]=c;ou(a);return;case 3:v[a+4240|0]=c>=E(.5);ou(a);return;case 4:b=fb-16|0;fb=b;e=b,f=Rl(E(c*E(32))),x[e+12>>2]=f;x[b+8>>2]=0;x[b+4>>2]=5;d=dk(b+12|0,b+8|0,b+4|0);fb=b+16|0;x[a+4232>>2]=x[d>>2];return;case 5:v[a+4241|0]=c>=E(.5);return;case 6:v[a+4242|0]=c>=E(.5);return;case 7:v[a+4244|0]=c>=E(.5);return;case 8:if(c==E(0)){Xz(a)}C[a+4256>>3]=c;break;default:break a}}}function rF(a){var b=0,c=0,d=0,e=0,f=0,g=0;a:{b=y[a|0]|y[a+1|0]<<8;b:{if((b|0)!=26217){if((b|0)!=20042){break a}if(y[a+110|0]<=64){break b}break a}if(y[a+110|0]>64){break a}}if(v[a+112|0]<0|y[a+111|0]>128){break a}b=a+110|0;c=a+2|0;while(1){if((c|0)==(b|0)){while(1){c=(f|0)==128;if(c){break a}d=a+f|0;b=v[d+113|0];if((b|0)<-2){break a}e=y[d+241|0];if(!e&(b|0)>=0|e>>>0>15){break a}f=f+1|0;if(y[d+369|0]<64){continue}break a}}g=(y[c|0]-32&255)>>>0<225;e=d+1|0;if(g|(e&255)>>>0<=40){d=g?d:e;c=c+1|0;continue}else{return 0}}}return c}function cla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;if(x[a+4>>2]!=x[zb(a)>>2]){d=fb-16|0;fb=d;c=d+4|0;x[c>>2]=a;a=x[a+4>>2];x[c+4>>2]=a;x[c+8>>2]=a+7;TT(x[c+4>>2],b);x[c+4>>2]=x[c+4>>2]+7;hc(c);fb=d+16|0;return}f=fb-32|0;fb=f;g=zb(a);h=f+12|0;e=EB(x[a>>2],x[a+4>>2])+1|0;c=fb-16|0;fb=c;x[c+12>>2]=e;a:{d=th(613566756);if(e>>>0<=d>>>0){e=FB(a);if(e>>>0<d>>>1>>>0){x[c+8>>2]=e<<1;d=x[ad(c+8|0,c+12|0)>>2]}fb=c+16|0;break a}dd();p()}c=WT(h,d,EB(x[a>>2],x[a+4>>2]),g);TT(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+7;VT(a,c);UT(c);fb=f+32|0}function L1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;x[c+12>>2]=x[x[a+1060>>2]>>2]-x[a+1064>>2];x[c+8>>2]=16384;d=x[Gb(c+12|0,c+8|0)>>2];x[a+1072>>2]=d;x[c+4>>2]=17;while(1){a:{if(!d){break a}e=x[c+4>>2];if((e|0)>17){break a}f=1<<e-1;d=gl(a,e);b:{c:{d:{if((e|0)<=6){if((d|0)!=(f|0)){break d}ds(c+4|0,gl(a,4));break b}if(e>>>0>16){break c}e=f-8|0;if((e|0)>(d|0)|(d|0)>(f+7|0)){break d}ds(c+4|0,d-e|0);break b}SF(a,d,f,b);break b}e=d&(f^-1);if(d&f){x[c+4>>2]=e+1;break b}SF(a,e,0,b)}d=x[a+1072>>2];continue}break}fb=c+16|0}function hra(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=fb-80|0;fb=d;c=Tf(d+52|0);x[31737]=0;e=P(523,b|0,c|0)|0;f=x[31737];x[31737]=0;a:{b:{c:{d:{if((f|0)!=1){if(e){break d}x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[31737]=0;R(524,a|0)|0;a=x[31737];x[31737]=0;if((a|0)!=1){break a}}break c}e=z[c+2>>1]|z[c+4>>1]<<16;x[31737]=0;S(186,d+12|0,b|0,e|0);b=x[31737];x[31737]=0;if((b|0)!=1){break b}}a=N()|0;Fd(c);Q(a|0);p()}b=d+12|0;e=ic(d+32|0,b);hd(c+8|0,e);ub(e);ub(b);XY(a,c)}Fd(c);fb=d+80|0}function _ma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=fb-16|0;fb=b;g=x[a+24>>2];h=x[a+20>>2];i=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;j=x[a+8>>2];k=x[a+12>>2];while(1){if(d){e=x[b+8>>2];f=x[b+12>>2]+i|0;e=e>>>21&2040;e=(((D(v[f|0],w[e+38194>>1])+D(v[f-1|0],w[e+38192>>1])|0)+D(v[f+1|0],w[e+38196>>1])|0)+D(v[f+2|0],w[e+38198>>1])<<8)/16384|0;x[c>>2]=x[c>>2]+D(e,h);x[c+4>>2]=x[c+4>>2]+D(e,g);Pb(b+8|0,j,k);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;fb=b+16|0}function TW(a){var b=0,c=0;a:{if((y[a+60|0]|y[a+61|0]<<8|(y[a+62|0]<<16|y[a+63|0]<<24))!=1297236819){break a}b=y[a+28|0]|y[a+29|0]<<8;b:{if(b>>>0<=63){if((b|0)==26){break b}break a}if(b>>>0>2112){break a}}b=y[a+42|0];if(b>>>0>64&(b|0)!=88|(y[a+48|0]|y[a+49|0]<<8)>>>0>64|(y[a+50|0]|y[a+51|0]<<8)>>>0>96){break a}b=y[a+52|0]|y[a+53|0]<<8;if(b>>>0>129&(b|0)!=257|(y[a+30|0]|y[a+31|0]<<8)|(y[a+38|0]|y[a+39|0]<<8|(y[a+40|0]<<16|y[a+41|0]<<24)|(y[a+44|0]|y[a+45|0]<<8|(y[a+46|0]<<16|y[a+47|0]<<24))!=1)){break a}c=WW(a+20|0)}return c}function sR(a,b,c,d){var e=0,f=0;e=fb-48|0;fb=e;x[e+44>>2]=d;x[e+40>>2]=d;a=Re(e+12|0,a,e+40|0,e+44|0);x[e+8>>2]=x[a+8>>2];d=x[a+4>>2];x[e>>2]=x[a>>2];x[e+4>>2]=d;Qe(e+24|0,e);while(1){if((b|0)!=(c|0)){Co(x[e+44>>2],x[b>>2]);x[e+44>>2]=x[e+44>>2]+4;b=b+4|0;continue}break}Pe(e+24|0);d=x[e+44>>2];if(!y[e+36|0]){b=fb-16|0;fb=b;a=vb(b+12|0,x[x[e+32>>2]>>2]);f=x[vb(b+8|0,x[x[e+28>>2]>>2])>>2];c=fb-16|0;fb=c;a=x[a>>2];x[c+12>>2]=a;while(1){if(pd(a,f)){qA(a);a=x[Mi(c+12|0)>>2];continue}break}fb=c+16|0;fb=b+16|0}fb=e+48|0;return d}function Yha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;a:{b:{c=y[a+11|0];c:{d:{if(Cd(c)){c=x[a+4>>2];d=ej(x[a+8>>2])-1|0;if((c|0)==(d|0)){break d}break c}d=10;c=Fh(c);if((c|0)!=10){break b}}c=fb-16|0;fb=c;e:{if((d|0)!=2147483631){f=Jb(a);e=c+4|0;if(d>>>0<=1073741798){x[c+12>>2]=d<<1;x[c+4>>2]=d+1;g=Dh(x[ad(e,c+12|0)>>2])+1|0}else{g=2147483631}sg(e,g);e=x[c+4>>2];if(d){Cg(e,f,d)}if((d|0)!=10){Db(f)}yd(a,e);of(a,x[c+8>>2]);fb=c+16|0;break e}pf();p()}c=d}d=x[a>>2];Yd(a,c+1|0);break a}Me(a,c+1|0);d=a}a=c+d|0;fd(a,b);fd(a+1|0,0)}function K1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;x[c+12>>2]=x[x[a+1060>>2]>>2]-x[a+1064>>2];x[c+8>>2]=32768;d=x[Gb(c+12|0,c+8|0)>>2];x[a+1072>>2]=d;x[c+4>>2]=9;while(1){a:{if(!d){break a}e=x[c+4>>2];if((e|0)>9){break a}f=1<<e-1;d=gl(a,e);b:{c:{d:{if((e|0)<=6){if((d|0)!=(f|0)){break d}ds(c+4|0,gl(a,3));break b}if(e>>>0>8){break c}e=f-4|0;if((e|0)>(d|0)|(d|0)>(f+3|0)){break d}ds(c+4|0,d-e|0);break b}RF(a,d,f,b);break b}e=d&(f^-1);if(d&f){x[c+4>>2]=e+1;break b}RF(a,e,0,b)}d=x[a+1072>>2];continue}break}fb=c+16|0}function Vsa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{e=fb-32|0;fb=e;a=Nb(a);b:{c:{d:{e:{while(1){c=x[b+8>>2];d=x[b>>2];x[31737]=0;c=U(151,d|0,c|0,8)|0;d=x[31737];x[31737]=0;if((d|0)==1){break c}if(c){x[31737]=0;c=e+4|0;O(408,c|0,b|0);d=x[31737];x[31737]=0;if((d|0)==1){break e}x[31737]=0;O(409,a|0,c|0);d=x[31737];x[31737]=0;if((d|0)==1){break d}Fd(c);d=c;c=Lr(x[a+4>>2]);wi(d,x[c>>2],x[c+4>>2]);if(($b(x[e+4>>2])|0)!=1162757187){continue}}break}fb=e+32|0;break a}b=N()|0;break b}b=N()|0;Fd(e+4|0);break b}b=N()|0}ie(a);Q(b|0);p()}}function nP(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=fb-32|0;fb=d;g=Nb(a);a=0;a:{b:{c:{d:{e:{while(1){c=x[b+24>>2];if(z[c+480188>>1]<=a>>>0){break a}x[31737]=0;f=d+8|0;O(1058,f|0,(c+(a<<5)|0)+480289|0);c=x[31737];x[31737]=0;if((c|0)!=1){e=x[b+24>>2];x[31737]=0;c=d+20|0;S(1059,c|0,e|0,f|0);e=x[31737];x[31737]=0;if((e|0)==1){break e}x[31737]=0;O(179,g|0,c|0);e=x[31737];x[31737]=0;if((e|0)==1){break d}a=a+1|0;tb(c);tb(f);continue}break}a=N()|0;break b}a=N()|0;break c}a=N()|0;tb(d+20|0)}tb(d+8|0)}Td(g);Q(a|0);p()}fb=d+32|0}function Sta(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;ld(b,0);g=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);x[b>>2]=g;e=y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24);x[b+12>>2]=e;f=y[a+8|0]|y[a+9|0]<<8|(y[a+10|0]<<16|y[a+11|0]<<24);x[b+16>>2]=f;c=y[a+12|0]|y[a+13|0]<<8;w[b+32>>1]=64;x[b+24>>2]=c;c=y[a+14|0];w[b+30>>1]=c?c+1|0:256;d=z[b+34>>1]&32767|!y[a+14|0]<<15;w[b+34>>1]=d;c=y[a+15|0];if(!(!(c&1)|e>>>0>=f>>>0)){d=d|8;w[b+34>>1]=d;c=y[a+15|0]}if(c&2){x[b+16>>2]=f>>>1;x[b+12>>2]=e>>>1;x[b>>2]=g>>>1;w[b+34>>1]=d|1}}function xN(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-16|0;fb=d;a:{b:{c:{a=x[a+32>>2];e=xq(a);d:{if(!e){if(wq(a)>>>0<=b>>>0){break d}a=ti(a,b+1&65535);w[a+34>>1]=z[a+34>>1]&64511|(c?1024:0);break b}if(b>>>0<e>>>0){break c}}a=ac(8);x[31737]=0;b=P(36,d+4|0,6e3)|0;c=x[31737];x[31737]=0;e:{if((c|0)!=1){pc(a,b);x[31737]=0;S(98,a|0,48540,1006);a=x[31737];x[31737]=0;if((a|0)!=1){break a}c=N()|0;tb(b);break e}c=N()|0;jc(a)}Q(c|0);p()}a=x[(a+(b<<2)|0)+900384>>2];if(!a){break b}v[a+15|0]=y[a+15|0]&253|(c?2:0)}fb=d+16|0;return}p()}function Tc(a){var b=0,c=0,d=0;d=fb-16|0;fb=d;b=d+4|0;x[b+4>>2]=1205;x[b>>2]=a;x[b+8>>2]=0;c=fb-16|0;fb=c;if(x[a>>2]!=-1){a:{b=vb(c+8|0,yf(c+12|0,b));while(1){if(x[a>>2]==1){continue}break}b:{if(!x[a>>2]){yd(a,1);b=x[x[b>>2]>>2];x[31737]=0;W(1206,b|0);b=x[31737];x[31737]=0;if((b|0)==1){break b}x[a>>2]=-1}break a}Y(T(0)|0)|0;yd(a,0);x[31737]=0;X(85);a=x[31737];x[31737]=0;c:{if((a|0)==1){a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)!=1){break c}T(0)|0;Sb()}p()}Q(a|0);p()}}fb=c+16|0;fb=d+16|0;return x[a+4>>2]-1|0}function mj(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=fb-16|0;fb=e;o(+b);g=j(1)|0;c=j(0)|0;d=g&2147483647;f=d+-1048576|0;a:{if((f|0)==2145386495|f>>>0<2145386495){h=c<<28;c=(d&15)<<28|c>>>4;d=(d>>>4|0)+1006632960|0;break a}if((d|0)==2146435072|d>>>0>2146435072){h=c<<28;c=(g&15)<<28|c>>>4;d=g>>>4|2147418112;break a}if(!(c|d)){c=0;d=0;break a}f=c;c=d?G(d):G(c)+32|0;bg(e,f,d,0,0,c+49|0);i=x[e>>2];h=x[e+4>>2];f=15372-c<<16;c=x[e+8>>2];d=f|x[e+12>>2]^65536}x[a>>2]=i;x[a+4>>2]=h;x[a+8>>2]=c;x[a+12>>2]=g&-2147483648|d;fb=e+16|0}function UW(a,b,c,d,e,f){b=y[(b&15)+25440|0];v[a+3|0]=b;a:{b:{switch(b-11|0){case 0:b=y[a+5|0];c=b&15;if(c){v[a+5|0]=c;return}v[a+5|0]=b&240;return;case 3:b=y[a+5|0];b=D(b&240,10)|b&15;v[a+5|0]=b;d=b&255;b=z[e>>1];if(!(d|(b|0)==65535)){v[a+5|0]=b;v[a+3|0]=12;w[e>>1]=65535}wc(f,c);return;case 1:w[e>>1]=y[a+5|0];x[f>>2]=63;v[a+3|0]=0;return;case 5:b=y[a+5|0];if(d>>>0<=20){c=((b&255)>>>0)/10|0;b=c<<4|D(c,-10)+b;v[a+5|0]=b}if(b&255){break a}v[a+3|0]=0;return;case 7:break a;default:break b}}if(y[a+5|0]){break a}v[a+3|0]=0}}function Kla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;a:{c=fb-16|0;fb=c;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);Rd(c+8|0,x[vb(c+4|0,a)>>2]);b:{d=Zc(x[b>>2],x[b+4>>2]);if(!d){break b}x[31737]=0;O(642,a|0,d|0);e=x[31737];x[31737]=0;if((e|0)!=1){e=x[b+4>>2];f=x[b>>2];x[31737]=0;ZU(a,f,e,d);d=x[31737];x[31737]=0;if((d|0)!=1){break b}}a=N()|0;Yj(c+8|0);Q(a|0);p()}d=c+8|0;Qd(d);Yj(d);fb=c+16|0;x[31737]=0;P(3,a+12|0,b+12|0)|0;c=x[31737];x[31737]=0;if((c|0)!=1){x[a+24>>2]=x[b+24>>2];w[a+28>>1]=z[b+28>>1];break a}b=N()|0;md(a);Q(b|0);p()}}function upa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{e=fb-32|0;fb=e;a=Nb(a);b:{c:{d:{e:{while(1){c=x[b+8>>2];d=x[b>>2];x[31737]=0;c=U(151,d|0,c|0,8)|0;d=x[31737];x[31737]=0;if((d|0)==1){break c}if(c){x[31737]=0;c=e+4|0;O(682,c|0,b|0);d=x[31737];x[31737]=0;if((d|0)==1){break e}x[31737]=0;O(683,a|0,c|0);d=x[31737];x[31737]=0;if((d|0)==1){break d}Fd(c);d=c;c=Lr(x[a+4>>2]);wi(d,x[c>>2],x[c+4>>2]);if(x[e+4>>2]!=1413891155){continue}}break}fb=e+32|0;break a}b=N()|0;break b}b=N()|0;Fd(e+4|0);break b}b=N()|0}ie(a);Q(b|0);p()}}function sga(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;v[a+4202|0]=1;c=Gk(E(E(A[x[a+16>>2]+24620>>2])*E(.04500000178813934)));d=Gk(E(E(c>>>0)*E(1.1892070770263672)));e=Gk(E(E(d>>>0)*E(1.1892070770263672)));h=Gk(E(E(e>>>0)*E(1.1892070770263672)));f=Gk(E(E(c+e>>>0)*E(.11546666920185089)));g=Gk(E(E(d+h>>>0)*E(.11546666920185089)));b=a+4272|0;i=yb(b,0),j=c-f|0,x[i>>2]=j;i=yb(b,1),j=e-f|0,x[i>>2]=j;i=yb(b,2),j=d-g|0,x[i>>2]=j;i=yb(b,3),j=h-g|0,x[i>>2]=j;i=yb(b,4),j=f,x[i>>2]=j;i=yb(b,5),j=g,x[i>>2]=j;UP(a);SP(a)}function jqa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=fb-608|0;fb=b;c=fb-16|0;fb=c;d=b+8|0;eY(c+8|0,d);e=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);f=x[c+4>>2];if((f|0)==(e|0)){gd(a,x[c+12>>2])}fb=c+16|0;e=(e|0)==(f|0);if(!e){dY(d)}c=-1;a:{if(!e){break a}c=0;if(!fY(d)){break a}c=-1;if(!kh(a,1024)){break a}c=0;e=fb-1024|0;fb=e;d=fb-16|0;fb=d;PC(d+8|0,e);f=x[d+12>>2];od(d,a,x[d+8>>2],x[d+12>>2]);g=x[d+4>>2];if((f|0)==(g|0)){gd(a,x[d+12>>2])}fb=d+16|0;if((f|0)==(g|0)){c=QC(e,0)>>>0<17}fb=e+1024|0}fb=b+608|0;return c|0}function NS(a,b,c){var d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;a:{if(b){v[c|0]=b;break a}b=y[c|0]}e=x[a+480180>>2];c=e&1048580?(b&240?-16:15)&b:b;b=c&15;c=c&255;b:{c:{d:{if(!((b|0)!=15|c>>>0<16)){if(!(y[a+480209|0]&16)){break b}b=c>>>3&30;break d}f=x[a+480208>>2]&4096;g=c&240;if(!(!b|(g|0)!=240)){if(!f){break b}b=0-(b<<1)|0;break c}if(f){break b}if(g){if(e&59314208?b:0){break b}b=c>>>3&30;break d}b=0-(b<<1)|0}if(!b){break b}}a=a+1074456|0;x[d+12>>2]=x[a>>2]+(b<<!(e&59314208));Fe(d+12|0,0,256);x[a>>2]=x[d+12>>2]}fb=d+16|0}function GB(a,b){var c=0;if(b>>>0<=999999){if(b>>>0<=9999){if(b>>>0<=99){if(b>>>0<=9){return Pq(a,b)}return Ul(a,b)}if(b>>>0<=999){c=a;a=(b>>>0)/100|0;return Ul(Pq(c,a),D(a,-100)+b|0)}return CB(a,b)}if(b>>>0<=99999){c=a;a=(b>>>0)/1e4|0;return CB(Pq(c,a),D(a,-1e4)+b|0)}return AB(a,b)}if(b>>>0<=99999999){if(b>>>0<=9999999){c=a;a=(b>>>0)/1e6|0;return AB(Pq(c,a),D(a,-1e6)+b|0)}return Ru(a,b)}if(b>>>0<=999999999){c=a;a=(b>>>0)/1e8|0;return Ru(Pq(c,a),D(a,-1e8)+b|0)}c=a;a=(b>>>0)/1e8|0;return Ru(Ul(c,a),D(a,-1e8)+b|0)}function kpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-80|0;fb=c;d=Tf(c+52|0);x[31737]=0;e=P(689,b|0,d|0)|0;f=x[31737];x[31737]=0;a:{b:{c:{d:{if((f|0)!=1){if(e){break d}x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[31737]=0;R(690,a|0)|0;a=x[31737];x[31737]=0;if((a|0)!=1){break a}}break c}e=x[d+4>>2];x[31737]=0;S(186,c+12|0,b|0,e|0);b=x[31737];x[31737]=0;if((b|0)!=1){break b}}a=N()|0;Fd(d);Q(a|0);p()}b=c+12|0;e=ic(c+32|0,b);hd(d+8|0,e);ub(e);ub(b);Sk(a,d)}Fd(d);fb=c+80|0}function Mta(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=fb-32|0;fb=c;ld(b,0);e=c+8|0;jk(e,1,a);d=c+20|0;Cc(d,e);ze(b+43|0,d);tb(d);x[b+24>>2]=y[a+32|0]|y[a+33|0]<<8|(y[a+34|0]<<16|y[a+35|0]<<24);w[b+34>>1]=z[b+34>>1]&65533|(y[a+13|0]|y[a+14|0]<<8)<<1&2;x[b>>2]=y[a+16|0]|y[a+17|0]<<8|(y[a+18|0]<<16|y[a+19|0]<<24);x[b+4>>2]=y[a+20|0]|y[a+21|0]<<8|(y[a+22|0]<<16|y[a+23|0]<<24);x[b+8>>2]=y[a+24|0]|y[a+25|0]<<8|(y[a+26|0]<<16|y[a+27|0]<<24);v[c+20|0]=y[a+15|0];v[c+8|0]=64;f=b,g=y[Qb(d,e)|0]<<2,w[f+30>>1]=g;fb=c+32|0}function ssa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=fb-32|0;fb=e;d=rf(e+20|0,1,0);a:{b:{while(1){f=Jb(d);hC(e+12|0,f,Cb(x[d+4>>2],y[d+11|0])+f|0,z[b>>1],c);if(!x[e+16>>2]){break b}f=qi(Cb(x[d+4>>2],y[d+11|0]));x[31737]=0;O(45,d|0,f|0);f=x[31737];x[31737]=0;if((f|0)!=1){continue}break}break a}b=x[e+12>>2];c=Jb(d);x[31737]=0;O(46,d|0,b-c|0);b=x[31737];x[31737]=0;c:{if((b|0)!=1){x[31737]=0;O(47,a|0,d|0);a=x[31737];x[31737]=0;if((a|0)!=1){break c}break a}break a}tb(d);fb=e+32|0;return}a=N()|0;tb(d);Q(a|0);p()}function r6(a){a=a|0;if(y[500552]){return x[125137]}if(!y[501360]){v[501360]=1}id(501072,5034);id(501084,5025);id(501096,10891);id(501108,10635);id(501120,5261);id(501132,11668);id(501144,5118);id(501156,5609);id(501168,8902);id(501180,8885);id(501192,8893);id(501204,8912);id(501216,10089);id(501228,13330);id(501240,8975);id(501252,7714);id(501264,5261);id(501276,9778);id(501288,10494);id(501300,10903);id(501312,9265);id(501324,6463);id(501336,5492);id(501348,13248);v[500552]=1;x[125137]=501072;return 501072}function Y9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=fb-32|0;fb=e;d=rf(e+20|0,1,0);a:{b:{while(1){f=Jb(d);ON(e+12|0,f,Cb(x[d+4>>2],y[d+11|0])+f|0,y[b|0],c);if(!x[e+16>>2]){break b}f=qi(Cb(x[d+4>>2],y[d+11|0]));x[31737]=0;O(45,d|0,f|0);f=x[31737];x[31737]=0;if((f|0)!=1){continue}break}break a}b=x[e+12>>2];c=Jb(d);x[31737]=0;O(46,d|0,b-c|0);b=x[31737];x[31737]=0;c:{if((b|0)!=1){x[31737]=0;O(304,a|0,d|0);a=x[31737];x[31737]=0;if((a|0)!=1){break c}break a}break a}tb(d);fb=e+32|0;return}a=N()|0;tb(d);Q(a|0);p()}function v1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=fb-16|0;fb=b;c=-1;d=b+12|0;a:{if(!eF(a,d)){break a}b:{if(dF(d)){if(gd(a,32)){break b}break a}c=0;if(!cF(b+12|0)){break a}}e=b+7|0;d=bF(y[b+15|0]);c=fb-32|0;fb=c;x[c+28>>2]=d;x[c+8>>2]=5;d=x[Gb(c+28|0,c+8|0)>>2];if(!kh(a,d)){d=(ib[x[x[a>>2]+24>>2]](a)|0)-x[a+12>>2]|0}f=c+8|0;ek(f,e);g=gc(c+16|0,x[c+8>>2],d);od(c,a,x[g>>2],x[g+4>>2]);ek(f,e);Rb(x[c+8>>2]+d|0,0,5-d|0);gd(a,x[c+28>>2]);fb=c+32|0;if(!d){c=-1;break a}c=aF(b+7|0,y[b+15|0])}fb=b+16|0;return c|0}function jV(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;k=b?33:32;c=y[a+16|0];l=c?-1:1;m=c?1:-1;e=x[a+8>>2]-1|0;n=c?e-(y[a+17|0]!=0&(e|0)!=0)|0:0;f=x[a+12>>2];o=(f|0)>0?f:0;p=c?0:e;h=x[a>>2]+D(f,62)|0;d=b?1:-1;q=D(f,d)<<1;c=e;a:while(1){if((i|0)!=(k|0)){g=x[a+4>>2]+(D(c,f)<<1)|0;b=0;while(1)if((b|0)==(o|0)){b:{if((c|0)==(e|0)){b=n;g=l;if((d|0)>0){break b}}b=c+d|0;c=!c&(d|0)<0;b=c?p:b;g=c?m:d}h=h+q|0;i=i+1|0;c=b;d=g;continue a}else{j=b<<1;w[j+h>>1]=z[g+j>>1];b=b+1|0;continue}}break}}function P3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(mh(a,x[b+8>>2],e)){Ox(b,c,d);return}a:{if(mh(a,x[b>>2],e)){if(!(x[b+16>>2]!=(c|0)&x[b+20>>2]!=(c|0))){if((d|0)!=1){break a}x[b+32>>2]=1;return}x[b+32>>2]=d;b:{if(x[b+44>>2]==4){break b}w[b+52>>1]=0;a=x[a+8>>2];ib[x[x[a>>2]+20>>2]](a,b,c,c,1,e);if(y[b+53|0]){x[b+44>>2]=3;if(!y[b+52|0]){break b}break a}x[b+44>>2]=4}x[b+20>>2]=c;x[b+40>>2]=x[b+40>>2]+1;if(x[b+36>>2]!=1|x[b+24>>2]!=2){break a}v[b+54|0]=1;return}a=x[a+8>>2];ib[x[x[a>>2]+24>>2]](a,b,c,d,e)}}function zK(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;a:{b:{if((a|0)!=(b|0)){c:{h=x[31612];x[31612]=0;Od();f=yK(a,e+12|0,d);a=f;d=hb;d:{g=x[31612];if(g){if(x[e+12>>2]!=(b|0)){break c}if((g|0)!=68){break d}x[c>>2]=4;a=2147483647;if(!!f&(d|0)>=0|(d|0)>0){break a}break b}x[31612]=h;if(x[e+12>>2]==(b|0)){break d}break c}if((d|0)<0&a>>>0<=2147483647|(d|0)<-1){x[c>>2]=4;break b}if((d|0)>=0&a>>>0>=2147483648|(d|0)>0){x[c>>2]=4;a=2147483647;break a}break a}}x[c>>2]=4;a=0;break a}a=-2147483648}fb=e+16|0;return a}function Qv(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=fb-16|0;fb=g;x[g+12>>2]=0;x[g+8>>2]=a;h=fb-16|0;fb=h;c=gc(h+8|0,x[g+8>>2],x[g+12>>2]);f=fb-16|0;fb=f;b=122;x[f+12>>2]=122;d=x[c+4>>2];a:{if(!d){d=x[c>>2];break a}e=32-d|0;x[f+8>>2]=e;b=x[c>>2];i=x[b>>2];j=e;e=x[Gb(f+8|0,f+12|0)>>2];x[b>>2]=(-1<<d&-1>>>j-e^-1)&i;i=x[f+12>>2];d=b+4|0;x[c>>2]=d;b=i-e|0}e=d;d=b>>>5|0;JF(e,d);b=b&31;x[f+12>>2]=b;if(b){e=c;c=x[c>>2]+(d<<2)|0;x[e>>2]=c;x[c>>2]=x[c>>2]&(-1>>>32-b^-1)}fb=f+16|0;fb=h+16|0;fb=g+16|0;return a}function vH(a,b,c,d){var e=0,f=0,g=0;e=fb-80|0;fb=e;f=Tf(e+52|0);x[31737]=0;d=P(d|0,b|0,f|0)|0;g=x[31737];x[31737]=0;a:{b:{c:{d:{if((g|0)!=1){if(d){break d}x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[31737]=0;R(c|0,a|0)|0;a=x[31737];x[31737]=0;if((a|0)!=1){break a}}break c}c=x[f+4>>2];x[31737]=0;S(186,e+12|0,b|0,$b(c)|0);b=x[31737];x[31737]=0;if((b|0)!=1){break b}}a=N()|0;Fd(f);Q(a|0);p()}b=e+12|0;c=ic(e+32|0,b);hd(f+8|0,c);ub(c);ub(b);Sk(a,f)}Fd(f);fb=e+80|0}function iI(a,b,c,d,e){var f=0,g=0,h=0,i=0;g=fb-16|0;fb=g;h=Fb(a);a=0;a:{b:{c:{d:{while(1){f=x[b>>2];if(Ud(f,x[b+4>>2])>>>0<=a>>>0){break c}e:{if(!a){f=Hd(f,0);break e}x[31737]=0;P(d|0,h|0,c|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break b}f=Hd(x[b>>2],a)}x[31737]=0;i=g+4|0;O(e|0,i|0,f|0);f=x[31737];x[31737]=0;if((f|0)!=1){x[31737]=0;P(d|0,h|0,i|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break d}a=a+1|0;tb(i);continue}break}a=N()|0;break a}a=N()|0;tb(g+4|0);break a}fb=g+16|0;return}a=N()|0}tb(h);Q(a|0);p()}function Wpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;bc(c+8|0,b,26);d=x[c+12>>2];lc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;if((d|0)!=(e|0)){v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b+6|0]=0;v[b+7|0]=0;v[b+24|0]=0;v[b+25|0]=0;v[b+16|0]=0;v[b+17|0]=0;v[b+18|0]=0;v[b+19|0]=0;v[b+20|0]=0;v[b+21|0]=0;v[b+22|0]=0;v[b+23|0]=0;v[b+8|0]=0;v[b+9|0]=0;v[b+10|0]=0;v[b+11|0]=0;v[b+12|0]=0;v[b+13|0]=0;v[b+14|0]=0;v[b+15|0]=0}}function $O(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0;b=fb-16|0;fb=b;a:{c=x[a+36>>2];d=x[a+40>>2];b:{if(Ib(c,d)){sc(b+12|0);break b}zo(b,a);x[31737]=0;c=R(1062,b|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break a}x[b+12>>2]=c;nf(b);d=x[a+40>>2];c=x[a+36>>2]}c=(f=a+36|0,g=x[b+12>>2],h=Ib(c,d),h?f:g);a=x[a+8>>2];c:{if((a|0)==-1){a=wb(x[c>>2]);x[b>>2]=a;c=wb(x[c+4>>2]);while(1){if(!Ib(a,c)){break c}e=e+C[a>>3];a=x[fA(b)>>2];continue}}e=C[wf(x[c>>2],a)>>3]}El(b+12|0);fb=b+16|0;return+e}a=N()|0;nf(b);Q(a|0);p()}function dn(a,b,c,d){var e=0;a:{e=a+1074312|0;if(Ob(e,84)){break a}b:{if(y[a+480209|0]&64){break b}if((d|0)!=8){if(!Ob(e,10)){break b}}x[b+88>>2]=x[b+88>>2]&-257}c:{d:{e:{switch(d-4|0){case 0:c=((c<<8|8)>>>0)/15|0;break d;case 2:c=(c>>>0>=64?64:c)<<2;break d;default:break e}}if(!(x[a+480180>>2]&2107410)){break d}if(c>>>0<=128){c=c<<1;break d}if((c|0)!=164){break c}x[b+88>>2]=x[b+88>>2]|256;c=128}x[b+692>>2]=c}w[b+784>>1]=0;x[b+88>>2]=x[b+88>>2]|2097152;if(!Ob(e,10)){break a}v[b+831|0]=0;w[b+778>>1]=0}}function Bra(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(x[a+4>>2]!=x[zb(a)>>2]){c=fb-16|0;fb=c;a=wx(c+4|0,a);d=x[a+4>>2];x[31737]=0;O(502,d|0,b|0);b=x[31737];x[31737]=0;a:{if((b|0)!=1){x[a+4>>2]=x[a+4>>2]+12;hc(a);fb=c+16|0;break a}b=N()|0;hc(a);Q(b|0);p()}return}d=fb-32|0;fb=d;c=zb(a);c=Dm(d+12|0,Wp(a,Ud(x[a>>2],x[a+4>>2])+1|0),Ud(x[a>>2],x[a+4>>2]),c);e=x[c+8>>2];x[31737]=0;O(502,e|0,b|0);b=x[31737];x[31737]=0;b:{if((b|0)!=1){x[c+8>>2]=x[c+8>>2]+12;vx(a,c);zs(c);fb=d+32|0;break b}a=N()|0;zs(c);Q(a|0);p()}}function N4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=b&512;f=b&256;g=b&128;h=b&64;i=b&32;j=b&16;k=b&8;l=b&4;m=b&2;b=b&1;a:{while(1){if((c|0)==(d|0)){break a}a=x[c>>2];b:{c:{if(b){if(vt(a)){break c}}if(m){if(ut(a)){break c}}if(l){if(tt(a)){break c}}if(k){if(st(a)){break c}}if(j){if(rt(a)){break c}}if(i){if(qt(a)){break c}}if(h){if(Oh(a)){break c}}if(g){if(pt(a)){break c}}if(f){if(ot(a)){break c}}if(!e){break b}if(!nt(a)){break b}}c=c+4|0;continue}break}d=c}return d|0}function Aea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=E(0);x[31737]=0;W(1002,a|0);d=x[31737];x[31737]=0;a:{if((d|0)==1){break a}x[31737]=0;W(1074,c|0);d=x[31737];x[31737]=0;if((d|0)==1){break a}d=x[a+24>>2];e=B[d+48>>2];d=x[d+24>>2];x[31737]=0;b=Ya(1075,d|0,E(e),b|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break a}x[c>>2]=b;return 1}Y(T(0)|0)|0;x[31737]=0;V(989,10369,a|0,0,0);a=x[31737];x[31737]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function opa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;e=fb-32|0;fb=e;ld(b,0);d=e+8|0;ND(d,a+1|0);c=e+20|0;Cc(c,d);ze(b+43|0,c);tb(c);x[b+24>>2]=y[a+73|0]|y[a+74|0]<<8|(y[a+75|0]<<16|y[a+76|0]<<24);c=y[a+54|0]|y[a+55|0]<<8|(y[a+56|0]<<16|y[a+57|0]<<24);x[b>>2]=c;x[b+4>>2]=y[a+58|0]|y[a+59|0]<<8|(y[a+60|0]<<16|y[a+61|0]<<24);d=y[a+62|0]|y[a+63|0]<<8|(y[a+64|0]<<16|y[a+65|0]<<24);if(d){x[b+8>>2]=d+1}w[b+30>>1]=(y[a+68|0]<<1)+2;w[b+34>>1]=z[b+34>>1]&65533|y[a|0]>>>6&2;wc(b+8|0,c);wc(b+4|0,x[b+8>>2]);fb=e+32|0}function gn(a,b,c,d,e,f){var g=0,h=0,i=0,j=0;a:{if(f&64){c=f+-64|0;b=c&31;if((c&63)>>>0>=32){c=0;b=e>>>b|0}else{c=e>>>b|0;b=((1<<b)-1&e)<<32-b|d>>>b}d=0;e=0;break a}if(!f){break a}i=d;h=64-f|0;g=h&31;if((h&63)>>>0>=32){h=d<<g;j=0}else{h=(1<<g)-1&i>>>32-g|e<<g;j=i<<g}i=b;b=f&31;if((f&63)>>>0>=32){g=0;b=c>>>b|0}else{g=c>>>b|0;b=((1<<b)-1&c)<<32-b|i>>>b}b=j|b;c=g|h;g=d;d=f&31;if((f&63)>>>0>=32){h=0;d=e>>>d|0}else{h=e>>>d|0;d=((1<<d)-1&e)<<32-d|g>>>d}e=h}x[a>>2]=b;x[a+4>>2]=c;x[a+8>>2]=d;x[a+12>>2]=e}function ska(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=(b-a|0)/160|0;while(1){if((b|0)>0){b=b-1|0;x[a>>2]=x[c>>2];d=a+4|0;if((d|0)!=(c+4|0)){e=fb-16|0;fb=e;g=x[c+4>>2];h=x[c+8>>2];f=Vj(g,h);a:{if(f>>>0<=dp(d)>>>0){j=h;k=x[d>>2];i=Vc(k,x[d+4>>2]);l=i>>>0>=f>>>0;if(!l){x[e+12>>2]=g;c$(e+12|0,i);j=x[e+12>>2]}i=Wg(g,j,k);if(!l){uv(d,j,h,f-Vc(x[d>>2],x[d+4>>2])|0);break a}or(d,i);break a}_v(d);$k(d,bm(d,f));uv(d,g,h,f)}fb=e+16|0}yc(a+16|0,c+16|0,144);a=a+160|0;continue}break}}function pH(a,b,c,d){var e=0,f=0,g=0;f=fb-32|0;fb=f;e=rf(f+20|0,1,0);a:{b:{while(1){g=Jb(e);hC(f+12|0,g,Cb(x[e+4>>2],y[e+11|0])+g|0,x[b>>2],c);if(!x[f+16>>2]){break b}g=qi(Cb(x[e+4>>2],y[e+11|0]));x[31737]=0;O(45,e|0,g|0);g=x[31737];x[31737]=0;if((g|0)!=1){continue}break}break a}b=x[f+12>>2];c=Jb(e);x[31737]=0;O(46,e|0,b-c|0);b=x[31737];x[31737]=0;c:{if((b|0)!=1){x[31737]=0;O(d|0,a|0,e|0);a=x[31737];x[31737]=0;if((a|0)!=1){break c}break a}break a}tb(e);fb=f+32|0;return}a=N()|0;tb(e);Q(a|0);p()}function fH(a,b,c,d){var e=0,f=0,g=0;f=fb-32|0;fb=f;e=rf(f+20|0,1,0);a:{b:{while(1){g=Jb(e);ON(f+12|0,g,Cb(x[e+4>>2],y[e+11|0])+g|0,x[b>>2],c);if(!x[f+16>>2]){break b}g=qi(Cb(x[e+4>>2],y[e+11|0]));x[31737]=0;O(45,e|0,g|0);g=x[31737];x[31737]=0;if((g|0)!=1){continue}break}break a}b=x[f+12>>2];c=Jb(e);x[31737]=0;O(46,e|0,b-c|0);b=x[31737];x[31737]=0;c:{if((b|0)!=1){x[31737]=0;O(d|0,a|0,e|0);a=x[31737];x[31737]=0;if((a|0)!=1){break c}break a}break a}tb(e);fb=f+32|0;return}a=N()|0;tb(e);Q(a|0);p()}function jga(a){a=a|0;var b=0,c=0,d=0;b=fb-32|0;fb=b;a:{b:{if(!a){a=Bg(22303);break b}x[31737]=0;c=P(36,b+8|0,a|0)|0;a=x[31737];x[31737]=0;c:{d:{if((a|0)!=1){x[31737]=0;d=b+20|0;O(988,d|0,c|0);a=x[31737];x[31737]=0;if((a|0)==1){break d}a=Bg(Jb(d));tb(d);tb(c);break b}a=T(0)|0;break c}a=T(0)|0;tb(c)}Y(a|0)|0;a=0;x[31737]=0;V(989,11031,0,0,0);c=x[31737];x[31737]=0;if((c|0)==1){break a}Z()}fb=b+32|0;return a|0}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function Ls(a,b,c,d,e,f){var g=0,h=0,i=0;g=fb-16|0;fb=g;a=pO(a);x[a+8>>2]=0;x[a>>2]=47740;x[31737]=0;i=R(856,104)|0;h=x[31737];x[31737]=0;a:{b:{c:{d:{if((h|0)!=1){x[31737]=0;d=R(1105,d|0)|0;h=x[31737];x[31737]=0;if((h|0)==1){break d}x[g+8>>2]=d;d=g+8|0;h=x[qe(g+12|0,d)>>2];x[31737]=0;b=ha(f|0,i|0,b|0,c|0,h|0,e|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break c}x[a+8>>2]=b;Uc(d);b=x[a+8>>2];Yd(a,b?b+8|0:0);fb=g+16|0;return a}b=N()|0;break a}b=N()|0;break b}b=N()|0;Uc(g+8|0)}Db(i)}Um(a);Q(b|0);p()}function AH(a,b,c,d){var e=0,f=0,g=0;f=fb-32|0;fb=f;e=rf(f+20|0,1,0);a:{b:{while(1){g=Jb(e);hC(f+12|0,g,Cb(x[e+4>>2],y[e+11|0])+g|0,y[b|0],c);if(!x[f+16>>2]){break b}g=qi(Cb(x[e+4>>2],y[e+11|0]));x[31737]=0;O(45,e|0,g|0);g=x[31737];x[31737]=0;if((g|0)!=1){continue}break}break a}b=x[f+12>>2];c=Jb(e);x[31737]=0;O(46,e|0,b-c|0);b=x[31737];x[31737]=0;c:{if((b|0)!=1){x[31737]=0;O(d|0,a|0,e|0);a=x[31737];x[31737]=0;if((a|0)!=1){break c}break a}break a}tb(e);fb=f+32|0;return}a=N()|0;tb(e);Q(a|0);p()}function YF(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;f=x[b+16>>2];x[a+4>>2]=0;x[a>>2]=f;a:{if(!f){break a}c=b+80|0;d=x[b+84>>2];if(d>>>0<=15){d=x[c>>2]}else{x[e+12>>2]=d-16;d=x[ad(c,e+12|0)>>2]}x[a+8>>2]=d;c=x[b+88>>2];if(!(c&2)){break a}d=c;c=x[b+104>>2];b:{c:{if(!WF(d,c)){d=x[b+84>>2];break c}d=x[b+84>>2];if(x[b+80>>2]!=x[c+12>>2]){break c}b=1;if(x[c+16>>2]==(d|0)){break b}}b=0;if(x[c+8>>2]!=(d|0)){break a}}g=a,h=D((x[c>>2]-d|0)+(b?112:48)|0,cl(z[c+34>>1]))+f|0,x[g+4>>2]=h}fb=e+16|0}function wN(a,b){a=a|0;b=b|0;var c=0,d=0;d=fb-16|0;fb=d;a:{b:{c:{a=x[a+32>>2];c=xq(a);d:{if(!c){if(wq(a)>>>0<=b>>>0){break d}c=(y[ti(a,b+1&65535)+35|0]&4)>>>2|0;break b}if(b>>>0<c>>>0){break c}}a=ac(8);x[31737]=0;b=P(36,d+4|0,6e3)|0;c=x[31737];x[31737]=0;e:{if((c|0)!=1){pc(a,b);x[31737]=0;S(98,a|0,48540,1006);a=x[31737];x[31737]=0;if((a|0)!=1){break a}c=N()|0;tb(b);break e}c=N()|0;jc(a)}Q(c|0);p()}a=x[(a+(b<<2)|0)+900384>>2];c=1;if(!a){break b}c=(y[a+15|0]&2)>>>1|0}fb=d+16|0;return c|0}p()}function joa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;a:{f=fb-48|0;fb=f;g=f+12|0;Mr(g,c);x[31737]=0;c=f+24|0;O(598,c|0,d|0);d=x[31737];x[31737]=0;b:{c:{d:{if((d|0)==1){break d}x[31737]=0;c=f+36|0;O(598,c|0,e|0);d=x[31737];x[31737]=0;if((d|0)==1){break d}rx(f+4|0,g);x[31737]=0;V(302,a|0,b|0,x[f+4>>2],x[f+8>>2]);a=x[31737];x[31737]=0;if((a|0)==1){break c}Yn(g);fb=f+48|0;break a}a=N()|0;while(1){c=tb(c-12|0);if((c|0)!=(f+12|0)){continue}break}break b}a=N()|0;Yn(f+12|0)}Q(a|0);p()}}function To(a){var b=0,c=0,d=0,e=0;d=z[x[a+4>>2]+28>>1]>>>(!y[a+77|0]<<1)|0;b=((d&3)<<4)+26240|0;x[a+40>>2]=b;e=z[a+24>>1];d=d>>>2|0;c=e+d|0;w[a+36>>1]=c>>>0<12?1:1<<c-12;c=12-c|0;c=c>>>0<=12?c:0;w[a+32>>1]=c;w[a+34>>1]=-1<<c^-1;if((e|0)==15){w[a+36>>1]=4095}x[a+52>>2]=b;x[a+64>>2]=b;b=d+z[a+26>>1]|0;w[a+48>>1]=b>>>0<12?1:1<<b-12;b=12-b|0;c=b>>>0<=12?b:0;w[a+44>>1]=c;b=d+z[a+30>>1]|0;w[a+60>>1]=b>>>0<12?1:1<<b-12;b=12-b|0;b=b>>>0<=12?b:0;w[a+56>>1]=b;w[a+46>>1]=-1<<c^-1;w[a+58>>1]=-1<<b^-1}function mP(a){a=a|0;var b=0,c=0,d=0,e=0;c=fb-32|0;fb=c;e=Nb(a);ge(c+24|0);a=0;b=x[c+28>>2];d=x[c+24>>2];x[31737]=0;O(177,e|0,hM(d,b)|0);b=x[31737];x[31737]=0;a:{if((b|0)!=1){b:{while(1){b=x[c+24>>2];if((hM(b,x[c+28>>2])|0)<=(a|0)){fb=c+32|0;return}b=x[b+(a<<3)>>2];x[31737]=0;b=P(36,c+12|0,b|0)|0;d=x[31737];x[31737]=0;if((d|0)!=1){x[31737]=0;O(179,e|0,b|0);d=x[31737];x[31737]=0;if((d|0)==1){break b}tb(b);a=a+1|0;continue}break}a=N()|0;break a}a=N()|0;tb(b);break a}a=N()|0}Td(e);Q(a|0);p()}function U2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=fb-32|0;fb=d;a:{b:{c:{d:{if(g=Ad(x[b+4>>2],y[b+11|0]),h=1,i=x[b+12>>2],i?g:h){Fb(a);break d}c=Cb(x[b+4>>2],y[b+11|0]);e=d+20|0;f=is(14355);hm(Xg(Xg(Jb(Fz(e,c+f|0)),Jb(b),c)+c|0,14355,f)+f|0,1,0);x[31737]=0;c=d+8|0;O(127,c|0,b+12|0);b=x[31737];x[31737]=0;if((b|0)==1){break c}x[31737]=0;S(2,a|0,e|0,c|0);a=x[31737];x[31737]=0;if((a|0)==1){break b}tb(c);tb(e)}fb=d+32|0;return}b=N()|0;break a}b=N()|0;tb(d+8|0)}tb(d+20|0);Q(b|0);p()}function O2(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;a:{f=fb-48|0;fb=f;g=f+12|0;Up(g,c);x[31737]=0;c=f+24|0;O(134,c|0,d|0);d=x[31737];x[31737]=0;b:{c:{d:{if((d|0)==1){break d}x[31737]=0;c=f+36|0;O(134,c|0,e|0);d=x[31737];x[31737]=0;if((d|0)==1){break d}rx(f+4|0,g);x[31737]=0;V(93,a|0,b|0,x[f+4>>2],x[f+8>>2]);a=x[31737];x[31737]=0;if((a|0)==1){break c}Yn(g);fb=f+48|0;break a}a=N()|0;while(1){c=tb(c-12|0);if((c|0)!=(f+12|0)){continue}break}break b}a=N()|0;Yn(f+12|0)}Q(a|0);p()}}function fja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=E(0);e=fb-16|0;fb=e;f=Hf(a,c);$d(e,x[a+36>>2]);h=a;a:{if(!f){Pc(e,a+32|0,5);c=0;if(Hb(x[x[e>>2]>>2],x[e+4>>2])){break a}}c=0;d=fb-16|0;fb=d;g=x[a+36>>2];tl(g,d+8|0);i=d,j=Bc(x[d+8>>2],x[d+12>>2]),x[i+4>>2]=j;x[d>>2]=256;Jl(b,x[Gb(d+4|0,d)>>2]);a=x[b>>2];while(1){if(oc(a,x[b+4>>2])>>>0<=c>>>0){fb=d+16|0}else{x[d+4>>2]=0;Bq(g,d+4|0);a=x[b>>2];i=yb(a,c),k=B[d+4>>2],B[i>>2]=k;c=c+1|0;continue}break}c=f}ff(h,c);fb=e+16|0}function O4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=b&512;f=b&256;g=b&128;h=b&64;i=b&32;j=b&16;k=b&8;l=b&4;m=b&2;b=b&1;a:{while(1){if((c|0)==(d|0)){break a}a=x[c>>2];b:{if(b){if(vt(a)){break b}}if(m){if(ut(a)){break b}}if(l){if(tt(a)){break b}}if(k){if(st(a)){break b}}if(j){if(rt(a)){break b}}if(i){if(qt(a)){break b}}if(h){if(Oh(a)){break b}}if(g){if(pt(a)){break b}}if(f){if(ot(a)){break b}}if(e){if(nt(a)){break b}}c=c+4|0;continue}break}d=c}return d|0}function Ks(a,b,c,d,e){var f=0,g=0,h=0;f=fb-16|0;fb=f;a=pO(a);x[a+8>>2]=0;x[a>>2]=47740;x[31737]=0;h=R(856,104)|0;g=x[31737];x[31737]=0;a:{b:{c:{d:{if((g|0)!=1){x[31737]=0;c=R(1105,c|0)|0;g=x[31737];x[31737]=0;if((g|0)==1){break d}x[f+8>>2]=c;c=f+8|0;g=x[qe(f+12|0,c)>>2];x[31737]=0;b=ba(e|0,h|0,b|0,g|0,d|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break c}x[a+8>>2]=b;Uc(c);b=x[a+8>>2];Yd(a,b?b+8|0:0);fb=f+16|0;return a}b=N()|0;break a}b=N()|0;break b}b=N()|0;Uc(f+8|0)}Db(h)}Um(a);Q(b|0);p()}function rN(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;d=fb-32|0;fb=d;C[d+24>>3]=c;a:{b:{c:{if(b>>>0>=256){b=ac(8);x[31737]=0;d=P(36,d+8|0,10751)|0;a=x[31737];x[31737]=0;if((a|0)==1){break c}pc(b,d);x[31737]=0;S(98,b|0,48540,1006);a=x[31737];x[31737]=0;if((a|0)!=1){break a}a=N()|0;tb(d);break b}a=x[a+32>>2];x[d+8>>2]=0;x[d+12>>2]=-1074790400;x[d>>2]=0;x[d+4>>2]=1072693248;e=(D(b,872)+a|0)+1075684|0,f=Zi(C[Yg(d+24|0,d+8|0,d)>>3]*128+128),x[e>>2]=f;fb=d+32|0;return}a=N()|0;jc(b)}Q(a|0)}p()}function cS(a,b){var c=0,d=0,e=0,f=0,g=0;d=fb-32|0;fb=d;a:{f=b-1&65535;if(f>>>0>3998){break a}c=D(b,104)+a|0;e=c+484380|0;if(!je(x[e>>2],x[c+484400>>2])){break a}g=a+1298224|0;c=a+1074992|0;while(1){if((c|0)==(g|0)){sn(e);x[e>>2]=0;a=(D(b,104)+a|0)+484414|0;w[a>>1]=z[a>>1]&65470;x[d+24>>2]=0;x[d+8>>2]=0;x[d+16>>2]=0;x[d+20>>2]=0;x[d>>2]=0;x[d+4>>2]=0;Yk(e,0,d);break a}if(x[c+104>>2]==(e|0)){x[c+76>>2]=0;x[c>>2]=0;x[c+4>>2]=0;x[c+16>>2]=0}c=c+872|0;continue}}fb=d+32|0;return f>>>0<3999}function x7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;g=fb-16|0;fb=g;e=Cb(x[a+4>>2],y[a+11|0]);d=zn(a);f=Sd(b,c);a:{if(!f){break a}b:{if(!IJ(a,b)){if(d-e>>>0<f>>>0){hy(a,d,(e-d|0)+f|0,e,e,0)}d=Jb(a)+(e<<2)|0;while(1){if((b|0)==(c|0)){break b}yd(d,x[b>>2]);b=b+4|0;d=d+4|0;continue}}b=ho(g+4|0,b,c);c=Jb(b);e=y[b+11|0];d=x[b+4>>2];x[31737]=0;U(1247,a|0,c|0,Cb(d,e)|0)|0;c=x[31737];x[31737]=0;if((c|0)!=1){Ub(b);break a}a=N()|0;Ub(b);Q(a|0);p()}yd(d,0);ng(a,e+f|0)}fb=g+16|0;return a|0}function RM(a){var b=0,c=0,d=0,e=0,f=0;while(1){d=x[a+16>>2];if(d>>>0<=e>>>0){while(1){if(!(A[a+12>>2]<=d>>>0)){while(1){f=TA(x[a>>2]);e=hb;c=x[a+36>>2];if((e|0)==(c|0)&A[a+32>>2]<=f>>>0|e>>>0>c>>>0){continue}break}c=b;b=x[a+8>>2];b=(f&x[a+48>>2])+(b>>>0<31?c<<b+1:0)|0;d=d+1|0;continue}break}}else{while(1){f=TA(x[a>>2]);d=hb;c=x[a+28>>2];if((d|0)==(c|0)&A[a+24>>2]<=f>>>0|d>>>0>c>>>0){continue}break}c=b;b=x[a+8>>2];b=(f&x[a+40>>2])+(b>>>0<32?c<<b:0)|0;e=e+1|0;continue}break}return b}function kV(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;i=b?33:32;c=x[a+8>>2]-1|0;e=x[a+12>>2];f=x[a>>2]+D(e,31)|0;g=b?1:-1;d=g;a:while(1){b:{b=0;if((h|0)==(i|0)){break b}while(1)if((b|0)>=(e|0)){b=x[a+8>>2]-1|0;c:{if(!((b|0)!=(c|0)|(d|0)<=0)){if(!y[a+16|0]){d=1;c=0;break c}d=-1;c=c-(y[a+17|0]!=0&(c|0)!=0)|0;break c}if(!((d|0)>=0|c)){c=y[a+16|0];d=c?1:-1;c=c?0:b;break c}c=c+d|0}f=D(e,g)+f|0;h=h+1|0;continue a}else{v[b+f|0]=y[(x[a+4>>2]+D(c,e)|0)+b|0];b=b+1|0;e=x[a+12>>2];continue}}break}}function bg(a,b,c,d,e,f){var g=0,h=0,i=0;a:{if(f&64){e=f+-64|0;f=b;d=e&31;if((e&63)>>>0>=32){e=f<<d;d=0}else{e=(1<<d)-1&f>>>32-d|c<<d;d=f<<d}b=0;c=0;break a}if(!f){break a}h=d;g=f&31;if((f&63)>>>0>=32){i=d<<g;h=0}else{i=(1<<g)-1&h>>>32-g|e<<g;h=h<<g}g=b;e=64-f|0;d=e&31;if((e&63)>>>0>=32){e=0;d=c>>>d|0}else{e=c>>>d|0;d=((1<<d)-1&c)<<32-d|g>>>d}d=h|d;e=e|i;h=b;g=f&31;if((f&63)>>>0>=32){i=b<<g;b=0}else{i=(1<<g)-1&h>>>32-g|c<<g;b=h<<g}c=i}x[a>>2]=b;x[a+4>>2]=c;x[a+8>>2]=d;x[a+12>>2]=e}function LX(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;a:{if(!y[b+8|0]){while(1){if((d|0)==8){x[c+24>>2]=0;x[c+28>>2]=0;d=gc(c+8|0,c+24|0,8);e=x[d>>2];lc(c+16|0,x[a>>2],x[a+8>>2],e,x[d+4>>2]);d=0;if(!(x[c+24>>2]!=(y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24))|x[c+28>>2]!=(y[b+4|0]|y[b+5|0]<<8|(y[b+6|0]<<16|y[b+7|0]<<24))|x[c+20>>2]!=8)){Vb(a,8);d=1}fb=c+32|0;break a}e=b+d|0;d=d+1|0;if(y[e|0]){continue}break}_(17527,9095,602,13238);p()}_(17506,9095,600,13238);p()}return d|0}function Kja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=fb-32|0;fb=e;f=e+8|0;aj(f,2,a+2|0);d=e+20|0;Cc(d,f);zc(b+492|0,d);f=b+236|0;g=c+1|0;tb(d);c=0;while(1){if((c|0)==120){x[b>>2]=(y[a+223|0]|y[a+224|0]<<8)<<5;a=a+158|0;BR(y[a|0]&15,y[a+1|0]&15,y[a+2|0]&15,y[a+3|0]&15,y[a+4|0]&15,a+5|0,b+48|0);BR(y[a|0]>>>4|0,y[a+1|0]>>>4|0,y[a+2|0]>>>4|0,y[a+3|0]>>>4|0,y[a+4|0]>>>4|0,a+35|0,b+68|0);fb=e+32|0}else{d=y[(a+c|0)+31|0];h=_b(f,c),i=d+g|0,w[h>>1]=i;c=c+1|0;continue}break}}function D7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;g=fb-16|0;fb=g;e=Cb(x[a+4>>2],y[a+11|0]);d=Mc(a);f=Vj(b,c);a:{if(!f){break a}b:{if(!Lz(a,b)){if(d-e>>>0<f>>>0){Wm(a,d,(e-d|0)+f|0,e,e,0,0)}d=Jb(a)+e|0;while(1){if((b|0)==(c|0)){break b}fd(d,y[b|0]);b=b+1|0;d=d+1|0;continue}}b=si(g+4|0,b,c);c=Jb(b);e=y[b+11|0];d=x[b+4>>2];x[31737]=0;U(1240,a|0,c|0,Cb(d,e)|0)|0;c=x[31737];x[31737]=0;if((c|0)!=1){tb(b);break a}a=N()|0;tb(b);Q(a|0);p()}fd(d,0);ng(a,e+f|0)}fb=g+16|0;return a|0}function px(a){var b=0,c=0,d=0;if(A[a+4>>2]<A[zb(a)>>2]){b=fb-16|0;fb=b;a=rG(b+4|0,a);c=x[a+4>>2];x[31737]=0;W(165,c|0);c=x[31737];x[31737]=0;a:{if((c|0)!=1){x[a+4>>2]=x[a+4>>2]+36;hc(a);fb=b+16|0;break a}b=N()|0;hc(a);Q(b|0);p()}return}c=fb-32|0;fb=c;b=zb(a);b=pG(c+12|0,qG(a,js(x[a>>2],x[a+4>>2])+1|0),js(x[a>>2],x[a+4>>2]),b);d=x[b+8>>2];x[31737]=0;W(165,d|0);d=x[31737];x[31737]=0;b:{if((d|0)!=1){x[b+8>>2]=x[b+8>>2]+36;oG(a,b);dx(b);fb=c+32|0;break b}a=N()|0;dx(b);Q(a|0);p()}}function p1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=fb-32|0;fb=d;ld(b,0);e=d+8|0;jk(e,1,a+33|0);c=d+20|0;Cc(c,e);ze(b+43|0,c);tb(c);f=y[a+50|0]|y[a+51|0]<<8;x[b>>2]=f;x[b+24>>2]=y[a+52|0]|y[a+53|0]<<8;v[d+20|0]=y[a+54|0];v[d+8|0]=64;g=b,h=y[Qb(c,e)|0]<<2,w[g+30>>1]=h;e=y[a+55|0]|y[a+56|0]<<8;x[b+4>>2]=e;c=y[a+57|0]|y[a+58|0]<<8;x[b+8>>2]=c;a:{if((c|0)==65535){x[b+4>>2]=0;x[b+8>>2]=0;break a}if(!y[a|0]|c>>>0<=e+2>>>0|c>>>0>f>>>0){break a}w[b+34>>1]=z[b+34>>1]|2}fb=d+32|0}function ip(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=fb-16|0;fb=g;f=(y[xb(b,0)|0]&15)<<8|y[xb(b,1)|0];d=0;a:{if(!f){break a}d=0;if((f|0)==4095){break a}while(1){d=108;if((e|0)==84){break a}b:{h=e<<1;d=z[h+31152>>1];if(f>>>0>=d>>>0){if(!e|(f|0)==(d|0)|(z[h+31150>>1]-f|0)>=(f-d|0)){break b}d=e+24|0;break a}e=e+1|0;continue}break}d=e+25|0}v[c|0]=d;e=y[xb(b,2)|0];d=y[xb(b,0)|0];v[c+3|0]=0;v[c+1|0]=d&16|e>>>4;c=y[xb(b,2)|0];i=g,j=y[xb(b,3)|0],v[i+15|0]=j;de(a,c&15,g+15|0);fb=g+16|0}function qS(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=x[a+104>>2];d=(g<<3)+a|0;b=((g+7>>>0)%12<<3)+a|0;f=x[b>>2];e=x[b+4>>2];b=x[a+100>>2];j=b;h=x[a+96>>2];a:{if(!(b|h)){c=x[d+4>>2];b=x[d>>2];i=(c|0)==(e|0)&b>>>0>f>>>0|e>>>0<c>>>0;break a}c=x[d+4>>2];b=x[d>>2];i=!(e|f)|((c|0)==(e|0)&b>>>0>=f>>>0|e>>>0<c>>>0)}c=c+j|0;b=b+h|0;c=b>>>0<h>>>0?c+1|0:c;x[d>>2]=f-b;x[d+4>>2]=e-(c+(b>>>0>f>>>0)|0)&65535;x[a+104>>2]=(g+1>>>0)%12;x[a+96>>2]=i;x[a+100>>2]=0;hb=x[d+4>>2];return x[d>>2]}function aba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c=fb-16|0;fb=c;a:{d=Zi(C[a+24>>3]*65536);if((d|0)==65536){break a}j=d>>31;k=x[b>>2];h=x[b+4>>2];l=x[b+8>>2];b:while(1){if((g|0)==(l|0)){break a}m=(D(g,h)<<2)+k|0;e=0;while(1)if((e|0)==(h|0)){g=g+1|0;continue b}else{i=(e<<2)+m|0;f=x[i>>2];f=Tua(Sua(f,f>>31,d,j),hb,65536,0);n=i,o=Gc(f,hb),x[n>>2]=o;e=e+1|0;continue}}}x[c+8>>2]=x[b+8>>2];d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;OM(a,c);fb=c+16|0}function Taa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c=fb-16|0;fb=c;a:{d=Zi(C[a+24>>3]*65536);if((d|0)==65536){break a}j=d>>31;k=x[b>>2];h=x[b+4>>2];l=x[b+8>>2];b:while(1){if((g|0)==(l|0)){break a}m=(D(g,h)<<2)+k|0;e=0;while(1)if((e|0)==(h|0)){g=g+1|0;continue b}else{i=(e<<2)+m|0;f=x[i>>2];f=Tua(Sua(f,f>>31,d,j),hb,65536,0);n=i,o=Gc(f,hb),x[n>>2]=o;e=e+1|0;continue}}}x[c+8>>2]=x[b+8>>2];d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;IM(a,c);fb=c+16|0}function zra(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=fb-16|0;fb=e;i=e,j=Xj(b),x[i+4>>2]=j;g=z[b>>1];c=fb-16|0;fb=c;f=a;d=ce(a);a:{if(d){b=ec(a);while(1){a=d;d=z[a+16>>1];if(cp(g,d)){b=a;d=x[a>>2];if(d){continue}break a}if(!cp(d,g)){break a}b=a+4|0;d=x[a+4>>2];if(d){continue}break}break a}a=ec(f);b=a}x[c+12>>2]=a;a=x[b>>2];if(!a){FZ(c,f,e+4|0);$g(f,x[c+12>>2],b,x[c>>2]);a=me(c);EZ(c);h=1}_g(e+8|0,x[vb(c,a)>>2],h);fb=c+16|0;a=td(x[e+8>>2]);fb=e+16|0;return a+4|0}function yA(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-48|0;fb=e;a:{if(!c){b=Xd(x[a>>2],b);a=x[d+12>>2];x[b+8>>2]=x[d+8>>2];x[b+12>>2]=a;a=x[d+4>>2];x[b>>2]=x[d>>2];x[b+4>>2]=a;break a}f=x[d+12>>2];x[e+24>>2]=x[d+8>>2];x[e+28>>2]=f;f=x[d+4>>2];x[e+16>>2]=x[d>>2];x[e+20>>2]=f;f=c>>>1|0;yA(a,b,f,e+16|0);g=C[d>>3];h=C[d+8>>3];d=Xd(x[a>>2],c);Si(e+32|0,g,h,C[d>>3],C[d+8>>3]);d=x[e+44>>2];x[e+8>>2]=x[e+40>>2];x[e+12>>2]=d;d=x[e+36>>2];x[e>>2]=x[e+32>>2];x[e+4>>2]=d;yA(a,b|c,f,e)}fb=e+48|0}function Yk(a,b,c){var d=0;d=z[a+34>>1];if(!b){if(d&512){Cp(a);d=z[a+34>>1]}w[a+34>>1]=d&65023;return}x[a>>2]=4;w[a+34>>1]=d&64958|512;Eh(a);b=y[c+8|0]|y[c+9|0]<<8|(y[c+10|0]<<16|y[c+11|0]<<24);v[a+76|0]=b;v[a+77|0]=b>>>8;v[a+78|0]=b>>>16;v[a+79|0]=b>>>24;b=y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24);c=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);v[a+68|0]=c;v[a+69|0]=c>>>8;v[a+70|0]=c>>>16;v[a+71|0]=c>>>24;v[a+72|0]=b;v[a+73|0]=b>>>8;v[a+74|0]=b>>>16;v[a+75|0]=b>>>24}function dR(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=fb-16|0;fb=e;i=e,j=Xj(b),x[i+4>>2]=j;g=z[b>>1];c=fb-16|0;fb=c;f=a;d=ce(a);a:{if(d){b=ec(a);while(1){a=d;d=z[a+16>>1];if(ar(g,d)){b=a;d=x[a>>2];if(d){continue}break a}if(!ar(d,g)){break a}b=a+4|0;d=x[a+4>>2];if(d){continue}break}break a}a=ec(f);b=a}x[c+12>>2]=a;a=x[b>>2];if(!a){FZ(c,f,e+4|0);$g(f,x[c+12>>2],b,x[c>>2]);a=me(c);EZ(c);h=1}_g(e+8|0,x[vb(c,a)>>2],h);fb=c+16|0;a=td(x[e+8>>2]);fb=e+16|0;return a+4|0}function Yia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;f=fb-48|0;fb=f;d=x[a+36>>2];kg(x[x[d>>2]-12>>2]+d|0,0);d=x[b>>2];g=x[d+8>>2];e=x[d+12>>2];if(g|e){h=x[a+36>>2];e=x[a+20>>2]+e|0;d=x[a+16>>2];g=g+d|0;e=gi(f+32|0,g,d>>>0>g>>>0?e+1|0:e);d=x[e+12>>2];x[f+8>>2]=x[e+8>>2];x[f+12>>2]=d;d=x[e+4>>2];x[f>>2]=x[e>>2];x[f+4>>2]=d;Zm(h,f)}d=f+16|0;$d(d,x[a+36>>2]);VB(x[a+36>>2],c,x[x[b>>2]+16>>2]);c=x[b>>2];b=yl(d,xb(x[a+40>>2],x[c>>2]),z[c+20>>1]);ff(a,c);Eb(b);fb=f+48|0}function mqa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=fb+-64|0;fb=d;b=-1;a:{if(!Cm(a,1084)){break a}cm(a,1080);c=d+60|0;rY(a,c);f=qY(d+40|0);b=0;if(!pY(c,f)){break a}cm(a,20);b=1;while(1){if((b&65535)>>>0>=32){b=A[f+4>>2]>=h>>>0}else{c=y[f+16|0];e=fb-16|0;fb=e;b:{g=d+10|0;if(!oY(a,g)|!c){break b}Cv(e+8|0,g);c=0;while(1){if(c>>>0>=30){break b}i=x[e+8>>2];tg(xb(i,c),xb(i,c|1));c=c+2|0;continue}}fb=e+16|0;b=b+1|0;h=WC(g)+h|0;continue}break}}fb=d- -64|0;return b|0}function dI(a,b,c,d,e,f,g,h){var i=0,j=0,k=0;i=fb-16|0;fb=i;x[31737]=0;W(1002,a|0);j=x[31737];x[31737]=0;a:{b:{if((j|0)!=1){c:{j=x[a+24>>2];x[31737]=0;k=h;h=i+4|0;ga(k|0,h|0,j|0,b|0,c|0,d|0,e|0,(f|0)!=0|0);b=x[31737];x[31737]=0;if((b|0)==1){break c}b=Bg(Jb(h));tb(h);break b}}Y(T(0)|0)|0;b=0;x[31737]=0;V(989,g|0,a|0,0,0);a=x[31737];x[31737]=0;if((a|0)==1){break a}Z()}fb=i+16|0;return b}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function ft(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;i=fb-16|0;fb=i;a:{b:{if(!a){break b}g=x[e+12>>2];h=c-b>>2;if((h|0)>0){if((rp(a,b,h)|0)!=(h|0)){break b}}b=d-b>>2;b=(b|0)<(g|0)?g-b|0:0;if((b|0)>0){f=ny(i+4|0,b,f);g=Jb(f);x[31737]=0;g=U(1229,a|0,g|0,b|0)|0;h=x[31737];x[31737]=0;if((h|0)==1){break a}Ub(f);if((b|0)!=(g|0)){break b}}b=d-c>>2;if((b|0)>0){if((rp(a,c,b)|0)!=(b|0)){break b}}tE(e);j=a}fb=i+16|0;return j|0}a=N()|0;Ub(f);Q(a|0);p()}function cI(a,b,c,d,e,f,g){var h=0,i=0,j=0;h=fb-16|0;fb=h;x[31737]=0;W(1002,a|0);i=x[31737];x[31737]=0;a:{b:{if((i|0)!=1){c:{i=x[x[a+24>>2]+24>>2];x[31737]=0;j=g;g=h+4|0;ja(j|0,g|0,i|0,b|0,c|0,d|0,e|0);b=x[31737];x[31737]=0;if((b|0)==1){break c}b=Bg(Jb(g));tb(g);break b}}Y(T(0)|0)|0;b=0;x[31737]=0;V(989,f|0,a|0,0,0);a=x[31737];x[31737]=0;if((a|0)==1){break a}Z()}fb=h+16|0;return b}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function TN(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0;f=c-b|0;a:{if((f|0)<=19){i=D(64-bu(d|1,e)|0,1233)>>>12|0;j=(i<<3)+124080|0;g=f;f=x[j+4>>2];h=61;if((g|0)<(((e|0)==(f|0)&d>>>0>=A[j>>2]|e>>>0>f>>>0)+i|0)){break a}}b:{if(!e){c=GB(b,d);break b}if((e|0)==2&d>>>0>=1410065408|e>>>0>2){c=Uua(d,e,1410065408,2);f=Sua(c,hb,-1410065408,-3);e=e+hb|0;g=d;d=d+f|0;e=g>>>0>d>>>0?e+1|0:e;b=GB(b,c)}c=Uua(d,e,1e8,0);e=hb;b=Ul(b,c);c=Sua(c,e,-1e8,0)+d|0;c=Ru(b,c)}h=0}x[a+4>>2]=h;x[a>>2]=c}function Gm(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;f=fb-16|0;fb=f;a:{b:{c:{d=zn(a);e=Sd(b,c);if(d>>>0<e>>>0){if(IJ(a,b)){break c}g=d;h=e-d|0;d=Cb(x[a+4>>2],y[a+11|0]);hy(a,g,h,d,0,d)}d=Jb(a);while(1){if((b|0)==(c|0)){break b}yd(d,x[b>>2]);b=b+4|0;d=d+4|0;continue}}b=ho(f+4|0,b,c);c=Jb(b);d=y[b+11|0];e=x[b+4>>2];x[31737]=0;S(1338,a|0,c|0,Cb(e,d)|0);c=x[31737];x[31737]=0;if((c|0)!=1){Ub(b);break a}a=N()|0;Ub(b);Q(a|0);p()}yd(d,0);ng(a,e)}fb=f+16|0;return a|0}function us(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if((a|0)!=(b|0)){if(!Cd(y[a+11|0])){c=y[b+11|0];if(!Cd(c)){d=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=d;x[a+8>>2]=x[b+8>>2];return}d=Jb(b);b=Cb(x[b+4>>2],c);a:{if(b>>>0<=10){Me(a,b);fd(Xg(a,d,b)+b|0,0);break a}e=a;a=Fh(y[a+11|0]);Yq(e,10,b-10|0,a,0,a,b,d)}return}d=Jb(b);b=Cb(x[b+4>>2],y[b+11|0]);c=ej(x[a+8>>2]);b:{if(b>>>0<c>>>0){c=x[a>>2];Yd(a,b);fd(Xg(c,d,b)+b|0,0);break b}e=a;a=x[a+4>>2];Yq(e,c-1|0,(b-c|0)+1|0,a,0,a,b,d)}}}function qw(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if((a|0)!=(b|0)){if(!Cd(y[a+11|0])){c=y[b+11|0];if(!Cd(c)){d=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=d;x[a+8>>2]=x[b+8>>2];return}d=Jb(b);b=Cb(x[b+4>>2],c);a:{if(b>>>0<=10){Me(a,b);fd(Cg(a,d,b)+b|0,0);break a}e=a;a=Fh(y[a+11|0]);dq(e,10,b-10|0,a,0,a,b,d)}return}d=Jb(b);b=Cb(x[b+4>>2],y[b+11|0]);c=ej(x[a+8>>2]);b:{if(b>>>0<c>>>0){c=x[a>>2];Yd(a,b);fd(Cg(c,d,b)+b|0,0);break b}e=a;a=x[a+4>>2];dq(e,c-1|0,(b-c|0)+1|0,a,0,a,b,d)}}}function qP(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;f=fb-16|0;fb=f;a:{b:{c:{d=Mc(a);e=Vj(b,c);if(d>>>0<e>>>0){if(Lz(a,b)){break c}g=d;h=e-d|0;d=Cb(x[a+4>>2],y[a+11|0]);Wm(a,g,h,d,0,d,0)}d=Jb(a);while(1){if((b|0)==(c|0)){break b}fd(d,y[b|0]);b=b+1|0;d=d+1|0;continue}}b=si(f+4|0,b,c);c=Jb(b);d=y[b+11|0];e=x[b+4>>2];x[31737]=0;S(73,a|0,c|0,Cb(e,d)|0);c=x[31737];x[31737]=0;if((c|0)!=1){tb(b);break a}a=N()|0;tb(b);Q(a|0);p()}fd(d,0);ng(a,e)}fb=f+16|0;return a|0}function Sha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;b=fb-16|0;fb=b;d=x[a+20>>2];c=x[d+4>>2];a:{if(!((Vc(c,x[d+8>>2])|0)!=7|(y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24))!=1869112133)){d=wb(c);g=wb(x[x[a+20>>2]+8>>2]);Pr(b+8|0,a+4228|0);f=wb(x[b+8>>2]);e=fb-16|0;fb=e;c=fb-32|0;fb=c;Id(c+24|0,d,g);wn(c+16|0,x[c+24>>2],x[c+28>>2],f);d=e$(d,x[c+16>>2]);h=c,i=WD(f,x[c+20>>2]),x[h+12>>2]=i;Ac(e+8|0,d,c+12|0);fb=c+32|0;fb=e+16|0;break a}$z(a,a)}ku(a);fb=b+16|0}function vY(a,b,c,d){var e=0,f=0;f=fb-16|0;fb=f;e=z[c>>1];while(1){a:{e=e<<1;w[c>>1]=e;v[b|0]=(e&65534)>>>0>255;e=y[c|0];w[c>>1]=e;if(!e){if(!Af(a,f+15|0)){break a}e=y[f+15|0];w[c>>1]=e<<1|1;v[b|0]=e>>>7;w[c>>1]=y[c|0]}v[d|0]=y[b|0]+(y[d|0]<<1);e=z[c>>1]<<1;w[c>>1]=e;v[b|0]=(e&65534)>>>0>255;e=y[c|0];w[c>>1]=e;if(!e){if(!Af(a,f+14|0)){break a}e=y[f+14|0];w[c>>1]=e<<1|1;v[b|0]=e>>>7;e=y[c|0];w[c>>1]=e;if(y[b|0]){continue}break a}if(y[b|0]){continue}}break}fb=f+16|0}function Zia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;g=fb-48|0;fb=g;e=x[a+36>>2];kg(x[x[e>>2]-12>>2]+e|0,0);e=x[b>>2];h=x[e+8>>2];f=x[e+12>>2];if(h|f){i=x[a+36>>2];f=x[a+20>>2]+f|0;e=x[a+16>>2];h=h+e|0;f=gi(g+32|0,h,e>>>0>h>>>0?f+1|0:f);e=x[f+12>>2];x[g+8>>2]=x[f+8>>2];x[g+12>>2]=e;e=x[f+4>>2];x[g>>2]=x[f>>2];x[g+4>>2]=e;Zm(i,g)}e=g+16|0;$d(e,x[a+36>>2]);_Q(d,x[a+36>>2],c);c=x[b>>2];b=yl(e,xb(x[a+40>>2],x[c>>2]),z[c+20>>1]);ff(a,c);Eb(b);fb=g+48|0}function Xia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;g=fb-48|0;fb=g;e=x[a+36>>2];kg(x[x[e>>2]-12>>2]+e|0,0);e=x[b>>2];h=x[e+8>>2];f=x[e+12>>2];if(h|f){i=x[a+36>>2];f=x[a+20>>2]+f|0;e=x[a+16>>2];h=h+e|0;f=gi(g+32|0,h,e>>>0>h>>>0?f+1|0:f);e=x[f+12>>2];x[g+8>>2]=x[f+8>>2];x[g+12>>2]=e;e=x[f+4>>2];x[g>>2]=x[f>>2];x[g+4>>2]=e;Zm(i,g)}e=g+16|0;$d(e,x[a+36>>2]);XQ(c,x[a+36>>2],d);c=x[b>>2];b=yl(e,xb(x[a+40>>2],x[c>>2]),z[c+20>>1]);ff(a,c);Eb(b);fb=g+48|0}function pw(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;i=fb-16|0;fb=i;a:{b:{if(!a){break b}g=x[e+12>>2];h=c-b|0;if((h|0)>0){if((rp(a,b,h)|0)!=(h|0)){break b}}b=d-b|0;b=(b|0)<(g|0)?g-b|0:0;if((b|0)>0){f=rf(i+4|0,b,f);g=Jb(f);x[31737]=0;g=U(32,a|0,g|0,b|0)|0;h=x[31737];x[31737]=0;if((h|0)==1){break a}tb(f);if((b|0)!=(g|0)){break b}}b=d-c|0;if((b|0)>0){if((rp(a,c,b)|0)!=(b|0)){break b}}tE(e);j=a}fb=i+16|0;return j|0}a=N()|0;tb(f);Q(a|0);p()}function L7(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;c=fb-128|0;fb=c;x[c+12>>2]=c+116;d=c+16|0;dK(x[a+8>>2],d,c+12|0,e,f,g);f=fb-16|0;fb=f;h=f+8|0;a=fb-32|0;fb=a;Id(a+24|0,d,x[c+12>>2]);i=a+16|0;e=x[a+24>>2];g=x[a+28>>2];d=fb-16|0;fb=d;x[d+12>>2]=b;while(1){if((e|0)!=(g|0)){lL(d+12|0,v[e|0]);e=e+1|0;continue}break}Ac(i,g,d+12|0);fb=d+16|0;b=x[a+16>>2];x[a+12>>2]=x[a+20>>2];Ac(h,b,a+12|0);fb=a+32|0;fb=f+16|0;fb=c+128|0;return x[f+12>>2]}function wK(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;a:{b:{if((a|0)!=(b|0)){c:{d:{f=y[a|0];if((f|0)!=45){break d}a=a+1|0;if((b|0)!=(a|0)){break d}break c}h=x[31612];x[31612]=0;Od();a=xy(a,e+12|0,d);d=hb;g=x[31612];e:{if(g){if(x[e+12>>2]!=(b|0)){break c}if(!d&a>>>0>65535|d|(g|0)==68){break e}break b}x[31612]=h;if(x[e+12>>2]!=(b|0)){break c}if(!d&a>>>0<65536){break b}}x[c>>2]=4;a=65535;break a}}x[c>>2]=4;a=0;break a}a=(f|0)==45?0-a|0:a}fb=e+16|0;return a&65535}function dua(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=fb-16|0;fb=d;a:{g=x[c+12>>2];if(!g){break a}e=lg(d+4|0,c+16|0);f=Yc(x[b+4>>2],y[b+11|0]);h=f-1|0;c=0;while(1){if((c|0)==(f|0)){tb(e);break a}b:{c:{if(!c|(c>>>0)%(g>>>0)){break c}if((c|0)==(h|0)){if(y[cc(b,0)|0]==43){break c}if(y[cc(b,0)|0]==45){break c}}x[31737]=0;U(305,b|0,f-c|0,e|0)|0;i=x[31737];x[31737]=0;if((i|0)==1){break b}}c=c+1|0;continue}break}a=N()|0;tb(e);Q(a|0);p()}_c(a,b);fb=d+16|0}function Kz(a,b,c){var d=0,e=0;d=(c|0)!=0;a:{b:{c:{if(!(a&3)|!c){break c}e=b&255;while(1){if((e|0)==y[a|0]){break b}c=c-1|0;d=(c|0)!=0;a=a+1|0;if(!(a&3)){break c}if(c){continue}break}}if(!d){break a}d=b&255;if(!((d|0)==y[a|0]|c>>>0<4)){d=D(d,16843009);while(1){e=d^x[a>>2];if((e^-1)&e-16843009&-2139062144){break b}a=a+4|0;c=c-4|0;if(c>>>0>3){continue}break}}if(!c){break a}}b=b&255;while(1){if((b|0)==y[a|0]){return a}a=a+1|0;c=c-1|0;if(c){continue}break}}return 0}function nm(a){var b=0,c=0;a:{b=x[a+4>>2];b=x[x[b>>2]-12>>2]+b|0;b:{if(!x[b+24>>2]|x[b+16>>2]|!(y[b+5|0]&32)){break b}if((db()|0)>0){break b}b=x[a+4>>2];b=x[(x[x[b>>2]-12>>2]+b|0)+24>>2];x[31737]=0;b=R(31,b|0)|0;c=x[31737];x[31737]=0;if((c|0)!=1){if((b|0)!=-1){break b}a=x[a+4>>2];b=x[x[a>>2]-12>>2];x[31737]=0;O(24,a+b|0,1);a=x[31737];x[31737]=0;if((a|0)!=1){break b}}Y(T(0)|0)|0;x[31737]=0;X(26);a=x[31737];x[31737]=0;if((a|0)==1){break a}}return}T(0)|0;Sb();p()}function coa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=fb-16|0;fb=d;a:{g=x[c+12>>2];if(!g){break a}e=Bm(d+4|0,c+16|0);f=Yc(x[b+4>>2],y[b+11|0]);h=f-1|0;c=0;while(1){if((c|0)==(f|0)){tb(e);break a}b:{c:{if(!c|(c>>>0)%(g>>>0)){break c}if((c|0)==(h|0)){if(y[cc(b,0)|0]==43){break c}if(y[cc(b,0)|0]==45){break c}}x[31737]=0;U(48,b|0,f-c|0,e|0)|0;i=x[31737];x[31737]=0;if((i|0)==1){break b}}c=c+1|0;continue}break}a=N()|0;tb(e);Q(a|0);p()}_c(a,b);fb=d+16|0}function Bia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a=Qi(a,b,c,d);x[a>>2]=42588;b=Nb(a+4208|0);x[a+4236>>2]=-1;x[a+4240>>2]=0;x[a+4228>>2]=1049926264;x[a+4232>>2]=0;x[a+4220>>2]=1056964608;x[a+4224>>2]=1056964608;v[a+4244|0]=0;Rb(a+4248|0,0,48);x[31737]=0;X(854);c=x[31737];x[31737]=0;a:{if((c|0)==1){break a}e=a,f=xS(),x[e+4296>>2]=f;ou(a);nu(a);x[31737]=0;O(947,a+44|0,2);c=x[31737];x[31737]=0;if((c|0)==1){break a}return a|0}c=N()|0;dc(b);ag(a);Q(c|0);p()}function sT(a,b){var c=0,d=0,e=0,f=0,g=0;a:{if(y[b+791|0]!=27){a=v[b+831|0];break a}e=a+1074312|0;c=Ob(e,21);d=a;a=y[b+821|0];a=IA(d,y[b+828|0],c?a:a+16>>>2|0);b:{if(!(!Ob(e,45)|y[b+828|0]!=3)){c=y[b+821|0];c:{if(!(!c|c>>>0>=y[b+829|0])){a=y[b+832|0];d=c+1|0;break c}v[b+832|0]=a;d=1}v[b+821|0]=d;a=a<<24>>24;break b}v[b+821|0]=y[b+821|0]+y[b+829|0]}if(!Ob(e,47)){break a}v[b+831|0]=a}if(a){f=b,g=Yb(x[b+684>>2]+((D(y[b+830|0],a)+2|0)/8|0)|0,0,256),x[f+684>>2]=g}}function lH(a,b,c,d,e,f){var g=0,h=0;a:{g=fb-48|0;fb=g;h=g+12|0;co(h,c);x[31737]=0;c=g+24|0;O(f|0,c|0,d|0);d=x[31737];x[31737]=0;b:{c:{d:{if((d|0)==1){break d}x[31737]=0;c=g+36|0;O(92,c|0,e|0);d=x[31737];x[31737]=0;if((d|0)==1){break d}rx(g+4|0,h);x[31737]=0;V(93,a|0,b|0,x[g+4>>2],x[g+8>>2]);a=x[31737];x[31737]=0;if((a|0)==1){break c}Yn(h);fb=g+48|0;break a}a=N()|0;while(1){c=tb(c-12|0);if((c|0)!=(g+12|0)){continue}break}break b}a=N()|0;Yn(g+12|0)}Q(a|0);p()}}function hR(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=x[a>>2];c=oc(d,x[a+4>>2]);if(c>>>0<=127){f=fb-32|0;fb=f;c=128-c|0;e=x[zb(a)>>2];d=x[a+4>>2];a:{if(c>>>0<=e-d>>2>>>0){nA(a,c,b);break a}e=zb(a);d=$f(f+12|0,Mf(a,oc(x[a>>2],d)+c|0),oc(x[a>>2],x[a+4>>2]),e);g=fb-16|0;fb=g;c=Ln(g+4|0,d+8|0,c);e=x[c>>2];while(1){if(x[c+4>>2]!=(e|0)){zk(e,B[b>>2]);e=x[c>>2]+4|0;x[c>>2]=e;continue}break}he(c);fb=g+16|0;mA(a,d);_f(d)}fb=f+32|0;return}if((c|0)!=128){Ih(a,d+512|0)}}function SR(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;a:{if((c|0)<2){break a}i=c-2>>>1|0;e=d-a|0;if((i|0)<e>>1){break a}g=e+1|0;f=(g<<1)+a|0;e=e+2|0;if((e|0)<(c|0)){h=e;e=Ll(b,z[f>>1],z[f+2>>1]);g=e?h:g;f=e?f+2|0:f}if(Ll(b,z[f>>1],z[d>>1])){break a}j=z[d>>1];while(1){b:{e=d;d=f;w[e>>1]=z[f>>1];if((g|0)>(i|0)){break b}e=g<<1;g=e|1;f=(g<<1)+a|0;e=e+2|0;if((e|0)<(c|0)){h=e;e=Ll(b,z[f>>1],z[f+2>>1]);g=e?h:g;f=e?f+2|0:f}if(!Ll(b,z[f>>1],j)){continue}}break}w[d>>1]=j}}function M5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if((a|0)!=(b|0)){d=fb-16|0;fb=d;c=x[b>>2];b=x[b+4>>2];e=Sd(c,b);a:{if(e>>>0<=Ug(a)>>>0){f=b;g=x[a>>2];h=oc(g,x[a+4>>2]);i=h>>>0>=e>>>0;if(!i){x[d+12>>2]=c;$C(d+12|0,h);f=x[d+12>>2]}c=Wg(c,f,g);if(!i){yI(a,f,b,e-oc(x[a>>2],x[a+4>>2])|0);break a}Ih(a,c);break a}if(x[a>>2]){Nf(a);cy(hq(a),x[a>>2],Ug(a));j=zb(a),k=0,x[j>>2]=k;x[a>>2]=0;x[a+4>>2]=0}AJ(a,Mf(a,e));yI(a,c,b,e)}fb=d+16|0}return a|0}function npa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-32|0;fb=d;ld(b,0);e=d+8|0;ND(e,a+1|0);c=d+20|0;Cc(c,e);ze(b+43|0,c);tb(c);x[b+24>>2]=y[a+78|0]|y[a+79|0]<<8;c=y[a+58|0]|y[a+59|0]<<8|(y[a+60|0]<<16|y[a+61|0]<<24);x[b>>2]=c;x[b+4>>2]=y[a+62|0]|y[a+63|0]<<8|(y[a+64|0]<<16|y[a+65|0]<<24);x[b+8>>2]=y[a+66|0]|y[a+67|0]<<8|(y[a+68|0]<<16|y[a+69|0]<<24);w[b+30>>1]=(y[a+73|0]<<1)+2;w[b+34>>1]=z[b+34>>1]&65533|y[a|0]>>>6&2;wc(b+8|0,c);wc(b+4|0,x[b+8>>2]);fb=d+32|0}function Ioa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb+-64|0;fb=c;on(c+52|0,b);re(c+24|0,x[c+52>>2],x[c+56>>2]);b=Nd(c+16|0);x[31737]=0;d=x[b+4>>2];x[c+8>>2]=x[b>>2];x[c+12>>2]=d;b=jg(161,c+32|0,x[c+24>>2],x[c+28>>2],c+8|0);d=x[31737];x[31737]=0;a:{if((d|0)!=1){d=Nb(a);a=x[c+56>>2];e=x[c+52>>2];x[31737]=0;S(734,b|0,d|0,Vc(e,a)>>>5|0);a=x[31737];x[31737]=0;if((a|0)==1){a=N()|0;Xi(d);ub(b);break a}ub(b);dc(c+52|0);fb=c- -64|0;return}a=N()|0}dc(c+52|0);Q(a|0);p()}function Foa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb+-64|0;fb=c;on(c+52|0,b);re(c+24|0,x[c+52>>2],x[c+56>>2]);b=Nd(c+16|0);x[31737]=0;d=x[b+4>>2];x[c+8>>2]=x[b>>2];x[c+12>>2]=d;b=jg(161,c+32|0,x[c+24>>2],x[c+28>>2],c+8|0);d=x[31737];x[31737]=0;a:{if((d|0)!=1){d=Nb(a);a=x[c+56>>2];e=x[c+52>>2];x[31737]=0;S(735,b|0,d|0,Vc(e,a)>>>2|0);a=x[31737];x[31737]=0;if((a|0)==1){a=N()|0;vc(d);ub(b);break a}ub(b);dc(c+52|0);fb=c- -64|0;return}a=N()|0}dc(c+52|0);Q(a|0);p()}function Eoa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb+-64|0;fb=c;on(c+52|0,b);re(c+24|0,x[c+52>>2],x[c+56>>2]);b=Nd(c+16|0);x[31737]=0;d=x[b+4>>2];x[c+8>>2]=x[b>>2];x[c+12>>2]=d;b=jg(161,c+32|0,x[c+24>>2],x[c+28>>2],c+8|0);d=x[31737];x[31737]=0;a:{if((d|0)!=1){d=Nb(a);a=x[c+56>>2];e=x[c+52>>2];x[31737]=0;S(736,b|0,d|0,Vc(e,a)>>>8|0);a=x[31737];x[31737]=0;if((a|0)==1){a=N()|0;qv(d);ub(b);break a}ub(b);dc(c+52|0);fb=c- -64|0;return}a=N()|0}dc(c+52|0);Q(a|0);p()}function Doa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb+-64|0;fb=c;on(c+52|0,b);re(c+24|0,x[c+52>>2],x[c+56>>2]);b=Nd(c+16|0);x[31737]=0;d=x[b+4>>2];x[c+8>>2]=x[b>>2];x[c+12>>2]=d;b=jg(161,c+32|0,x[c+24>>2],x[c+28>>2],c+8|0);d=x[31737];x[31737]=0;a:{if((d|0)!=1){d=Nb(a);a=x[c+56>>2];e=x[c+52>>2];x[31737]=0;S(737,b|0,d|0,Vc(e,a)>>>4|0);a=x[31737];x[31737]=0;if((a|0)==1){a=N()|0;pn(d);ub(b);break a}ub(b);dc(c+52|0);fb=c- -64|0;return}a=N()|0}dc(c+52|0);Q(a|0);p()}function A1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=fb-16|0;fb=e;c=e+12|0;f=fb-16|0;fb=f;h=Ec(168);x[31737]=0;g=P(36,f+4|0,22303)|0;d=x[31737];x[31737]=0;a:{b:{c:{if((d|0)!=1){x[31737]=0;d=U(37,h|0,g|0,0)|0;i=x[31737];x[31737]=0;if((i|0)==1){break c}tb(g);x[c>>2]=d;fl(d);fb=f+16|0;break a}a=N()|0;break b}a=N()|0;tb(g)}Db(h);Q(a|0);p()}x[31737]=0;S(27,a|0,c|0,b|0);a=x[31737];x[31737]=0;if((a|0)!=1){Zb(c);fb=e+16|0;return}a=N()|0;Zb(c);Q(a|0);p()}function sra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=wb(x[b>>2]);h=wb(x[b+4>>2]);g=fb-16|0;fb=g;x[g+12>>2]=d;while(1){a:{if(!Ib(d,h)){break a}e=fb-16|0;fb=e;f=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);v[e+10|0]=f;v[e+11|0]=f>>>8;v[e+12|0]=f>>>16;v[e+13|0]=f>>>24;f=y[d+4|0]|y[d+5|0]<<8;v[e+14|0]=f;v[e+15|0]=f>>>8;fb=e+16|0;if(z[e+10>>1]==(c|0)){break a}d=x[lm(g+12|0)>>2];continue}break}fb=g+16|0;if(mc(d,wb(x[b+4>>2]))){ai(a);return}qp(a,d)}function tK(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;a:{if((a|0)!=(b|0)){b:{c:{f=y[a|0];if((f|0)!=45){break c}a=a+1|0;if((b|0)!=(a|0)){break c}break b}h=x[31612];x[31612]=0;Od();a=xy(a,e+12|0,d);d=hb;d:{g=x[31612];if(g){if(x[e+12>>2]!=(b|0)){break b}if((g|0)!=68){break d}x[c>>2]=4;a=-1;b=-1;break a}x[31612]=h;if(x[e+12>>2]==(b|0)){break d}break b}b=a;c=(f|0)==45;a=c?0-b|0:b;b=c?0-(d+((b|0)!=0)|0)|0:d;break a}}x[c>>2]=4;a=0;b=0}fb=e+16|0;hb=b;return a}function JT(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=fb-16|0;fb=d;j=d,k=Xj(b),x[j+4>>2]=k;c=fb-16|0;fb=c;g=eB(a,c+12|0,y[b|0],x[b+4>>2]);b=x[g>>2];if(!b){e=fb-16|0;fb=e;b=ec(a);h=Bh(c,Ec(28),Mg(e+8|0,b));b=x[h>>2];f=x[d+4>>2];i=x[f>>2];f=x[f+4>>2];x[b+24>>2]=0;x[b+16>>2]=i;x[b+20>>2]=f;j=ec(h),k=1,v[j+4|0]=k;fb=e+16|0;$g(a,x[c+12>>2],g,x[c>>2]);b=me(c);dm(c);e=1}_g(d+8|0,x[vb(c,b)>>2],e);fb=c+16|0;a=td(x[d+8>>2]);fb=d+16|0;return a+8|0}function $ha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;e=d+4|0;c=fb-32|0;fb=c;f=c+8|0;Wf(f,b);x[31737]=0;b=c+20|0;S(11,b|0,0,f|0);g=x[31737];x[31737]=0;a:{b:{c:{if((g|0)!=1){x[31737]=0;O(968,e|0,b|0);g=x[31737];x[31737]=0;if((g|0)==1){break c}Ub(b);tb(f);fb=c+32|0;break a}a=N()|0;break b}a=N()|0;Ub(c+20|0)}tb(c+8|0);Q(a|0);p()}x[31737]=0;P(966,a|0,e|0)|0;a=x[31737];x[31737]=0;if((a|0)!=1){tb(e);fb=d+16|0;return}a=N()|0;tb(d+4|0);Q(a|0);p()}function lka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=fb-16|0;fb=e;d=z[a+30>>1];if(d){b=hA(b<<16>>16,d<<16>>16)}w[e+14>>1]=b;a=a+52|0;a:{if(!Ad(x[c+4>>2],y[c+11|0])){us(dR(a,e+14|0),c);break a}b=iA(a,e+14|0);if(!Zg(b,Rf(a))){break a}c=fb-16|0;fb=c;b=x[vb(c+8|0,b)>>2];d=fb-16|0;fb=d;f=ah(vb(d+12|0,b));if((b|0)==x[a>>2]){x[a>>2]=x[f>>2]}g=zb(a);x[g>>2]=x[g>>2]-1;nV(x[ec(a)>>2],b);a=x[f>>2];fb=d+16|0;Wj(td(b));Db(b);vb(c+12|0,a);fb=c+16|0}fb=e+16|0}function xI(a,b,c,d,e,f,g,h){var i=0,j=0,k=0;i=fb-16|0;fb=i;if(1073741806-b>>>0>=c>>>0){k=Jb(a);j=i+4|0;if(b>>>0<=536870886){x[i+12>>2]=b<<1;x[i+4>>2]=b+c;c=yn(x[ad(j,i+12|0)>>2])+1|0}else{c=1073741807}Uj(j,c);c=x[i+4>>2];if(e){Yi(c,k,e)}if(g){Yi(c+(e<<2)|0,h,g)}j=e+f|0;h=d-j|0;if((d|0)!=(j|0)){d=e<<2;Yi((d+c|0)+(g<<2)|0,(d+k|0)+(f<<2)|0,h)}if((b|0)!=1){Db(k)}yd(a,c);of(a,x[i+8>>2]);b=a;a=h+(e+g|0)|0;Yd(b,a);yd(c+(a<<2)|0,0);fb=i+16|0;return}pf();p()}function M9(){var a=0,b=0,c=0,d=0,e=0,f=0;c=fb-48|0;fb=c;if(LL(1,c+24|0)){It(x[31612],12795);p()}b=we(c+16|0,x[c+24>>2],x[c+28>>2]);f=ZA(c+8|0,x[c+32>>2]);d=fb-16|0;fb=d;e=fb-16|0;fb=e;a=we(e+8|0,Sua(x[b>>2],x[b+4>>2],1e9,0),hb);b=x[a>>2];a=x[a+4>>2];fb=e+16|0;x[d>>2]=b;x[d+4>>2]=a;a=x[d>>2];e=a+x[f>>2]|0;f=x[f+4>>2]+x[d+4>>2]|0;b=we(d+8|0,e,a>>>0>e>>>0?f+1|0:f);a=x[b>>2];fb=d+16|0;b=we(c+40|0,a,x[b+4>>2]);a=x[b>>2];fb=c+48|0;hb=x[b+4>>2];return a|0}function ona(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=fb-16|0;fb=b;h=x[a+24>>2];i=x[a+20>>2];j=x[a+16>>2];f=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=f;f=x[a+8>>2];k=x[a+12>>2];while(1){if(d){g=x[b+12>>2]+j|0;e=v[g|0];e=((D(v[g+1|0]-e|0,x[b+8>>2]>>>10&4194048)|0)/16384|0)+(e<<8)|0;x[c>>2]=x[c>>2]+D(e,i);x[c+4>>2]=x[c+4>>2]+D(e,h);Pb(b+8|0,f,k);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;fb=b+16|0}function ZE(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=x[a>>2];c=Zc(d,x[a+4>>2]);if(c>>>0<b>>>0){e=fb-32|0;fb=e;b=b-c|0;c=x[zb(a)>>2];d=x[a+4>>2];a:{if(b>>>0<=c-d>>1>>>0){QE(a,b);break a}c=zb(a);c=kk(e+12|0,lk(a,Zc(x[a>>2],d)+b|0),Zc(x[a>>2],x[a+4>>2]),c);f=fb-16|0;fb=f;b=Gp(f+4|0,c+8|0,b);d=x[b>>2];while(1){if(x[b+4>>2]!=(d|0)){Vw(d);d=x[b>>2]+2|0;x[b>>2]=d;continue}break}he(b);fb=f+16|0;Yr(a,c);jj(c)}fb=e+32|0;return}if(b>>>0<c>>>0){In(a,d+(b<<1)|0)}}function Kaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;f=fb-16|0;fb=f;d=fb-32|0;fb=d;Id(d+24|0,a,b);h=d+16|0;e=x[d+24>>2];g=x[d+28>>2];b=fb-16|0;fb=b;x[b+12>>2]=c;a:{while(1){if((e|0)==(g|0)){break a}c=Dc(b,x[e>>2]);x[31737]=0;P(1151,b+12|0,c|0)|0;i=x[31737];x[31737]=0;if((i|0)!=1){tb(c);e=e+4|0;continue}break}a=N()|0;tb(c);Q(a|0);p()}Ac(h,g,b+12|0);fb=b+16|0;b=x[d+16>>2];x[d+12>>2]=x[d+20>>2];Ac(f+8|0,kA(a,b),d+12|0);fb=d+32|0;fb=f+16|0}function uV(a,b,c,d,e){var f=0,g=0,h=0;h=-1;g=d&2147483647;f=(g|0)==2147418112;a:{if(f&!c?a|b:f&(c|0)!=0|g>>>0>2147418112){break a}f=e&2147483647;if(((f|0)==2147418112&0|f>>>0>2147418112)&(f|0)!=2147418112){break a}if(!(a|c|(f|g|b))){return 0}f=d&e;if((f|0)>0){f=1}else{f=(f|0)>=0}if(f){if(((c|0)!=0|(d|0)!=(e|0))&(d|0)<(e|0)){break a}return(a|c|(d^e|b))!=0}if(!c&(d|0)==(e|0)?a|b:(c|0)!=0&(d|0)>=(e|0)|(d|0)>(e|0)){break a}h=(a|c|(d^e|b))!=0}return h}function jaa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;g=fb-32|0;fb=g;e=x[b+276>>2];kg(x[x[e>>2]-12>>2]+e|0,0);$d(g+16|0,x[b+276>>2]);f=gi(g,-1,-1);e=x[g+24>>2];h=x[g+28>>2];a:{if(!eo(e,h,x[f+8>>2],x[f+12>>2])){b:{if((c|0)!=(e|0)|h){break b}break a}}Hi(x[b+276>>2],c,0,0)}e=x[d>>2];d=x[d+4>>2];c=0;while(1){if(d){f=x[b+276>>2];h=th(d);Dj(f,c+e|0,h);f=x[x[b+276>>2]+4>>2];d=d-f|0;c=c+f|0;if((f|0)==(h|0)){continue}}break}bc(a,e,c);fb=g+32|0}function Bta(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);f=d+8|0;Rd(f,x[vb(d+4|0,a)>>2]);x[31737]=0;W(345,a|0);b=x[31737];x[31737]=0;if((b|0)!=1){g=fb-16|0;fb=g;b=g+4|0;x[b>>2]=a;e=x[a+4>>2];x[b+4>>2]=e;x[b+8>>2]=e+32768;c=x[b+4>>2];e=x[b+8>>2];while(1){if((c|0)==(e|0)){hc(b);fb=g+16|0}else{w[c>>1]=0;w[c+2>>1]=0;c=c+4|0;x[b+4>>2]=c;continue}break}Qd(f);ch(f);fb=d+16|0;return a|0}a=N()|0;ch(d+8|0);Q(a|0);p()}function Pua(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;a:{b:{if(!kh(a,7)){break b}c=0;if(!OE(a,18467)){break a}if(!kh(a,1)){break b}c=-1;if(!gd(a,Qr(a))){break a}c=fb-16|0;fb=c;f=d+9|0;Pr(c+8|0,f);e=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(e|0)){gd(a,x[c+12>>2])}fb=c+16|0;e=(e|0)==(g|0);if(!e){DE(f)}c=-1;if(!e){break a}c=0;if(!P0(y[d+9|0],y[d+10|0])){break a}c=ve(a,b,O0(f),hb);break a}c=-1}fb=d+16|0;return c|0}function L9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=fb-32|0;fb=d;x[d+16>>2]=b;e=x[a+48>>2];x[d+20>>2]=c-((e|0)!=0);g=x[a+44>>2];x[d+28>>2]=e;x[d+24>>2]=g;a:{b:{if(Yy(cb(x[a+60>>2],d+16|0,2,d+12|0)|0)){b=32}else{e=x[d+12>>2];if((e|0)>0){break b}b=e?32:16}x[a>>2]=b|x[a>>2];break a}f=e;g=x[d+20>>2];if(g>>>0>=e>>>0){break a}f=x[a+44>>2];x[a+4>>2]=f;x[a+8>>2]=f+(e-g|0);if(x[a+48>>2]){x[a+4>>2]=f+1;v[(b+c|0)-1|0]=y[f|0]}f=c}fb=d+32|0;return f|0}function nna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=fb-16|0;fb=b;g=x[a+24>>2];h=x[a+20>>2];i=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;j=x[a+8>>2];k=x[a+12>>2];while(1){if(d){e=(x[b+12>>2]<<1)+i|0;f=w[e>>1];e=f+((D(w[e+2>>1]-f|0,x[b+8>>2]>>>18|0)|0)/16384|0)|0;x[c>>2]=x[c>>2]+D(e,h);x[c+4>>2]=x[c+4>>2]+D(e,g);Pb(b+8|0,j,k);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;fb=b+16|0}function dH(a,b,c,d,e){var f=0,g=0,h=0;a:{g=fb-32|0;fb=g;h=Nb(a);b:{c:{d:{e:{while(1){a=x[b+8>>2];f=x[b>>2];x[31737]=0;a=U(151,f|0,a|0,8)|0;f=x[31737];x[31737]=0;if((f|0)==1){break c}if(!a){break d}x[31737]=0;a=g+4|0;S(e|0,a|0,b|0,c|0);f=x[31737];x[31737]=0;if((f|0)!=1){x[31737]=0;O(d|0,h|0,a|0);f=x[31737];x[31737]=0;if((f|0)==1){break e}Fd(a);continue}break}a=N()|0;break b}a=N()|0;Fd(g+4|0);break b}fb=g+32|0;break a}a=N()|0}ie(h);Q(a|0);p()}}function Mfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=fb-32|0;fb=e;x[e+28>>2]=c;c=e+28|0;f=x[qe(e+24|0,c)>>2];x[31737]=0;g=x[b+12>>2];x[e+16>>2]=x[b+8>>2];x[e+20>>2]=g;g=x[b+4>>2];x[e+8>>2]=x[b>>2];x[e+12>>2]=g;ba(996,a+8|0,e+8|0,f|0,d|0)|0;b=x[31737];x[31737]=0;if((b|0)!=1){a=Ez(a);b=Dz(a+88|0);d=Cz(a+92|0);f=Bz(a+96|0);x[a>>2]=47820;x[b>>2]=47936;x[d>>2]=48016;x[f>>2]=48056;Uc(c);fb=e+32|0;return a|0}a=N()|0;Uc(e+28|0);Q(a|0);p()}function i4(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=fb-32|0;fb=f;g=ho(f+20|0,b,c);x[31737]=0;e=U(1344,f+8|0,d|0,e|0)|0;a=x[31737];x[31737]=0;if((a|0)!=1){c=Jb(g);d=Jb(e);a=x[d>>2];b=x[c>>2];a:{if(!a|!b|(a|0)!=(b|0)){break a}while(1){a=x[d+4>>2];b=x[c+4>>2];if(!a|!b){break a}d=d+4|0;c=c+4|0;if((a|0)==(b|0)){continue}break}}Ub(e);Ub(g);fb=f+32|0;a=(a|0)>(b|0)?-1:(a|0)<(b|0);return((a|0)<0?-1:(a|0)!=0)|0}a=N()|0;Ub(g);Q(a|0);p()}function S2(a,b){a=a|0;b=b|0;var c=0;a=Fb(a);a:{if(y[b+16|0]){x[31737]=0;P(128,a|0,4945)|0;c=x[31737];x[31737]=0;if((c|0)==1){break a}}if(y[b+17|0]){x[31737]=0;P(128,a|0,12624)|0;c=x[31737];x[31737]=0;if((c|0)==1){break a}}if(Ad(x[a+4>>2],y[a+11|0])){x[31737]=0;P(128,a|0,10083)|0;c=x[31737];x[31737]=0;if((c|0)==1){break a}}if(y[b+18|0]){x[31737]=0;P(128,a|0,11143)|0;b=x[31737];x[31737]=0;if((b|0)==1){break a}}return}b=N()|0;tb(a);Q(b|0);p()}function Nk(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=x[a>>2];c=Vc(d,x[a+4>>2]);if(c>>>0<b>>>0){e=fb-32|0;fb=e;b=b-c|0;c=x[zb(a)>>2];d=x[a+4>>2];a:{if(b>>>0<=c-d>>>0){cY(a,b);break a}c=zb(a);c=un(e+12|0,bm(a,Vc(x[a>>2],d)+b|0),Vc(x[a>>2],x[a+4>>2]),c);f=fb-16|0;fb=f;b=yC(f+4|0,c+8|0,b);d=x[b>>2];while(1){if(x[b+4>>2]!=(d|0)){JX(d);d=x[b>>2]+1|0;x[b>>2]=d;continue}break}he(b);fb=f+16|0;gr(a,c);tn(c)}fb=e+32|0;return}if(b>>>0<c>>>0){or(a,b+d|0)}}function $p(a,b,c,d,e){var f=0,g=0,h=0;a:{g=fb-32|0;fb=g;h=Nb(a);b:{c:{d:{e:{while(1){a=x[b+8>>2];f=x[b>>2];x[31737]=0;a=U(151,f|0,a|0,e|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break c}if(!a){break d}x[31737]=0;a=g+4|0;O(d|0,a|0,b|0);f=x[31737];x[31737]=0;if((f|0)!=1){x[31737]=0;O(c|0,h|0,a|0);f=x[31737];x[31737]=0;if((f|0)==1){break e}Fd(a);continue}break}a=N()|0;break b}a=N()|0;Fd(g+4|0);break b}fb=g+32|0;break a}a=N()|0}ie(h);Q(a|0);p()}}function rc(a,b){var c=0,d=0,e=0;c=x[a+1396>>2];if((c|0)>=0){a:{b:{if((b|0)<=(c|0)){break b}if((b|0)>24){return rc(a,24)+(rc(a,b-24|0)<<24)|0}if(!c){x[a+1392>>2]=0}while(1){if((b|0)<=(c|0)){break b}c=-1;e=Pt(a);d=0;if((e|0)==-1){break a}d=x[a+1396>>2];c=d+8|0;x[a+1396>>2]=c;x[a+1392>>2]=x[a+1392>>2]+(e<<d);continue}}if((b|0)>(c|0)){_(10093,13274,1632,6865);p()}d=x[a+1392>>2];x[a+1392>>2]=d>>>b;c=c-b|0;d=d&(-1<<b^-1)}x[a+1396>>2]=c}return d}function hu(a){var b=0,c=0,d=0,e=0;a:{while(1){if(!a){b=0;if(x[31606]){b=hu(x[31606])}if(!x[31532]){break a}c=b|c;a=x[31532];continue}break}d=x[a+76>>2]<0;b:{c:{if(x[a+20>>2]==x[a+28>>2]){break c}ib[x[a+36>>2]](a,0,0)|0;if(x[a+20>>2]){break c}b=-1;if(!d){break b}break a}b=x[a+8>>2];e=x[a+4>>2];if((b|0)!=(e|0)){b=e-b|0;ib[x[a+40>>2]](a,b,b>>31,1)|0}b=0;x[a+28>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+4>>2]=0;x[a+8>>2]=0;if(d){break a}}}return b|c}function Goa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=fb-4096|0;fb=c;on(a,b);a:while(1){if(Vc(x[a>>2],x[a+4>>2])>>>12>>>0>e>>>0){f=e<<12;b=0;d=0;while(1)if((b|0)==2048){h=f|2048;b=0;while(1){g=x[a>>2];if((b|0)!=2048){d=y[xb(g,b+h|0)|0]+d|0;i=xb(c,b<<1),j=d,v[i|0]=j;b=b+1|0;continue}break}ov(c,sC(c),uf(wb(g),f));e=e+1|0;continue a}else{d=y[xb(x[a>>2],b+f|0)|0]+d|0;i=xb(c,b<<1|1),j=d,v[i|0]=j;b=b+1|0;continue}}break}fb=c+4096|0}function $sa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);Rd(d+8|0,x[vb(d+4|0,a)>>2]);a:{if(b){x[31737]=0;O(375,a|0,b|0);e=x[31737];x[31737]=0;if((e|0)==1){break a}f=fb-16|0;fb=f;e=_h(f+4|0,a,b);b=x[e+4>>2];g=x[e+8>>2];while(1){if((b|0)==(g|0)){hc(e);fb=f+16|0}else{hj(b,y[c|0]|y[c+1|0]<<8);b=b+2|0;x[e+4>>2]=b;continue}break}}b=d+8|0;Qd(b);Yj(b);fb=d+16|0;return a|0}a=N()|0;Yj(d+8|0);Q(a|0);p()}function HR(a,b,c,d,e,f,g,h){var i=0,j=0;i=fb-16|0;fb=i;x[i+12>>2]=d;a:{if(!(y[a+12|0]|y[a+13|0]<<8|(y[a+14|0]<<16|y[a+15|0]<<24))){break a}x[i+8>>2]=y[a+8|0]|y[a+9|0]<<8|(y[a+10|0]<<16|y[a+11|0]<<24);j=b;b=x[Gb(i+8|0,i+12|0)>>2];x[j>>2]=b;b=Kd(y[a+12|0]|y[a+13|0]<<8|(y[a+14|0]<<16|y[a+15|0]<<24),b,d);x[c>>2]=((h^1)&b>>>0<d>>>0)+b;b=z[e>>1]|f;w[e>>1]=b;if((y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24))!=1){break a}w[e>>1]=b|g}fb=i+16|0}function Vy(a,b){a:{if(a){if(b>>>0<=127){break a}b:{if(!x[x[124243]>>2]){if((b&-128)==57216){break a}break b}if(b>>>0<=2047){v[a+1|0]=b&63|128;v[a|0]=b>>>6|192;return 2}if(!((b&-8192)!=57344&b>>>0>=55296)){v[a+2|0]=b&63|128;v[a|0]=b>>>12|224;v[a+1|0]=b>>>6&63|128;return 3}if(b-65536>>>0<=1048575){v[a+3|0]=b&63|128;v[a|0]=b>>>18|240;v[a+2|0]=b>>>6&63|128;v[a+1|0]=b>>>12&63|128;return 4}}x[31612]=25;a=-1}else{a=1}return a}v[a|0]=b;return 1}function roa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=fb-16|0;fb=c;d=Xc(c+12|0,16,1,1,0);x[c+8>>2]=0;ld(a,0);xc(b);a:{b:{if(Tr(b,13883)){cd(b,12);if(!sp(b)){Bp(d,2)}cd(b,24);break b}if(gk(b,13770)){xc(b);x[c+8>>2]=4;e=1;break a}fd(d,8)}e=0}f=a,g=(kf(b)>>>0)/(D(y[d|0],mr(y[d+1|0]))>>>3>>>0)|0,x[f>>2]=g;b=fg(d,a,b);if(!(!b|!e)){d=x[a+20>>2];f=c,g=Vk(x[a>>2],z[a+34>>1]),x[f+4>>2]=g;Rb(d,0,x[Gb(c+8|0,c+4|0)>>2])}fb=c+16|0;return(b|0)!=0|0}function mZ(a,b){var c=0,d=0,e=0,f=0;d=x[a>>2];c=oc(d,x[a+4>>2]);if(c>>>0<b>>>0){e=fb-32|0;fb=e;b=b-c|0;c=x[zb(a)>>2];d=x[a+4>>2];a:{if(b>>>0<=c-d>>2>>>0){jD(a,b);break a}c=zb(a);c=$f(e+12|0,Mf(a,oc(x[a>>2],d)+b|0),oc(x[a>>2],x[a+4>>2]),c);f=fb-16|0;fb=f;b=Ln(f+4|0,c+8|0,b);d=x[b>>2];while(1){if(x[b+4>>2]!=(d|0)){Hn(d);d=x[b>>2]+4|0;x[b>>2]=d;continue}break}he(b);fb=f+16|0;kZ(a,c);_f(c)}fb=e+32|0;return}if(b>>>0<c>>>0){Ih(a,d+(b<<2)|0)}}function bU(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=fb-16|0;fb=e;j=e,k=Xj(b),x[j+4>>2]=k;c=fb-16|0;fb=c;f=LB(a,c+12|0,z[b>>1],x[b+4>>2]);b=x[f>>2];if(!b){b=fb-16|0;fb=b;d=ec(a);g=Bh(c,Ec(36),Mg(b+8|0,d));d=x[g>>2]+16|0;h=x[e+4>>2];i=x[h+4>>2];x[d>>2]=x[h>>2];x[d+4>>2]=i;Nb(d+8|0);j=ec(g),k=1,v[j+4|0]=k;fb=b+16|0;$g(a,x[c+12>>2],f,x[c>>2]);b=me(c);gU(c);d=1}_g(e+8|0,x[vb(c,b)>>2],d);fb=c+16|0;a=td(x[e+8>>2]);fb=e+16|0;return a+8|0}function Efa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=+e;var f=0,g=0;x[31737]=0;W(1027,a|0);f=x[31737];x[31737]=0;a:{b:{if((f|0)!=1){f=x[a+28>>2];g=x[x[f>>2]+72>>2];x[31737]=0;b=Ta(g|0,f|0,b|0,c|0,+d,+e)|0;c=x[31737];x[31737]=0;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[31737]=0;V(989,11314,a|0,0,0);a=x[31737];x[31737]=0;if((a|0)==1){break a}Z();b=-1}return b|0}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function Faa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=fb-16|0;fb=f;e=f+4|0;x[e+4>>2]=1;h=e,i=Ec(56),x[h+8>>2]=i;c=ym(x[e+8>>2]);x[c>>2]=77520;g=nc(c);c=fb-16|0;fb=c;d=x[b+12>>2];x[c+8>>2]=x[b+8>>2];x[c+12>>2]=d;d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;d=BM(g);x[d>>2]=77684;b=x[c+4>>2];x[d+24>>2]=x[c>>2];x[d+28>>2]=b;b=x[c+12>>2];x[d+32>>2]=x[c+8>>2];x[d+36>>2]=b;v[d+40|0]=0;fb=c+16|0;b=a;a=Wn(e);Vn(b,nc(a),a);zm(e);fb=f+16|0}function $2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=a+32|0;qw(c,b);x[a+44>>2]=0;b=x[a+48>>2];if(b&8){b=Jb(c)+Cb(x[a+36>>2],y[a+43|0])|0;x[a+44>>2]=b;d=Jb(c);ko(a,d,d,b);b=x[a+48>>2]}a:{if(!(b&16)){break a}b=Cb(x[a+36>>2],y[a+43|0]);e=a,f=b+Jb(c)|0,x[e+44>>2]=f;eC(c,Mc(c));c=Jb(c);My(a,c,Cb(x[a+36>>2],y[a+43|0])+c|0);if(!(y[a+48|0]&3)){break a}while(1){if((b|0)<0){Bt(a,2147483647);b=b-2147483647|0;continue}break}if(!b){break a}Bt(a,b)}}function zba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-48|0;fb=e;x[e+44>>2]=d;x[e+40>>2]=d;a=Re(e+12|0,a,e+40|0,e+44|0);x[e+8>>2]=x[a+8>>2];d=x[a+4>>2];x[e>>2]=x[a>>2];x[e+4>>2]=d;Qe(e+24|0,e);a:{while(1){if((b|0)==(c|0)){break a}x[31737]=0;O(1130,x[e+44>>2],b|0);a=x[31737];x[31737]=0;if((a|0)!=1){x[e+44>>2]=x[e+44>>2]+16;b=b+16|0;continue}break}a=N()|0;kN(e+24|0);Q(a|0);p()}a=e+24|0;Pe(a);b=x[e+44>>2];kN(a);fb=e+48|0;return b|0}function tl(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=fb-16|0;fb=e;x[b>>2]=0;x[b+4>>2]=0;v[e+15|0]=0;mi(a,e+15|0);c=y[e+15|0];f=(c&252)>>>2|0;i=-1<<(c&3)^-1;while(1){x[b>>2]=f;x[b+4>>2]=d;if(!h&(g|0)==(i|0)){fb=e+16|0}else{v[e+15|0]=0;mi(a,e+15|0);d=x[b>>2];j=x[b+4>>2];f=y[e+15|0];c=h;g=g+1|0;h=g?c:c+1|0;k=d;c=(g<<3)-2|0;d=c&31;if((c&63)>>>0>=32){c=f<<d;d=0}else{c=(1<<d)-1&f>>>32-d;d=f<<d}f=k|d;d=c|j;continue}break}}function eaa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-48|0;fb=e;x[e+44>>2]=d;x[e+40>>2]=d;a=Re(e+12|0,a,e+40|0,e+44|0);x[e+8>>2]=x[a+8>>2];d=x[a+4>>2];x[e>>2]=x[a>>2];x[e+4>>2]=d;Qe(e+24|0,e);a:{while(1){if((b|0)==(c|0)){break a}x[31737]=0;O(1166,x[e+44>>2],b|0);a=x[31737];x[31737]=0;if((a|0)!=1){x[e+44>>2]=x[e+44>>2]+12;b=b+12|0;continue}break}a=N()|0;mM(e+24|0);Q(a|0);p()}a=e+24|0;Pe(a);b=x[e+44>>2];mM(a);fb=e+48|0;return b|0}function Vu(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;i=OB(x[a+24>>2],y[a+32|0]);g=Oj(i);j=65535;a:{while(1){if((d|0)==(g|0)){d=g;a=-1;break a}b:{c:{if(!bj(i,d&65535)){break c}e=x[a>>2];if(Ud(e,x[a+4>>2])>>>0<=d>>>0){break b}f=0;h=Hd(e,d);while(1){d:{e=x[h+4>>2];if(e>>>0>f>>>0){if(!BC(x[h>>2],f)){break d}e=x[h+4>>2]}if((f|0)==(e|0)){break b}break c}f=f+1|0;continue}}d=d+1|0;continue}break}j=d;a=0}w[b>>1]=j;x[c>>2]=a;return d>>>0<g>>>0}function Jla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=x[a>>2];d=Lg(e,x[a+4>>2]);if(d>>>0<b>>>0){e=fb-32|0;fb=e;a:{b:{d=b-d|0;b=x[zb(a)>>2];f=x[a+4>>2];c:{if(d>>>0<=b-f>>5>>>0){YB(a,d,c);break c}b=zb(a);b=fv(e+12|0,_q(a,Lg(x[a>>2],f)+d|0),Lg(x[a>>2],x[a+4>>2]),b);x[31737]=0;S(788,b|0,d|0,c|0);c=x[31737];x[31737]=0;if((c|0)==1){break b}YU(a,b);XB(b)}fb=e+32|0;break a}a=N()|0;XB(b);Q(a|0);p()}return}if(b>>>0<d>>>0){_U(a,e+(b<<5)|0)}}function Hz(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;b=fb-48|0;fb=b;x[b+40>>2]=e;x[b+44>>2]=f;c=gc(b+32|0,c,d);d=x[c+4>>2];x[b+8>>2]=x[c>>2];x[b+12>>2]=d;a:{a=zu(a,b+8|0,b+40|0);if(a+1>>>0>=3){a=ac(8);x[31737]=0;b=P(36,b+20|0,8057)|0;c=x[31737];x[31737]=0;b:{if((c|0)!=1){pc(a,b);x[31737]=0;S(98,a|0,48540,1006);a=x[31737];x[31737]=0;if((a|0)!=1){break a}c=N()|0;tb(b);break b}c=N()|0;jc(a)}Q(c|0);p()}fb=b+48|0;return a|0}p()}function Of(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0;i=Sua(b,c,h,i);h=hb;e=Sua(d,e,f,g);i=e+i|0;d=hb+h|0;h=e>>>0>i>>>0?d+1|0:d;j=g;e=0;k=c;d=0;c=Sua(g,e,c,d);g=c+i|0;i=hb+h|0;l=g;c=c>>>0>g>>>0?i+1|0:i;g=Sua(f,0,b,0);h=hb;i=0;d=Sua(f,i,k,d);h=h+d|0;f=hb+i|0;f=d>>>0>h>>>0?f+1|0:f;i=f+l|0;d=c;f=f>>>0>i>>>0?d+1|0:d;b=Sua(b,m,j,e)+h|0;e=hb;e=b>>>0<h>>>0?e+1|0:e;h=e+i|0;i=f;x[a+8>>2]=h;x[a+12>>2]=e>>>0>h>>>0?i+1|0:i;x[a>>2]=g;x[a+4>>2]=b}function iV(a,b,c,d){var e=0,f=0,g=0;g=fb-16|0;fb=g;d=_h(g+4|0,a,d);e=zb(a);a=fb+-64|0;fb=a;f=x[d+4>>2];x[a+56>>2]=f;x[a+60>>2]=b;x[a+52>>2]=f;e=Re(a+24|0,e,a+52|0,a+56|0);x[a+16>>2]=x[e+8>>2];f=x[e+4>>2];x[a+8>>2]=x[e>>2];x[a+12>>2]=f;Qe(a+36|0,a+8|0);while(1){if(Ib(b,c)){fj(x[a+56>>2],z[b>>1]);b=Md(a+60|0);x[a+56>>2]=x[a+56>>2]+2;b=x[b>>2];continue}break}b=a+36|0;Pe(b);c=x[a+56>>2];pE(b);fb=a- -64|0;x[d+4>>2]=c;hc(d);fb=g+16|0}function LH(a,b,c,d,e,f){var g=0,h=0,i=0;g=fb-256|0;fb=g;x[g+248>>2]=37;x[g+252>>2]=0;h=g+248|0;ht(h|1,10632,f,x[b+4>>2]);f=Od();x[g>>2]=d;x[g+4>>2]=e;d=g+224|0;e=ph(d,24,f,h,g)+d|0;h=sj(d,e,x[b+4>>2]);f=g+20|0;bd(f,x[b+28>>2]);x[31737]=0;i=d;d=g+32|0;ga(1227,i|0,h|0,e|0,d|0,g+28|0,g+24|0,f|0);e=x[31737];x[31737]=0;a:{if((e|0)!=1){Zb(f);a=ft(a,d,x[g+28>>2],x[g+24>>2],b,c);fb=g+256|0;break a}a=N()|0;Zb(g+20|0);Q(a|0);p()}return a}function y$(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=x[a+1064>>2];a:{while(1){if((b|0)>255){break a}f=(D(b,6)+a|0)+1072|0,g=gl(a,7),v[f|0]=g;d=gl(a,1);e=gl(a,1);c=x[a+1060>>2];if((c|0)>255){break a}b=x[a+1064>>2]+1|0;x[a+1060>>2]=b;x[a+1064>>2]=b;b:{if(d){w[(D(c,6)+a|0)+1068>>1]=b;y$(a);b=x[a+1064>>2];break b}w[(D(c,6)+a|0)+1068>>1]=65535}x[a+1060>>2]=b;if(e){w[(D(c,6)+a|0)+1070>>1]=b;continue}break}w[(D(c,6)+a|0)+1070>>1]=65535}}function XD(a,b,c,d){var e=0,f=0,g=0;g=fb-16|0;fb=g;d=$l(g+4|0,a,d);e=zb(a);a=fb+-64|0;fb=a;f=x[d+4>>2];x[a+56>>2]=f;x[a+60>>2]=b;x[a+52>>2]=f;e=Re(a+24|0,e,a+52|0,a+56|0);x[a+16>>2]=x[e+8>>2];f=x[e+4>>2];x[a+8>>2]=x[e>>2];x[a+12>>2]=f;Qe(a+36|0,a+8|0);while(1){if(Ib(b,c)){Dl(x[a+56>>2],y[b|0]);b=le(a+60|0);x[a+56>>2]=x[a+56>>2]+1;b=x[b>>2];continue}break}b=a+36|0;Pe(b);c=x[a+56>>2];d$(b);fb=a- -64|0;x[d+4>>2]=c;hc(d);fb=g+16|0}function NH(a,b,c,d,e,f){var g=0,h=0,i=0;g=fb-112|0;fb=g;x[g+104>>2]=37;x[g+108>>2]=0;h=g+104|0;ht(h|1,10632,f,x[b+4>>2]);f=Od();x[g>>2]=d;x[g+4>>2]=e;d=g+80|0;e=ph(d,24,f,h,g)+d|0;h=sj(d,e,x[b+4>>2]);f=g+20|0;bd(f,x[b+28>>2]);x[31737]=0;i=d;d=g+32|0;ga(1224,i|0,h|0,e|0,d|0,g+28|0,g+24|0,f|0);e=x[31737];x[31737]=0;a:{if((e|0)!=1){Zb(f);a=pw(a,d,x[g+28>>2],x[g+24>>2],b,c);fb=g+112|0;break a}a=N()|0;Zb(g+20|0);Q(a|0);p()}return a}function Ena(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=fb-16|0;fb=b;h=x[a+16>>2];f=mg(1,2);e=hb;i=e;Pb(a,f,e);j=x[a+24>>2];k=x[a+20>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;e=x[a+8>>2];l=x[a+12>>2];while(1){if(d){g=w[(x[b+12>>2]<<1)+h>>1];x[c>>2]=x[c>>2]+D(g,k);x[c+4>>2]=x[c+4>>2]+D(j,g);Pb(b+8|0,e,l);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;Hg(a,f,i);fb=b+16|0}function gu(a,b){var c=0,d=0,e=0,f=0,g=0;e=fb-16|0;fb=e;c=ce(a);d=ec(a);f=fb-16|0;fb=f;while(1){if(c){g=Tu(c+16|0,b);d=g?d:c;c=x[(g?c+4|0:c)>>2];continue}break}c=x[vb(f+12|0,d)>>2];fb=f+16|0;a:{if(Ib(c,rg(a))){if(!Tu(b,td(c))){break a}}c=rg(a)}if(!mc(c,rg(a))){b=x[vb(e+12|0,c)>>2];c=fb-16|0;fb=c;d=ah(vb(c+12|0,b));if((b|0)==x[a>>2]){x[a>>2]=x[d>>2]}d=zb(a);x[d>>2]=x[d>>2]-1;nV(x[ec(a)>>2],b);fb=c+16|0;en(td(b));Db(b)}fb=e+16|0}function Hfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;x[31737]=0;W(1027,a|0);e=x[31737];x[31737]=0;a:{b:{if((e|0)!=1){e=x[a+28>>2];f=x[x[e>>2]+12>>2];x[31737]=0;b=ba(f|0,e|0,b|0,c|0,d|0)|0;c=x[31737];x[31737]=0;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[31737]=0;V(989,11459,a|0,0,0);a=x[31737];x[31737]=0;if((a|0)==1){break a}Z();b=-1}return b|0}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function uK(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;a:{b:{if((a|0)!=(b|0)){c:{d:{f=y[a|0];if((f|0)!=45){break d}a=a+1|0;if((b|0)!=(a|0)){break d}break c}h=x[31612];x[31612]=0;Od();a=xy(a,e+12|0,d);d=hb;g=x[31612];e:{if(g){if(x[e+12>>2]!=(b|0)){break c}if((g|0)==68|d){break e}break b}x[31612]=h;if(x[e+12>>2]!=(b|0)){break c}if(!d){break b}}x[c>>2]=4;a=-1;break a}}x[c>>2]=4;a=0;break a}a=(f|0)==45?0-a|0:a}fb=e+16|0;return a}function dq(a,b,c,d,e,f,g,h){var i=0,j=0,k=0;i=fb-16|0;fb=i;if(2147483630-b>>>0>=c>>>0){k=Jb(a);j=i+4|0;if(b>>>0<=1073741798){x[i+12>>2]=b<<1;x[i+4>>2]=b+c;c=Dh(x[ad(j,i+12|0)>>2])+1|0}else{c=2147483631}sg(j,c);c=x[i+4>>2];if(e){Cg(c,k,e)}if(g){Cg(c+e|0,h,g)}j=e+f|0;h=d-j|0;if((d|0)!=(j|0)){Cg((c+e|0)+g|0,(e+k|0)+f|0,h)}if((b|0)!=10){Db(k)}yd(a,c);of(a,x[i+8>>2]);b=a;a=h+(e+g|0)|0;Yd(b,a);fd(a+c|0,0);fb=i+16|0;return}pf();p()}function Yq(a,b,c,d,e,f,g,h){var i=0,j=0,k=0;i=fb-16|0;fb=i;if(2147483630-b>>>0>=c>>>0){k=Jb(a);j=i+4|0;if(b>>>0<=1073741798){x[i+12>>2]=b<<1;x[i+4>>2]=b+c;c=Dh(x[ad(j,i+12|0)>>2])+1|0}else{c=2147483631}sg(j,c);c=x[i+4>>2];if(e){Xg(c,k,e)}if(g){Xg(c+e|0,h,g)}j=e+f|0;h=d-j|0;if((d|0)!=(j|0)){Xg((c+e|0)+g|0,(e+k|0)+f|0,h)}if((b|0)!=10){Db(k)}yd(a,c);of(a,x[i+8>>2]);b=a;a=h+(e+g|0)|0;Yd(b,a);fd(a+c|0,0);fb=i+16|0;return}pf();p()}function Tr(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-32|0;fb=c;a:{if(!y[b+7|0]){while(1){if((d|0)==7){d=0;v[c+27|0]=0;v[c+28|0]=0;v[c+29|0]=0;v[c+30|0]=0;x[c+24>>2]=0;e=c+24|0;f=gc(c+8|0,e,7);lc(c+16|0,x[a>>2],x[a+8>>2],x[f>>2],x[f+4>>2]);b:{if(x[c+20>>2]!=7){break b}if(kd(e,b,7)){break b}Vb(a,7);d=1}fb=c+32|0;break a}e=b+d|0;d=d+1|0;if(y[e|0]){continue}break}_(17527,9095,602,13238);p()}_(17506,9095,600,13238);p()}return d|0}function Gfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;x[31737]=0;W(1027,a|0);e=x[31737];x[31737]=0;a:{b:{if((e|0)!=1){e=x[a+28>>2];f=x[x[e>>2]+8>>2];x[31737]=0;b=ba(f|0,e|0,b|0,c|0,d|0)|0;c=x[31737];x[31737]=0;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[31737]=0;V(989,11495,a|0,0,0);a=x[31737];x[31737]=0;if((a|0)==1){break a}Z();b=-1}return b|0}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function jc(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;a:{d=ol(a);a=d;if(a>>>0<502768&a>>>0>=502256){b=a-4|0;e=x[125562];c=e;while(1){a=c;if(!(!a|(a|0)==502768)){if((tI(a)|0)==(b|0)){w[a+2>>1]=z[d-2>>1]+z[a+2>>1];break a}if((tI(b)|0)==(a|0)){c=d-2|0;w[c>>1]=z[a+2>>1]+z[c>>1];if(!f){x[125562]=b;w[b>>1]=z[a>>1];break a}g=f,h=Qx(b),w[g>>1]=h;break a}else{c=Rx(z[a>>1]);f=a;continue}}break}g=b,h=Qx(e),w[g>>1]=h;x[125562]=b;break a}Db(d)}}function Fna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=fb-16|0;fb=b;h=x[a+16>>2];f=mg(1,2);e=hb;i=e;Pb(a,f,e);j=x[a+24>>2];k=x[a+20>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;e=x[a+8>>2];l=x[a+12>>2];while(1){if(d){g=v[x[b+12>>2]+h|0]<<8;x[c>>2]=x[c>>2]+D(g,k);x[c+4>>2]=x[c+4>>2]+D(j,g);Pb(b+8|0,e,l);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;Hg(a,f,i);fb=b+16|0}function SW(a){var b=0,c=0,d=0;b=fb-16|0;fb=b;x[b+4>>2]=((y[a+48|0]|y[a+49|0]<<8)<<1)+((y[a+32|0]|y[a+33|0]<<8)<<4);x[b+8>>2]=((y[a+50|0]|y[a+51|0]<<8)<<1)+((y[a+34|0]|y[a+35|0]<<8)<<4);x[b+12>>2]=(D(y[a+52|0]|y[a+53|0]<<8,5)+((y[a+36|0]|y[a+37|0]<<8)<<4)|0)+32;a=b+4|0;d=yb(a,3);a:{if((a|0)==(d|0)){break a}c=a;while(1){c=c+4|0;if((d|0)==(c|0)){break a}a=cr(x[a>>2],x[c>>2])?c:a;continue}}fb=b+16|0;a=x[a>>2];hb=a>>31;return a}function AF(a){var b=0,c=0,d=0,e=0,f=0,g=0;a:{if((y[a|0]|y[a+1|0]<<8)!=26215|(y[a+514|0]-16&255)>>>0<241|y[a+515|0]>128){break a}d=a+514|0;c=a+2|0;while(1){if((c|0)!=(d|0)){f=zb(c);b=c;while(1){if((b|0)!=(f|0)){g=y[b|0];b=b+1|0;if(g>>>0>31){continue}break a}break}c=c+8|0;continue}break}d=a+772|0;b=a+516|0;c=-1;while(1){e=(b|0)==(d|0);if(e){break a}a=c;c=y[b|0]|y[b+1|0]<<8;a=(a|0)<(c|0);b=b+2|0;if(a){continue}break}}return e}function zfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;x[31737]=0;W(1027,a|0);d=x[31737];x[31737]=0;e=1;a:{b:{if((d|0)!=1){d=x[a+28>>2];f=x[x[d>>2]+56>>2];x[31737]=0;S(f|0,d|0,b|0,(c|0)!=0|0);b=x[31737];x[31737]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31737]=0;V(989,6749,a|0,0,0);a=x[31737];x[31737]=0;if((a|0)==1){break a}Z();e=0}return e|0}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function waa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;e=ym(a);x[e>>2]=77020;d=nc(e);a=fb-16|0;fb=a;c=x[b+12>>2];x[a+8>>2]=x[b+8>>2];x[a+12>>2]=c;c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;b=fb-16|0;fb=b;c=x[a+12>>2];x[b+8>>2]=x[a+8>>2];x[b+12>>2]=c;c=x[a+4>>2];x[b>>2]=x[a>>2];x[b+4>>2]=c;d=uM(d,vM(b));x[d>>2]=77184;c=x[a+4>>2];x[d+8>>2]=x[a>>2];x[d+12>>2]=c;c=x[a+12>>2];x[d+16>>2]=x[a+8>>2];x[d+20>>2]=c;fb=b+16|0;fb=a+16|0;return e|0}function nra(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=x[a>>2];c=Uf(d,x[a+4>>2]);if(c>>>0<b>>>0){d=fb-32|0;fb=d;a:{b:{c=b-c|0;b=x[zb(a)>>2];e=x[a+4>>2];c:{if(c>>>0<=(b-e|0)/20>>>0){WE(a,c);break c}b=zb(a);b=QD(d+12|0,RD(a,Uf(x[a>>2],e)+c|0),Uf(x[a>>2],x[a+4>>2]),b);x[31737]=0;O(522,b|0,c|0);c=x[31737];x[31737]=0;if((c|0)==1){break b}PD(a,b);Yv(b)}fb=d+32|0;break a}a=N()|0;Yv(b);Q(a|0);p()}return}if(b>>>0<c>>>0){SE(a,d+D(b,20)|0)}}function Bfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;x[31737]=0;W(1027,a|0);d=x[31737];x[31737]=0;e=1;a:{b:{if((d|0)!=1){d=x[a+28>>2];f=x[x[d>>2]+64>>2];x[31737]=0;S(f|0,d|0,b|0,(c|0)!=0|0);b=x[31737];x[31737]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31737]=0;V(989,6695,a|0,0,0);a=x[31737];x[31737]=0;if((a|0)==1){break a}Z();e=0}return e|0}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function xg(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;w[d+12>>1]=65535;w[d+14>>1]=b;f=d+12|0;b=z[Nc(41468,d+14|0)>>1];e=x[a>>2];c=Zc(e,x[a+4>>2]);a:{if(b>>>0>c>>>0){e=fb-32|0;fb=e;b=b-c|0;c=x[zb(a)>>2];g=x[a+4>>2];b:{if(b>>>0<=c-g>>1>>>0){yp(a,b,f);break b}c=zb(a);c=kk(e+12|0,lk(a,Zc(x[a>>2],g)+b|0),Zc(x[a>>2],x[a+4>>2]),c);sF(c,b,f);Yr(a,c);jj(c)}fb=e+32|0;break a}if(b>>>0<c>>>0){In(a,e+(b<<1)|0)}}fb=d+16|0}function EV(a,b,c,d){var e=0,f=0,g=0;a:{b:{if(!((c|0)==255|(b|0)!=11)){e=c+1|0;f=11;break b}if((b&254)==16){e=c&15|b<<4|-128;f=14;break b}if((b|0)==18){break b}e=c;f=b;if(b>>>0>18){break a}}Bf(a,f,e&255);b=y[a+3|0];c:{d:{if(!((d|0)!=4|(b|0)!=13)){b=y[a+5|0];if(b&3?(b|0)!=255:0){break d}v[a+5|0]=b+3>>>2;return 1}if((b&255)!=13){break c}}b=46;v[a+3|0]=46}g=1;if((d|0)==4|(b&255)!=17|y[a+5|0]!=32){break a}v[a+3|0]=16}return g}function z3(a,b,c,d,e,f,g,h,i,j,k,l){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0;x[31737]=0;m=a;a=0;a=kI(1099,m|a,b,c,d,a|e,f);b=x[31737];x[31737]=0;a:{b:{if((b|0)==1){Y(T(0)|0)|0;x[31737]=0;ga(985,8859,g|0,h|0,i|0,j|0,k|0,l|0);a=x[31737];x[31737]=0;if((a|0)==1){break b}Z();a=-255}break a}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}return a|0}function ve(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;e=fb-16|0;fb=e;f=Kh(a);a:{b:{if(!b){i=e,j=Kh(a),x[i+8>>2]=j;x[e+12>>2]=0;break b}g=x[b>>2];b=x[b+4>>2];h=b;x[e+8>>2]=g;x[e+12>>2]=b;a=x[a+12>>2];x[e>>2]=2048;x[e+4>>2]=0;b=a+c|0;d=a>>>0>b>>>0?d+1|0:d;a=_r(e+8|0,e);c=x[a>>2];a=x[a+4>>2];if(!a&c>>>0>f>>>0|a){a=-1;if(!d&b>>>0<=f>>>0){break b}break a}a=0;if((d|0)==(h|0)&b>>>0>g>>>0|d>>>0>h>>>0){break a}}a=1}fb=e+16|0;return a}function qu(a){var b=0,c=0,d=0;b=y[a+4266|0];B[a+4236>>2]=E(b>>>0)*E(.00390625);B[a+4240>>2]=E(256-b|0)*E(.00390625);c=y[a+4267|0];b=y[a+4265|0];B[a+4244>>2]=E(D(c,b)|0)*E(152587890625e-16);d=c|-256;B[a+4256>>2]=E(D(d,b|-256)|0)*E(152587890625e-16);B[a+4252>>2]=E(D(b,d)|0)*E(152587890625e-16);B[a+4248>>2]=E(D(256-b|0,c)|0)*E(152587890625e-16);b=a;c=x[a+4232>>2];a=y[a+4264|0];x[b+4228>>2]=(D(c,(a?a:-89)&255)+250>>>0)/500}function ZU(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;g=fb-16|0;fb=g;d=_h(g+4|0,a,d);e=zb(a);a=fb-48|0;fb=a;f=x[d+4>>2];x[a+44>>2]=f;x[a+40>>2]=f;e=Re(a+12|0,e,a+40|0,a+44|0);x[a+8>>2]=x[e+8>>2];f=x[e+4>>2];x[a>>2]=x[e>>2];x[a+4>>2]=f;Qe(a+24|0,a);while(1){if((b|0)!=(c|0)){fj(x[a+44>>2],z[b>>1]);x[a+44>>2]=x[a+44>>2]+2;b=b+2|0;continue}break}b=a+24|0;Pe(b);c=x[a+44>>2];pE(b);fb=a+48|0;x[d+4>>2]=c;hc(d);fb=g+16|0}function Fsa(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;g=fb-16|0;fb=g;a:{if(z[a+480192>>1]<b>>>0){break a}b=x[((b<<2)+a|0)+900380>>2];if(!b){break a}h=g+4|0;q_(h,b);b=wb(x[g+4>>2]);x[g>>2]=b;h=rg(h);i=z[a+480190>>1];while(1){if(!Ib(b,h)){Tv(g+4|0);break a}b=z[hp(b)>>1];if(b>>>0<=i>>>0){b=D(b,104)+a|0;v[b+484421|0]=f;v[b+484418|0]=c;v[b+484420|0]=e;v[b+484419|0]=d}b=x[ah(g)>>2];continue}}fb=g+16|0}function uv(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;g=fb-16|0;fb=g;d=$l(g+4|0,a,d);e=zb(a);a=fb-48|0;fb=a;f=x[d+4>>2];x[a+44>>2]=f;x[a+40>>2]=f;e=Re(a+12|0,e,a+40|0,a+44|0);x[a+8>>2]=x[e+8>>2];f=x[e+4>>2];x[a>>2]=x[e>>2];x[a+4>>2]=f;Qe(a+24|0,a);while(1){if((b|0)!=(c|0)){Dl(x[a+44>>2],y[b|0]);x[a+44>>2]=x[a+44>>2]+1;b=b+1|0;continue}break}b=a+24|0;Pe(b);c=x[a+44>>2];d$(b);fb=a+48|0;x[d+4>>2]=c;hc(d);fb=g+16|0}function TL(a){var b=0,c=E(0),d=E(0),e=E(0),f=E(0),g=E(0),h=E(0),i=0,j=0,k=0,l=E(0),m=E(0),n=E(0),o=E(0),p=0;c=B[a>>2];i=a-16|0;d=B[i>>2];e=E(c+d);b=a-8|0;f=B[b>>2];j=a-24|0;g=B[j>>2];h=E(f+g);B[a>>2]=e+h;B[b>>2]=e-h;b=a-12|0;h=B[b>>2];k=a-28|0;l=B[k>>2];e=E(h+l);p=b;b=a-4|0;m=B[b>>2];a=a-20|0;n=B[a>>2];o=E(m+n);B[p>>2]=o-e;f=E(f-g);g=E(m-n);B[k>>2]=f+g;c=E(c-d);d=E(h-l);B[i>>2]=c+d;B[j>>2]=c-d;B[b>>2]=e+o;B[a>>2]=g-f}function x9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=fb-16|0;fb=e;while(1){a:{if((c|0)<=(g|0)){break a}d=x[a+12>>2];f=x[a+16>>2];b:{if(d>>>0<f>>>0){x[e+12>>2]=2147483647;x[e+8>>2]=f-d>>2;x[e+4>>2]=c-g;f=d;d=x[ud(e+12|0,ud(e+8|0,e+4|0))>>2];b=Yi(b,f,d);f=d<<2;x[a+12>>2]=f+x[a+12>>2];b=b+f|0;break b}d=ib[x[x[a>>2]+40>>2]](a)|0;if((d|0)==-1){break a}x[b>>2]=d;d=1;b=b+4|0}g=d+g|0;continue}break}fb=e+16|0;return g|0}function eu(a,b,c,d,e){var f=0,g=0;a:{if(!St(b)){break a}f=x[a+484344>>2];if(!He(f,x[a+484348>>2],b&65535)){break a}b=Wb(f,b);if(x[b+12>>2]<=(c|0)|e>>>0>5|z[a+480188>>1]<=d>>>0|(c|d)<0){break a}b=jd(x[b>>2],x[x[b+48>>2]+12>>2],c,d&65535);b:{c:{switch(e|0){case 1:b=b+1|0;break b;case 2:b=b+2|0;break b;case 3:b=b+3|0;break b;case 4:b=b+4|0;break b;case 0:break b;case 5:break c;default:break a}}b=b+5|0}g=y[b|0]}return g}function Naa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=E(0),j=0,k=0;c=fb-16|0;fb=c;h=x[a+4>>2];x[c+8>>2]=x[b+8>>2];d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;EM(a,c);a:{f=C[a+24>>3];if(f==1){break a}i=E(f);d=x[b+4>>2];j=x[b+8>>2];b:while(1){if((e|0)==(j|0)){break a}k=x[a+12>>2]+(D(x[a+16>>2],e+h|0)<<2)|0;b=0;while(1)if((b|0)==(d|0)){e=e+1|0;continue b}else{g=(b<<2)+k|0;B[g>>2]=B[g>>2]*i;b=b+1|0;continue}}}fb=c+16|0}function HO(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=fb-16|0;fb=h;a:{b:{c:{if(g?!f|(!d|!e):1){a=ac(8);x[31737]=0;b=P(36,h+4|0,8200)|0;c=x[31737];x[31737]=0;if((c|0)==1){break c}pc(a,b);x[31737]=0;S(98,a|0,48540,1006);a=x[31737];x[31737]=0;if((a|0)!=1){break a}d=N()|0;tb(b);break b}Il(a,b,4);c=rz(a,c,d,e,f,g);C[a+16>>3]=C[a+16>>3]+ +(c>>>0)/+(b|0);fb=h+16|0;return c|0}d=N()|0;jc(a)}Q(d|0)}p()}function AO(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=fb-16|0;fb=h;a:{b:{c:{if(g?!f|(!d|!e):1){a=ac(8);x[31737]=0;b=P(36,h+4|0,8200)|0;c=x[31737];x[31737]=0;if((c|0)==1){break c}pc(a,b);x[31737]=0;S(98,a|0,48540,1006);a=x[31737];x[31737]=0;if((a|0)!=1){break a}d=N()|0;tb(b);break b}Il(a,b,4);c=sz(a,c,d,e,f,g);C[a+16>>3]=C[a+16>>3]+ +(c>>>0)/+(b|0);fb=h+16|0;return c|0}d=N()|0;jc(a)}Q(d|0)}p()}function xfa(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;x[31737]=0;W(1027,a|0);d=x[31737];x[31737]=0;e=1;a:{b:{if((d|0)!=1){d=x[a+28>>2];f=x[x[d>>2]+48>>2];x[31737]=0;ra(f|0,d|0,b|0,+c);b=x[31737];x[31737]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31737]=0;V(989,11694,a|0,0,0);a=x[31737];x[31737]=0;if((a|0)==1){break a}Z();e=0}return e|0}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function nfa(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;x[31737]=0;W(1027,a|0);d=x[31737];x[31737]=0;e=1;a:{b:{if((d|0)!=1){d=x[a+28>>2];f=x[x[d>>2]+96>>2];x[31737]=0;ra(f|0,d|0,b|0,+c);b=x[31737];x[31737]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31737]=0;V(989,11632,a|0,0,0);a=x[31737];x[31737]=0;if((a|0)==1){break a}Z();e=0}return e|0}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function lfa(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;x[31737]=0;W(1027,a|0);d=x[31737];x[31737]=0;e=1;a:{b:{if((d|0)!=1){d=x[a+28>>2];f=x[x[d>>2]+88>>2];x[31737]=0;ra(f|0,d|0,b|0,+c);b=x[31737];x[31737]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31737]=0;V(989,11082,a|0,0,0);a=x[31737];x[31737]=0;if((a|0)==1){break a}Z();e=0}return e|0}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function e1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=fb-16|0;fb=c;x[c+12>>2]=-1;if(fh(a,c+11|0)){x[c+4>>2]=y[c+11|0];g=x[Gb(c+4|0,c+12|0)>>2];d=fb+-64|0;fb=d;f=d+44|0;ug(f,a,g);h=x[d+44>>2];a=d+20|0;wg(a,3,_e(f),h);x[31737]=0;e=d+32|0;O(219,e|0,a|0);a=x[31737];x[31737]=0;a:{if((a|0)!=1){a=d+12|0;gc(a,b,11);tm(a,e);tb(e);Kc(f);fb=d- -64|0;e=!g|(h|0)!=0;break a}a=N()|0;Kc(d+44|0);Q(a|0);p()}}fb=c+16|0;return e|0}function Waa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=E(0),j=0,k=0;c=fb-16|0;fb=c;d=x[a+4>>2];x[c+8>>2]=x[b+8>>2];e=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=e;KM(a,c);a:{g=C[a+24>>3];if(g==1){break a}i=E(g);e=x[b+4>>2];j=x[b+8>>2];d=d<<2;b:while(1){if((f|0)==(j|0)){break a}k=x[a+12>>2];b=0;while(1)if((b|0)==(e|0)){f=f+1|0;continue b}else{h=(d+x[(b<<2)+k>>2]|0)+(f<<2)|0;B[h>>2]=B[h>>2]*i;b=b+1|0;continue}}}fb=c+16|0}function H3(a){a=a|0;var b=0,c=0,d=0,e=0;c=fb-32|0;fb=c;b=tc(c+8|0,16817);x[31737]=0;S(99,c+20|0,a|0,b|0);a=x[31737];x[31737]=0;a:{if((a|0)!=1){tb(b);a=0;b=0;while(1){d=x[c+20>>2];if(!(b>>>0<=3&Ud(d,x[c+24>>2])>>>0>b>>>0)){Td(c+20|0);fb=c+32|0;return a|0}x[31737]=0;d=R(100,Hd(d,b)|0)|0;e=x[31737];x[31737]=0;if((e|0)!=1){a=(d&255)<<24-(b<<3)|a;b=b+1|0;continue}break}a=N()|0;Td(c+20|0);break a}a=N()|0;tb(b)}Q(a|0);p()}function t0(a){a=a|0;var b=0,c=0,d=0;b=x[a>>2];if(b){AQ(x[b+12>>2],b);b=x[a>>2];ib[x[x[b>>2]+8>>2]](b);x[a>>2]=0}a=a+4|0;ep(a);b=fb-32|0;fb=b;a:{b:{d=dp(a);c=Vc(x[a>>2],x[a+4>>2]);c:{if(d>>>0<=c>>>0){break c}x[31737]=0;c=ba(956,b+12|0,c|0,c|0,zb(a)|0)|0;d=x[31737];x[31737]=0;if((d|0)!=1){gr(a,c);tn(c);break c}Y(T(0)|0)|0;x[31737]=0;X(26);a=x[31737];x[31737]=0;if((a|0)==1){break b}}fb=b+32|0;break a}T(0)|0;Sb();p()}}function Y7(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;a=fb-208|0;fb=a;g=Od();x[a>>2]=e;e=a+176|0;h=ph(e,20,g,9278,a);g=h+e|0;i=sj(e,g,x[c+4>>2]);f=a+12|0;bd(f,x[c+28>>2]);x[31737]=0;j=R(1211,x[a+12>>2])|0;k=x[31737];x[31737]=0;if((k|0)!=1){Zb(f);f=e;e=a+16|0;nK(j,f,g,e);f=b;b=e+(h<<2)|0;b=ft(f,e,(g|0)==(i|0)?b:((i-a<<2)+a|0)-688|0,b,c,d);fb=a+208|0;return b|0}b=N()|0;Zb(a+12|0);Q(b|0);p()}function MH(a,b,c,d,e){var f=0,g=0,h=0,i=0;f=fb-144|0;fb=f;x[f+136>>2]=37;x[f+140>>2]=0;g=f+136|0;ht(g|1,10799,e,x[b+4>>2]);e=Od();x[f>>2]=d;d=f+123|0;e=ph(d,13,e,g,f)+d|0;h=sj(d,e,x[b+4>>2]);g=f+4|0;bd(g,x[b+28>>2]);x[31737]=0;i=d;d=f+16|0;ga(1227,i|0,h|0,e|0,d|0,f+12|0,f+8|0,g|0);e=x[31737];x[31737]=0;a:{if((e|0)!=1){Zb(g);a=ft(a,d,x[f+12>>2],x[f+8>>2],b,c);fb=f+144|0;break a}a=N()|0;Zb(f+4|0);Q(a|0);p()}return a}function J9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=fb-16|0;fb=e;while(1){a:{if((c|0)<=(f|0)){break a}g=x[a+16>>2];d=x[a+12>>2];b:{if(g>>>0>d>>>0){x[e+12>>2]=2147483647;x[e+8>>2]=g-d;x[e+4>>2]=c-f;g=d;d=x[ud(e+12|0,ud(e+8|0,e+4|0))>>2];b=Cg(b,g,d);x[a+12>>2]=x[a+12>>2]+d;b=b+d|0;break b}d=ib[x[x[a>>2]+40>>2]](a)|0;if((d|0)==-1){break a}v[b|0]=d<<24>>24;d=1;b=b+1|0}f=d+f|0;continue}break}fb=e+16|0;return f|0}function OH(a,b,c,d,e){var f=0,g=0,h=0,i=0;f=fb+-64|0;fb=f;x[f+56>>2]=37;x[f+60>>2]=0;g=f+56|0;ht(g|1,10799,e,x[b+4>>2]);e=Od();x[f>>2]=d;d=f+43|0;e=ph(d,13,e,g,f)+d|0;h=sj(d,e,x[b+4>>2]);g=f+4|0;bd(g,x[b+28>>2]);x[31737]=0;i=d;d=f+16|0;ga(1224,i|0,h|0,e|0,d|0,f+12|0,f+8|0,g|0);e=x[31737];x[31737]=0;a:{if((e|0)!=1){Zb(g);a=pw(a,d,x[f+12>>2],x[f+8>>2],b,c);fb=f- -64|0;break a}a=N()|0;Zb(f+4|0);Q(a|0);p()}return a}function Hja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;f=fb-32|0;fb=f;d=f+8|0;Ve(d,2,a+6|0);e=f+20|0;Cc(e,d);zc(b+492|0,e);d=b+236|0;g=c+1|0;tb(e);c=0;while(1){if((c|0)==128){x[b>>2]=(y[a+226|0]|y[a+227|0]<<8)<<5;uA(a+180|0,b+48|0,0);uA(a+228|0,b+88|0,2);uA(a+276|0,b+68|0,1);if(!(y[a+324|0]|y[a+325|0]<<8)){Rb(d,0,256)}fb=f+32|0}else{e=y[(a+c|0)+38|0];h=_b(d,c),i=e+g|0,w[h>>1]=i;c=c+1|0;continue}break}}function o2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=fb-16|0;fb=g;f=g+4|0;x[f+4>>2]=1;j=f,k=Ec(32),x[j+8>>2]=k;e=ym(x[f+8>>2]);x[e>>2]=41480;h=nc(e);e=fb-16|0;fb=e;b=wm(e+8|0,x[b>>2],x[b+4>>2]);d=x[d>>2];c=x[c>>2];i=x[b+4>>2];x[e>>2]=x[b>>2];x[e+4>>2]=i;b=Un(h);x[b>>2]=41616;wm(b+4|0,x[e>>2],x[e+4>>2]);x[b+16>>2]=d;x[b+12>>2]=c;ke(e);fb=e+16|0;b=a;a=Wn(f);Vn(b,nc(a),a);zm(f);fb=g+16|0}function mU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=fb-32|0;fb=d;x[a+4>>2]=0;a:{if(b){b:{if(ev(a)>>>0>=b>>>0){x[a+4>>2]=b;break b}e=Xo(d+20|0);x[31737]=0;f=P(761,a|0,b|0)|0;g=x[31737];x[31737]=0;if((g|0)==1){break a}x[31737]=0;O(762,e|0,f|0);f=x[31737];x[31737]=0;if((f|0)==1){break a}x[e+4>>2]=b;iC(a,e);tf(e)}rn(d+12|0,x[a>>2]);Qw(x[d+12>>2],x[d+16>>2],b,y[c|0])}fb=d+32|0;return}a=N()|0;tf(e);Q(a|0);p()}function SL(a,b){var c=0,d=0,e=0;if(!y[b+21|0]){fc(a,21);return-1}if(x[a+1396>>2]<=9){Cl(a)}d=x[a+1392>>2];c=w[(((d&1023)<<1)+b|0)+36>>1];a:{if((c|0)>=0){e=d;d=c&65535;c=y[d+x[b+8>>2]|0];x[a+1392>>2]=e>>>c;c=x[a+1396>>2]-c|0;x[a+1396>>2]=(c|0)>0?c:0;c=(c|0)<0?-1:d;break a}c=Nm(a,b)}if(!((c|0)>=x[b+2092>>2]?y[b+23|0]:0)){if(!(!(x[a+1384>>2]?y[a+1376|0]:1)|(c|0)>=0)){fc(a,21)}return c}_(7566,13274,1793,5750);p()}function IA(a,b,c){if(Ob(a+1074312|0,21)){c=c&255;a:{switch((b&3)-1|0){default:return v[c+31920|0];case 0:return 64-(c+1>>>1|0)|0;case 1:return(c>>>0<128)<<6;case 2:break a}}return UR(Io(a))+-64|0}if(z[a+480182>>1]&1032){return v[(c>>>1&31)+30576|0]}a=c&63;b:{switch((b&3)-1|0){default:return v[a+31792|0];case 0:return(a>>>0>=32?255:0)-(a<<2)|0;case 1:return a>>>0<32?127:-127;case 2:break b}}return v[a+31856|0]}function Cha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a=Qi(a,b,c,d);x[a>>2]=43668;c=Nb(a+4256|0);b=a+4208|0;e=yb(b,0),f=1056964608,x[e>>2]=f;e=yb(b,1),f=1017370378,x[e>>2]=f;e=yb(b,2),f=1028670828,x[e>>2]=f;e=yb(b,3),f=1059760811,x[e>>2]=f;e=yb(b,4),f=1017370378,x[e>>2]=f;e=yb(b,5),f=1065353216,x[e>>2]=f;x[31737]=0;O(947,a+44|0,2);b=x[31737];x[31737]=0;if((b|0)!=1){return a|0}b=N()|0;vc(c);ag(a);Q(b|0);p()}function dz(a){var b=0,c=0,d=0;a:{b:{if(!x[a+1384>>2]){b=x[a+1380>>2];if((b|0)==-1){x[a+1388>>2]=x[a+1116>>2]-1;if(!Ot(a)){x[a+1384>>2]=1;return 0}if(!(v[a+1375|0]&1)){break b}b=x[a+1380>>2]}d=b+1|0;x[a+1380>>2]=d;c=y[(a+b|0)+1120|0];if((c|0)!=255){x[a+1388>>2]=b;x[a+1384>>2]=1}if(x[a+1116>>2]<=(d|0)){x[a+1380>>2]=-1}if(y[a+1376|0]){break a}v[a+1376|0]=c}return c}fc(a,32);return 0}_(15830,13274,1564,6036);p()}function uD(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=c;c=0;a:{if(!b){break a}if(!Mb(x[a>>2],x[a+8>>2],b)){break a}if(b>>>0<=3){c=fb-16|0;fb=c;if(Mb(x[a>>2],x[a+8>>2],b)){while(1){if((d|0)==4){Qm(c+4|0,x[c+12>>2]);d=x[c+4>>2]}else{v[c+11|0]=0;b:{if(b>>>0>d>>>0){fh(a,c+11|0);e=v[c+11|0];g=e>>>31|0;break b}e=0-g|0}v[(c+12|0)+d|0]=e;d=d+1|0;continue}break}}fb=c+16|0;c=d;break a}c=Pg(a);Vb(a,b-4|0)}v[f|0]=c}function spa(a){a=a|0;var b=0,c=0,d=0;b=fb-16|0;fb=b;v[b+15|0]=128;a=fw(a,127,b+15|0);x[31737]=0;v[b+14|0]=64;d=U(601,a+12|0,127,b+14|0)|0;c=x[31737];x[31737]=0;a:{b:{if((c|0)!=1){x[31737]=0;v[b+13|0]=0;P(681,a+24|0,b+13|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break b}x[a+44>>2]=0;x[a+48>>2]=0;x[a+36>>2]=-1;x[a+40>>2]=108855296;w[a+52>>1]=0;fb=b+16|0;return a|0}b=N()|0;break a}b=N()|0;dc(d)}dc(a);Q(b|0);p()}function bB(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=fb-16|0;fb=d;f=Nu(a,a+1074376|0,b,c);a:{if(!f){break a}Kb(d+8|0,a+1074312|0,117);if(Hb(x[x[d+8>>2]>>2],x[d+12>>2])){break a}c=D(b,872)+a|0;e=x[c+1075648>>2];if(!e){break a}g=y[e+33|0];if(!g){break a}h=a;a=c+1074992|0;c=Iq(h,x[a+88>>2],e);if(!c){break a}a=y[a+799|0];if(!(!e|(!a|a>>>0>128))){a=y[xb(e+108|0,a-1|0)|0]}ib[x[x[c>>2]+88>>2]](c,f,a,g<<24>>24,b)}fb=d+16|0}function mta(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;h=fb-16|0;fb=h;x[h+12>>2]=d;g=Cb(x[a+4>>2],y[a+11|0]);f=Mc(a);a:{if(f-g>>>0>=b>>>0){f=Jb(a);if((c|0)==(g|0)){break a}i=c+f|0;Ui(i+b|0,i,g-c|0);break a}Wm(a,f,(b+g|0)-f|0,g,c,0,b);f=x[a>>2]}b=b+g|0;ng(a,b);fd(b+f|0,0);b=c+f|0;while(1){if(Ib(d,e)){fd(b,y[d|0]);b=b+1|0;d=x[le(h+12|0)>>2];continue}break}a=uf(zd(a),c);fb=h+16|0;return a|0}function NF(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;f=e+8|0;d=fb-32|0;fb=d;Id(d+24|0,a,b);g=d+16|0;b=x[d+24>>2];h=x[d+28>>2];a=fb-16|0;fb=a;x[a+8>>2]=c;x[a+12>>2]=b;while(1){if(pd(b,h)){b=xf(b);c=xf(x[a+8>>2]);v[c+2|0]=y[b+2|0];w[c>>1]=z[b>>1];b=Mi(a+12|0);Mi(a+8|0);b=x[b>>2];continue}break}Ac(g,b,a+8|0);fb=a+16|0;a=x[d+16>>2];x[d+12>>2]=x[d+20>>2];Ac(f,a,d+12|0);fb=d+32|0;fb=e+16|0;return x[e+12>>2]}function pfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;x[31737]=0;W(1027,a|0);c=x[31737];x[31737]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+16>>2];x[31737]=0;O(e|0,c|0,b|0);b=x[31737];x[31737]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31737]=0;V(989,12863,a|0,0,0);a=x[31737];x[31737]=0;if((a|0)==1){break a}Z();d=0}return d|0}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function kfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;x[31737]=0;W(1027,a|0);c=x[31737];x[31737]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+84>>2];x[31737]=0;O(e|0,c|0,b|0);b=x[31737];x[31737]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31737]=0;V(989,12346,a|0,0,0);a=x[31737];x[31737]=0;if((a|0)==1){break a}Z();d=0}return d|0}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function jfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;x[31737]=0;W(1027,a|0);c=x[31737];x[31737]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+80>>2];x[31737]=0;O(e|0,c|0,b|0);b=x[31737];x[31737]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31737]=0;V(989,11168,a|0,0,0);a=x[31737];x[31737]=0;if((a|0)==1){break a}Z();d=0}return d|0}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function ifa(a,b){a=a|0;b=+b;var c=0,d=0,e=0;x[31737]=0;W(1027,a|0);c=x[31737];x[31737]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+104>>2];x[31737]=0;la(e|0,c|0,+b);c=x[31737];x[31737]=0;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[31737]=0;V(989,15233,a|0,0,0);a=x[31737];x[31737]=0;if((a|0)==1){break a}Z();d=0}return d|0}a=N()|0;x[31737]=0;X(26);d=x[31737];x[31737]=0;if((d|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function g8(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;a=fb-96|0;fb=a;g=Od();x[a>>2]=e;e=a- -64|0;h=ph(e,20,g,9278,a);g=h+e|0;i=sj(e,g,x[c+4>>2]);f=a+12|0;bd(f,x[c+28>>2]);x[31737]=0;j=R(28,x[a+12>>2])|0;k=x[31737];x[31737]=0;if((k|0)!=1){Zb(f);f=e;e=a+16|0;rK(j,f,g,e);f=b;b=e+h|0;b=pw(f,e,(g|0)==(i|0)?b:((i-a|0)+a|0)-48|0,b,c,d);fb=a+96|0;return b|0}b=N()|0;Zb(a+12|0);Q(b|0);p()}function Ffa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;x[31737]=0;W(1027,a|0);c=x[31737];x[31737]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+76>>2];x[31737]=0;O(e|0,c|0,b|0);b=x[31737];x[31737]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31737]=0;V(989,11324,a|0,0,0);a=x[31737];x[31737]=0;if((a|0)==1){break a}Z();d=0}return d|0}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function vfa(a,b){a=a|0;b=+b;var c=0,d=0,e=0;x[31737]=0;W(1027,a|0);c=x[31737];x[31737]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+40>>2];x[31737]=0;la(e|0,c|0,+b);c=x[31737];x[31737]=0;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[31737]=0;V(989,11732,a|0,0,0);a=x[31737];x[31737]=0;if((a|0)==1){break a}Z();d=0}return d|0}a=N()|0;x[31737]=0;X(26);d=x[31737];x[31737]=0;if((d|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function qfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;x[31737]=0;W(1027,a|0);c=x[31737];x[31737]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+20>>2];x[31737]=0;O(e|0,c|0,b|0);b=x[31737];x[31737]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31737]=0;V(989,9328,a|0,0,0);a=x[31737];x[31737]=0;if((a|0)==1){break a}Z();d=0}return d|0}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function ofa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;x[31737]=0;W(1027,a|0);c=x[31737];x[31737]=0;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+100>>2];x[31737]=0;d=+qa(e|0,c|0,b|0);b=x[31737];x[31737]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31737]=0;V(989,11650,a|0,0,0);a=x[31737];x[31737]=0;if((a|0)==1){break a}Z();d=0}return+d}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function c_(a){var b=0,c=0,d=0,e=0;a:{if((y[a+60|0]|y[a+61|0]<<8|(y[a+62|0]<<16|y[a+63|0]<<24))!=808537417|(y[a+32|0]|y[a+33|0]<<8)>>>0>256|(y[a+49|0]<32|(y[a+36|0]|y[a+37|0]<<8)>>>0>255)){break a}if(v[a+51|0]<4|y[a+50|0]>64){break a}d=a+576|0;a=a- -64|0;while(1){if((a|0)==(d|0)){e=b;break a}c=1;b:{switch(y[a+15|0]){case 2:c=b;break;case 0:case 1:break b;default:break a}}a=a+16|0;b=c;continue}}return e&1}function yfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;x[31737]=0;W(1027,a|0);c=x[31737];x[31737]=0;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+52>>2];x[31737]=0;d=+qa(e|0,c|0,b|0);b=x[31737];x[31737]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31737]=0;V(989,11713,a|0,0,0);a=x[31737];x[31737]=0;if((a|0)==1){break a}Z();d=0}return+d}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function tfa(a,b){a=a|0;b=+b;var c=0,d=0,e=0;x[31737]=0;W(1027,a|0);c=x[31737];x[31737]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+32>>2];x[31737]=0;la(e|0,c|0,+b);c=x[31737];x[31737]=0;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[31737]=0;V(989,7777,a|0,0,0);a=x[31737];x[31737]=0;if((a|0)==1){break a}Z();d=0}return d|0}a=N()|0;x[31737]=0;X(26);d=x[31737];x[31737]=0;if((d|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function rfa(a,b){a=a|0;b=+b;var c=0,d=0,e=0;x[31737]=0;W(1027,a|0);c=x[31737];x[31737]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+24>>2];x[31737]=0;la(e|0,c|0,+b);c=x[31737];x[31737]=0;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[31737]=0;V(989,7725,a|0,0,0);a=x[31737];x[31737]=0;if((a|0)==1){break a}Z();d=0}return d|0}a=N()|0;x[31737]=0;X(26);d=x[31737];x[31737]=0;if((d|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function mfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;x[31737]=0;W(1027,a|0);c=x[31737];x[31737]=0;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+92>>2];x[31737]=0;d=+qa(e|0,c|0,b|0);b=x[31737];x[31737]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31737]=0;V(989,11102,a|0,0,0);a=x[31737];x[31737]=0;if((a|0)==1){break a}Z();d=0}return+d}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function Kx(a,b,c){var d=0,e=0,f=0,g=0;e=Jb(a);a=Cb(x[a+4>>2],y[a+11|0]);d=Jb(b);b=Cb(x[b+4>>2],y[b+11|0]);a:{if(a>>>0>=c>>>0){if(!b){break a}c=c+e|0;a=a+e|0;b=b+d|0;b:{if((b|0)==(d|0)){break b}c:{b=b-d|0;if((b|0)>(a-c|0)){break c}g=y[d|0];while(1){f=a-c|0;if((f|0)<(b|0)){break c}c=Fu(c,(f-b|0)+1|0,g);if(!c){break c}if(!_G(c,d,b)){break b}c=c+1|0;continue}}c=a}c=(a|0)==(c|0)?-1:c-e|0}else{c=-1}}return c}function AU(a,b){var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);Rd(c+8|0,x[vb(c+4|0,a)>>2]);a:{if(b){x[31737]=0;O(804,a|0,b|0);d=x[31737];x[31737]=0;if((d|0)==1){break a}e=fb-16|0;fb=e;d=gv(e+4|0,a,b);b=x[d+4>>2];f=x[d+8>>2];while(1){if((b|0)==(f|0)){hc(d);fb=e+16|0}else{Wl(b,0,0);b=b+16|0;x[d+4>>2]=b;continue}break}}b=c+8|0;Qd(b);pU(b);fb=c+16|0;return a}a=N()|0;pU(c+8|0);Q(a|0);p()}function mB(a,b,c){var d=0;d=x[a+480180>>2];a:{if((d|0)!=1048576){if((d|0)!=4){break a}d=y[b+813|0];if(c){v[b+813|0]=d&240|c&15;break a}c=d&15;break a}if(c){v[b+813|0]=c;break a}c=y[b+813|0]}b:{if(!(v[b+851|0]&1)|!x[b+700>>2]){break b}c=c&255;if(!c){break b}Ck(a,b,b+700|0,0-(c<<2)|0,0);if(x[b+700>>2]<65536){break b}if(Ob(a+1074312|0,7)|(x[a+480180>>2]!=4?y[a+480208|0]&16:0)){break b}x[b+700>>2]=65535}}function gk(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;a:{if(!y[b+4|0]){while(1){if((d|0)==4){d=0;x[c+28>>2]=0;e=gc(c+8|0,c+28|0,4);lc(c+20|0,x[a>>2],x[a+8>>2],x[e>>2],x[e+4>>2]);if(!(x[c+24>>2]!=4|x[c+28>>2]!=(y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24)))){Vb(a,4);d=1}fb=c+32|0;break a}e=b+d|0;d=d+1|0;if(y[e|0]){continue}break}_(17527,9095,602,13238);p()}_(17506,9095,600,13238);p()}return d|0}function Gda(a,b,c){a=a|0;b=+b;c=c|0;var d=0,e=0;d=fb-48|0;fb=d;x[d+44>>2]=c;c=Nd(d+16|0);x[31737]=0;e=x[c+4>>2];x[d>>2]=x[c>>2];x[d+4>>2]=e;c=d+24|0;S(1121,c|0,a|0,d|0);a=x[31737];x[31737]=0;a:{b:{if((a|0)!=1){a=d+44|0;e=x[qe(d+12|0,a)>>2];x[31737]=0;b=+pa(987,c|0,+b,e|0);e=x[31737];x[31737]=0;if((e|0)==1){break b}ub(c);Uc(a);fb=d+48|0;return+b}c=N()|0;break a}c=N()|0;ub(d+24|0)}Uc(d+44|0);Q(c|0);p()}function Dfa(a,b){a=a|0;b=b|0;var c=0,d=0;x[31737]=0;W(1027,a|0);c=x[31737];x[31737]=0;a:{b:{if((c|0)!=1){c=x[a+28>>2];d=x[x[c>>2]+68>>2];x[31737]=0;b=P(d|0,c|0,b|0)|0;c=x[31737];x[31737]=0;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[31737]=0;V(989,6722,a|0,0,0);a=x[31737];x[31737]=0;if((a|0)==1){break a}Z();b=-1}return b|0}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function Afa(a,b){a=a|0;b=b|0;var c=0,d=0;x[31737]=0;W(1027,a|0);c=x[31737];x[31737]=0;a:{b:{if((c|0)!=1){c=x[a+28>>2];d=x[x[c>>2]+60>>2];x[31737]=0;b=P(d|0,c|0,b|0)|0;c=x[31737];x[31737]=0;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[31737]=0;V(989,6773,a|0,0,0);a=x[31737];x[31737]=0;if((a|0)==1){break a}Z();b=-1}return b|0}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function SM(a,b){var c=0,d=0;x[a+4>>2]=b;x[a>>2]=126992;x[a+24>>2]=0;x[a+28>>2]=65536;x[a+8>>2]=b;x[a+32>>2]=0;x[a+36>>2]=65536;c=(b|0)!=0;x[a+12>>2]=c;x[a+16>>2]=c;d=63-b|0;c=d&31;if((d&63)>>>0>=32){d=0;c=-1>>>c|0}else{d=-1>>>c|0;c=d|(1<<c)-1<<32-c}x[a+48>>2]=c;x[a+52>>2]=d;d=64-b|0;c=d&31;if((d&63)>>>0>=32){d=0;c=-1>>>c|0}else{d=-1>>>c|0;c=d|(1<<c)-1<<32-c}x[a+40>>2]=b?c:0;x[a+44>>2]=b?d:0;return a}function OF(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=fb-16|0;fb=e;f=e+8|0;d=fb-32|0;fb=d;Id(d+24|0,a,b);g=d+16|0;b=x[d+24>>2];h=x[d+28>>2];a=fb-16|0;fb=a;x[a+8>>2]=c;x[a+12>>2]=b;while(1){if(pd(b,h)){b=Mn(b);i=Mn(x[a+8>>2]),j=z[b>>1],w[i>>1]=j;b=ij(a+12|0);ij(a+8|0);b=x[b>>2];continue}break}Ac(g,b,a+8|0);fb=a+16|0;a=x[d+16>>2];x[d+12>>2]=x[d+20>>2];Ac(f,a,d+12|0);fb=d+32|0;fb=e+16|0;return x[e+12>>2]}function H9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=fb-16|0;fb=e;while(1){a:{if((c|0)<=(f|0)){break a}g=x[a+28>>2];d=x[a+24>>2];if(g>>>0<=d>>>0){if(((i=a,j=Pf(v[b|0]),h=x[x[a>>2]+52>>2],ib[h](i|0,j|0)|0)|0)==-1){break a}f=f+1|0;b=b+1|0}else{x[e+12>>2]=g-d;x[e+8>>2]=c-f;g=d;d=x[ud(e+12|0,e+8|0)>>2];Cg(g,b,d);x[a+24>>2]=d+x[a+24>>2];f=f+d|0;b=b+d|0}continue}break}fb=e+16|0;return f|0}function fk(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=fb-16|0;fb=f;x[f+12>>2]=c;a:{if(!Mb(x[b>>2],x[b+8>>2],c)){break a}wc(f+12|0,65535);xg(a,z[f+12>>1]);c=wb(x[a>>2]);x[f+4>>2]=c;h=wb(x[a+4>>2]);while(1){if(!Ib(c,h)){break a}a=f+11|0;if(!fh(b,a)){eh(a)}a=y[f+11|0];w[c>>1]=a;g=65535;b:{if((a|0)!=(d|0)){g=65534;if((a|0)!=(e|0)){break b}}w[c>>1]=g}c=x[Md(f+4|0)>>2];continue}}fb=f+16|0}function tO(a,b){var c=0;a:{b:{if((a^b)&3){c=y[b|0];break b}if(b&3){while(1){c=y[b|0];v[a|0]=c;if(!c){break a}a=a+1|0;b=b+1|0;if(b&3){continue}break}}c=x[b>>2];if((c^-1)&c-16843009&-2139062144){break b}while(1){x[a>>2]=c;c=x[b+4>>2];a=a+4|0;b=b+4|0;if(!(c-16843009&(c^-1)&-2139062144)){continue}break}}v[a|0]=c;if(!(c&255)){break a}while(1){c=y[b+1|0];v[a+1|0]=c;a=a+1|0;b=b+1|0;if(c){continue}break}}}function hX(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=fb-16|0;fb=e;f=e+8|0;d=fb-32|0;fb=d;Id(d+24|0,a,b);g=d+16|0;b=x[d+24>>2];h=x[d+28>>2];a=fb-16|0;fb=a;x[a+8>>2]=c;x[a+12>>2]=b;while(1){if(pd(b,h)){b=PW(b);i=PW(x[a+8>>2]),j=y[b|0],v[i|0]=j;b=vC(a+12|0);vC(a+8|0);b=x[b>>2];continue}break}Ac(g,b,a+8|0);fb=a+16|0;a=x[d+16>>2];x[d+12>>2]=x[d+20>>2];Ac(f,a,d+12|0);fb=d+32|0;fb=e+16|0;return x[e+12>>2]}function Pna(a,b){a=a|0;b=b|0;var c=0,d=0;if(A[a+4>>2]<A[zb(a)>>2]){c=fb-16|0;fb=c;a=gC(c+4|0,a);Qm(x[a+4>>2],y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24));x[a+4>>2]=x[a+4>>2]+4;hc(a);fb=c+16|0;return}d=fb-32|0;fb=d;c=zb(a);c=$f(d+12|0,Mf(a,oc(x[a>>2],x[a+4>>2])+1|0),oc(x[a>>2],x[a+4>>2]),c);Qm(x[c+8>>2],y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24));x[c+8>>2]=x[c+8>>2]+4;kZ(a,c);_f(c);fb=d+32|0}function av(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;x[b+40>>2]=0;x[b+44>>2]=0;f=b- -64|0;x[f>>2]=0;x[f+4>>2]=0;x[b+56>>2]=0;x[b+60>>2]=0;x[b+48>>2]=0;x[b+52>>2]=0;while(1){if((d|0)==1e4){a:{d=wb(x[c>>2]);x[e+12>>2]=d;f=wb(x[c+4>>2]);while(1){if(!Ib(d,f)){break a}g=d,h=rU(b,C[d>>3]),C[g>>3]=h;d=x[Yu(e+12|0)>>2];continue}}}else{rU(b,C[Ue(x[c>>2],0)>>3]);d=d+1|0;continue}break}_l(a,c);fb=e+16|0}function vS(a,b){var c=0,d=0,e=0,f=0;c=x[a>>2];x[a>>2]=b;if(c){b=fb-16|0;fb=b;d=wb(x[c>>2]);x[b+12>>2]=d;f=wb(x[c+4>>2]);while(1){a:{b:{if(Ib(d,f)){while(1){a=x[d>>2];e=x[a>>2];if(!e){break b}AQ(a,e);a=x[x[e>>2]+8>>2];x[31737]=0;W(a|0,e|0);a=x[31737];x[31737]=0;if((a|0)!=1){continue}break}T(0)|0;Sb();p()}a=vc(c);fb=b+16|0;break a}Eb(a+20|0);Eb(a+8|0);Db(a);d=x[Je(b+12|0)>>2];continue}break}Db(a)}}function lB(a,b,c){var d=0;d=x[a+480180>>2];a:{if((d|0)!=1048576){if((d|0)!=4){break a}d=y[b+814|0];if(c){v[b+814|0]=d&240|c&15;break a}c=d&15;break a}if(c){v[b+813|0]=c;break a}c=y[b+813|0]}b:{if(!(v[b+851|0]&1)|!x[b+700>>2]){break b}c=c&255;if(!c){break b}Ck(a,b,b+700|0,0-c|0,0);if(x[b+700>>2]<65536){break b}if(Ob(a+1074312|0,7)|(x[a+480180>>2]!=4?y[a+480208|0]&16:0)){break b}x[b+700>>2]=65535}}function _H(a,b,c,d,e,f,g,h,i){var j=0;x[31737]=0;W(1002,a|0);j=x[31737];x[31737]=0;a:{b:{if((j|0)!=1){j=x[a+24>>2];x[31737]=0;b=sa(i|0,j|0,b|0,c|0,d|0,e|0,f|0,g|0)|0;c=x[31737];x[31737]=0;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[31737]=0;V(989,h|0,a|0,0,0);a=x[31737];x[31737]=0;if((a|0)==1){break a}Z();b=0}return b}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function RA(a,b){a=a|0;b=b|0;var c=E(0),d=0,e=0,f=0;v[a+1074368|0]=b;oS(a+1074332|0,b);a=a+906300|0;f=Ak(a);while(1){if((a|0)!=(f|0)){b=x[a>>2];if(b){c=E(1);d=x[b+20>>2];if(d){c=E(E(y[d+26|0])*E(.10000000149011612))}c=c<E(.10000000149011612)?E(1):c;if(ib[x[x[b>>2]+140>>2]](b)|0){d=x[b+16>>2];e=d+1074332|0;c=E(E(c/B[e+8>>2])*E(E(A[d+480232>>2])/B[e+20>>2]))}B[b+4196>>2]=c}a=a+160|0;continue}break}}function Ora(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=fb-16|0;fb=e;c=Hf(a,c);$d(e,x[a+36>>2]);a:{b:{if(!c){Pc(e,a+32|0,5);d=-1;if(!Hb(x[x[e>>2]>>2],x[e+4>>2])){break b}break a}d=x[c+16>>2]}f=x[a+36>>2];c:{d:{switch(d+1|0){case 0:case 2:d=fb-32|0;fb=d;v[d+31|0]=0;Cj(d+8|0,d+31|0);Sm(d+20|0,f,x[d+8>>2],x[d+12>>2]);v[b|0]=y[d+31|0];fb=d+32|0;break c;default:break d}}CZ(f,b,d)}f=c}ff(a,f);fb=e+16|0}function OE(a,b){var c=0,d=0,e=0,f=0;c=fb-32|0;fb=c;a:{if(!y[b+7|0]){while(1){if((d|0)==7){d=0;v[c+27|0]=0;v[c+28|0]=0;v[c+29|0]=0;v[c+30|0]=0;x[c+24>>2]=0;e=c+24|0;f=gc(c+8|0,e,7);od(c+16|0,a,x[f>>2],x[f+4>>2]);b:{if(x[c+20>>2]!=7){break b}if(kd(e,b,7)){break b}gd(a,7);d=1}fb=c+32|0;break a}e=b+d|0;d=d+1|0;if(y[e|0]){continue}break}_(17527,9095,602,13238);p()}_(17506,9095,600,13238);p()}return d}function Eba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;Vo(c+4|0,b);b=0;a=Fb(a);d=y[c+15|0];e=x[c+8>>2];x[31737]=0;O(111,a|0,xh(e,d)|0);d=x[31737];x[31737]=0;if((d|0)!=1){a:{while(1){if(xh(x[c+8>>2],y[c+15|0])>>>0>b>>>0){d=v[cc(c+4|0,b)|0];x[31737]=0;O(112,a|0,d|0);d=x[31737];x[31737]=0;if((d|0)==1){break a}b=b+1|0;continue}break}tb(c+4|0);fb=c+16|0;return}}b=N()|0;tb(a);tb(c+4|0);Q(b|0);p()}function zO(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=fb-16|0;fb=f;a:{b:{c:{if(!(e?d:0)){a=ac(8);x[31737]=0;b=P(36,f+4|0,8200)|0;c=x[31737];x[31737]=0;if((c|0)==1){break c}pc(a,b);x[31737]=0;S(98,a|0,48540,1006);a=x[31737];x[31737]=0;if((a|0)!=1){break a}e=N()|0;tb(b);break b}Il(a,b,2);c=sz(a,c,d,e,0,0);C[a+16>>3]=C[a+16>>3]+ +(c>>>0)/+(b|0);fb=f+16|0;return c|0}e=N()|0;jc(a)}Q(e|0)}p()}function to(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;Zk(c+4|0,b);b=0;a=Fb(a);d=y[c+15|0];e=x[c+8>>2];x[31737]=0;O(111,a|0,xh(e,d)|0);d=x[31737];x[31737]=0;if((d|0)!=1){a:{b:{while(1){if(xh(x[c+8>>2],y[c+15|0])>>>0<=b>>>0){break b}d=v[cc(c+4|0,b)|0];x[31737]=0;O(112,a|0,d|0);d=x[31737];x[31737]=0;if((d|0)!=1){b=b+1|0;continue}break}break a}tb(c+4|0);fb=c+16|0;return}}b=N()|0;tb(a);tb(c+4|0);Q(b|0);p()}function bea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;x[31737]=0;W(1002,a|0);d=x[31737];x[31737]=0;e=1;a:{b:{if((d|0)!=1){d=x[a+24>>2];x[31737]=0;S(1098,d|0,b|0,c|0);b=x[31737];x[31737]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31737]=0;V(989,10337,a|0,0,0);a=x[31737];x[31737]=0;if((a|0)==1){break a}Z();e=0}return e|0}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function GO(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=fb-16|0;fb=f;a:{b:{c:{if(!(e?d:0)){a=ac(8);x[31737]=0;b=P(36,f+4|0,8200)|0;c=x[31737];x[31737]=0;if((c|0)==1){break c}pc(a,b);x[31737]=0;S(98,a|0,48540,1006);a=x[31737];x[31737]=0;if((a|0)!=1){break a}e=N()|0;tb(b);break b}Il(a,b,2);c=rz(a,c,d,e,0,0);C[a+16>>3]=C[a+16>>3]+ +(c>>>0)/+(b|0);fb=f+16|0;return c|0}e=N()|0;jc(a)}Q(e|0)}p()}function Ax(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;Zk(c+4|0,b);b=0;a=Fb(a);d=y[c+15|0];e=x[c+8>>2];x[31737]=0;O(111,a|0,xh(e,d)|0);d=x[31737];x[31737]=0;if((d|0)!=1){a:{while(1){if(xh(x[c+8>>2],y[c+15|0])>>>0>b>>>0){d=v[cc(c+4|0,b)|0];x[31737]=0;O(112,a|0,d|0);d=x[31737];x[31737]=0;if((d|0)==1){break a}b=b+1|0;continue}break}tb(c+4|0);fb=c+16|0;return}}b=N()|0;tb(a);tb(c+4|0);Q(b|0);p()}function hI(a,b,c){a=Fb(a);x[31737]=0;O(c|0,a|0,4);c=x[31737];x[31737]=0;a:{b:{if((c|0)==1){break b}x[31737]=0;O(b|0,a|0,32);c=x[31737];x[31737]=0;if((c|0)==1){break b}x[31737]=0;O(b|0,a|0,10);c=x[31737];x[31737]=0;if((c|0)==1){break b}x[31737]=0;O(b|0,a|0,13);c=x[31737];x[31737]=0;if((c|0)==1){break b}x[31737]=0;O(b|0,a|0,9);b=x[31737];x[31737]=0;if((b|0)!=1){break a}}b=N()|0;tb(a);Q(b|0);p()}}function Jna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;b=fb-16|0;fb=b;d=-1;a:{if(!kh(a,1)){break a}e=Qr(a);if((e-5&255)>>>0>=253){while(1){if((f|0)==127){d=1;break a}c=fb-16|0;fb=c;bE(c+8|0,b);g=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);h=x[c+4>>2];if((h|0)==(g|0)){gd(a,x[c+12>>2])}fb=c+16|0;c=(g|0)==(h|0);if(!c){Jr(b)}if(!c){break a}f=f+1|0;if(FV(b,e)){continue}break}}d=0}fb=b+16|0;return d|0}function IE(a,b,c){var d=0,e=0,f=0;d=x[c+16>>2];a:{if(!d){if(lF(c)){break a}d=x[c+16>>2]}e=x[c+20>>2];if(d-e>>>0<b>>>0){return ib[x[c+36>>2]](c,a,b)|0}b:{c:{if(!b|x[c+80>>2]<0){break c}d=b;while(1){f=a+d|0;if(y[f-1|0]!=10){d=d-1|0;if(d){continue}break c}break}e=ib[x[c+36>>2]](c,a,d)|0;if(e>>>0<d>>>0){break a}b=b-d|0;e=x[c+20>>2];break b}f=a;d=0}yc(e,f,b);x[c+20>>2]=x[c+20>>2]+b;e=b+d|0}return e}function Hpa(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;b=-1;a:{if(!kh(a,8)){break a}b=fb-32|0;fb=b;x[b+24>>2]=0;x[b+28>>2]=0;d=gc(b+8|0,b+24|0,8);od(b+16|0,a,x[d>>2],x[d+4>>2]);d=x[b+24>>2]==1096043343&x[b+28>>2]==1196314451&x[b+20>>2]==8;if(d){gd(a,8)}fb=b+32|0;b=0;if(!d){break a}b=-1;if(!nk(a,c+8|0)){break a}b=0;if(!$b(x[c+12>>2])){break a}b=!($b(x[c+8>>2])&-2139062144)}fb=c+16|0;return b|0}function jN(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;Wf(c+4|0,b);b=0;a=Fb(a);d=y[c+15|0];e=x[c+8>>2];x[31737]=0;O(94,a|0,xh(e,d)|0);d=x[31737];x[31737]=0;if((d|0)!=1){a:{b:{while(1){if(xh(x[c+8>>2],y[c+15|0])>>>0<=b>>>0){break b}d=y[cc(c+4|0,b)|0];x[31737]=0;O(96,a|0,d|0);d=x[31737];x[31737]=0;if((d|0)!=1){b=b+1|0;continue}break}break a}tb(c+4|0);fb=c+16|0;return}}b=N()|0;tb(a);tb(c+4|0);Q(b|0);p()}function dea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;x[31737]=0;W(1002,a|0);d=x[31737];x[31737]=0;a:{b:{if((d|0)!=1){d=x[a+24>>2];x[31737]=0;e=+oa(1094,d|0,b|0,c|0);b=x[31737];x[31737]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31737]=0;V(989,5350,a|0,0,0);a=x[31737];x[31737]=0;if((a|0)==1){break a}Z();e=0}return+e}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function y3(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;x[31737]=0;a=Ha(1101,a|0,b|0,c|0,d|0)|0;b=x[31737];x[31737]=0;a:{b:{if((b|0)==1){Y(T(0)|0)|0;x[31737]=0;ga(985,11208,e|0,f|0,g|0,h|0,i|0,j|0);a=x[31737];x[31737]=0;if((a|0)==1){break b}Z();a=-255}break a}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}return a|0}function wfa(a){a=a|0;var b=0,c=0,d=0;x[31737]=0;W(1027,a|0);b=x[31737];x[31737]=0;a:{b:{if((b|0)!=1){b=x[a+28>>2];d=x[x[b>>2]+44>>2];x[31737]=0;c=+ia(d|0,b|0);b=x[31737];x[31737]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31737]=0;V(989,11750,a|0,0,0);a=x[31737];x[31737]=0;if((a|0)==1){break a}Z();c=0}return+c}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function rD(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{e=Nb(a+8|0);x[31737]=0;c=R(203,b|0)|0;d=x[31737];x[31737]=0;b:{if((d|0)==1){break b}c:{if(!BZ(c)){x[31737]=0;X(508);a=x[31737];x[31737]=0;if((a|0)!=1){break c}break b}x[31737]=0;c=R(203,b|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break b}x[31737]=0;S(170,a|0,b|0,c|0);a=x[31737];x[31737]=0;if((a|0)==1){break b}break a}p()}a=N()|0;dc(e);Q(a|0);p()}}function Xna(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=fb-16|0;fb=b;w[b+12>>1]=0;w[b+14>>1]=1;Gf(b+14|0,z[x[x[a+24>>2]+8>>2]+12>>1]);e=b+12|0;d=fb-16|0;fb=d;c=z[b+14>>1];x[d+12>>2]=c;a:{if(Nn(a)>>>0>=c>>>0){g=x[a>>2];f=Zc(g,x[a+4>>2]);x[d+8>>2]=f;Fv(g,x[Gb(d+12|0,d+8|0)>>2],e);if(c>>>0>f>>>0){yp(a,c-f|0,e);break a}In(a,x[a>>2]+(c<<1)|0);break a}hV(a);GC(a,lk(a,c));yp(a,c,e)}fb=d+16|0;fb=b+16|0}
function yN(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{b:{c:{d:{if((b|0)>=0){a=x[a+32>>2];if((Ao(a)|0)>(b|0)){break d}}b=ac(8);x[31737]=0;c=P(36,c+4|0,10751)|0;a=x[31737];x[31737]=0;if((a|0)==1){break c}pc(b,c);x[31737]=0;S(98,b|0,48540,1006);a=x[31737];x[31737]=0;if((a|0)!=1){break a}a=N()|0;tb(c);break b}fb=c+16|0;return(x[(a+D(b,872)|0)+1075080>>2]&67109888)!=0|0}a=N()|0;jc(b)}Q(a|0)}p()}function ufa(a){a=a|0;var b=0,c=0,d=0;x[31737]=0;W(1027,a|0);b=x[31737];x[31737]=0;a:{b:{if((b|0)!=1){b=x[a+28>>2];d=x[x[b>>2]+36>>2];x[31737]=0;c=+ia(d|0,b|0);b=x[31737];x[31737]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31737]=0;V(989,7794,a|0,0,0);a=x[31737];x[31737]=0;if((a|0)==1){break a}Z();c=0}return+c}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function sfa(a){a=a|0;var b=0,c=0,d=0;x[31737]=0;W(1027,a|0);b=x[31737];x[31737]=0;a:{b:{if((b|0)!=1){b=x[a+28>>2];d=x[x[b>>2]+28>>2];x[31737]=0;c=+ia(d|0,b|0);b=x[31737];x[31737]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31737]=0;V(989,7742,a|0,0,0);a=x[31737];x[31737]=0;if((a|0)==1){break a}Z();c=0}return+c}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function kla(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;c=fb-16|0;fb=c;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);e=c+8|0;Rd(e,x[vb(c+4|0,a)>>2]);x[31737]=0;W(809,a|0);b=x[31737];x[31737]=0;if((b|0)!=1){f=fb-16|0;fb=f;d=_h(f+4|0,a,2304);b=x[d+4>>2];g=x[d+8>>2];while(1){if((b|0)==(g|0)){hc(d);fb=f+16|0}else{Vw(b);b=b+2|0;x[d+4>>2]=b;continue}break}Qd(e);Yj(e);fb=c+16|0;return a|0}a=N()|0;Yj(c+8|0);Q(a|0);p()}function WY(a){var b=0;a:{if(kd(a,14321,3)|(y[a+3|0]-52&255)>>>0<252){break a}if($b(y[a+8|0]|y[a+9|0]<<8|(y[a+10|0]<<16|y[a+11|0]<<24))+788>>>0<840){break a}if($b(y[a+16|0]|y[a+17|0]<<8|(y[a+18|0]<<16|y[a+19|0]<<24))>>>0<52){break a}if($b(y[a+24|0]|y[a+25|0]<<8|(y[a+26|0]<<16|y[a+27|0]<<24))-1>>>0<51){break a}b=$b(y[a+32|0]|y[a+33|0]<<8|(y[a+34|0]<<16|y[a+35|0]<<24))>>>0<4294967216}return b}function X1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-16|0;fb=d;x[a>>2]=0;x[a+4>>2]=0;if(!Mb(x[b>>2],x[b+8>>2],c)){c=kf(b)}x[a>>2]=c;c=x[b>>2];a:{if(ib[x[x[c>>2]+16>>2]](c)|0){c=a;a=x[b>>2];e=c,f=(ib[x[x[a>>2]+20>>2]](a)|0)+x[b+8>>2]|0,x[e+4>>2]=f;break a}Nk(a+8|0,x[a>>2]);c=x[a+8>>2];a=x[a+12>>2];if(mc(c,a)){break a}re(d+8|0,c,a);lc(d,x[b>>2],x[b+8>>2],x[d+8>>2],x[d+12>>2])}fb=d+16|0}function Sv(a,b){var c=0;c=fb-16|0;fb=c;x[c+12>>2]=b;a:{b:{switch(a|0){case 0:a=b>>31<<6|b>>>26;b=b<<6;a=Gc(Tua(b- -8192|0,a-((b>>>0<4294959104)-1|0)|0,16384,0),hb);break a;case 1:a=b>>31<<6|b>>>26;b=(b<<6)+2048|0;a=b>>>0<2048?a+1|0:a;a=Gc(Tua(b,a,4096,0),hb);break a;default:break b}}x[c+8>>2]=1;a=Zi(ZL(8192/+x[Ye(c+12|0,c+8|0)>>2])*24+8)}fb=c+16|0;a=(a|0)>=64?64:a;return((a|0)>0?a:0)&255}function Hta(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=fb-16|0;fb=e;a:{f=Zd(a);b:{if(f>>>0>1){break b}c:{if(f){x[31737]=0;d=e+4|0;S(335,d|0,a|0,c|0);a=x[31737];x[31737]=0;if((a|0)!=1){Fn(b,d);dc(d);break c}a=T(28896)|0;if((gb|0)!=($(28896)|0)){break a}Y(a|0)|0;Z();d=0;break b}if(!Mb(x[a>>2],x[a+8>>2],c)){break b}uw(a,b,c)}d=Vc(x[b>>2],x[b+4>>2])>>>0>=c>>>0}fb=e+16|0;return d|0}Q(a|0);p()}function nz(a,b,c){var d=0,e=0;d=fb-32|0;fb=d;a:{if(y[a+20|0]){break a}b=b+c|0;b=b>>>0<c>>>0?-1:b;c=x[a+16>>2];if(b>>>0<=c>>>0){break a}b=xM(b,4096);wM(a,b-c|0);c=x[a+16>>2];b=gc(d+16|0,xb(x[a+4>>2],c),b-c|0);c=x[x[a>>2]+44>>2];e=x[b+4>>2];x[d+8>>2]=x[b>>2];x[d+12>>2]=e;ib[c|0](d+24|0,a,d+8|0);x[a+16>>2]=x[a+16>>2]+x[d+28>>2];if(!(ib[x[x[a>>2]+40>>2]](a)|0)){break a}v[a+20|0]=1}fb=d+32|0}function AN(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{b:{c:{d:{if((b|0)>=0){a=x[a+32>>2];if((Ao(a)|0)>(b|0)){break d}}b=ac(8);x[31737]=0;c=P(36,c+4|0,10751)|0;a=x[31737];x[31737]=0;if((a|0)==1){break c}pc(b,c);x[31737]=0;S(98,b|0,48540,1006);a=x[31737];x[31737]=0;if((a|0)!=1){break a}a=N()|0;tb(c);break b}fb=c+16|0;return+(+x[(a+D(b,872)|0)+1075740>>2]*.015625)}a=N()|0;jc(b)}Q(a|0)}p()}function Bba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);Rd(c+8|0,x[vb(c+4|0,a)>>2]);a:{d=Ik(x[b+4>>2],x[b+8>>2]);if(!d){break a}x[31737]=0;O(1127,a|0,d|0);e=x[31737];x[31737]=0;if((e|0)!=1){e=x[b+8>>2];b=x[b+4>>2];x[31737]=0;V(1128,a|0,b|0,e|0,d|0);a=x[31737];x[31737]=0;if((a|0)!=1){break a}}a=N()|0;mN(c+8|0);Q(a|0);p()}a=c+8|0;Qd(a);mN(a);fb=c+16|0}function ZH(a,b,c,d,e,f,g){var h=0;x[31737]=0;W(1002,a|0);h=x[31737];x[31737]=0;a:{b:{if((h|0)!=1){h=x[a+24>>2];x[31737]=0;b=ha(g|0,h|0,b|0,c|0,d|0,e|0)|0;c=x[31737];x[31737]=0;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[31737]=0;V(989,f|0,a|0,0,0);a=x[31737];x[31737]=0;if((a|0)==1){break a}Z();b=0}return b}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function Vaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=fb-16|0;fb=c;a:{if(C[a+24>>3]==1){break a}h=x[b>>2];f=x[b+4>>2];i=x[b+8>>2];b:while(1){if((e|0)==(i|0)){break a}j=(D(e,f)<<3)+h|0;d=0;while(1)if((d|0)==(f|0)){e=e+1|0;continue b}else{g=(d<<3)+j|0;C[g>>3]=C[a+24>>3]*C[g>>3];d=d+1|0;continue}}}x[c+8>>2]=x[b+8>>2];d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;JM(a,c);fb=c+16|0}function Saa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=fb-16|0;fb=c;a:{if(C[a+24>>3]==1){break a}h=x[b>>2];f=x[b+4>>2];i=x[b+8>>2];b:while(1){if((e|0)==(i|0)){break a}j=(D(e,f)<<3)+h|0;d=0;while(1)if((d|0)==(f|0)){e=e+1|0;continue b}else{g=(d<<3)+j|0;C[g>>3]=C[a+24>>3]*C[g>>3];d=d+1|0;continue}}}x[c+8>>2]=x[b+8>>2];d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;HM(a,c);fb=c+16|0}function Rma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;f=Jb(c);c=Cb(x[c+4>>2],y[c+11|0]);a:{d=Cb(x[a+4>>2],y[a+11|0]);if(d>>>0>=b>>>0){e=Mc(a);if(c>>>0<=e-d>>>0){if(!c){break a}e=Jb(a);h=e+b|0;if((b|0)!=(d|0)){g=b+e|0;Ui(c+g|0,g,d-b|0);f=(f>>>0>=g>>>0?d+e>>>0>f>>>0?c:0:0)+f|0}Ui(h,f,c);b=c+d|0;ng(a,b);fd(b+e|0,0);break a}Yq(a,e,(c+d|0)-e|0,d,b,0,c,f);break a}jn();p()}return a|0}function Maa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=fb-16|0;fb=c;a:{if(C[a+24>>3]==1){break a}h=x[b>>2];f=x[b+4>>2];i=x[b+8>>2];b:while(1){if((e|0)==(i|0)){break a}j=(D(e,f)<<3)+h|0;d=0;while(1)if((d|0)==(f|0)){e=e+1|0;continue b}else{g=(d<<3)+j|0;C[g>>3]=C[a+24>>3]*C[g>>3];d=d+1|0;continue}}}x[c+8>>2]=x[b+8>>2];d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;DM(a,c);fb=c+16|0}function $aa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=fb-16|0;fb=c;a:{if(C[a+24>>3]==1){break a}h=x[b>>2];f=x[b+4>>2];i=x[b+8>>2];b:while(1){if((e|0)==(i|0)){break a}j=(D(e,f)<<3)+h|0;d=0;while(1)if((d|0)==(f|0)){e=e+1|0;continue b}else{g=(d<<3)+j|0;C[g>>3]=C[a+24>>3]*C[g>>3];d=d+1|0;continue}}}x[c+8>>2]=x[b+8>>2];d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;NM(a,c);fb=c+16|0}function sta(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;bc(c+8|0,b,15);d=x[c+12>>2];lc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;if((d|0)!=(e|0)){v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b+6|0]=0;v[b+7|0]=0;v[b+7|0]=0;v[b+8|0]=0;v[b+9|0]=0;v[b+10|0]=0;v[b+11|0]=0;v[b+12|0]=0;v[b+13|0]=0;v[b+14|0]=0}}function sK(a,b,c){var d=0,e=0,f=E(0),g=0,h=E(0);e=fb-16|0;fb=e;a:{b:{c:{if((a|0)!=(b|0)){g=x[31612];x[31612]=0;Od();d=fb-16|0;fb=d;By(d,a,e+12|0,0);f=UG(x[d>>2],x[d+4>>2],x[d+8>>2],x[d+12>>2]);fb=d+16|0;a=x[31612];if(!a){break c}if(x[e+12>>2]!=(b|0)){break b}h=f;if((a|0)!=68){break a}break b}x[c>>2]=4;break a}x[31612]=g;if(x[e+12>>2]==(b|0)){break a}}x[c>>2]=4;f=h}fb=e+16|0;return f}function hea(a,b){a=a|0;b=b|0;var c=0,d=0;x[31737]=0;W(1002,a|0);c=x[31737];x[31737]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+24>>2];x[31737]=0;O(1093,c|0,b|0);b=x[31737];x[31737]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31737]=0;V(989,10916,a|0,0,0);a=x[31737];x[31737]=0;if((a|0)==1){break a}Z();d=0}return d|0}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function aY(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+22|0]=0;v[a+23|0]=0;v[a+24|0]=0;v[a+25|0]=0;v[a+26|0]=0;v[a+27|0]=0;v[a+28|0]=0;v[a+29|0]=0;v[a+16|0]=0;v[a+17|0]=0;v[a+18|0]=0;v[a+19|0]=0;v[a+20|0]=0;v[a+21|0]=0;v[a+22|0]=0;v[a+23|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a+12|0]=0;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0}function RV(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+24|0]=0;v[a+25|0]=0;v[a+26|0]=0;v[a+27|0]=0;v[a+28|0]=0;v[a+29|0]=0;v[a+30|0]=0;v[a+31|0]=0;v[a+16|0]=0;v[a+17|0]=0;v[a+18|0]=0;v[a+19|0]=0;v[a+20|0]=0;v[a+21|0]=0;v[a+22|0]=0;v[a+23|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a+12|0]=0;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0}function Hra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;a:{d=fb-16|0;fb=d;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);Rd(d+8|0,x[vb(d+4|0,a)>>2]);b:{f=b+c|0;c=Vj(b,f);if(c){x[31737]=0;O(346,a|0,c|0);e=x[31737];x[31737]=0;if((e|0)==1){break b}e=fb-16|0;fb=e;a=$l(e+4|0,a,c);g=a,h=zr(b,f,x[a+4>>2]),x[g+4>>2]=h;hc(a);fb=e+16|0}a=d+8|0;Qd(a);cj(a);fb=d+16|0;break a}a=N()|0;cj(d+8|0);Q(a|0);p()}}function pra(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;bc(c+8|0,b,14);d=x[c+12>>2];lc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;if((d|0)!=(e|0)){v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b+6|0]=0;v[b+7|0]=0;v[b+6|0]=0;v[b+7|0]=0;v[b+8|0]=0;v[b+9|0]=0;v[b+10|0]=0;v[b+11|0]=0;v[b+12|0]=0;v[b+13|0]=0}}function r4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=x[a>>2];f=6;a:{b:{if((e|0)==(b|0)){break b}e=v[e|0];f=4;if(!Jf(x[d+8>>2],64,e)){break b}f=4;g=rl(d,e);while(1){c:{e=x[a>>2]+1|0;x[a>>2]=e;g=g-48|0;if((b|0)==(e|0)|f>>>0<2){break c}e=v[e|0];if(!Jf(x[d+8>>2],64,e)){break a}f=f-1|0;g=rl(d,e)+D(g,10)|0;continue}break}if((b|0)!=(e|0)){break a}f=2}x[c>>2]=f|x[c>>2]}return g|0}function qj(a,b,c,d,e){var f=0,g=0,h=0;f=fb-16|0;fb=f;x[f+12>>2]=b;b=0;g=6;a:{b:{if(sh(a,f+12|0)){break b}h=Al(x[a>>2]);g=4;if(!Jf(x[d+8>>2],64,h)){break b}b=rl(d,h);while(1){c:{b=b-48|0;h=Km(a);if(sh(h,f+12|0)|(e|0)<2){break c}g=Al(x[h>>2]);if(!Jf(x[d+8>>2],64,g)){break a}e=e-1|0;b=rl(d,g)+D(b,10)|0;continue}break}g=2;if(!sh(h,f+12|0)){break a}}x[c>>2]=x[c>>2]|g}fb=f+16|0;return b}function Nia(a){a=a|0;var b=0,c=0;b=x[a+20>>2];x[b+148>>2]=-1;x[31737]=0;O(288,b+4|0,8);b=x[31737];x[31737]=0;if((b|0)!=1){b=x[a+4264>>2];c=x[x[a+20>>2]+4>>2];a=x[a+4260>>2];v[c|0]=a;v[c+1|0]=a>>>8;v[c+2|0]=a>>>16;v[c+3|0]=a>>>24;v[c+4|0]=b;v[c+5|0]=b>>>8;v[c+6|0]=b>>>16;v[c+7|0]=b>>>24;return}b=T(125048)|0;if((gb|0)==($(125048)|0)){Y(b|0)|0;ep(x[a+20>>2]+4|0);Z();return}Q(b|0);p()}function IO(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-16|0;fb=e;a:{b:{c:{if(!d){a=ac(8);x[31737]=0;c=P(36,e+4|0,8200)|0;b=x[31737];x[31737]=0;if((b|0)==1){break c}pc(a,c);x[31737]=0;S(98,a|0,48540,1006);a=x[31737];x[31737]=0;if((a|0)!=1){break a}b=N()|0;tb(c);break b}Il(a,b,1);c=rz(a,c,d,0,0,0);C[a+16>>3]=C[a+16>>3]+ +(c>>>0)/+(b|0);fb=e+16|0;return c|0}b=N()|0;jc(a)}Q(b|0)}p()}function BO(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-16|0;fb=e;a:{b:{c:{if(!d){a=ac(8);x[31737]=0;c=P(36,e+4|0,8200)|0;b=x[31737];x[31737]=0;if((b|0)==1){break c}pc(a,c);x[31737]=0;S(98,a|0,48540,1006);a=x[31737];x[31737]=0;if((a|0)!=1){break a}b=N()|0;tb(c);break b}Il(a,b,1);c=sz(a,c,d,0,0,0);C[a+16>>3]=C[a+16>>3]+ +(c>>>0)/+(b|0);fb=e+16|0;return c|0}b=N()|0;jc(a)}Q(b|0)}p()}function qla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);Rd(c+8|0,x[vb(c+4|0,a)>>2]);a:{d=jh(x[b>>2],x[b+4>>2]);if(!d){break a}x[31737]=0;O(802,a|0,d|0);e=x[31737];x[31737]=0;if((e|0)!=1){e=x[b+4>>2];b=x[b>>2];x[31737]=0;sU(a,b,e,d);b=x[31737];x[31737]=0;if((b|0)!=1){break a}}a=N()|0;Zu(c+8|0);Q(a|0);p()}b=c+8|0;Qd(b);Zu(b);fb=c+16|0;return a|0}function pja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);Rd(c+8|0,x[vb(c+4|0,a)>>2]);a:{d=oc(x[b>>2],x[b+4>>2]);if(!d){break a}x[31737]=0;O(226,a|0,d|0);e=x[31737];x[31737]=0;if((e|0)!=1){e=x[b+4>>2];b=x[b>>2];x[31737]=0;vu(a,b,e,d);b=x[31737];x[31737]=0;if((b|0)!=1){break a}}a=N()|0;ch(c+8|0);Q(a|0);p()}b=c+8|0;Qd(b);ch(b);fb=c+16|0;return a|0}function mpa(a,b){a=a|0;b=b|0;var c=0,d=0;a:{a=zC(a,b);x[31737]=0;c=P(685,a+12|0,b+12|0)|0;d=x[31737];x[31737]=0;b:{c:{if((d|0)!=1){x[31737]=0;P(686,a+24|0,b+24|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break c}c=x[b+40>>2];x[a+36>>2]=x[b+36>>2];x[a+40>>2]=c;w[a+52>>1]=z[b+52>>1];c=x[b+48>>2];x[a+44>>2]=x[b+44>>2];x[a+48>>2]=c;break a}b=N()|0;break b}b=N()|0;dc(c)}dc(a);Q(b|0);p()}}function lha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Qi(a,b,c,d);x[a>>2]=44288;b=Nb(a+4208|0);x[a+4240>>2]=0;x[a+4244>>2]=0;c=x[c+24620>>2];x[a+4260>>2]=0;x[a+4256>>2]=c;x[a+4236>>2]=0;c=a+4228|0;x[c>>2]=1048550822;x[c+4>>2]=1048550822;x[a+4220>>2]=1056964608;x[a+4224>>2]=1056964608;x[31737]=0;O(947,a+44|0,2);c=x[31737];x[31737]=0;if((c|0)!=1){return a|0}c=N()|0;vc(b);ag(a);Q(c|0);p()}function Jfa(a){a=a|0;var b=0;x[31737]=0;W(1027,a|0);b=x[31737];x[31737]=0;if((b|0)!=1){x[a+24>>2]=0;b=x[a+28>>2];if(b){ib[x[x[b>>2]+4>>2]](b)}x[a+28>>2]=0;b=x[a+20>>2];if(b){Db(b);x[a+20>>2]=0}Db(a);return}Y(T(0)|0)|0;x[31737]=0;V(989,5051,a|0,0,0);a=x[31737];x[31737]=0;if((a|0)!=1){Z();return}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function zC(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);Rd(c+8|0,x[vb(c+4|0,a)>>2]);a:{d=Vc(x[b>>2],x[b+4>>2]);if(!d){break a}x[31737]=0;O(323,a|0,d|0);e=x[31737];x[31737]=0;if((e|0)!=1){e=x[b+4>>2];b=x[b>>2];x[31737]=0;uv(a,b,e,d);b=x[31737];x[31737]=0;if((b|0)!=1){break a}}a=N()|0;cj(c+8|0);Q(a|0);p()}b=c+8|0;Qd(b);cj(b);fb=c+16|0;return a|0}function pN(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;d=fb-16|0;fb=d;a:{b:{c:{if(b>>>0>=256){b=ac(8);x[31737]=0;d=P(36,d+4|0,10751)|0;a=x[31737];x[31737]=0;if((a|0)==1){break c}pc(b,d);x[31737]=0;S(98,b|0,48540,1006);a=x[31737];x[31737]=0;if((a|0)!=1){break a}a=N()|0;tb(d);break b}e=(x[a+32>>2]+D(b,872)|0)+1075766|0,f=qC(c*32768),w[e>>1]=f;fb=d+16|0;return}a=N()|0;jc(b)}Q(a|0)}p()}function _n(a,b,c,d,e,f){var g=0;x[31737]=0;W(1002,a|0);g=x[31737];x[31737]=0;a:{b:{if((g|0)!=1){g=x[a+24>>2];x[31737]=0;b=ba(f|0,g|0,b|0,c|0,d|0)|0;c=x[31737];x[31737]=0;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[31737]=0;V(989,e|0,a|0,0,0);a=x[31737];x[31737]=0;if((a|0)==1){break a}Z();b=0}return b}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function uO(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=fb-32|0;fb=b;c=gc(b+24|0,c,d);d=x[c+4>>2];x[b>>2]=x[c>>2];x[b+4>>2]=d;a:{a=zu(a,b,0);if(a+1>>>0>=3){a=ac(8);x[31737]=0;b=P(36,b+12|0,8057)|0;c=x[31737];x[31737]=0;b:{if((c|0)!=1){pc(a,b);x[31737]=0;S(98,a|0,48540,1006);a=x[31737];x[31737]=0;if((a|0)!=1){break a}c=N()|0;tb(b);break b}c=N()|0;jc(a)}Q(c|0);p()}fb=b+32|0;return a|0}p()}function qK(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;a:{b:{c:{if((a|0)!=(b|0)){g=x[31612];x[31612]=0;Od();d=fb-16|0;fb=d;By(d,a,e+12|0,1);f=yx(x[d>>2],x[d+4>>2],x[d+8>>2],x[d+12>>2]);fb=d+16|0;a=x[31612];if(!a){break c}if(x[e+12>>2]!=(b|0)){break b}h=f;if((a|0)!=68){break a}break b}x[c>>2]=4;break a}x[31612]=g;if(x[e+12>>2]==(b|0)){break a}}x[c>>2]=4;f=h}fb=e+16|0;return f}function lY(a,b){var c=0,d=0,e=0,f=0;c=fb-32|0;fb=c;a:{if(!y[b+5|0]){while(1){if((d|0)==5){d=0;v[c+28|0]=0;x[c+24>>2]=0;e=c+24|0;f=gc(c+8|0,e,5);lc(c+16|0,x[a>>2],x[a+8>>2],x[f>>2],x[f+4>>2]);b:{if(x[c+20>>2]!=5){break b}if(kd(e,b,5)){break b}Vb(a,5);d=1}fb=c+32|0;break a}e=b+d|0;d=d+1|0;if(y[e|0]){continue}break}_(17527,9095,602,13238);p()}_(17506,9095,600,13238);p()}return d}function cL(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-32|0;fb=d;e=Dc(d+8|0,c);x[31737]=0;c=d+20|0;S(1188,c|0,b|0,e|0);f=x[31737];x[31737]=0;a:{b:{if((f|0)!=1){x[31737]=0;a=P(1189,a|0,c|0)|0;f=x[31737];x[31737]=0;if((f|0)==1){break b}tb(c);tb(e);x[a>>2]=124320;c=x[b+4>>2];x[a+8>>2]=x[b>>2];x[a+12>>2]=c;fb=d+32|0;return a|0}c=N()|0;break a}c=N()|0;tb(d+20|0)}tb(e);Q(c|0);p()}function v9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=fb-16|0;fb=f;while(1){a:{if((c|0)<=(g|0)){break a}d=x[a+24>>2];e=x[a+28>>2];if(d>>>0>=e>>>0){if((ib[x[x[a>>2]+52>>2]](a,x[b>>2])|0)==-1){break a}g=g+1|0;b=b+4|0}else{x[f+12>>2]=e-d>>2;x[f+8>>2]=c-g;e=d;d=x[ud(f+12|0,f+8|0)>>2];Yi(e,b,d);e=d<<2;x[a+24>>2]=e+x[a+24>>2];g=g+d|0;b=b+e|0}continue}break}fb=f+16|0;return g|0}function fka(a){a=a|0;var b=0,c=0,d=0,e=0;e=fb-16|0;fb=e;b=Ec(2500);c=fb-2496|0;fb=c;TQ(a,c,c+2496|0);a=0;while(1){if((a|0)==624){x[b+2496>>2]=0;a:{if(x[b>>2]<0){break a}a=1;while(1){if((a|0)!=624){d=a<<2;a=a+1|0;if(!x[b+d>>2]){continue}break a}break}x[b>>2]=-2147483648}fb=c+2496|0}else{d=a<<2;x[d+b>>2]=x[c+d>>2];a=a+1|0;continue}break}a=yf(e+12|0,b);fb=e+16|0;return x[a>>2]}function cea(a,b){a=a|0;b=+b;var c=0;x[31737]=0;W(1002,a|0);c=x[31737];x[31737]=0;a:{b:{if((c|0)!=1){c=x[a+24>>2];x[31737]=0;b=+Wa(1095,c|0,+b);c=x[31737];x[31737]=0;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[31737]=0;V(989,7606,a|0,0,0);a=x[31737];x[31737]=0;if((a|0)==1){break a}Z();b=0}return+b}a=N()|0;x[31737]=0;X(26);c=x[31737];x[31737]=0;if((c|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function Kna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-16|0;fb=d;a:{c=x[b+4>>2];if(!c){break a}w[d>>1]=z[a+480190>>1];w[d+14>>1]=c-1;c=z[Nc(d,d+14|0)>>1];while(1){if(!c){break a}b:{if(BC(x[b>>2],c)){break b}if(cS(a,c&65535)){e=Dc(d,22303);zc(((c<<5)+a|0)+946304|0,e);tb(e)}if(c>>>0<2){break b}e=z[a+480190>>1];if((e|0)!=(c|0)){break b}w[a+480190>>1]=e-1}c=c-1|0;continue}}fb=d+16|0}function i1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=fb-16|0;fb=e;c=-1;a:{if(!kh(a,7)){break a}c=0;if(!OE(a,11790)){break a}c=fb-16|0;fb=c;f=e+5|0;Hw(c+8|0,f);d=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(d|0)){gd(a,x[c+12>>2])}fb=c+16|0;d=(d|0)==(g|0);if(!d){LE(f)}c=-1;if(!d){break a}c=0;if(!NE(y[e+6|0])){break a}c=ve(a,b,ME(f),hb)}fb=e+16|0;return c|0}function Hx(a,b,c,d,e,f){var g=0,h=0,i=0;g=fb-16|0;fb=g;x[a+4>>2]=0;x[a>>2]=47700;i=Ec(80);x[31737]=0;d=R(1105,d|0)|0;h=x[31737];x[31737]=0;a:{b:{if((h|0)!=1){x[g+8>>2]=d;d=g+8|0;h=x[qe(g+12|0,d)>>2];x[31737]=0;b=ha(f|0,i|0,b|0,c-b|0,h|0,e|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break b}x[a+4>>2]=b;Uc(d);fb=g+16|0;return a}a=N()|0;break a}a=N()|0;Uc(g+8|0)}Db(i);Q(a|0);p()}function xia(a,b){a=a|0;b=b|0;var c=E(0);a:{switch(b|0){case 0:return E(B[a+4220>>2]);case 1:return E(B[a+4224>>2]);case 2:return E(B[a+4228>>2]);case 3:return E(y[a+4240|0]?E(1):E(0));case 4:return E(E(E(x[a+4232>>2])*E(.03125)));case 5:return E(y[a+4241|0]?E(1):E(0));case 6:return E(y[a+4242|0]?E(1):E(0));case 7:c=y[a+4244|0]?E(1):E(0);break;default:break a}}return E(c)}function z6(a){a=a|0;if(y[500544]){return x[125135]}if(!y[501064]){v[501064]=1}wd(500896,120200);wd(500908,120228);wd(500920,120256);wd(500932,120288);wd(500944,120328);wd(500956,120364);wd(500968,120392);wd(500980,120428);wd(500992,120444);wd(501004,120460);wd(501016,120476);wd(501028,120492);wd(501040,120508);wd(501052,120524);v[500544]=1;x[125135]=500896;return 500896}function Is(a,b,c,d,e,f){var g=0,h=0,i=0;g=fb-16|0;fb=g;x[a+4>>2]=0;x[a>>2]=47700;i=Ec(80);x[31737]=0;d=R(1105,d|0)|0;h=x[31737];x[31737]=0;a:{b:{if((h|0)!=1){x[g+8>>2]=d;d=g+8|0;h=x[qe(g+12|0,d)>>2];x[31737]=0;b=ha(f|0,i|0,b|0,c|0,h|0,e|0)|0;c=x[31737];x[31737]=0;if((c|0)==1){break b}x[a+4>>2]=b;Uc(d);fb=g+16|0;return a}a=N()|0;break a}a=N()|0;Uc(g+8|0)}Db(i);Q(a|0);p()}function Hea(a){a=a|0;var b=0,c=0;x[31737]=0;W(1002,a|0);b=x[31737];x[31737]=0;a:{b:{if((b|0)!=1){b=x[a+24>>2];x[31737]=0;b=R(1070,b|0)|0;c=x[31737];x[31737]=0;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[31737]=0;V(989,7278,a|0,0,0);a=x[31737];x[31737]=0;if((a|0)==1){break a}Z();b=0}return b|0}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function N9(){var a=0,b=0,c=0,d=0,e=0,f=0;b=fb-48|0;fb=b;if(LL(0,b+24|0)){It(x[31612],12758);p()}a=we(b+16|0,x[b+24>>2],x[b+28>>2]);d=ZA(b+8|0,x[b+32>>2]/1e3|0);c=fb-16|0;fb=c;a=Du(c,x[a>>2],x[a+4>>2]);e=x[a>>2];f=e+x[d>>2]|0;a=x[d+4>>2]+x[a+4>>2]|0;a=we(c+8|0,f,f>>>0<e>>>0?a+1|0:a);d=x[a>>2];fb=c+16|0;c=we(b+40|0,d,x[a+4>>2]);a=x[c>>2];fb=b+48|0;hb=x[c+4>>2];return a|0}function $_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-32|0;fb=d;e=Nb(a);a=wb(x[b>>2]);x[d+28>>2]=a;f=wb(x[b+4>>2]);a:{while(1){if(Ib(a,f)){b=d+8|0;wi(b,x[a>>2],x[a+4>>2]);if(($b(x[d+8>>2])|0)==(c|0)){qp(b,a);x[31737]=0;O(361,e|0,b|0);a=x[31737];x[31737]=0;if((a|0)==1){break a}ub(b)}a=x[lm(d+28|0)>>2];continue}break}fb=d+32|0;return}a=N()|0;ub(d+8|0);Qc(e);Q(a|0);p()}function x_(a){var b=0,c=0;a:{if(kd(a,15331,3)){break a}c=y[a+3|0];if(c>>>0>9){break a}if((Bb(y[a+202|0]|y[a+203|0]<<8)-1e4&65535)>>>0<57516){break a}b=1;b:{if(c>>>0>5){break b}if(!Bb(y[a+228|0]|y[a+229|0]<<8)){break a}if(!Bb(y[a+230|0]|y[a+231|0]<<8)){break a}b=0;if(Bb(y[a+232|0]|y[a+233|0]<<8)>>>0>4095){break b}b=Bb(y[a+234|0]|y[a+235|0]<<8)>>>0<100}return b}return 0}function kB(a,b,c){var d=0,e=0,f=0;f=Fb(a);d=y[b+11|0];e=x[b+4>>2];a=0;x[31737]=0;O(53,f|0,Yc(e,d)|0);d=x[31737];x[31737]=0;if((d|0)!=1){a:{while(1){if(Yc(x[b+4>>2],y[b+11|0])>>>0>a>>>0){d=65533;e=v[cc(b,a)|0];if((e|0)>=-96){d=x[((e&255)<<2)+c>>2]}x[31737]=0;O(35,f|0,d|0);d=x[31737];x[31737]=0;if((d|0)==1){break a}a=a+1|0;continue}break}return}}a=N()|0;Ub(f);Q(a|0);p()}function fQ(a){var b=E(0),c=0,d=E(0);b=B[a+4224>>2];B[a+4260>>2]=M(E(E(1)-E(b*b)));v[a+4264|0]=B[a+4236>>2]>E(.5);d=E(A[a+4256>>2]);b=E(E(E(E(B[a+4228>>2]*E(1999))+E(1))/E(1e3))*d);a:{if(b<E(4294967296)&b>=E(0)){c=~~b>>>0;break a}c=0}x[a+4248>>2]=c;c=a+4252|0;b=E(E(E(E(B[a+4232>>2]*E(1999))+E(1))/E(1e3))*d);b:{if(b<E(4294967296)&b>=E(0)){a=~~b>>>0;break b}a=0}x[c>>2]=a}function Qea(a){a=a|0;var b=0,c=0;x[31737]=0;W(1002,a|0);b=x[31737];x[31737]=0;a:{b:{if((b|0)!=1){b=x[a+24>>2];x[31737]=0;c=+ia(1061,b|0);b=x[31737];x[31737]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31737]=0;V(989,7678,a|0,0,0);a=x[31737];x[31737]=0;if((a|0)==1){break a}Z();c=0}return+c}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function B4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=x[a>>2];f=6;a:{b:{if((e|0)==(b|0)){break b}e=x[e>>2];f=4;if(!yj(d,64,e)){break b}g=uk(d,e);f=4;while(1){c:{e=x[a>>2]+4|0;x[a>>2]=e;g=g-48|0;if((b|0)==(e|0)|f>>>0<2){break c}e=x[e>>2];if(!yj(d,64,e)){break a}f=f-1|0;g=uk(d,e)+D(g,10)|0;continue}break}if((b|0)!=(e|0)){break a}f=2}x[c>>2]=f|x[c>>2]}return g|0}
function fba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;a:{b:{if((yk(y[a+140|0])|0)!=1){break b}if(($M(a)|0)!=(b|0)){break b}d=a+120|0;_t(y[d+20|0]);b=fb-16|0;fb=b;x[b+12>>2]=c+15;a=fb-16|0;fb=a;e=x[18395];x[a+8>>2]=x[18394];x[a+12>>2]=e;e=x[18393];x[a>>2]=x[18392];x[a+4>>2]=e;ib[x[tq(a,yk(y[d+20|0]))>>2]](b+12|0,d);fb=a+16|0;fb=b+16|0;break a}_M(a,1,b)}fb=c+16|0}function Wia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=fb-16|0;fb=d;c=Ec(64);x[31737]=0;e=R(879,c|0)|0;f=x[31737];x[31737]=0;a:{if((f|0)!=1){c=yf(d+8|0,e);e=x[c>>2];x[31737]=0;a=U(945,e|0,a|0,b|0)|0;b=x[31737];x[31737]=0;b:{c:{if((b|0)!=1){if((a|0)==1){break c}sc(d+12|0);break b}a=N()|0;og(c);break a}qe(d+12|0,c)}og(c);fb=d+16|0;return x[d+12>>2]}a=N()|0;Db(c)}Q(a|0);p()}function E5(a,b){a=a|0;b=b|0;var c=0,d=0;c=Jb(b);b=fb-32|0;fb=b;a=xd(a,0);x[a>>2]=113312;d=xk(c);x[a+8>>2]=d;if(!d){a=Dc(b+8|0,c);x[31737]=0;c=b+20|0;S(1017,c|0,17563,a|0);d=x[31737];x[31737]=0;a:{b:{if((d|0)!=1){x[31737]=0;W(1325,c|0);c=x[31737];x[31737]=0;if((c|0)==1){break b}p()}c=N()|0;break a}c=N()|0;tb(b+20|0)}tb(a);Q(c|0);p()}fb=b+32|0;x[a>>2]=119688;return a|0}function wV(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;d=Fb(a);a=y[b+11|0];e=x[b+4>>2];x[31737]=0;O(115,d|0,Yc(e,a)|0);a=x[31737];x[31737]=0;a:{if((a|0)!=1){a=zd(b);x[c+12>>2]=a;b=Df(b);while(1){if(!Ib(a,b)){break a}a=y[a|0];x[31737]=0;O(116,d|0,((a|0)==13?10:a)<<24>>24);a=x[31737];x[31737]=0;if((a|0)!=1){a=x[le(c+12|0)>>2];continue}break}}a=N()|0;tb(d);Q(a|0);p()}fb=c+16|0}function Vz(a){var b=E(0),c=E(0),d=0,e=E(0),f=0;b=E(A[x[a+16>>2]+24620>>2]);c=E(E(E(ib[x[x[a>>2]+208>>2]](a))*b)/E(1e3));d=a,e=E(E(c*E(ib[x[x[a>>2]+200>>2]](a)))*E(2048)),B[d+4248>>2]=e;d=a,f=Rl(E(E(c+E(2))*E(4096))),x[d+4256>>2]=f;c=E(ib[x[x[a>>2]+212>>2]](a));B[a+4252>>2]=c;b=E(c/b);if(!(ib[x[x[a>>2]+196>>2]](a)|0)){b=nQ(E(b*E(3.1415927410125732)))}B[a+4244>>2]=b+b}function pj(a,b,c,d,e){var f=0,g=0,h=0;f=fb-16|0;fb=f;x[f+12>>2]=b;b=0;g=6;a:{b:{if(li(a,f+12|0)){break b}g=4;h=zl(x[a>>2]);if(!yj(d,64,h)){break b}b=uk(d,h);while(1){c:{b=b-48|0;h=lo(a);if(li(h,f+12|0)|(e|0)<2){break c}g=zl(x[h>>2]);if(!yj(d,64,g)){break a}e=e-1|0;b=uk(d,g)+D(b,10)|0;continue}break}g=2;if(!li(h,f+12|0)){break a}}x[c>>2]=x[c>>2]|g}fb=f+16|0;return b}function jf(a){var b=0,c=0,d=0;d=fb-16|0;fb=d;o(+a);c=j(1)|0;j(0)|0;c=c&2147483647;a:{if(c>>>0<=1072243195){b=1;if(c>>>0<1044816030){break a}b=bq(a,0);break a}b=a-a;if(c>>>0>=2146435072){break a}c=qI(a,d);a=C[d+8>>3];b=C[d>>3];b:{switch(c&3){case 0:b=bq(b,a);break a;case 1:b=-cq(b,a,1);break a;case 2:b=-bq(b,a);break a;default:break b}}b=cq(b,a,1)}fb=d+16|0;return b}function YH(a,b,c,d,e){var f=0;f=fb-16|0;fb=f;a:{b:{c:{if(!d){a=ac(8);x[31737]=0;c=P(36,f+4|0,8200)|0;b=x[31737];x[31737]=0;if((b|0)==1){break c}pc(a,c);x[31737]=0;S(98,a|0,48540,1006);a=x[31737];x[31737]=0;if((a|0)!=1){break a}b=N()|0;tb(c);break b}Il(a,b,e);c=QH(a,c,e,d,76192,76964);C[a+16>>3]=C[a+16>>3]+ +(c>>>0)/+(b|0);fb=f+16|0;return c}b=N()|0;jc(a)}Q(b|0)}p()}function XH(a,b,c,d,e){var f=0;f=fb-16|0;fb=f;a:{b:{c:{if(!d){a=ac(8);x[31737]=0;c=P(36,f+4|0,8200)|0;b=x[31737];x[31737]=0;if((b|0)==1){break c}pc(a,c);x[31737]=0;S(98,a|0,48540,1006);a=x[31737];x[31737]=0;if((a|0)!=1){break a}b=N()|0;tb(c);break b}Il(a,b,e);c=QH(a,c,e,d,75364,76136);C[a+16>>3]=C[a+16>>3]+ +(c>>>0)/+(b|0);fb=f+16|0;return c}b=N()|0;jc(a)}Q(b|0)}p()}function HN(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;a:{b:{c:{if(b<=0|b>4){a=ac(8);x[31737]=0;c=P(36,c+4|0,7854)|0;d=x[31737];x[31737]=0;if((d|0)==1){break c}pc(a,c);x[31737]=0;S(98,a|0,48540,1006);a=x[31737];x[31737]=0;if((a|0)!=1){break a}d=N()|0;tb(c);break b}a=x[a+32>>2];e=a,f=Ze(65536/b),x[e+480244>>2]=f;Gq(a);fb=c+16|0;return}d=N()|0;jc(a)}Q(d|0)}p()}function FN(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;a:{b:{c:{if(b<=0|b>4){a=ac(8);x[31737]=0;c=P(36,c+4|0,7875)|0;d=x[31737];x[31737]=0;if((d|0)==1){break c}pc(a,c);x[31737]=0;S(98,a|0,48540,1006);a=x[31737];x[31737]=0;if((a|0)!=1){break a}d=N()|0;tb(c);break b}a=x[a+32>>2];e=a,f=Ze(b*65536),x[e+480240>>2]=f;Gq(a);fb=c+16|0;return}d=N()|0;jc(a)}Q(d|0)}p()}function hy(a,b,c,d,e,f){var g=0,h=0,i=0;g=fb-16|0;fb=g;if(1073741807-b>>>0>=c>>>0){i=Jb(a);h=g+4|0;if(b>>>0<=536870886){x[g+12>>2]=b<<1;x[g+4>>2]=b+c;c=yn(x[ad(h,g+12|0)>>2])+1|0}else{c=1073741807}Uj(h,c);c=x[g+4>>2];if(e){Yi(c,i,e)}h=e+f|0;if((h|0)!=(d|0)){e=e<<2;Yi(e+c|0,(e+i|0)+(f<<2)|0,d-h|0)}if((b|0)!=1){Db(i)}yd(a,c);of(a,x[g+8>>2]);fb=g+16|0;return}pf();p()}function UO(a){a=a|0;var b=0,c=0,d=0;b=fb-16|0;fb=b;a:{c=x[a+36>>2];d=x[a+40>>2];b:{if(Ib(c,d)){sc(b+12|0);break b}zo(b,a);x[31737]=0;c=R(1062,b|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break a}x[b+12>>2]=c;nf(b);d=x[a+40>>2];c=x[a+36>>2]}c:{if(Ib(c,d)){a=a+36|0;break c}a=x[b+12>>2];c=x[a>>2]}a=oj(c,x[a+4>>2]);El(b+12|0);fb=b+16|0;return a|0}a=N()|0;nf(b);Q(a|0);p()}function Om(a){if((a|0)>=0){if(a>>>0<=16383){if(a>>>0<=15){return v[a+89168|0]}if(a>>>0<=511){return v[(a>>>5|0)+89168|0]+5|0}return v[(a>>>10|0)+89168|0]+10|0}if(a>>>0<=16777215){if(a>>>0<=524287){return v[(a>>>15|0)+89168|0]+15|0}return v[(a>>>20|0)+89168|0]+20|0}if(a>>>0<=536870911){return v[(a>>>25|0)+89168|0]+25|0}a=v[(a>>>30|0)+89168|0]+30|0}else{a=0}return a}function Hs(a,b,c,d,e){var f=0,g=0,h=0;f=fb-16|0;fb=f;x[a+4>>2]=0;x[a>>2]=47700;h=Ec(80);x[31737]=0;c=R(1105,c|0)|0;g=x[31737];x[31737]=0;a:{b:{if((g|0)!=1){x[f+8>>2]=c;c=f+8|0;g=x[qe(f+12|0,c)>>2];x[31737]=0;b=ba(e|0,h|0,b|0,g|0,d|0)|0;d=x[31737];x[31737]=0;if((d|0)==1){break b}x[a+4>>2]=b;Uc(c);fb=f+16|0;return a}a=N()|0;break a}a=N()|0;Uc(f+8|0)}Db(h);Q(a|0);p()}function uN(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{b:{c:{if(b>>>0>=256){b=ac(8);x[31737]=0;c=P(36,c+4|0,10751)|0;a=x[31737];x[31737]=0;if((a|0)==1){break c}pc(b,c);x[31737]=0;S(98,b|0,48540,1006);a=x[31737];x[31737]=0;if((a|0)!=1){break a}a=N()|0;tb(c);break b}a=x[a+32>>2]+D(b,872)|0;x[a+1075008>>2]=0;x[a+1075068>>2]=0;fb=c+16|0;return}a=N()|0;jc(b)}Q(a|0)}p()}function Zta(a,b){a=a|0;b=b|0;var c=0,d=0;d=fb-16|0;fb=d;c=d+14|0;Y$(c,a,b);Bf(b,y[d+14|0],y[Jc(c)|0]);a=y[b+3|0];a:{if((a|0)!=9){if((a|0)!=19){break a}a=y[b+5|0];c=a&240;if((c|0)!=128){if((c|0)!=64){if((c|0)!=48){break a}v[b+3|0]=45;v[b+5|0]=a&15;break a}if((a|0)!=64){break a}v[b+3|0]=0;v[b|0]=254;break a}v[b+3|0]=20;v[b+5|0]=a&15|160;break a}v[b+3|0]=0}fb=d+16|0}function Xsa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=fb-240|0;fb=d;c=fb-16|0;fb=c;f=d+4|0;v_(c+8|0,f);e=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(e|0)){gd(a,x[c+12>>2])}fb=c+16|0;e=(e|0)==(g|0);if(!e){u_(f)}c=-1;a:{if(!e){break a}c=0;if(!x_(f)){break a}c=ve(a,b,w_(y[d+8|0]|y[d+9|0]<<8|(y[d+10|0]<<16|y[d+11|0]<<24)),hb)}fb=d+240|0;return c|0}function Wi(a){var b=0,c=0,d=0;c=fb-16|0;fb=c;o(+a);b=j(1)|0;j(0)|0;b=b&2147483647;a:{if(b>>>0<=1072243195){if(b>>>0<1045430272){break a}a=cq(a,0,0);break a}if(b>>>0>=2146435072){a=a-a;break a}b=qI(a,c);a=C[c+8>>3];d=C[c>>3];b:{switch(b&3){case 0:a=cq(d,a,1);break a;case 1:a=bq(d,a);break a;case 2:a=-cq(d,a,1);break a;default:break b}}a=-bq(d,a)}fb=c+16|0;return a}function lg(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(!Cd(y[b+11|0])){c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;x[a+8>>2]=x[b+8>>2];return a|0}c=a;f=x[b>>2];e=fb-16|0;fb=e;a:{b:{d=x[b+4>>2];c:{if(Rk(d)){Me(a,d);break c}if(d>>>0>=2147483632){break b}sg(e+8|0,Dh(d)+1|0);b=x[e+8>>2];yd(c,b);of(c,x[e+12>>2]);Yd(c,d);c=b}Cg(c,f,d+1|0);fb=e+16|0;break a}pf();p()}return a|0}function l0(a,b){var c=0,d=0;b=!x[a+24>>2]|b;x[a+16>>2]=b;if(b&x[a+20>>2]){a=fb-16|0;fb=a;c=ac(16);b=fb-16|0;fb=b;if(!y[497008]){v[497008]=1}gc(b+8|0,1,126132);d=x[b+12>>2];x[a+8>>2]=x[b+8>>2];x[a+12>>2]=d;fb=b+16|0;b=x[a+12>>2];a=x[a+8>>2];x[31737]=0;a=Ca(1190,c|0,8959,a|0,b|0)|0;b=x[31737];x[31737]=0;if((b|0)!=1){da(a|0,94620,1191);p()}a=N()|0;jc(c);Q(a|0);p()}}function jq(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(!Cd(y[b+11|0])){c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;x[a+8>>2]=x[b+8>>2];return a|0}c=a;f=x[b>>2];e=fb-16|0;fb=e;a:{b:{d=x[b+4>>2];c:{if(jr(d)){Me(a,d);break c}if(d>>>0>=1073741808){break b}Uj(e+8|0,yn(d)+1|0);b=x[e+8>>2];yd(c,b);of(c,x[e+12>>2]);Yd(c,d);c=b}Yi(c,f,d+1|0);fb=e+16|0;break a}pf();p()}return a|0}function gt(a,b,c){var d=0,e=0;if(c&2048){v[a|0]=43;a=a+1|0}if(c&1024){v[a|0]=35;a=a+1|0}d=c&260;if((d|0)!=260){v[a|0]=46;v[a+1|0]=42;a=a+2|0}c=c&16384;while(1){e=y[b|0];if(e){v[a|0]=e;a=a+1|0;b=b+1|0;continue}break}a:{b:{if((d|0)!=256){if((d|0)!=4){break b}b=c?70:102;break a}b=c?69:101;break a}b=c?65:97;if((d|0)==260){break a}b=c?71:103}v[a|0]=b;return(d|0)!=260}function Wm(a,b,c,d,e,f,g){var h=0,i=0,j=0;h=fb-16|0;fb=h;if(2147483631-b>>>0>=c>>>0){j=Jb(a);i=h+4|0;if(b>>>0<=1073741798){x[h+12>>2]=b<<1;x[h+4>>2]=b+c;c=Dh(x[ad(i,h+12|0)>>2])+1|0}else{c=2147483631}sg(i,c);c=x[h+4>>2];if(e){Cg(c,j,e)}i=e+f|0;if((i|0)!=(d|0)){Cg((c+e|0)+g|0,(e+j|0)+f|0,d-i|0)}if((b|0)!=10){Db(j)}yd(a,c);of(a,x[h+8>>2]);fb=h+16|0;return}pf();p()}function Bm(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(!Cd(y[b+11|0])){c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;x[a+8>>2]=x[b+8>>2];return a|0}c=a;f=x[b>>2];e=fb-16|0;fb=e;a:{b:{d=x[b+4>>2];c:{if(Rk(d)){Me(a,d);break c}if(d>>>0>=2147483632){break b}sg(e+8|0,Dh(d)+1|0);b=x[e+8>>2];yd(c,b);of(c,x[e+12>>2]);Yd(c,d);c=b}Xg(c,f,d+1|0);fb=e+16|0;break a}pf();p()}return a|0}function qN(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{b:{c:{if(b>>>0>=256){b=ac(8);x[31737]=0;c=P(36,c+4|0,10751)|0;a=x[31737];x[31737]=0;if((a|0)==1){break c}pc(b,c);x[31737]=0;S(98,b|0,48540,1006);a=x[31737];x[31737]=0;if((a|0)!=1){break a}a=N()|0;tb(c);break b}fb=c+16|0;return+(+(x[(x[a+32>>2]+D(b,872)|0)+1075684>>2]-128|0)*.0078125)}a=N()|0;jc(b)}Q(a|0)}p()}function EC(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-32|0;fb=d;e=Nb(a);a=wb(x[b>>2]);x[d+28>>2]=a;f=wb(x[b+4>>2]);a:{while(1){if(Ib(a,f)){b=d+8|0;wi(b,x[a>>2],x[a+4>>2]);if(x[d+8>>2]==(c|0)){qp(b,a);x[31737]=0;O(361,e|0,b|0);a=x[31737];x[31737]=0;if((a|0)==1){break a}ub(b)}a=x[lm(d+28|0)>>2];continue}break}fb=d+32|0;return}a=N()|0;ub(d+8|0);Qc(e);Q(a|0);p()}function oN(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{b:{c:{if(b>>>0>=256){b=ac(8);x[31737]=0;c=P(36,c+4|0,10751)|0;a=x[31737];x[31737]=0;if((a|0)==1){break c}pc(b,c);x[31737]=0;S(98,b|0,48540,1006);a=x[31737];x[31737]=0;if((a|0)!=1){break a}a=N()|0;tb(c);break b}fb=c+16|0;return+(+w[(x[a+32>>2]+D(b,872)|0)+1075766>>1]*30517578125e-15)}a=N()|0;jc(b)}Q(a|0)}p()}function c1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-32|0;fb=d;b:{c:{d:{e:{if((b|0)==4){Wf(a,c);break e}e=d+8|0;Wf(e,c);x[31737]=0;c=d+20|0;S(124,c|0,b|0,e|0);b=x[31737];x[31737]=0;if((b|0)==1){break d}x[31737]=0;S(245,a|0,4,c|0);a=x[31737];x[31737]=0;if((a|0)==1){break c}Ub(c);tb(e)}fb=d+32|0;break a}a=N()|0;break b}a=N()|0;Ub(d+20|0)}tb(d+8|0);Q(a|0);p()}}function ZQ(a,b){var c=0,d=0,e=0,f=0,g=0,h=E(0);c=fb-16|0;fb=c;d=0;a:{if(x[(x[x[a>>2]-12>>2]+a|0)+16>>2]){break a}x[c+12>>2]=0;Lk(a,c+12|0);e=x[c+12>>2];d=0;if(e>>>0>65535){break a}Jl(b,e);while(1){if((f|0)==(e|0)){d=!x[(x[x[a>>2]-12>>2]+a|0)+16>>2]}else{x[c+8>>2]=0;Bq(a,c+8|0);g=yb(x[b>>2],f),h=B[c+8>>2],B[g>>2]=h;f=f+1|0;continue}break}}a=d;fb=c+16|0;return a}function Nra(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;f=fb-16|0;fb=f;c=Hf(a,c);$d(f,x[a+36>>2]);a:{if(!c){Pc(f,a+32|0,5);e=0;if(Hb(x[x[f>>2]>>2],x[f+4>>2])){break a}}h=x[a+36>>2];g=fb-16|0;fb=g;e=Fb(g+4|0);x[31737]=0;ba(470,b|0,h|0,e|0,d|0)|0;b=x[31737];x[31737]=0;b:{if((b|0)!=1){tb(e);fb=g+16|0;break b}a=N()|0;tb(e);Q(a|0);p()}e=c}ff(a,e);fb=f+16|0}function YR(a,b){var c=0,d=0,e=0,f=0;a:{if(z[a+480188>>1]<=b>>>0){break a}b:{c:{c=D(b,872)+a|0;d=y[c+1075783|0];switch(d-31|0){case 1:break b;case 0:break c;default:break a}}if(!(y[a+480209|0]&16)){break a}}e=a+1074376|0;f=(d|0)==32;c=v[c+1075785|0];d:{if((c|0)>=0){d=Oe(a+901692|0,y[(D(b,872)+a|0)+1075836|0]);break d}d=Oe(a+902204|0,c&127)}tT(a,e,b,f,d,c&255)}}function P4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;while(1){if((b|0)!=(c|0)){a=x[b>>2];a:{b:{if(a>>>0<=127){a=x[(a<<2)+112160>>2];break b}e=(vt(a)|0)!=0;e=ut(a)?e|2:e;e=tt(a)?e|4:e;e=st(a)?e|8:e;e=rt(a)?e|16:e;e=qt(a)?e|32:e;e=Oh(a)?e|64:e;e=pt(a)?e|128:e;e=ot(a)?e|256:e;x[d>>2]=e;if(!nt(a)){break a}a=e|512}x[d>>2]=a}d=d+4|0;b=b+4|0;continue}break}return c|0}function qX(a){var b=0,c=0;a:{if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=-28486832|y[a+63|0]!=26){break a}b=y[a+65|0];if(y[a+66|0]|(b|0)!=16&(b|0)!=1|(y[a+64|0]&3|(y[a+78|0]|y[a+79|0]<<8)>>>0>127)){break a}if((y[a+80|0]|y[a+81|0]<<8)>>>0>127){break a}b=a+80|0;a=a+78|0;a=bl(y[a|0]|y[a+1|0]<<8,y[b|0]|y[b+1|0]<<8)?b:a;c=(y[a|0]|y[a+1|0]<<8)!=0}return c}function nX(a){var b=0;a:{if((y[a+44|0]|y[a+45|0]<<8|(y[a+46|0]<<16|y[a+47|0]<<24))!=1179472976|y[a+28|0]!=26|(y[a+40|0]|y[a+41|0]<<8|y[a+30|0]>2)){break a}if(((y[a+38|0]|y[a+39|0]<<8)-33&65535)>>>0<65504|((y[a+32|0]|y[a+33|0]<<8)-257&65535)>>>0<65280|((y[a+34|0]|y[a+35|0]<<8)-256&65535)>>>0<65281){break a}b=((y[a+36|0]|y[a+37|0]<<8)-1&65535)>>>0<128}return b}function Npa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=fb-1120|0;fb=d;c=fb-16|0;fb=c;e=d+12|0;PX(c+8|0,e);f=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(f|0)){gd(a,x[c+12>>2])}fb=c+16|0;c=-1;a:{if((f|0)!=(g|0)){break a}c=0;if(!RX(e)){break a}c=ve(a,b,QX(y[d+1116|0]|y[d+1117|0]<<8|(y[d+1118|0]<<16|y[d+1119|0]<<24)),hb)}fb=d+1120|0;return c|0}function Mo(a,b,c,d){a:{if(x[a+480180>>2]==4){if(c){v[b+810|0]=y[b+810|0]&15|c<<4;break a}c=y[b+810|0]>>>4|0;break a}if(d){if(c){v[b+834|0]=c;break a}c=y[b+834|0];break a}if(c){v[b+810|0]=c;break a}c=y[b+810|0]}b:{if(!(v[b+851|0]&1)){break b}c=x[b+688>>2]+((c&255)<<2)|0;x[b+688>>2]=(c|0)>=256?256:c;if(!(v[a+480180|0]&1)){break b}x[b+88>>2]=x[b+88>>2]|2097152}}function tR(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;if((a|0)!=(b|0)){d=fb-16|0;fb=d;c=x[b>>2];b=x[b+4>>2];e=Sd(c,b);a:{if(e>>>0<=Ug(a)>>>0){f=b;g=x[a>>2];h=oc(g,x[a+4>>2]);i=h>>>0>=e>>>0;if(!i){x[d+12>>2]=c;$C(d+12|0,h);f=x[d+12>>2]}c=Wg(c,f,g);if(!i){vu(a,f,b,e-oc(x[a>>2],x[a+4>>2])|0);break a}Ih(a,c);break a}tr(a);qm(a,Mf(a,e));vu(a,c,b,e)}fb=d+16|0}return a}function sha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a=Qi(a,b,c,d);x[a>>2]=43908;b=a+4208|0;e=yb(b,0),f=1060320051,x[e>>2]=f;e=yb(b,1),f=1041865114,x[e>>2]=f;e=yb(b,2),f=1065353216,x[e>>2]=f;e=yb(b,3),f=1049951732,x[e>>2]=f;e=yb(b,4),f=1049951732,x[e>>2]=f;x[31737]=0;O(947,a+44|0,2);b=x[31737];x[31737]=0;if((b|0)!=1){return a|0}b=N()|0;ag(a);Q(b|0);p()}function haa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-16|0;fb=d;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);Rd(d+8|0,x[vb(d+4|0,a)>>2]);a:{if(!c){break a}x[31737]=0;O(1163,a|0,c|0);e=x[31737];x[31737]=0;if((e|0)!=1){x[31737]=0;V(1164,a|0,b|0,Hd(b,c)|0,c|0);b=x[31737];x[31737]=0;if((b|0)!=1){break a}}a=N()|0;nM(d+8|0);Q(a|0);p()}b=d+8|0;Qd(b);nM(b);fb=d+16|0;return a|0}function lv(a,b){var c=0,d=0;c=fb-32|0;fb=c;d=c+16|0;jW(d,a,a+1|0,a+2|0,a+3|0);jW(c,b,b+1|0,b+2|0,b+3|0);a=kv(y[x[d>>2]],y[x[c>>2]]);a:{if(!Sj(a)){break a}a=y[x[d+4>>2]];b=y[x[c+4>>2]];a=(a|0)!=(b|0)?a<<24>>24<b<<24>>24?-1:1:0;if(!Sj(a)){break a}a=kv(y[x[d+8>>2]],y[x[c+8>>2]]);if(!Sj(a)){break a}a=kv(y[x[d+12>>2]],y[x[c+12>>2]])}a=Cd(a);fb=c+32|0;return a}function una(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Fb(a);c=y[b+11|0];e=x[b+4>>2];a=0;x[31737]=0;O(49,d|0,Yc(e,c)|0);c=x[31737];x[31737]=0;if((c|0)!=1){a:{b:{while(1){if(Yc(x[b+4>>2],y[b+11|0])>>>0<=a>>>0){break b}c=v[cc(b,a)|0];x[31737]=0;O(50,d|0,Pf(Pf(c))|0);c=x[31737];x[31737]=0;if((c|0)!=1){a=a+1|0;continue}break}break a}return}}a=N()|0;tb(d);Q(a|0);p()}function Sfa(a){a=a|0;var b=0;x[31737]=0;W(1002,a|0);b=x[31737];x[31737]=0;if((b|0)!=1){b=x[a+24>>2];if(b){Db(zq(b))}x[a+24>>2]=0;b=x[a+20>>2];if(b){Db(b);x[a+20>>2]=0}Db(a);return}Y(T(0)|0)|0;x[31737]=0;V(989,5078,a|0,0,0);a=x[31737];x[31737]=0;if((a|0)!=1){Z();return}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function xK(a,b,c,d){var e=0,f=0,g=0;e=fb-16|0;fb=e;a:{if((a|0)!=(b|0)){g=x[31612];x[31612]=0;Od();a=yK(a,e+12|0,d);d=hb;f=x[31612];b:{if(f){if(x[e+12>>2]!=(b|0)){break b}if((f|0)!=68){break a}x[c>>2]=4;b=!!a&(d|0)>=0|(d|0)>0;a=b?-1:0;d=b?2147483647:-2147483648;break a}x[31612]=g;if(x[e+12>>2]==(b|0)){break a}}}x[c>>2]=4;a=0;d=0}fb=e+16|0;hb=d;return a}function Rg(a,b){var c=0,d=0,e=0,f=0,g=0;e=Jb(a);d=Cb(x[a+4>>2],y[a+11|0]);c=Cf(b);a=0;a:{if(!c){break a}a=e;d=d+a|0;c=b+c|0;b:{if((c|0)==(b|0)){break b}c:{c=c-b|0;if((c|0)>(d-a|0)){break c}g=y[b|0];while(1){f=d-a|0;if((c|0)>(f|0)){break c}a=yq(a,(f-c|0)+1|0,g);if(!a){break c}if(!ty(a,b,c)){break b}a=a+1|0;continue}}a=d}a=(a|0)==(d|0)?-1:a-e|0}return a}function Oka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;x[a>>2]=b;c=fb-16|0;fb=c;d=Ec(223888);x[31737]=0;b=P(846,d|0,b+1074376|0)|0;e=x[31737];x[31737]=0;a:{if((e|0)!=1){b=yf(c+12|0,b);fb=c+16|0;b=x[b>>2];break a}a=N()|0;Db(d);Q(a|0);p()}x[a+4>>2]=b;b=Nb(a+8|0);x[31737]=0;W(608,a|0);c=x[31737];x[31737]=0;if((c|0)!=1){return a|0}c=N()|0;Ae(b);hT(a+4|0);Q(c|0);p()}function kq(a,b,c){var d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;f=d+12|0;bd(f,b);x[31737]=0;b=R(1212,x[d+12>>2])|0;e=x[31737];x[31737]=0;a:{if((e|0)==1){break a}x[31737]=0;e=R(1220,b|0)|0;g=x[31737];x[31737]=0;if((g|0)==1){break a}x[c>>2]=e;x[31737]=0;O(1221,a|0,b|0);a=x[31737];x[31737]=0;if((a|0)==1){break a}Zb(f);fb=d+16|0;return}a=N()|0;Zb(d+12|0);Q(a|0);p()}function mq(a,b,c){var d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;f=d+12|0;bd(f,b);x[31737]=0;b=R(1195,x[d+12>>2])|0;e=x[31737];x[31737]=0;a:{if((e|0)==1){break a}x[31737]=0;e=R(1207,b|0)|0;g=x[31737];x[31737]=0;if((g|0)==1){break a}v[c|0]=e;x[31737]=0;O(1208,a|0,b|0);a=x[31737];x[31737]=0;if((a|0)==1){break a}Zb(f);fb=d+16|0;return}a=N()|0;Zb(d+12|0);Q(a|0);p()}function cB(a,b,c,d){a:{if(x[a+1074392>>2]!=(c|0)){break a}b:{if(d){c=D(b,872)+a|0;x[c+1075688>>2]=0;d=c+1075e3|0;x[d>>2]=0;x[d+4>>2]=0;c=x[c+1075080>>2]|4096;break b}c=D(b,872)+a|0;x[c+1075680>>2]=0;c=x[c+1075080>>2]}d=D(b,872)+a|0;x[d+1075080>>2]=c|2097152;bn(a,b,255,0);if(!(y[d+1075081|0]&2)){break a}a=x[a+1298300>>2];if(!Dd(a)){break a}Lj(a,b,0)}}function Ofa(a,b){a=a|0;b=b|0;var c=0;x[31737]=0;W(1002,a|0);c=x[31737];x[31737]=0;a:{b:{if((c|0)!=1){x[a+16>>2]=b;b=x[a+20>>2];if(!b){break b}Db(b);x[a+20>>2]=0;return}Y(T(0)|0)|0;x[31737]=0;V(989,5660,a|0,0,0);a=x[31737];x[31737]=0;if((a|0)==1){break a}Z()}return}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function cs(a,b,c){var d=0,e=0,f=0,g=0;a:{d=Fk(b,zd(a));b=Fk(c,b);if(Cb(x[a+4>>2],y[a+11|0])>>>0>=d>>>0){if((b|0)==-1){BU(a,d);break a}c=a;e=fb-16|0;fb=e;x[e+12>>2]=b;if(b){f=Cb(x[a+4>>2],y[a+11|0]);g=Jb(a);b=f-d|0;x[e+8>>2]=b;a=x[Gb(e+12|0,e+8|0)>>2];b:{if((b|0)==(a|0)){a=b;break b}d=d+g|0;Ui(d,a+d|0,b-a|0)}_u(c,g,f-a|0)}fb=e+16|0;break a}jn();p()}}function eha(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;b=xQ(a,b,c,d,e^1);x[b>>2]=44520;a=b+4208|0;f=yb(a,0),g=1056964608,x[f>>2]=g;f=yb(a,1),g=1065353216,x[f>>2]=g;f=yb(a,2),g=1020054733,x[f>>2]=g;f=yb(a,3),g=1065353216,x[f>>2]=g;f=yb(a,4),g=1056964608,x[f>>2]=g;f=yb(a,5),g=1048406533,x[f>>2]=g;f=yb(a,6),g=1056964608,x[f>>2]=g;return b|0}function SH(a,b,c){var d=0;d=fb-16|0;fb=d;a:{b:{c:{if(b>>>0>=256){b=ac(8);x[31737]=0;c=P(36,d+4|0,10751)|0;a=x[31737];x[31737]=0;if((a|0)==1){break c}pc(b,c);x[31737]=0;S(98,b|0,48540,1006);a=x[31737];x[31737]=0;if((a|0)!=1){break a}a=N()|0;tb(c);break b}a=(x[a+32>>2]+D(b,872)|0)+1075080|0;x[a>>2]=x[a>>2]|c;fb=d+16|0;return}a=N()|0;jc(b)}Q(a|0)}p()}function Q8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=x[a+84>>2];f=x[e>>2];d=x[e+4>>2];h=x[a+28>>2];g=x[a+20>>2]-h|0;g=d>>>0<g>>>0?d:g;if(g){yc(f,h,g);f=g+x[e>>2]|0;x[e>>2]=f;d=x[e+4>>2]-g|0;x[e+4>>2]=d}d=c>>>0>d>>>0?d:c;if(d){yc(f,b,d);f=d+x[e>>2]|0;x[e>>2]=f;x[e+4>>2]=x[e+4>>2]-d}v[f|0]=0;b=x[a+44>>2];x[a+28>>2]=b;x[a+20>>2]=b;return c|0}function IN(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{b:{c:{if(b-513>>>0<=4294966814){b=ac(8);x[31737]=0;c=P(36,c+4|0,9379)|0;a=x[31737];x[31737]=0;if((a|0)==1){break c}pc(b,c);x[31737]=0;S(98,b|0,48540,1006);a=x[31737];x[31737]=0;if((a|0)!=1){break a}a=N()|0;tb(c);break b}x[x[a+32>>2]+1074420>>2]=D(b,1e4);fb=c+16|0;return}a=N()|0;jc(b)}Q(a|0)}p()}function ZB(a,b,c,d,e,f){var g=0,h=0,i=0;g=fb-16|0;fb=g;if(2147483631-b>>>0>=c>>>0){h=Jb(a);i=g+4|0;if(b>>>0<=1073741798){x[g+12>>2]=b<<1;x[g+4>>2]=b+c;c=Dh(x[ad(i,g+12|0)>>2])+1|0}else{c=2147483631}sg(i,c);c=x[g+4>>2];if(e){Xg(c,h,e)}if((d|0)!=(e|0)){Xg((c+e|0)+f|0,e+h|0,d-e|0)}if((b|0)!=10){Db(h)}yd(a,c);of(a,x[g+8>>2]);fb=g+16|0;return}pf();p()}function GQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=fb-16|0;fb=d;e=YD(b,c);a:{if(e>>>0<=dp(a)>>>0){x[d+12>>2]=c;g=x[a>>2];f=Vc(g,x[a+4>>2]);h=f>>>0>=e>>>0;if(h){f=c}else{x[d+12>>2]=b;j$(d+12|0,f);f=x[d+12>>2]}b=Br(b,f,g);if(!h){XD(a,x[d+12>>2],c,e-Vc(x[a>>2],x[a+4>>2])|0);break a}or(a,b);break a}_v(a);$k(a,bm(a,e));XD(a,b,c,e)}fb=d+16|0}function Asa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=fb-576|0;fb=d;c=fb-16|0;fb=c;a_(c+8|0,d);e=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);f=x[c+4>>2];if((f|0)==(e|0)){gd(a,x[c+12>>2])}fb=c+16|0;e=(e|0)==(f|0);if(!e){$Z(d)}c=-1;a:{if(!e){break a}c=0;if(!c_(d)){break a}c=ve(a,b,b_(y[d+34|0]|y[d+35|0]<<8,y[d+36|0]|y[d+37|0]<<8),hb)}fb=d+576|0;return c|0}function s6(a){a=a|0;if(y[500536]){return x[125133]}if(!y[500888]){v[500888]=1}id(500720,5240);id(500732,5247);id(500744,5213);id(500756,5221);id(500768,5204);id(500780,5254);id(500792,5231);id(500804,9774);id(500816,9980);id(500828,11310);id(500840,12946);id(500852,5503);id(500864,10813);id(500876,6622);v[500536]=1;x[125133]=500720;return 500720}function zR(a){var b=0,c=0;a:{if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=1163089229){break a}b=y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24);if((b|0)!=-1095062050&(b|0)!=-1346458146){break a}b=y[a+16|0]|y[a+17|0]<<8|(y[a+18|0]<<16|y[a+19|0]<<24);if(!b){break a}c=(b+24|0)==(y[a+8|0]|y[a+9|0]<<8|(y[a+10|0]<<16|y[a+11|0]<<24))}return c}function eua(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=fb-16|0;fb=e;a:{if(!(c&1024)){break a}f=e,g=zd(b),x[f+12>>2]=g;c=Yc(x[b+4>>2],y[b+11|0]);b:{if(!c){break b}if(y[cc(b,0)|0]!=43){if(y[cc(b,0)|0]!=45){break b}}d=d+1|0;vV(e+12|0)}if(c>>>0>=d>>>0){break a}JE(b,x[vb(e+8|0,x[e+12>>2])>>2],d-Yc(x[b+4>>2],y[b+11|0])|0,48)}_c(a,b);fb=e+16|0}function Dsa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;if(A[a+4>>2]<A[zb(a)>>2]){d=fb-16|0;fb=d;a=Tg(d+4|0,a,1);i_(x[a+4>>2],z[b>>1],y[c|0]);x[a+4>>2]=x[a+4>>2]+4;hc(a);fb=d+16|0;return}e=fb-32|0;fb=e;d=zb(a);d=$f(e+12|0,Mf(a,oc(x[a>>2],x[a+4>>2])+1|0),oc(x[a>>2],x[a+4>>2]),d);i_(x[d+8>>2],z[b>>1],y[c|0]);x[d+8>>2]=x[d+8>>2]+4;bs(a,d);_f(d);fb=e+32|0}function D_(a){var b=0,c=0;a:{if(kd(a,13968,3)|(y[a+3|0]-1&255)>>>0>3){break a}if(Bb(y[a+196|0]|y[a+197|0]<<8)>>>0>255){break a}if((Bb(y[a+198|0]|y[a+199|0]<<8)-1&65535)>>>0>255){break a}if((Bb(y[a+200|0]|y[a+201|0]<<8)-1&65535)>>>0>31){break a}b=Bb(y[a+202|0]|y[a+203|0]<<8);if(b>>>0>256){break a}c=Bb(y[a+204|0]|y[a+205|0]<<8)>>>0<b>>>0}return c}function Lo(a,b,c,d){a:{if(x[a+480180>>2]==4){d=y[b+810|0];if(c){v[b+810|0]=d&240|c;break a}c=d&15;break a}if(d){if(c){v[b+834|0]=c;break a}c=y[b+834|0];break a}if(c){v[b+810|0]=c;break a}c=y[b+810|0]}b:{if(!(v[b+851|0]&1)){break b}c=x[b+688>>2]-((c&255)<<2)|0;x[b+688>>2]=(c|0)>0?c:0;if(!(v[a+480180|0]&1)){break b}x[b+88>>2]=x[b+88>>2]|2097152}}function Px(a,b,c,d){v[a+53|0]=1;a:{if(x[a+4>>2]!=(c|0)){break a}v[a+52|0]=1;c=x[a+16>>2];b:{if(!c){x[a+36>>2]=1;x[a+24>>2]=d;x[a+16>>2]=b;if((d|0)!=1){break a}if(x[a+48>>2]==1){break b}break a}if((b|0)==(c|0)){c=x[a+24>>2];if((c|0)==2){x[a+24>>2]=d;c=d}if(x[a+48>>2]!=1){break a}if((c|0)==1){break b}break a}x[a+36>>2]=x[a+36>>2]+1}v[a+54|0]=1}}function JN(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{b:{c:{if(b-65536>>>0<=4294901760){b=ac(8);x[31737]=0;c=P(36,c+4|0,5848)|0;a=x[31737];x[31737]=0;if((a|0)==1){break c}pc(b,c);x[31737]=0;S(98,b|0,48540,1006);a=x[31737];x[31737]=0;if((a|0)!=1){break a}a=N()|0;tb(c);break b}x[x[a+32>>2]+1074416>>2]=b;fb=c+16|0;return}a=N()|0;jc(b)}Q(a|0)}p()}function GE(a,b,c,d){var e=0,f=0;a:{e=y[a|0];f=y[c|0];b:{if(!(y[d|0]|((e|0)!=11|(f-5&255)>>>0>1))){v[a|0]=(f|0)==5?7:6;break b}if(!(y[b|0]|((f|0)!=11|(e-5&255)>>>0>1))){v[a|0]=(e|0)==5?7:6;v[b|0]=y[d|0];break b}if(!((e|0)!=10|(f|0)!=20|y[d|0]!=159)){v[a|0]=42;break b}if((f|0)!=10|(e|0)!=20|y[b|0]!=159){break a}v[a|0]=42;v[b|0]=y[d|0]}v[c|0]=0}}function vM(a){var b=0,c=0,d=0,e=0,f=0,g=0;a:{b=x[a>>2];b:{if(!b){break b}c=x[a+8>>2];if(!c){break b}d=x[a+12>>2];if(!d){break b}a=ib[d|0](b)|0;e=hb;if((e|0)<0){break b}if((ib[c|0](b,0,0,0)|0)<0){break a}if((ib[c|0](b,0,0,2)|0)<0){break a}d=ib[d|0](b)|0;f=hb;ib[c|0](b,a,e,0)|0;if((f|0)<0){break b}g=Su(d,f)}return g}ib[c|0](b,a,e,0)|0;return 0}function kl(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;f=fb-16|0;fb=f;x[f+8>>2]=a;x[f+12>>2]=b;h=x[a+8>>2]+120|0;_t(y[h+20|0]);g=fb-16|0;fb=g;x[g+12>>2]=f+8;e=fb-16|0;fb=e;i=x[d+4>>2];x[e+8>>2]=x[d>>2];x[e+12>>2]=i;d=x[c+4>>2];x[e>>2]=x[c>>2];x[e+4>>2]=d;ib[x[tq(e,yk(y[h+20|0]))>>2]](g+12|0,h);fb=e+16|0;fb=g+16|0;x[a+4>>2]=x[a+4>>2]+x[b+8>>2];fb=f+16|0}function Xf(a,b,c,d){var e=0,f=0,g=0;a:{if(!Cb(x[a+4>>2],y[a+11|0])|(c-b|0)<5){break a}jt(b,c);e=c-4|0;c=Jb(a);g=c+Cb(x[a+4>>2],y[a+11|0])|0;b:{while(1){c:{a=v[c|0];f=a-127|0;if(b>>>0>=e>>>0){break c}if((a|0)!=x[b>>2]&(f&255)>>>0>=130){break b}b=b+4|0;c=((g-c|0)>1)+c|0;continue}break}if((f&255)>>>0<130|a>>>0>x[e>>2]-1>>>0){break a}}x[d>>2]=4}}function TH(a,b,c,d,e,f,g){var h=0,i=0,j=0;h=fb-16|0;fb=h;a:{b:{c:{if(b<g|b>f){a=ac(8);x[31737]=0;d=P(36,h+4|0,e|0)|0;e=x[31737];x[31737]=0;if((e|0)==1){break c}pc(a,d);x[31737]=0;S(98,a|0,48540,1006);a=x[31737];x[31737]=0;if((a|0)!=1){break a}e=N()|0;tb(d);break b}i=x[a+32>>2]+d|0,j=Ze(b*c),x[i>>2]=j;fb=h+16|0;return}e=N()|0;jc(a)}Q(e|0)}p()}function Rfa(a){a=a|0;var b=0;x[31737]=0;W(1002,a|0);b=x[31737];x[31737]=0;a:{b:{if((b|0)!=1){x[a+16>>2]=0;b=x[a+20>>2];if(!b){break b}Db(b);x[a+20>>2]=0;return}Y(T(0)|0)|0;x[31737]=0;V(989,8932,a|0,0,0);a=x[31737];x[31737]=0;if((a|0)==1){break a}Z()}return}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function R3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb+-64|0;fb=d;e=1;a:{if(mh(a,b,0)){break a}e=0;if(!b){break a}b=gB(b,124656,124704);e=0;if(!b){break a}Rb(d+12|0,0,52);x[d+56>>2]=1;x[d+20>>2]=-1;x[d+16>>2]=a;x[d+8>>2]=b;ib[x[x[b>>2]+28>>2]](b,d+8|0,x[c>>2],1);a=x[d+32>>2];if((a|0)==1){x[c>>2]=x[d+24>>2]}e=(a|0)==1}a=e;fb=d- -64|0;return a|0}function CF(a,b){var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;a:{if(b>>>0<3){if(!b){break a}if(!Mb(x[a>>2],x[a+8>>2],b)){break a}while(1)if((d|0)==2){hj(c+10|0,z[c+14>>1]);d=z[c+10>>1];break a}else{v[c+13|0]=0;f=(c+14|0)+d|0;if(b>>>0>d>>>0){fh(a,c+13|0);e=y[c+13|0]}else{e=0}v[f|0]=e;d=d+1|0;continue}}_(11251,9095,325,14260);p()}fb=c+16|0;return d&65535}function kka(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=fb-16|0;fb=b;w[a>>1]=0;c=Nb(a+4|0);d=Nb(a+16|0);x[a+36>>2]=0;e=Fb(a+40|0);f=qg(a+52|0);Nf(c);w[a+28>>1]=65472;x[31737]=0;x[b+12>>2]=1065353216;O(883,c|0,b+12|0);g=x[31737];x[31737]=0;if((g|0)!=1){x[a+32>>2]=0;w[a+30>>1]=0;Nf(d);fb=b+16|0;return a|0}a=N()|0;HZ(f);tb(e);vc(d);vc(c);Q(a|0);p()}function g1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a:{e=fb-32|0;fb=e;f=e+8|0;EE(f,c);c=y[d|0];x[31737]=0;O(244,e+20|0,c|0);c=x[31737];x[31737]=0;b:{c:{if((c|0)!=1){rk(e,f);x[31737]=0;V(93,a|0,b|0,x[e>>2],x[e+4>>2]);a=x[31737];x[31737]=0;if((a|0)==1){break c}Ag(f);fb=e+32|0;break a}a=N()|0;tb(e+8|0);break b}a=N()|0;Ag(e+8|0)}Q(a|0);p()}}function YI(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;a=wJ(a,c);x[a>>2]=113192;c=xk(Jb(b));x[a+16>>2]=c;a:{b:{c:{if(!c){x[31737]=0;c=d+4|0;S(1008,c|0,18024,b|0);b=x[31737];x[31737]=0;if((b|0)==1){break c}x[31737]=0;W(1325,c|0);b=x[31737];x[31737]=0;if((b|0)!=1){break a}b=N()|0;tb(c);break b}fb=d+16|0;return a|0}b=N()|0}Zs(a);Q(b|0)}p()}function Pfa(a){a=a|0;var b=0;x[31737]=0;W(1002,a|0);b=x[31737];x[31737]=0;a:{b:{if((b|0)!=1){a=x[a+20>>2];if(!a){break b}return Bg(a)|0}Y(T(0)|0)|0;x[31737]=0;V(989,12259,a|0,0,0);a=x[31737];x[31737]=0;if((a|0)==1){break a}Z();return 0}return Bg(22303)|0}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function y2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=fb-16|0;fb=d;x[d>>2]=b;x[d+4>>2]=c;x[d+8>>2]=b;x[d+12>>2]=c;f=fb-16|0;fb=f;g=fb-16|0;fb=g;e=g+4|0;x[e+4>>2]=1;h=e,i=Ec(24),x[h+8>>2]=i;b=ym(x[e+8>>2]);x[b>>2]=78600;EG(nc(b),x[d>>2],x[d+4>>2]);c=f+8|0;b=Wn(e);Vn(c,nc(b),b);zm(e);fb=g+16|0;Ef(a,c);ke(c);fb=f+16|0;fb=d+16|0}function uba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=x[b+1298404>>2];b=fb-32|0;fb=b;e=b+8|0;Wf(e,c);x[31737]=0;c=b+20|0;S(503,c|0,d|0,e|0);d=x[31737];x[31737]=0;b:{c:{if((d|0)!=1){x[31737]=0;S(245,a|0,0,c|0);a=x[31737];x[31737]=0;if((a|0)==1){break c}Ub(c);tb(e);fb=b+32|0;break a}a=N()|0;break b}a=N()|0;Ub(b+20|0)}tb(b+8|0);Q(a|0);p()}}function pk(a,b){a:{if((b|0)>=1024){a=a*898846567431158e293;if(b>>>0<2047){b=b-1023|0;break a}a=a*898846567431158e293;b=((b|0)>=3069?3069:b)-2046|0;break a}if((b|0)>-1023){break a}a=a*2004168360008973e-307;if(b>>>0>4294965304){b=b+969|0;break a}a=a*2004168360008973e-307;b=((b|0)<=-2960?-2960:b)+1938|0}l(0,0);l(1,b+1023<<20);return a*+n()}function mv(a,b){var c=0,d=0;if(a-268435457>>>0>=4026531840){a=a+208|0;c=D(a,b);Sua(b,0,a,0);a=hb?0:c}else{a=0}a:{if(!a){break a}x[31737]=0;b=R(783,a|0)|0;c=x[31737];x[31737]=0;b:{c:{if((c|0)==1){Y(T(0)|0)|0;x[31737]=0;X(26);c=x[31737];x[31737]=0;b=0;if((c|0)==1){break c}}break b}T(0)|0;Sb();p()}if(!b){break a}d=Rb(b,0,a)- -64|0}return d}function kta(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=fb-112|0;fb=d;c=fb-16|0;fb=c;f=d+14|0;T_(c+8|0,f);e=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(e|0)){gd(a,x[c+12>>2])}fb=c+16|0;e=(e|0)==(g|0);if(!e){S_(f)}c=-1;a:{if(!e){break a}c=0;if(!V_(f)){break a}c=ve(a,b,U_(y[d+61|0]|y[d+62|0]<<8),hb)}fb=d+112|0;return c|0}function PG(a){var b=0;if(!((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=1129474426|(y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24))!=1634291279|(y[a+8|0]|y[a+9|0]<<8)!=14|(!(y[a+12|0]|y[a+13|0]<<8)|(y[a+14|0]|y[a+15|0]<<8|(y[a+16|0]<<16|y[a+17|0]<<24))<=0))){b=(y[a+18|0]|y[a+19|0]<<8|(y[a+20|0]<<16|y[a+21|0]<<24))>>>0>23}return b}function LT(a,b,c,d,e){var f=0,g=0,h=0,i=0;f=fb-16|0;fb=f;i=x[d+20>>2];h=x[d+52>>2];g=!h|e;v[f+15|0]=g;a:{if(!g|(b|0)!=2){break a}g=c&65535;c=0;while(1){if((c|0)==(g|0)){break a}x[(D(c,872)+d|0)+1380>>2]=0;c=c+1|0;continue}}x[d+24>>2]=0;x[d+16>>2]=0;x[d+20>>2]=0;x[d+48>>2]=h;w[d+72>>1]=z[d+74>>1];de(a,i>>>0>1&e&(b|0)==1,f+15|0);fb=f+16|0}function Cea(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;x[31737]=0;W(1002,a|0);f=x[31737];x[31737]=0;if((f|0)!=1){return eu(x[x[a+24>>2]+24>>2],b,c,d,e)|0}Y(T(0)|0)|0;x[31737]=0;V(989,12502,a|0,0,0);a=x[31737];x[31737]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function hf(a,b,c){var d=0,e=0,f=0;e=Fb(a);d=y[b+11|0];f=x[b+4>>2];a=0;x[31737]=0;O(53,e|0,Yc(f,d)|0);d=x[31737];x[31737]=0;if((d|0)!=1){a:{while(1){if(Yc(x[b+4>>2],y[b+11|0])>>>0>a>>>0){d=x[(y[cc(b,a)|0]<<2)+c>>2];x[31737]=0;O(35,e|0,d|0);d=x[31737];x[31737]=0;if((d|0)==1){break a}a=a+1|0;continue}break}return}}a=N()|0;Ub(e);Q(a|0);p()}function h7(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;while(1){a:{if((c|0)==(d|0)|e>>>0<=h>>>0){break a}f=1;g=fb-16|0;fb=g;k=Nh(g+12|0,x[a+8>>2]);i=xt(0,c,d-c|0,b?b:500252);Mh(k);fb=g+16|0;b:{switch(i+2|0){default:f=i;break;case 0:case 1:break a;case 2:break b}}h=h+1|0;j=f+j|0;c=c+f|0;continue}break}return j|0}function ara(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;c=yb(b,c);d=fb-16|0;fb=d;e=Sd(b,c);a:{if(e>>>0<=Ug(a)>>>0){f=c;g=x[a>>2];h=oc(g,x[a+4>>2]);i=h>>>0>=e>>>0;if(!i){x[d+12>>2]=b;$C(d+12|0,h);f=x[d+12>>2]}b=Wg(b,f,g);if(!i){IY(a,f,c,e-oc(x[a>>2],x[a+4>>2])|0);break a}Ih(a,b);break a}tr(a);qm(a,Mf(a,e));IY(a,b,c,e)}fb=d+16|0}function QB(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+23|0]=0;v[a+24|0]=0;v[a+25|0]=0;v[a+26|0]=0;v[a+16|0]=0;v[a+17|0]=0;v[a+18|0]=0;v[a+19|0]=0;v[a+20|0]=0;v[a+21|0]=0;v[a+22|0]=0;v[a+23|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a+12|0]=0;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0}function z1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=fb-512|0;fb=d;c=fb-16|0;fb=c;f=d+15|0;pF(c+8|0,f);e=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(e|0)){gd(a,x[c+12>>2])}fb=c+16|0;e=(e|0)==(g|0);if(!e){oF(f)}c=-1;a:{if(!e){break a}c=0;if(!rF(f)){break a}c=ve(a,b,qF(y[d+125|0],y[d+126|0]),hb)}fb=d+512|0;return c|0}function h2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=fb-32|0;fb=e;f=x[b+16>>2];a:{if(f>>>0<=c>>>0){bc(a,x[d>>2],0);break a}g=x[b+12>>2];b=x[b+4>>2];x[e+20>>2]=x[d+4>>2];x[e+16>>2]=f-c;bc(e+24|0,x[d>>2],x[Gb(e+20|0,e+16|0)>>2]);d=x[x[b>>2]+28>>2];f=x[e+28>>2];x[e+8>>2]=x[e+24>>2];x[e+12>>2]=f;ib[d|0](a,b,c+g|0,e+8|0)}fb=e+32|0}function WK(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=fb-16|0;fb=b;e=b+16|0;a:{while(1){d=x[a+36>>2];c=b+8|0;f=ib[x[x[d>>2]+20>>2]](d,x[a+40>>2],c,e,b+4|0)|0;d=-1;g=c;c=x[b+4>>2]-c|0;if((Tk(g,1,c,x[a+32>>2])|0)!=(c|0)){break a}b:{switch(f-1|0){case 1:break a;case 0:continue;default:break b}}break}d=hu(x[a+32>>2])?-1:0}fb=b+16|0;return d|0}function RJ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=fb-16|0;fb=d;i=x[b>>2];h=x[a>>2];e=x[ec(a)>>2]==1232;f=x[c>>2];g=f-h|0;f=g>>>0>=2147483647?-1:(h|0)==(f|0)?4:g<<1;g=Nv(e?0:h,f);if(g){if(!e){me(a)}x[d+4>>2]=1199;e=Be(d+8|0,g,d+4|0);a=OJ(a,e);Lc(e);x[b>>2]=x[a>>2]+(i-h|0);x[c>>2]=x[a>>2]+(f&-4);fb=d+16|0;return}Pv();p()}function cT(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;d=x[a+16>>2];e=d?y[(D(b,872)+a|0)+1429|0]:e;f=x[a+40>>2];b=D(b,872)+a|0;a=b+1467|0;v[a|0]=y[a|0]|64;a=b+1468|0;h=a;i=x[a>>2];g=(+(d>>>0)+1)*+(c|0)/+(f>>>0);a:{if(F(g)<2147483648){a=~~g;break a}a=-2147483648}x[h>>2]=i+(a+((c|0)<0?e:0-e|0)|0);c=(d+1|0)==(f|0)?c:a;a=c>>31;v[b+1429|0]=(a^c)-a}function Vja(a){a=a|0;var b=0,c=0,d=0;b=fb-32|0;fb=b;v[b+23|0]=0;v[b+24|0]=0;v[b+25|0]=0;v[b+26|0]=0;v[b+27|0]=0;v[b+28|0]=0;v[b+29|0]=0;v[b+30|0]=0;x[b+16>>2]=0;x[b+20>>2]=0;d=b+16|0;c=gc(b,d,15);lc(b+8|0,x[a>>2],x[a+8>>2],x[c>>2],x[c+4>>2]);c=0;a:{if(x[b+12>>2]!=15){break a}if(kd(d,8525,15)){break a}Vb(a,15);c=1}fb=b+32|0;return c|0}function Pqa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a:{e=fb-32|0;fb=e;f=e+8|0;Mr(f,c);x[31737]=0;O(598,e+20|0,d|0);c=x[31737];x[31737]=0;b:{c:{if((c|0)!=1){rk(e,f);x[31737]=0;V(302,a|0,b|0,x[e>>2],x[e+4>>2]);a=x[31737];x[31737]=0;if((a|0)==1){break c}Ag(f);fb=e+32|0;break a}a=N()|0;tb(e+8|0);break b}a=N()|0;Ag(e+8|0)}Q(a|0);p()}}function Ota(a,b){a=a|0;b=b|0;var c=0,d=0;b=fb-32|0;fb=b;d=b+20|0;c=-1;a:{if(!$D(a,d)){break a}c=0;if(!x$(d)){break a}if((y[b+20|0]|y[b+21|0]<<8|(y[b+22|0]<<16|y[b+23|0]<<24))==1179472708){c=-1;if(!gd(a,4)){break a}}c=-1;if(!nk(a,b+12|0)){break a}c=(y[b+12|0]|y[b+13|0]<<8|(y[b+14|0]<<16|y[b+15|0]<<24))==1196314451}fb=b+32|0;return c|0}function DF(a,b){var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;a:{if(b>>>0<5){if(!b){break a}if(!Mb(x[a>>2],x[a+8>>2],b)){break a}while(1)if((d|0)==4){Qm(c+4|0,x[c+12>>2]);d=x[c+4>>2];break a}else{v[c+11|0]=0;f=(c+12|0)+d|0;if(b>>>0>d>>>0){fh(a,c+11|0);e=y[c+11|0]}else{e=0}v[f|0]=e;d=d+1|0;continue}}_(11251,9095,325,14260);p()}fb=c+16|0;return d}function Kqa(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);Rd(c+8|0,x[vb(c+4|0,a)>>2]);a:{if(!b){break a}x[31737]=0;O(591,a|0,b|0);d=x[31737];x[31737]=0;if((d|0)!=1){x[31737]=0;O(592,a|0,b|0);b=x[31737];x[31737]=0;if((b|0)!=1){break a}}a=N()|0;xY(c+8|0);Q(a|0);p()}b=c+8|0;Qd(b);xY(b);fb=c+16|0;return a|0}function Caa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=fb-16|0;fb=e;g=x[d+4>>2];nz(b,c,g);f=x[b+16>>2];a:{if(f>>>0<=c>>>0){bc(a,x[d>>2],0);break a}x[e+12>>2]=f-c;x[e+8>>2]=g;d=x[d>>2];f=x[Gb(e+12|0,e+8|0)>>2];Cr(e,d,g,0,f);h=x[e>>2];i=x[e+4>>2];Br(uf(wb(x[b+4>>2]),c),uf(wb(x[b+4>>2]),c+i|0),h);Cr(a,d,g,0,f)}fb=e+16|0}function r1(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);Rd(c+8|0,x[vb(c+4|0,a)>>2]);a:{if(!b){break a}x[31737]=0;O(227,a|0,b|0);d=x[31737];x[31737]=0;if((d|0)!=1){x[31737]=0;O(228,a|0,b|0);b=x[31737];x[31737]=0;if((b|0)!=1){break a}}a=N()|0;VE(c+8|0);Q(a|0);p()}b=c+8|0;Qd(b);VE(b);fb=c+16|0;return a|0}function Qsa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a:{e=fb-32|0;fb=e;f=e+8|0;e_(f,c);x[31737]=0;O(92,e+20|0,d|0);c=x[31737];x[31737]=0;b:{c:{if((c|0)!=1){rk(e,f);x[31737]=0;V(93,a|0,b|0,x[e>>2],x[e+4>>2]);a=x[31737];x[31737]=0;if((a|0)==1){break c}Ag(f);fb=e+32|0;break a}a=N()|0;tb(e+8|0);break b}a=N()|0;Ag(e+8|0)}Q(a|0);p()}}function Or(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=wb(x[b>>2]);g=wb(x[b+4>>2]);e=fb-16|0;fb=e;x[e+12>>2]=d;while(1){a:{if(!Ib(d,g)){break a}f=fb-16|0;fb=f;wi(f+8|0,x[d>>2],x[d+4>>2]);h=$b(x[f+8>>2]);fb=f+16|0;if((c|0)==(h|0)){break a}d=x[lm(e+12|0)>>2];continue}break}fb=e+16|0;if(mc(d,wb(x[b+4>>2]))){ai(a);return}qp(a,d)}function CP(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;b=fb-16|0;fb=b;a=Nb(a);x[31737]=0;c=b+4|0;W(992,c|0);d=x[31737];x[31737]=0;a:{b:{if((d|0)!=1){d=wb(x[b+4>>2]);e=wb(x[b+8>>2]);f=x[vb(b,a)>>2];x[31737]=0;S(993,d|0,e|0,f|0);d=x[31737];x[31737]=0;if((d|0)==1){break b}vc(c);fb=b+16|0;return}c=N()|0;break a}c=N()|0;vc(b+4|0)}Td(a);Q(c|0);p()}
function ioa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;c=fb-16|0;fb=c;x[c+12>>2]=4925421;x[c+8>>2]=2147483647;e=Gb(c+12|0,c+8|0);fb=c+16|0;if(A[e>>2]<b>>>0){dd();p()}if(b>>>0>=4925422){Zj();p()}c=Ec(D(b,872));x[d+12>>2]=b;x[d+8>>2]=c;b=x[d+8>>2];x[a+4>>2]=b;x[a>>2]=b;f=zb(a),g=b+D(x[d+12>>2],872)|0,x[f>>2]=g;fb=d+16|0}function X4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a:{e=fb-32|0;fb=e;f=e+8|0;co(f,c);x[31737]=0;O(92,e+20|0,d|0);c=x[31737];x[31737]=0;b:{c:{if((c|0)!=1){rk(e,f);x[31737]=0;V(93,a|0,b|0,x[e>>2],x[e+4>>2]);a=x[31737];x[31737]=0;if((a|0)==1){break c}Ag(f);fb=e+32|0;break a}a=N()|0;tb(e+8|0);break b}a=N()|0;Ag(e+8|0)}Q(a|0);p()}}function Tha(a){a=a|0;var b=0,c=0,d=0,e=0;b=fb-16|0;fb=b;x[x[a+20>>2]+148>>2]=-1;Pr(b+8|0,a+4228|0);c=x[a+20>>2];d=wb(x[b+8>>2]);e=Wk(x[b+8>>2],x[b+12>>2]);x[31737]=0;S(971,c+4|0,d|0,e|0);c=x[31737];x[31737]=0;a:{if((c|0)==1){c=T(125048)|0;if((gb|0)!=($(125048)|0)){break a}Y(c|0)|0;ep(x[a+20>>2]+4|0);Z()}fb=b+16|0;return}Q(c|0);p()}function CE(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a:{e=fb-32|0;fb=e;f=e+8|0;xw(f,c);x[31737]=0;O(92,e+20|0,d|0);c=x[31737];x[31737]=0;b:{c:{if((c|0)!=1){rk(e,f);x[31737]=0;V(93,a|0,b|0,x[e>>2],x[e+4>>2]);a=x[31737];x[31737]=0;if((a|0)==1){break c}Ag(f);fb=e+32|0;break a}a=N()|0;tb(e+8|0);break b}a=N()|0;Ag(e+8|0)}Q(a|0);p()}}function $c(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=fb-16|0;fb=d;fl(b);e=a+8|0;f=yf(d+12|0,b);a:{b=x[a+8>>2];if(oc(b,x[a+12>>2])>>>0<=c>>>0){x[31737]=0;O(1286,e|0,c+1|0);a=x[31737];x[31737]=0;if((a|0)==1){break a}b=x[e>>2]}a=yb(b,c);b=x[a>>2];if(b){Am(b);a=yb(x[e>>2],c)}g=a,h=me(f),x[g>>2]=h;jJ(f);fb=d+16|0;return}a=N()|0;jJ(f);Q(a|0);p()}function tA(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=fb-16|0;fb=e;d=fb-32|0;fb=d;Id(d+24|0,a,b);b=fb-16|0;fb=b;f=x[d+28>>2];g=x[d+24>>2];h=f-g|0;i=b,j=ml(c,g,h)+D((h|0)/6|0,6)|0,x[i+12>>2]=j;Ac(d+16|0,f,b+12|0);fb=b+16|0;a=wR(a,x[d+16>>2]);i=d,j=rA(c,x[d+20>>2]),x[i+12>>2]=j;Ac(e+8|0,a,d+12|0);fb=d+32|0;fb=e+16|0;return x[e+12>>2]}function ld(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;sn(a);x[a+16>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[a>>2]=0;x[a+4>>2]=0;w[a+32>>1]=64;x[a+24>>2]=8363;x[a+28>>2]=16777344;x[a+36>>2]=0;v[a+39|0]=0;v[a+40|0]=0;v[a+41|0]=0;v[a+42|0]=0;d=z[a+34>>1]&-25151;w[a+34>>1]=(b|0)==4?d|32:d;b=Dc(c+4|0,22303);ze(a+43|0,b);tb(b);oW(a);fb=c+16|0}function wua(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;bc(c+8|0,b,10);d=x[c+12>>2];lc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b+6|0]=0;v[b+7|0]=0;v[b+8|0]=0;v[b+9|0]=0}return a|0}function Esa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;x[c+12>>2]=1;a:{if(Ug(a)){d=x[a>>2];e=oc(d,x[a+4>>2]);x[c+8>>2]=e;f=x[Gb(c+12|0,c+8|0)>>2];while(1){if(f){w[d>>1]=z[b>>1];v[d+2|0]=y[b+2|0];f=f-1|0;d=d+4|0;continue}break}if(!e){l_(a,1-e|0,b);break a}Ih(a,x[a>>2]+4|0);break a}tr(a);qm(a,Mf(a,1));l_(a,1,b)}fb=c+16|0}function jQ(a){a=a|0;var b=0,c=0;c=fb-16|0;fb=c;b=x[x[a+16>>2]+24620>>2]/5|0;b=Gc(b,b>>31);x[a+4272>>2]=b;x[31737]=0;x[c+12>>2]=0;S(953,a+4256|0,b<<1,c+12|0);b=x[31737];x[31737]=0;a:{if((b|0)==1){b=T(125048)|0;if((gb|0)!=($(125048)|0)){break a}Y(b|0)|0;x[a+4272>>2]=0;Z()}x[a+4276>>2]=0;x[a+4268>>2]=0;fb=c+16|0;return}Q(b|0);p()}function Wha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Qi(a,b,c,d);x[a>>2]=43408;c=Nb(a+4208|0);x[a+4220>>2]=0;x[a+4224>>2]=1056964608;b=a+4228|0;v[b+4|0]=0;v[b+5|0]=4;v[b|0]=69;v[b+1|0]=99;v[b+2|0]=104;v[b+3|0]=111;v[b+6|0]=1;x[31737]=0;O(947,a+44|0,2);b=x[31737];x[31737]=0;if((b|0)!=1){ku(a);return a|0}b=N()|0;vc(c);ag(a);Q(b|0);p()}function Sq(a){var b=0,c=0,d=0,e=0,f=0;d=fb-16|0;fb=d;b=wb(x[a>>2]);f=wb(x[a+4>>2]);e=fb-16|0;fb=e;x[e+12>>2]=b;while(1){if(Ib(b,f)){c=c+C[b>>3];b=x[Yu(e+12|0)>>2];continue}break}fb=e+16|0;b=wb(x[a>>2]);x[d+12>>2]=b;c=-c;a=wb(x[a+4>>2]);while(1){if(Ib(b,a)){c=c+C[b>>3];C[b>>3]=c;b=x[Yu(d+12|0)>>2];continue}else{fb=d+16|0}break}}function Ms(a,b,c,d,e,f){var g=0,h=0;g=fb-16|0;fb=g;x[g+12>>2]=d;d=g+12|0;h=x[qe(g+8|0,d)>>2];x[31737]=0;ha(f|0,a+8|0,b|0,c|0,h|0,e|0)|0;b=x[31737];x[31737]=0;if((b|0)!=1){a=Ez(a);b=Dz(a+88|0);c=Cz(a+92|0);e=Bz(a+96|0);x[a>>2]=47820;x[b>>2]=47936;x[c>>2]=48016;x[e>>2]=48056;Uc(d);fb=g+16|0;return a}a=N()|0;Uc(g+12|0);Q(a|0);p()}function Gla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-32|0;fb=d;e=d+8|0;Rv(e,c);x[31737]=0;O(475,d+20|0,41724);c=x[31737];x[31737]=0;b:{c:{if((c|0)!=1){rk(d,e);x[31737]=0;V(93,a|0,b|0,x[d>>2],x[d+4>>2]);a=x[31737];x[31737]=0;if((a|0)==1){break c}Ag(e);fb=d+32|0;break a}a=N()|0;tb(d+8|0);break b}a=N()|0;Ag(d+8|0)}Q(a|0);p()}}function CM(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;c=x[a>>2];a:{if(!c){break a}d=x[a+8>>2];if(!d){break a}e=x[a+12>>2];if(!e){break a}a=ib[e|0](c)|0;f=hb;if((f|0)<0){break a}b=0;b:{if((ib[d|0](c,0,0,0)|0)<0){break b}b=0;if((ib[d|0](c,0,0,2)|0)<0){break b}ib[e|0](c)|0;b=hb;if((b|0)>0){b=1}else{b=(b|0)>=0}}ib[d|0](c,a,f,0)|0}return b|0}function nsa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-16|0;fb=d;x[d+12>>2]=c;a:{e=Mb(x[b>>2],x[b+8>>2],c<<2);if(!e){break a}wc(d+12|0,65535);xg(a,z[d+12>>1]);c=wb(x[a>>2]);x[d+4>>2]=c;a=wb(x[a+4>>2]);while(1){if(!Ib(c,a)){break a}f=d+8|0;if(!Sn(b,f)){Hn(f)}w[c>>1]=x[d+8>>2];c=x[Md(d+4|0)>>2];continue}}fb=d+16|0;return e|0}function F7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=fb-16|0;fb=d;i=x[b>>2];h=x[a>>2];e=x[ec(a)>>2]==1232;f=x[c>>2]-h|0;g=f<<1;f=f>>>0>=2147483647?-1:g>>>0<=1?1:g;g=Nv(e?0:h,f);if(g){if(!e){me(a)}x[d+4>>2]=1199;e=Be(d+8|0,g,d+4|0);a=OJ(a,e);Lc(e);x[b>>2]=x[a>>2]+(i-h|0);x[c>>2]=f+x[a>>2];fb=d+16|0;return}Pv();p()}function s9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=x[a+44>>2];c=x[a+24>>2];if(e>>>0<c>>>0){x[a+44>>2]=c;e=c}g=x[a+8>>2];f=x[a+12>>2];d=-1;a:{if(g>>>0>=f>>>0){break a}if(mc(b,-1)){ko(a,g,f-1|0,e);return Ly(b)|0}c=b<<24>>24;if(!(x[a+48>>2]&16)){d=-1;if(!mc(c,v[f-1|0])){break a}}ko(a,g,f-1|0,e);v[x[a+12>>2]]=c;d=b}return d|0}function OR(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;a:{b:{while(1){x[e+12>>2]=b;x[e+8>>2]=d;if(A[Gb(e+12|0,e+8|0)>>2]<=f>>>0){break b}g=Oq(v[xb(a,f)|0]);h=Oq(v[xb(c,f)|0]);if((g|0)!=(h|0)){a=g>>>0<h>>>0?-1:1;break a}f=f+1|0;if(g){continue}break}a=0;break a}a=0;if((b|0)==(d|0)){break a}a=b>>>0<d>>>0?-1:1}fb=e+16|0;return a}function mka(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;if(!Dd(x[a+1298300>>2])){b=x[a+24620>>2];d=fb-16|0;fb=d;e=Ec(536);x[31737]=0;f=P(878,e|0,b|0)|0;b=x[31737];x[31737]=0;a:{if((b|0)!=1){b=yf(d+12|0,f);fb=d+16|0;b=x[b>>2];break a}a=N()|0;Db(e);Q(a|0);p()}x[c+12>>2]=b;b=a+1298300|0;a=c+12|0;uS(b,me(a));WA(a)}fb=c+16|0}function gpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=fb-608|0;fb=d;c=fb-16|0;fb=c;lX(c+8|0,d);e=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);f=x[c+4>>2];if((f|0)==(e|0)){gd(a,x[c+12>>2])}fb=c+16|0;e=(e|0)==(f|0);if(!e){kX(d)}c=-1;a:{if(!e){break a}c=0;if(!nX(d)){break a}c=ve(a,b,mX(y[d+34|0]|y[d+35|0]<<8),hb)}fb=d+608|0;return c|0}function bja(a,b){a=a|0;b=b|0;var c=0,d=0;if(x[a+4>>2]!=x[zb(a)>>2]){c=fb-16|0;fb=c;a=Tg(c+4|0,a,1);zk(x[a+4>>2],B[b>>2]);x[a+4>>2]=x[a+4>>2]+4;hc(a);fb=c+16|0;return}d=fb-32|0;fb=d;c=zb(a);c=$f(d+12|0,Mf(a,oc(x[a>>2],x[a+4>>2])+1|0),oc(x[a>>2],x[a+4>>2]),c);zk(x[c+8>>2],B[b>>2]);x[c+8>>2]=x[c+8>>2]+4;mA(a,c);_f(c);fb=d+32|0}function JE(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;b=Fk(b,zd(a));a:{f=Cb(x[a+4>>2],y[a+11|0]);if(b>>>0<=f>>>0){if(c){e=Mc(a);b:{if(e-f>>>0>=c>>>0){e=Jb(a);if((b|0)==(f|0)){break b}g=b+e|0;Ui(g+c|0,g,f-b|0);break b}Wm(a,e,(c+f|0)-e|0,f,b,0,c);e=x[a>>2]}hm(b+e|0,c,d);b=c+f|0;ng(a,b);fd(b+e|0,0)}break a}jn();p()}zd(a)}function Dla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=fb-32|0;fb=e;x[e+28>>2]=d;c=Hf(a,c);d=e+8|0;$d(d,x[a+36>>2]);f=a;a:{if(!c){Pc(d,a+32|0,5);d=0;if(Hb(x[x[e+8>>2]>>2],x[e+12>>2])){break a}}d=x[a+36>>2];a=0;ZE(b,x[e+28>>2]);while(1){if(A[e+28>>2]>a>>>0){VU(d,_b(x[b>>2],a));a=a+1|0;continue}break}d=c}ff(f,d);fb=e+32|0}function mja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=fb-16|0;fb=e;f=x[a+8>>2];d=e+4|0;x[d+8>>2]=a+8;x[d>>2]=f;x[d+4>>2]=D(b,52)+f;b=x[d>>2];a:{while(1){if(x[d+4>>2]==(b|0)){break a}x[31737]=0;O(924,b|0,c|0);a=x[31737];x[31737]=0;if((a|0)!=1){b=x[d>>2]+52|0;x[d>>2]=b;continue}break}a=N()|0;he(d);Q(a|0);p()}he(d);fb=e+16|0}function fea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;x[31737]=0;W(1002,a|0);d=x[31737];x[31737]=0;if((d|0)!=1){x[a+16>>2]=0;x[a+12>>2]=c;x[a+8>>2]=b;return}Y(T(0)|0)|0;x[31737]=0;V(989,13123,a|0,0,0);a=x[31737];x[31737]=0;if((a|0)!=1){Z();return}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function csa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=x[a>>2];d=Vc(e,x[a+4>>2]);if(d>>>0<b>>>0){e=fb-32|0;fb=e;b=b-d|0;d=x[zb(a)>>2];f=x[a+4>>2];a:{if(b>>>0<=d-f>>>0){Fp(a,b,c);break a}d=zb(a);d=un(e+12|0,bm(a,Vc(x[a>>2],f)+b|0),Vc(x[a>>2],x[a+4>>2]),d);sZ(d,b,c);gr(a,d);tn(d)}fb=e+32|0;return}if(b>>>0<d>>>0){or(a,b+e|0)}}function M0(a,b){a=a|0;b=b|0;var c=0,d=0;if(x[a+4>>2]!=x[zb(a)>>2]){c=fb-16|0;fb=c;a=_h(c+4|0,a,1);fj(x[a+4>>2],z[b>>1]);x[a+4>>2]=x[a+4>>2]+2;hc(a);fb=c+16|0;return}d=fb-32|0;fb=d;c=zb(a);c=kk(d+12|0,lk(a,Zc(x[a>>2],x[a+4>>2])+1|0),Zc(x[a>>2],x[a+4>>2]),c);fj(x[c+8>>2],z[b>>1]);x[c+8>>2]=x[c+8>>2]+2;Yr(a,c);jj(c);fb=d+32|0}function C1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=fb-784|0;fb=e;c=fb-16|0;fb=c;f=e+12|0;yF(c+8|0,f);d=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(d|0)){gd(a,x[c+12>>2])}fb=c+16|0;d=(d|0)==(g|0);if(!d){xF(f)}c=-1;a:{if(!d){break a}c=0;if(!AF(f)){break a}c=ve(a,b,zF(y[e+527|0]),0)}fb=e+784|0;return c|0}function ho(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=a;e=fb-16|0;fb=e;a:{f=Sd(b,c);if(f>>>0<1073741808){b:{if(jr(f)){Me(d,f);break b}Uj(e+8|0,yn(f)+1|0);g=x[e+8>>2];yd(d,g);of(d,x[e+12>>2]);Yd(d,f);d=g}while(1){if((b|0)!=(c|0)){yd(d,x[b>>2]);d=d+4|0;b=b+4|0;continue}break}yd(d,0);fb=e+16|0;break a}pf();p()}return a|0}function x1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=fb-48|0;fb=e;c=fb-16|0;fb=c;f=e+10|0;hF(c+8|0,f);d=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(d|0)){gd(a,x[c+12>>2])}fb=c+16|0;d=(d|0)==(g|0);if(!d){gF(f)}c=-1;a:{if(!d){break a}c=0;if(!jF(f)){break a}c=ve(a,b,iF(y[e+45|0]),hb)}fb=e+48|0;return c|0}function si(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=a;e=fb-16|0;fb=e;a:{f=Vj(b,c);if(f>>>0<2147483632){b:{if(Rk(f)){Me(d,f);break b}sg(e+8|0,Dh(f)+1|0);g=x[e+8>>2];yd(d,g);of(d,x[e+12>>2]);Yd(d,f);d=g}while(1){if((b|0)!=(c|0)){fd(d,y[b|0]);d=d+1|0;b=b+1|0;continue}break}fd(d,0);fb=e+16|0;break a}pf();p()}return a|0}function j0(a,b,c,d){var e=0,f=0,g=0,h=0;e=Cb(x[a+4>>2],y[a+11|0]);if(e>>>0>=b>>>0){f=Mc(a);a:{if(f-e>>>0>=d>>>0){if(!d){break a}f=Jb(a);h=f+b|0;if((b|0)!=(e|0)){g=b+f|0;Ui(g+d|0,g,e-b|0);c=(c>>>0>=g>>>0?e+f>>>0>c>>>0?d:0:0)+c|0}Ui(h,c,d);b=d+e|0;ng(a,b);fd(b+f|0,0);return a}dq(a,f,(d+e|0)-f|0,e,b,0,d,c)}return a}jn();p()}function e3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=fb-16|0;fb=e;bd(a,x[b+28>>2]);x[31737]=0;d=e+12|0;S(109,d|0,b|0,c|0);f=x[31737];x[31737]=0;a:{if((f|0)==1){break a}Zb(d);b=x[b+24>>2];if(b){x[31737]=0;d=e+8|0;S(110,d|0,b|0,c|0);b=x[31737];x[31737]=0;if((b|0)==1){break a}Zb(d)}fb=e+16|0;return}b=N()|0;Zb(a);Q(b|0);p()}function b0(a){var b=0,c=0,d=0,e=0;if(!y[a+12|0]){c=fb-16|0;fb=c;b=vb(c+12|0,x[x[a+8>>2]>>2]);e=x[vb(c+8|0,x[x[a+4>>2]>>2])>>2];d=fb-16|0;fb=d;a=x[b>>2];x[d+12>>2]=a;while(1){if(ci(a,e)){b=fb-16|0;fb=b;x[b+12>>2]=a;x[b+12>>2]=x[b+12>>2]+28;fb=b+16|0;Fd(lE(x[b+12>>2]));a=x[lm(d+12|0)>>2];continue}break}fb=d+16|0;fb=c+16|0}}function Oj(a){var b=0,c=0,d=0,e=0,f=0;b=x[a+4>>2];if(mc(x[a>>2],b)){a=0}else{b=_i(b);e=_i(x[a>>2]);c=fb-16|0;fb=c;x[c+12>>2]=b;while(1){a:{if(!Zg(b,e)){break a}d=fb-16|0;fb=d;x[d+12>>2]=b;f=ij(d+12|0);fb=d+16|0;if(z[x[f>>2]>>1]!=65535){break a}b=x[ij(c+12|0)>>2];continue}break}fb=c+16|0;a=nE(wb(x[a>>2]),b)}return a&65535}function Js(a,b,c,d,e){var f=0,g=0;f=fb-16|0;fb=f;x[f+12>>2]=c;c=f+12|0;g=x[qe(f+8|0,c)>>2];x[31737]=0;ba(e|0,a+8|0,b|0,g|0,d|0)|0;b=x[31737];x[31737]=0;if((b|0)!=1){a=Ez(a);b=Dz(a+88|0);d=Cz(a+92|0);e=Bz(a+96|0);x[a>>2]=47820;x[b>>2]=47936;x[d>>2]=48016;x[e>>2]=48056;Uc(c);fb=f+16|0;return a}a=N()|0;Uc(f+12|0);Q(a|0);p()}function Wja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;a:{d=fb-32|0;fb=d;e=d+8|0;Vo(e,c);x[31737]=0;c=d+20|0;O(14,c|0,e|0);f=x[31737];x[31737]=0;b:{c:{if((f|0)!=1){x[31737]=0;S(845,a|0,b|0,c|0);a=x[31737];x[31737]=0;if((a|0)==1){break c}Ub(c);tb(e);fb=d+32|0;break a}a=N()|0;break b}a=N()|0;Ub(d+20|0)}tb(d+8|0);Q(a|0);p()}}function _F(a){var b=0,c=0;a:{if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=1179340888|(y[a+8|0]|y[a+9|0]<<8|(y[a+10|0]<<16|y[a+11|0]<<24))!=1213419859){break a}b=$b(y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24));if(!b){break a}c=($b(y[a+12|0]|y[a+13|0]<<8|(y[a+14|0]<<16|y[a+15|0]<<24))|0)!=0&b>>>0>27}return c}function Qia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=x[a>>2];c=oc(d,x[a+4>>2]);if(c>>>0<b>>>0){d=fb-32|0;fb=d;b=b-c|0;c=x[zb(a)>>2];e=x[a+4>>2];a:{if(b>>>0<=c-e>>2>>>0){Zq(a,b);break a}c=zb(a);c=$f(d+12|0,Mf(a,oc(x[a>>2],e)+b|0),oc(x[a>>2],x[a+4>>2]),c);jA(c,b);Ym(a,c);_f(c)}fb=d+32|0;return}if(b>>>0<c>>>0){Ih(a,d+(b<<2)|0)}}function jia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-32|0;fb=d;x[d+28>>2]=c;x[d+8>>2]=33;e=x[a>>2];f=x[a+8>>2];c=x[Gb(d+28|0,d+8|0)>>2];if(!Mb(e,f,c)){c=kf(a)}e=d+8|0;hD(e,b);f=gc(d+16|0,x[d+8>>2],c);lc(d,x[a>>2],x[a+8>>2],x[f>>2],x[f+4>>2]);hD(e,b);Rb(x[d+8>>2]+c|0,0,33-c|0);Vb(a,x[d+28>>2]);fb=d+32|0;return c|0}function ZX(a){var b=0;a:{if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=808604749|((y[a+8|0]|y[a+9|0]<<8)-768&65535)>>>0<65280|(((y[a+112|0]|y[a+113|0]<<8)-65&65535)>>>0<65472|(y[a+106|0]|y[a+107|0]<<8)>>>0>256)){break a}if((y[a+122|0]|y[a+123|0]<<8)>>>0>255){break a}b=(y[a+124|0]|y[a+125|0]<<8)>>>0<4e3}return b}function W3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-16|0;fb=d;a:{e=x[b>>2];if(Dd(e)){f=d+4|0;if(!Ad(x[c+4>>2],y[c+11|0])){BP(c,18418);e=x[b>>2]}b=x[b+4>>2];ib[x[x[b>>2]+24>>2]](f,b,e);x[31737]=0;P(842,c|0,f|0)|0;b=x[31737];x[31737]=0;if((b|0)==1){break a}tb(f)}_c(a,c);fb=d+16|0;return}a=N()|0;tb(d+4|0);Q(a|0);p()}function $9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-32|0;fb=d;e=d+8|0;Vo(e,c);x[31737]=0;c=d+20|0;S(503,c|0,b|0,e|0);b=x[31737];x[31737]=0;b:{c:{if((b|0)!=1){x[31737]=0;S(245,a|0,0,c|0);a=x[31737];x[31737]=0;if((a|0)==1){break c}Ub(c);tb(e);fb=d+32|0;break a}a=N()|0;break b}a=N()|0;Ub(d+20|0)}tb(d+8|0);Q(a|0);p()}}function zA(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=c>=.999?.999:c;h=c*3.141592653589793;i=$u(b);while(1){if((e|0)!=32768){f=((e^-1)<<12&28672)+(e>>>3|0)|0;if((f|0)!=16384){d=+(f-16384|0)*.000244140625;g=h*d;d=Wi(g)*$u(M(d*d*-.0625+1)*b)/(i*g)}else{d=1}j=a,k=qC(c*d*32768),w[j>>1]=k;e=e+1|0;a=a+2|0;continue}break}}function ita(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=fb-224|0;fb=d;c=fb-16|0;fb=c;e=d+6|0;L_(c+8|0,e);f=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(f|0)){gd(a,x[c+12>>2])}fb=c+16|0;c=-1;a:{if((f|0)!=(g|0)){break a}c=0;if(!N_(e)){break a}c=ve(a,b,M_(y[d+222|0],y[d+223|0]),hb)}fb=d+224|0;return c|0}function fra(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;f=fb+-64|0;fb=f;c=fb-16|0;fb=c;e=f+12|0;UY(c+8|0,e);d=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(d|0)){gd(a,x[c+12>>2])}fb=c+16|0;d=(d|0)==(g|0);if(!d){TY(e)}c=-1;a:{if(!d){break a}c=0;if(!WY(e)){break a}c=ve(a,b,VY(e),hb)}fb=f- -64|0;return c|0}function Yqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-32|0;fb=d;e=d+8|0;Ep(e,b,c);x[31737]=0;b=d+20|0;S(124,b|0,28,e|0);c=x[31737];x[31737]=0;b:{c:{if((c|0)!=1){x[31737]=0;O(12,a|0,b|0);a=x[31737];x[31737]=0;if((a|0)==1){break c}Ub(b);tb(e);fb=d+32|0;break a}a=N()|0;break b}a=N()|0;Ub(d+20|0)}tb(d+8|0);Q(a|0);p()}}function yM(a){var b=0,c=0,d=0,e=0;b=fb-32|0;fb=b;if(!y[a+20|0]){while(1){if(!(ib[x[x[a>>2]+40>>2]](a)|0)){wM(a,65536);c=gc(b+16|0,xb(x[a+4>>2],x[a+16>>2]),65536);d=x[x[a>>2]+44>>2];e=x[c+4>>2];x[b+8>>2]=x[c>>2];x[b+12>>2]=e;ib[d|0](b+24|0,a,b+8|0);x[a+16>>2]=x[a+16>>2]+x[b+28>>2];continue}break}v[a+20|0]=1}fb=b+32|0}function kqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-32|0;fb=d;e=d+8|0;Vo(e,c);x[31737]=0;c=d+20|0;S(124,c|0,b|0,e|0);b=x[31737];x[31737]=0;b:{c:{if((b|0)!=1){x[31737]=0;O(12,a|0,c|0);a=x[31737];x[31737]=0;if((a|0)==1){break c}Ub(c);tb(e);fb=d+32|0;break a}a=N()|0;break b}a=N()|0;Ub(d+20|0)}tb(d+8|0);Q(a|0);p()}}function NU(a){a=a|0;var b=0,c=0,d=0;b=fb-16|0;fb=b;if(y[a+534|0]){while(1){d=c&65535;if(d>>>0>=256){v[a+534|0]=0}else{Lj(a,d,1);c=c+1|0;continue}break}}v[b+15|0]=0;Vh(a+8|0,18,b+15|0);Fv(a+26|0,18,27610);v[b+14|0]=255;Vh(a+62|0,256,b+14|0);yh(x[a>>2],x[a+4>>2],65535,261,1);yh(x[a>>2],x[a+4>>2],65535,260,0);fb=b+16|0}function K3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(mh(a,x[b+8>>2],e)){Ox(b,c,d);return}a:{if(!mh(a,x[b>>2],e)){break a}if(!(x[b+16>>2]!=(c|0)&x[b+20>>2]!=(c|0))){if((d|0)!=1){break a}x[b+32>>2]=1;return}x[b+20>>2]=c;x[b+32>>2]=d;x[b+40>>2]=x[b+40>>2]+1;if(!(x[b+36>>2]!=1|x[b+24>>2]!=2)){v[b+54|0]=1}x[b+44>>2]=4}}function Cua(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=fb-1968|0;fb=e;c=fb-16|0;fb=c;f=e+14|0;E0(c+8|0,f);d=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(d|0)){gd(a,x[c+12>>2])}fb=c+16|0;d=(d|0)==(g|0);if(!d){D0(f)}c=-1;a:{if(!d){break a}c=0;if(!G0(f)){break a}c=ve(a,b,1024,0)}fb=e+1968|0;return c|0}function xga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a=Qi(a,b,c,d);x[a>>2]=45788;b=a+4208|0;e=yb(b,0),f=1065353216,x[e>>2]=f;e=yb(b,1),f=1065353216,x[e>>2]=f;e=yb(b,2),f=1051372203,x[e>>2]=f;e=yb(b,3),f=0,x[e>>2]=f;x[31737]=0;O(947,a+44|0,2);b=x[31737];x[31737]=0;if((b|0)!=1){return a|0}b=N()|0;ag(a);Q(b|0);p()}function cta(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;f=fb-208|0;fb=f;c=fb-16|0;fb=c;e=f+2|0;B_(c+8|0,e);d=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(d|0)){gd(a,x[c+12>>2])}fb=c+16|0;d=(d|0)==(g|0);if(!d){A_(e)}c=-1;a:{if(!d){break a}c=0;if(!D_(e)){break a}c=ve(a,b,C_(e),hb)}fb=f+208|0;return c|0}function _y(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;g=fb-240|0;fb=g;x[g>>2]=a;h=1;a:{if((c|0)<2){break a}e=a;while(1){e=e-4|0;i=c-2|0;f=e-x[(i<<2)+d>>2]|0;if((qo(a,f,b)|0)>=0){if((qo(a,e,b)|0)>=0){break a}}j=f;f=(qo(f,e,b)|0)>=0;e=f?j:e;x[(h<<2)+g>>2]=e;h=h+1|0;c=f?c-1|0:i;if((c|0)>1){continue}break}}IL(g,h);fb=g+240|0}function WQ(a){var b=0,c=0,d=0;c=fb-32|0;fb=c;a:{d=cA(a);b=mk(x[a>>2],x[a+4>>2]);b:{if(d>>>0<=b>>>0){break b}x[31737]=0;b=ba(951,c+12|0,b|0,b|0,zb(a)|0)|0;d=x[31737];x[31737]=0;if((d|0)!=1){SQ(a,b);RQ(b);break b}Y(T(0)|0)|0;x[31737]=0;X(26);a=x[31737];x[31737]=0;if((a|0)==1){break a}}fb=c+32|0;return}T(0)|0;Sb();p()}function VQ(a){var b=0,c=0,d=0;c=fb-32|0;fb=c;a:{d=Ug(a);b=oc(x[a>>2],x[a+4>>2]);b:{if(d>>>0<=b>>>0){break b}x[31737]=0;b=ba(952,c+12|0,b|0,b|0,zb(a)|0)|0;d=x[31737];x[31737]=0;if((d|0)!=1){Ym(a,b);_f(b);break b}Y(T(0)|0)|0;x[31737]=0;X(26);a=x[31737];x[31737]=0;if((a|0)==1){break a}}fb=c+32|0;return}T(0)|0;Sb();p()}function KZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-32|0;fb=d;e=d+8|0;Wf(e,c);x[31737]=0;c=d+20|0;S(503,c|0,b|0,e|0);b=x[31737];x[31737]=0;b:{c:{if((b|0)!=1){x[31737]=0;O(12,a|0,c|0);a=x[31737];x[31737]=0;if((a|0)==1){break c}Ub(c);tb(e);fb=d+32|0;break a}a=N()|0;break b}a=N()|0;Ub(d+20|0)}tb(d+8|0);Q(a|0);p()}}function Ega(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a=Qi(a,b,c,d);x[a+4272>>2]=1065353216;x[a>>2]=45552;b=a+4208|0;e=yb(b,0),f=1056880300,x[e>>2]=f;e=yb(b,1),f=1050733080,x[e>>2]=f;e=yb(b,2),f=1056964608,x[e>>2]=f;x[31737]=0;O(947,a+44|0,2);b=x[31737];x[31737]=0;if((b|0)!=1){return a|0}b=N()|0;ag(a);Q(b|0);p()}function kS(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=fb-32|0;fb=c;d=c+8|0;iS(d,b+80|0);x[31737]=0;b=c+20|0;S(124,b|0,0,d|0);e=x[31737];x[31737]=0;b:{c:{if((e|0)!=1){x[31737]=0;O(12,a|0,b|0);a=x[31737];x[31737]=0;if((a|0)==1){break c}Ub(b);tb(d);fb=c+32|0;break a}a=N()|0;break b}a=N()|0;Ub(c+20|0)}tb(c+8|0);Q(a|0);p()}}function Dpa(a,b){a=a|0;b=b|0;var c=0,d=0;if(x[a+4>>2]!=x[zb(a)>>2]){c=fb-16|0;fb=c;a=zw(c+4|0,a,1);IX(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+20;hc(a);fb=c+16|0;return}d=fb-32|0;fb=d;c=zb(a);c=QD(d+12|0,RD(a,Uf(x[a>>2],x[a+4>>2])+1|0),Uf(x[a>>2],x[a+4>>2]),c);IX(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+20;PD(a,c);Yv(c);fb=d+32|0}function nta(a,b){a=a|0;b=b|0;var c=0,d=0;if(A[a+4>>2]<A[zb(a)>>2]){c=fb-16|0;fb=c;a=zw(c+4|0,a,1);SD(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+20;hc(a);fb=c+16|0;return}d=fb-32|0;fb=d;c=zb(a);c=QD(d+12|0,RD(a,Uf(x[a>>2],x[a+4>>2])+1|0),Uf(x[a>>2],x[a+4>>2]),c);SD(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+20;PD(a,c);Yv(c);fb=d+32|0}function jE(a,b){a=a|0;b=b|0;var c=0,d=0;if(x[a+4>>2]!=x[zb(a)>>2]){c=fb-16|0;fb=c;a=I$(c+4|0,a,1);H$(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+40;hc(a);fb=c+16|0;return}d=fb-32|0;fb=d;c=zb(a);c=F$(d+12|0,G$(a,Hr(x[a>>2],x[a+4>>2])+1|0),Hr(x[a>>2],x[a+4>>2]),c);H$(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+40;E$(a,c);D$(c);fb=d+32|0}function eea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;x[31737]=0;W(1002,a|0);d=x[31737];x[31737]=0;if((d|0)!=1){x[a+4>>2]=c;x[a>>2]=b?b:983;return}Y(T(0)|0)|0;x[31737]=0;V(989,13153,a|0,0,0);a=x[31737];x[31737]=0;if((a|0)!=1){Z();return}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function cfa(a,b){a=a|0;b=b|0;var c=0;x[31737]=0;W(1002,a|0);c=x[31737];x[31737]=0;if((c|0)!=1){return E(lP(x[x[a+24>>2]+24>>2],b))}Y(T(0)|0)|0;x[31737]=0;V(989,6229,a|0,0,0);a=x[31737];x[31737]=0;if((a|0)!=1){Z();return E(E(0))}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function afa(a,b){a=a|0;b=b|0;var c=0;x[31737]=0;W(1002,a|0);c=x[31737];x[31737]=0;if((c|0)!=1){return E(kP(x[x[a+24>>2]+24>>2],b))}Y(T(0)|0)|0;x[31737]=0;V(989,9393,a|0,0,0);a=x[31737];x[31737]=0;if((a|0)!=1){Z();return E(E(0))}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function _ea(a,b){a=a|0;b=b|0;var c=0;x[31737]=0;W(1002,a|0);c=x[31737];x[31737]=0;if((c|0)!=1){return E(iP(x[x[a+24>>2]+24>>2],b))}Y(T(0)|0)|0;x[31737]=0;V(989,6174,a|0,0,0);a=x[31737];x[31737]=0;if((a|0)!=1){Z();return E(E(0))}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function Zea(a,b){a=a|0;b=b|0;var c=0;x[31737]=0;W(1002,a|0);c=x[31737];x[31737]=0;if((c|0)!=1){return E(hP(x[x[a+24>>2]+24>>2],b))}Y(T(0)|0)|0;x[31737]=0;V(989,6130,a|0,0,0);a=x[31737];x[31737]=0;if((a|0)!=1){Z();return E(E(0))}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function Xka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-32|0;fb=d;b=lg(d+8|0,b);x[31737]=0;e=d+20|0;S(841,e|0,b|0,c|0);f=x[31737];x[31737]=0;a:{b:{if((f|0)!=1){x[31737]=0;S(72,a|0,e|0,c|0);a=x[31737];x[31737]=0;if((a|0)==1){break b}tb(e);tb(b);fb=d+32|0;return}c=N()|0;break a}c=N()|0;tb(d+20|0)}tb(b);Q(c|0);p()}function Hla(a,b){a=a|0;b=b|0;var c=0,d=0;if(A[a+4>>2]<A[zb(a)>>2]){c=fb-16|0;fb=c;a=jC(c+4|0,a,1);WB(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+32;hc(a);fb=c+16|0;return}d=fb-32|0;fb=d;c=zb(a);c=fv(d+12|0,_q(a,Lg(x[a>>2],x[a+4>>2])+1|0),Lg(x[a>>2],x[a+4>>2]),c);WB(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+32;YU(a,c);XB(c);fb=d+32|0}function $ea(a,b){a=a|0;b=b|0;var c=0;x[31737]=0;W(1002,a|0);c=x[31737];x[31737]=0;if((c|0)!=1){return E(jP(x[x[a+24>>2]+24>>2],b))}Y(T(0)|0)|0;x[31737]=0;V(989,6272,a|0,0,0);a=x[31737];x[31737]=0;if((a|0)!=1){Z();return E(E(0))}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function bqa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=fb-128|0;fb=e;c=fb-16|0;fb=c;f=e+2|0;YX(c+8|0,f);d=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(d|0)){gd(a,x[c+12>>2])}fb=c+16|0;d=(d|0)==(g|0);if(!d){XX(f)}c=-1;a:{if(!d){break a}c=0;if(!ZX(f)){break a}c=ve(a,b,256,0)}fb=e+128|0;return c|0}function Noa(a,b){a=a|0;b=b|0;var c=0,d=0;if(x[a+4>>2]!=x[zb(a)>>2]){c=fb-16|0;fb=c;a=wx(c+4|0,a);tC(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+12;hc(a);fb=c+16|0;return}d=fb-32|0;fb=d;c=zb(a);c=Dm(d+12|0,Wp(a,Ud(x[a>>2],x[a+4>>2])+1|0),Ud(x[a>>2],x[a+4>>2]),c);tC(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+12;JW(a,c);IW(c);fb=d+32|0}function ME(a){var b=0,c=0,d=0,e=0;c=y[a+9|0]|y[a+10|0]<<8;d=Sua(y[a+3|0],0,18,0);c=c+d|0;b=hb;e=d>>>0>c>>>0?b+1|0:b;d=y[a+6|0]|y[a+7|0]<<8;b=d>>>31|0;d=d<<1;c=d+c|0;b=b+e|0;d=d>>>0>c>>>0?b+1|0:b;a=y[a+4|0]|y[a+5|0]<<8;b=a>>>30|0;e=c;c=a<<2;e=e+c|0;a=b+d|0;a=c>>>0>e>>>0?a+1|0:a;b=e+3|0;hb=b>>>0<3?a+1|0:a;return b}function ira(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-16|0;fb=d;e=x[a+8>>2];c=d+4|0;x[c+8>>2]=a+8;x[c>>2]=e;x[c+4>>2]=D(b,20)+e;b=x[c>>2];a:{while(1){if(x[c+4>>2]==(b|0)){break a}x[31737]=0;W(229,b|0);a=x[31737];x[31737]=0;if((a|0)!=1){b=x[c>>2]+20|0;x[c>>2]=b;continue}break}a=N()|0;he(c);Q(a|0);p()}he(c);fb=d+16|0}function iA(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;d=fb-16|0;fb=d;h=z[b>>1];c=ce(a);e=ec(a);f=fb-16|0;fb=f;while(1){if(c){g=ar(z[c+16>>1],h);e=g?e:c;c=x[(g?c+4|0:c)>>2];continue}break}c=x[vb(f+12|0,e)>>2];fb=f+16|0;a:{if(Ib(c,rg(a))){if(!ar(z[b>>1],z[td(c)>>1])){break a}}c=rg(a)}a=vb(d+12|0,c);fb=d+16|0;return x[a>>2]}function cia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=fb-32|0;fb=c;d=c+8|0;Wf(d,b);x[31737]=0;b=c+20|0;O(964,b|0,d|0);e=x[31737];x[31737]=0;b:{c:{if((e|0)!=1){x[31737]=0;S(965,a|0,0,b|0);a=x[31737];x[31737]=0;if((a|0)==1){break c}Ub(b);tb(d);fb=c+32|0;break a}a=N()|0;break b}a=N()|0;Ub(c+20|0)}tb(c+8|0);Q(a|0);p()}}function Nna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-32|0;fb=d;x[d+28>>2]=c;x[d+8>>2]=4896;e=x[a>>2];f=x[a+8>>2];c=x[Gb(d+28|0,d+8|0)>>2];if(!Mb(e,f,c)){c=kf(a)}e=d+8|0;kD(e,b);f=gc(d+16|0,x[d+8>>2],c);lc(d,x[a>>2],x[a+8>>2],x[f>>2],x[f+4>>2]);kD(e,b);Rb(x[d+8>>2]+c|0,0,4896-c|0);Vb(a,x[d+28>>2]);fb=d+32|0}function I2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-32|0;fb=d;b=Bm(d+8|0,b);x[31737]=0;e=d+20|0;S(149,e|0,b|0,c|0);f=x[31737];x[31737]=0;a:{b:{if((f|0)!=1){x[31737]=0;S(4,a|0,e|0,c|0);a=x[31737];x[31737]=0;if((a|0)==1){break b}tb(e);tb(b);fb=d+32|0;return}c=N()|0;break a}c=N()|0;tb(d+20|0)}tb(b);Q(c|0);p()}function uH(a,b,c,d,e){var f=0,g=0;a:{f=fb-32|0;fb=f;g=f+8|0;Up(g,c);x[31737]=0;O(e|0,f+20|0,d|0);c=x[31737];x[31737]=0;b:{c:{if((c|0)!=1){rk(f,g);x[31737]=0;V(93,a|0,b|0,x[f>>2],x[f+4>>2]);a=x[31737];x[31737]=0;if((a|0)==1){break c}Ag(g);fb=f+32|0;break a}a=N()|0;tb(f+8|0);break b}a=N()|0;Ag(f+8|0)}Q(a|0);p()}}function rua(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-16|0;fb=d;x[d+12>>2]=c;a:{if(!Mb(x[b>>2],x[b+8>>2],c<<1)){break a}wc(d+12|0,65535);xg(a,z[d+12>>1]);c=wb(x[a>>2]);x[d+4>>2]=c;a=wb(x[a+4>>2]);while(1){if(!Ib(c,a)){break a}HE(b,d+10|0);e=c,f=Bb(z[d+10>>1]),w[e>>1]=f;c=x[Md(d+4|0)>>2];continue}}fb=d+16|0}function nH(a,b,c,d,e){var f=0,g=0;a:{f=fb-32|0;fb=f;g=f+8|0;Y_(g,c);x[31737]=0;O(e|0,f+20|0,d|0);c=x[31737];x[31737]=0;b:{c:{if((c|0)!=1){rk(f,g);x[31737]=0;V(93,a|0,b|0,x[f>>2],x[f+4>>2]);a=x[31737];x[31737]=0;if((a|0)==1){break c}Ag(g);fb=f+32|0;break a}a=N()|0;tb(f+8|0);break b}a=N()|0;Ag(f+8|0)}Q(a|0);p()}}function Sja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=fb-32|0;fb=c;d=c+8|0;Vo(d,b);x[31737]=0;b=c+20|0;O(14,b|0,d|0);e=x[31737];x[31737]=0;b:{c:{if((e|0)!=1){x[31737]=0;S(245,a|0,0,b|0);a=x[31737];x[31737]=0;if((a|0)==1){break c}Ub(b);tb(d);fb=c+32|0;break a}a=N()|0;break b}a=N()|0;Ub(c+20|0)}tb(c+8|0);Q(a|0);p()}}function S1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=fb-32|0;fb=c;d=c+8|0;Wf(d,b);x[31737]=0;b=c+20|0;S(124,b|0,22,d|0);e=x[31737];x[31737]=0;b:{c:{if((e|0)!=1){x[31737]=0;O(12,a|0,b|0);a=x[31737];x[31737]=0;if((a|0)==1){break c}Ub(b);tb(d);fb=c+32|0;break a}a=N()|0;break b}a=N()|0;Ub(c+20|0)}tb(c+8|0);Q(a|0);p()}}function R1(a,b){a=a|0;b=b|0;var c=0,d=0;if(A[a+4>>2]<A[zb(a)>>2]){c=fb-16|0;fb=c;a=rG(c+4|0,a);bx(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+36;hc(a);fb=c+16|0;return}d=fb-32|0;fb=d;c=zb(a);c=pG(d+12|0,qG(a,js(x[a>>2],x[a+4>>2])+1|0),js(x[a>>2],x[a+4>>2]),c);bx(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+36;oG(a,c);dx(c);fb=d+32|0}function Jta(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=fb-32|0;fb=e;c=fb-16|0;fb=c;f=e+15|0;R0(c+8|0,f);d=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(d|0)){gd(a,x[c+12>>2])}fb=c+16|0;d=(d|0)==(g|0);if(!d){FE(f)}c=-1;a:{if(!d){break a}c=0;if(!n$(f)){break a}c=ve(a,b,72,0)}fb=e+32|0;return c|0}function Bja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=fb-32|0;fb=c;d=c+8|0;Zk(d,b);x[31737]=0;b=c+20|0;O(14,b|0,d|0);e=x[31737];x[31737]=0;b:{c:{if((e|0)!=1){x[31737]=0;S(245,a|0,0,b|0);a=x[31737];x[31737]=0;if((a|0)==1){break c}Ub(b);tb(d);fb=c+32|0;break a}a=N()|0;break b}a=N()|0;Ub(c+20|0)}tb(c+8|0);Q(a|0);p()}}function X2(a){a=a|0;var b=0,c=0,d=0,e=0;a:{b=fb-32|0;fb=b;c=b+8|0;Dc(c,13592);x[31737]=0;d=b+20|0;S(124,d|0,1,c|0);e=x[31737];x[31737]=0;b:{c:{if((e|0)!=1){x[31737]=0;O(12,a|0,d|0);a=x[31737];x[31737]=0;if((a|0)==1){break c}Ub(d);tb(c);fb=b+32|0;break a}a=N()|0;break b}a=N()|0;Ub(b+20|0)}tb(b+8|0);Q(a|0);p()}}function Vna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-32|0;fb=d;x[d+28>>2]=c;x[d+8>>2]=263;e=x[a>>2];f=x[a+8>>2];c=x[Gb(d+28|0,d+8|0)>>2];if(!Mb(e,f,c)){c=kf(a)}e=d+8|0;GV(e,b);f=gc(d+16|0,x[d+8>>2],c);lc(d,x[a>>2],x[a+8>>2],x[f>>2],x[f+4>>2]);GV(e,b);Rb(x[d+8>>2]+c|0,0,263-c|0);Vb(a,x[d+28>>2]);fb=d+32|0}function SX(a){var b=0,c=0,d=0,e=0,f=0;f=y[a+28|0]|y[a+29|0]<<8;c=Sua(y[a+30|0],0,37,0);d=hb;b=Sua(y[a+24|0]|y[a+25|0]<<8,0,192,0);c=b+c|0;d=hb+d|0;b=b>>>0>c>>>0?d+1|0:d;a=y[a+26|0];d=a>>>26|0;e=c;c=a<<6;e=e+c|0;a=b+d|0;a=c>>>0>e>>>0?a+1|0:a;b=e+f|0;a=b>>>0<e>>>0?a+1|0:a;b=b+192|0;hb=b>>>0<192?a+1|0:a;return b}function Ksa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-32|0;fb=d;x[d+28>>2]=c;x[d+8>>2]=102;e=x[a>>2];f=x[a+8>>2];c=x[Gb(d+28|0,d+8|0)>>2];if(!Mb(e,f,c)){c=kf(a)}e=d+8|0;m_(e,b);f=gc(d+16|0,x[d+8>>2],c);lc(d,x[a>>2],x[a+8>>2],x[f>>2],x[f+4>>2]);m_(e,b);Rb(x[d+8>>2]+c|0,0,102-c|0);Vb(a,x[d+28>>2]);fb=d+32|0}function oA(a,b,c){var d=0,e=0,f=0;e=fb-16|0;fb=e;d=e+4|0;x[d>>2]=a;a=x[a+4>>2];x[d+4>>2]=a;x[d+8>>2]=a+D(b,52);b=x[d+4>>2];f=x[d+8>>2];a:{while(1){if((b|0)==(f|0)){break a}x[31737]=0;O(924,b|0,c|0);a=x[31737];x[31737]=0;if((a|0)!=1){b=b+52|0;x[d+4>>2]=b;continue}break}a=N()|0;hc(d);Q(a|0);p()}hc(d);fb=e+16|0}function bra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-32|0;fb=d;x[d+28>>2]=c;x[d+8>>2]=22;e=x[a>>2];f=x[a+8>>2];c=x[Gb(d+28|0,d+8|0)>>2];if(!Mb(e,f,c)){c=kf(a)}e=d+8|0;Zv(e,b);f=gc(d+16|0,x[d+8>>2],c);lc(d,x[a>>2],x[a+8>>2],x[f>>2],x[f+4>>2]);Zv(e,b);Rb(x[d+8>>2]+c|0,0,22-c|0);Vb(a,x[d+28>>2]);fb=d+32|0}function $qa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-32|0;fb=d;x[d+28>>2]=c;x[d+8>>2]=40;e=x[a>>2];f=x[a+8>>2];c=x[Gb(d+28|0,d+8|0)>>2];if(!Mb(e,f,c)){c=kf(a)}e=d+8|0;aD(e,b);f=gc(d+16|0,x[d+8>>2],c);lc(d,x[a>>2],x[a+8>>2],x[f>>2],x[f+4>>2]);aD(e,b);Rb(x[d+8>>2]+c|0,0,40-c|0);Vb(a,x[d+28>>2]);fb=d+32|0}function n1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-32|0;fb=d;x[d+28>>2]=c;x[d+8>>2]=65;e=x[a>>2];f=x[a+8>>2];c=x[Gb(d+28|0,d+8|0)>>2];if(!Mb(e,f,c)){c=kf(a)}e=d+8|0;yw(e,b);f=gc(d+16|0,x[d+8>>2],c);lc(d,x[a>>2],x[a+8>>2],x[f>>2],x[f+4>>2]);yw(e,b);Rb(x[d+8>>2]+c|0,0,65-c|0);Vb(a,x[d+28>>2]);fb=d+32|0}function dQ(a){var b=0,c=E(0),d=0,e=0;e=x[x[a+16>>2]+24620>>2];b=fb-16|0;fb=b;x[b+12>>2]=0;x[b+8>>2]=1065353216;c=ri(E(B[Lv(a+4208|0,b+12|0,b+8|0)>>2]*E(999)));a:{if(c<E(4294967296)&c>=E(0)){d=~~c>>>0;break a}d=0}fb=b+16|0;b=(e>>>0)/(d+1>>>0)|0;b=b>>>0<=2?2:b;x[a+4216>>2]=b;x[a+4220>>2]=b>>>1;wc(a+4224|0,b)}function aea(a,b){a=a|0;b=b|0;var c=0;x[31737]=0;W(1002,a|0);c=x[31737];x[31737]=0;if((c|0)!=1){wO(x[x[a+24>>2]+24>>2],b);return 1}Y(T(0)|0)|0;x[31737]=0;V(989,5784,a|0,0,0);a=x[31737];x[31737]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function R7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=fb-32|0;fb=g;h=x[28003];x[g+24>>2]=x[28002];x[g+28>>2]=h;h=x[28001];x[g+16>>2]=x[28e3];x[g+20>>2]=h;h=x[27999];x[g+8>>2]=x[27998];x[g+12>>2]=h;h=x[27997];x[g>>2]=x[27996];x[g+4>>2]=h;h=a;a=g+32|0;b=vk(h,b,c,d,e,f,g,a);fb=a;return b|0}function Q4(a,b,c){a=a|0;b=b|0;c=c|0;a=0;if(b&1){a=(vt(c)|0)!=0}if(b&2){a=(ut(c)|0)!=0|a}if(b&4){a=(tt(c)|0)!=0|a}if(b&8){a=(st(c)|0)!=0|a}if(b&16){a=(rt(c)|0)!=0|a}if(b&32){a=(qt(c)|0)!=0|a}if(b&64){a=(Oh(c)|0)!=0|a}if(b&128){a=(pt(c)|0)!=0|a}if(b&256){a=(ot(c)|0)!=0|a}if(b&512){a=(nt(c)|0)!=0|a}return a|0}function Jl(a,b){var c=0,d=0,e=0;d=x[a>>2];c=oc(d,x[a+4>>2]);if(c>>>0<b>>>0){d=fb-32|0;fb=d;b=b-c|0;c=x[zb(a)>>2];e=x[a+4>>2];a:{if(b>>>0<=c-e>>2>>>0){Zq(a,b);break a}c=zb(a);c=$f(d+12|0,Mf(a,oc(x[a>>2],e)+b|0),oc(x[a>>2],x[a+4>>2]),c);jA(c,b);mA(a,c);_f(c)}fb=d+32|0;return}if(b>>>0<c>>>0){Ih(a,d+(b<<2)|0)}}function Dea(a,b){a=a|0;b=b|0;var c=0;x[31737]=0;W(1002,a|0);c=x[31737];x[31737]=0;if((c|0)!=1){return QO(x[x[a+24>>2]+24>>2],b)|0}Y(T(0)|0)|0;x[31737]=0;V(989,6659,a|0,0,0);a=x[31737];x[31737]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function _sa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-32|0;fb=d;x[d+28>>2]=c;x[d+8>>2]=5;e=x[a>>2];f=x[a+8>>2];c=x[Gb(d+28|0,d+8|0)>>2];if(!Mb(e,f,c)){c=kf(a)}e=d+8|0;ek(e,b);f=gc(d+16|0,x[d+8>>2],c);lc(d,x[a>>2],x[a+8>>2],x[f>>2],x[f+4>>2]);ek(e,b);Rb(x[d+8>>2]+c|0,0,5-c|0);Vb(a,x[d+28>>2]);fb=d+32|0}function YQ(a,b){var c=0,d=0,e=0,f=0,g=E(0);c=fb-16|0;fb=c;if(!x[(x[x[a>>2]-12>>2]+a|0)+16>>2]){w[c+14>>1]=0;pg(a,c+14|0);e=z[c+14>>1];Jl(b,e);while(1){if((d|0)!=(e|0)){x[c+8>>2]=0;Bq(a,c+8|0);f=yb(x[b>>2],d),g=B[c+8>>2],B[f>>2]=g;d=d+1|0;continue}break}d=!x[(x[x[a>>2]-12>>2]+a|0)+16>>2]}fb=c+16|0;return d}function EQ(a){a=a|0;var b=0,c=0,d=0;b=C[a+4264>>3]*+A[x[a+16>>2]+1074376>>2];a:{if(F(b)<0x8000000000000000){d=~~b>>>0;if(F(b)>=1){c=~~(b>0?H(J(b*2.3283064365386963e-10),4294967295):K((b-+(~~b>>>0>>>0))*2.3283064365386963e-10))>>>0}else{c=0}break a}c=-2147483648}C[a+4256>>3]=b-(+(d>>>0)+ +(c|0)*4294967296)}function j7(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;g=fb-16|0;fb=g;x[e>>2]=c;b=g+12|0;a=fy(b,0,x[a+8>>2]);f=2;a:{if(a+1>>>0<2){break a}c=a-1|0;f=1;if(c>>>0>d-x[e>>2]>>>0){break a}while(1){if(c){a=y[b|0];d=x[e>>2];x[e>>2]=d+1;v[d|0]=a;c=c-1|0;b=b+1|0;continue}break}f=0}a=f;fb=g+16|0;return a|0}function Pn(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;a:{e=x[d>>2];if(e|x[c>>2]){while(1){if((b|0)==(g|0)){break a}f=x[c>>2];h=c,i=f-qd((qd(0-f|0,31)&255)+f|0,8)|0,x[h>>2]=i;h=d,i=x[d>>2]-qd((qd(0-e|0,31)&255)+e|0,8)|0,x[h>>2]=i;e=(g<<3)+a|0;x[e>>2]=x[c>>2];f=e;e=x[d>>2];x[f+4>>2]=e;g=g+1|0;continue}}Rb(a,0,b<<3)}}function KQ(a){a=a|0;var b=0,c=0;c=fb-16|0;fb=c;b=x[a+4232>>2];b=(b>>>1)+(b>>>6)|0;x[a+4220>>2]=b;x[31737]=0;x[c+12>>2]=0;S(953,a+4208|0,b<<1,c+12|0);b=x[31737];x[31737]=0;a:{if((b|0)==1){b=T(125048)|0;if((gb|0)!=($(125048)|0)){break a}Y(b|0)|0;x[a+4220>>2]=0;Z()}x[a+4224>>2]=0;fb=c+16|0;return}Q(b|0);p()}function vm(a,b,c,d,e){var f=0;a:{if(c>>>0>255){break a}b:{switch(d-2|0){case 0:d=D(c,872)+b|0;f=ZS(x[d+720>>2],x[d+1272>>2],e);if((f+5&255)>>>0>5){break a}return YS(a,b,c,e);case 1:break b;default:break a}}f=YS(a,b,c,e);if((f+5&255)>>>0>5){break a}a=D(c,872)+b|0;f=ZS(x[a+720>>2],x[a+1272>>2],e)}return f}function rsa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=fb-192|0;fb=d;c=fb-16|0;fb=c;ow(c+8|0,d);e=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);f=x[c+4>>2];if((f|0)==(e|0)){gd(a,x[c+12>>2])}fb=c+16|0;e=(e|0)==(f|0);if(!e){WZ(d)}c=-1;a:{if(!e){break a}c=0;if(!YZ(d)){break a}c=ve(a,b,XZ(d),hb)}fb=d+192|0;return c|0}function ou(a){var b=0,c=0,d=0;b=Di(+B[a+4228>>2]*8)*.25+-.25;C[a+4248>>3]=b;if(y[a+4240|0]){if(b>45e-5){c=sq(b)/.6931471805599453;b=c-J(c);d=c-b;c=0;a:{if(b<.2075187496394219){break a}c=.4150374992788438;if(b<.5){break a}c=b<.792481250360578?.5849625007211562:1}b=Di(d+c)*.5}else{b=0}C[a+4248>>3]=b}nu(a)}function h$(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=fb-16|0;fb=d;e=x[b+4>>2];f=vb(d+12|0,c);g=vb(d+8|0,x[a>>2]);h=vb(d+4|0,x[b+4>>2]);i=b,j=hX(x[f>>2],x[g>>2],x[h>>2]),x[i+4>>2]=j;i=b,j=zr(c,x[a+4>>2],x[b+8>>2]),x[i+8>>2]=j;Tb(a,b+4|0);Tb(a+4|0,b+8|0);Tb(zb(a),nc(b));x[b>>2]=x[b+4>>2];fb=d+16|0;return e}function cV(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=fb-16|0;fb=d;e=x[b+4>>2];f=vb(d+12|0,c);g=vb(d+8|0,x[a>>2]);h=vb(d+4|0,x[b+4>>2]);i=b,j=OF(x[f>>2],x[g>>2],x[h>>2]),x[i+4>>2]=j;i=b,j=zr(c,x[a+4>>2],x[b+8>>2]),x[i+8>>2]=j;Tb(a,b+4|0);Tb(a+4|0,b+8|0);Tb(zb(a),nc(b));x[b>>2]=x[b+4>>2];fb=d+16|0;return e}function UQ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=fb-16|0;fb=e;Kg(a+12|0,d);a:{if(!b){d=0;b=0;break a}if(b>>>0>=2097152){Zj();p()}d=Ec(b<<11);x[e+12>>2]=b;x[e+8>>2]=d;d=x[e+12>>2];b=x[e+8>>2]}x[a>>2]=b;c=b+(c<<11)|0;x[a+8>>2]=c;x[a+4>>2]=c;f=nc(a),g=b+(d<<11)|0,x[f>>2]=g;fb=e+16|0;return a|0}function ht(a,b,c,d){var e=0;a:{if(!(d&2048)){break a}e=d&74;if(!c|((e|0)==8|(e|0)==64)){break a}v[a|0]=43;a=a+1|0}if(d&512){v[a|0]=35;a=a+1|0}while(1){e=y[b|0];if(e){v[a|0]=e;a=a+1|0;b=b+1|0;continue}break}e=d&74;b=111;b:{if((e|0)==64){break b}b=d&16384?88:120;if((e|0)==8){break b}b=c?100:117}v[a|0]=b}function a2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;d=c+8|0;Zk(d,b);x[31737]=0;b=c+20|0;O(14,b|0,d|0);e=x[31737];x[31737]=0;a:{b:{if((e|0)!=1){x[31737]=0;O(15,a|0,b|0);a=x[31737];x[31737]=0;if((a|0)==1){break b}Ub(b);tb(d);fb=c+32|0;return}b=N()|0;break a}b=N()|0;Ub(c+20|0)}tb(c+8|0);Q(b|0);p()}function Zna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=fb-80|0;fb=d;c=fb-16|0;fb=c;pZ(c+8|0,d);e=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);f=x[c+4>>2];if((f|0)==(e|0)){gd(a,x[c+12>>2])}fb=c+16|0;e=(e|0)==(f|0);if(!e){mD(d)}c=-1;a:{if(!e){break a}c=0;if(!KV(d)){break a}c=ve(a,b,JV(d),hb)}fb=d+80|0;return c|0}function Loa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;c=fb-16|0;fb=c;x[c+12>>2]=477218588;x[c+8>>2]=2147483647;e=Gb(c+12|0,c+8|0);fb=c+16|0;if(A[e>>2]<b>>>0){dd();p()}c=Ec(D(b,9));x[d+12>>2]=b;x[d+8>>2]=c;b=x[d+8>>2];x[a+4>>2]=b;x[a>>2]=b;f=zb(a),g=b+D(x[d+12>>2],9)|0,x[f>>2]=g;fb=d+16|0}function vv(a){var b=0,c=0;b=x[a+76>>2];a:{if(!((b|0)>=0&(!b|x[124225]!=(b&-1073741825)))){b=x[a+4>>2];if((b|0)!=x[a+8>>2]){x[a+4>>2]=b+1;a=y[b|0];break a}a=Jy(a);break a}b=a+76|0;c=x[b>>2];x[b>>2]=c?c:1073741823;c=x[a+4>>2];b:{if((c|0)!=x[a+8>>2]){x[a+4>>2]=c+1;a=y[c|0];break b}a=Jy(a)}me(b)}return a}function vU(a,b,c){var d=0,e=0,f=0,g=0;if(c==0){e=a;b=Ft(b);o(0);a=j(1)|0;f=j(0)|0;o(+c);d=j(1)|0;j(0)|0;l(0,f|0);l(1,a&2147483647|d&-2147483648);Wl(e,b,+n());return}a:{if(!zf(b)){break a}d=F(c)<Infinity;if(b<0){c=d?c:1;break a}if(d){break a}Wl(a,b,zf(c)?NaN:c);return}b=Ft(b);g=Wi(c);Wl(a,b*jf(c),g*b)}function TI(a){a=a|0;var b=0,c=0,d=0;b=a+12|0;Ub(b+520|0);Ub(b+508|0);Ub(b+496|0);d=b+460|0;c=Ub(b+484|0);while(1){c=Ub(c-12|0);if((d|0)!=(c|0)){continue}break}c=b+172|0;while(1){d=Ub(d-12|0);if((d|0)!=(c|0)){continue}break}d=b+4|0;while(1){c=Ub(c-12|0);if((d|0)!=(c|0)){continue}break}Xs(b);return a|0}function HI(a){a=a|0;var b=0,c=0,d=0;b=a+12|0;tb(b+520|0);tb(b+508|0);tb(b+496|0);d=b+460|0;c=tb(b+484|0);while(1){c=tb(c-12|0);if((d|0)!=(c|0)){continue}break}c=b+172|0;while(1){d=tb(d-12|0);if((d|0)!=(c|0)){continue}break}d=b+4|0;while(1){c=tb(c-12|0);if((d|0)!=(c|0)){continue}break}Xs(b);return a|0}function Cla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-16|0;fb=d;c=Hf(a,c);$d(d,x[a+36>>2]);a:{b:{if(!c){Pc(d,a+32|0,5);e=-1;if(!Hb(x[x[d>>2]>>2],x[d+4>>2])){break b}break a}e=x[c+16>>2]}f=x[a+36>>2];c:{d:{switch(e+1|0){case 0:case 2:Ki(f,b);break c;default:break d}}CZ(f,b,e)}f=c}ff(a,f);fb=d+16|0}function sH(a,b,c,d){var e=0,f=0;a:{e=fb-32|0;fb=e;f=e+8|0;Cc(f,c);x[31737]=0;c=e+20|0;S(d|0,c|0,b|0,f|0);b=x[31737];x[31737]=0;b:{c:{if((b|0)!=1){x[31737]=0;O(12,a|0,c|0);a=x[31737];x[31737]=0;if((a|0)==1){break c}Ub(c);tb(f);fb=e+32|0;break a}a=N()|0;break b}a=N()|0;Ub(e+20|0)}tb(e+8|0);Q(a|0);p()}}function ny(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=a;f=fb-16|0;fb=f;a:{if(b>>>0<1073741808){b:{if(jr(b)){Me(d,b);break b}Uj(f+8|0,yn(b)+1|0);e=x[f+8>>2];yd(d,e);of(d,x[f+12>>2]);Yd(d,b);d=e}e=fb-16|0;fb=e;x[e+12>>2]=c;KF(d,b,e+12|0);fb=e+16|0;yd((b<<2)+d|0,0);fb=f+16|0;break a}pf();p()}return a|0}function DV(a){var b=0,c=0,d=0,e=0;c=fb-16|0;fb=c;e=c+14|0;b=fb-16|0;fb=b;d=x[a+24>>2];a:{if(!d){wp(e);break a}dE(b+8|0,Yb(Zi(sq(+(d>>>0)*.00011957431543704412)*2215.9795828054475),-16384,16383),128);d=x[b+8>>2];v[b+7|0]=x[b+12>>2];de(e,d,b+7|0)}fb=b+16|0;b=c+4|0;VD(b,a+36|0,a+37|0);UD(b,e);fb=c+16|0}function wt(a,b,c,d){var e=0,f=0,g=0;e=fb-160|0;fb=e;f=b?a:e+158|0;x[e+148>>2]=f;a=-1;g=b-1|0;x[e+152>>2]=b>>>0>=g>>>0?g:0;e=Rb(e,0,144);x[e+76>>2]=-1;x[e+36>>2]=1194;x[e+80>>2]=-1;x[e+44>>2]=e+159;x[e+84>>2]=e+148;a:{if((b|0)<0){x[31612]=61;break a}v[f|0]=0;a=DL(e,c,d,1176,1177)}fb=e+160|0;return a}function xH(a,b,c){var d=0,e=0;a:{d=fb-32|0;fb=d;e=d+8|0;Dc(e,b);x[31737]=0;b=d+20|0;S(124,b|0,c|0,e|0);c=x[31737];x[31737]=0;b:{c:{if((c|0)!=1){x[31737]=0;O(12,a|0,b|0);a=x[31737];x[31737]=0;if((a|0)==1){break c}Ub(b);tb(e);fb=d+32|0;break a}a=N()|0;break b}a=N()|0;Ub(d+20|0)}tb(d+8|0);Q(a|0);p()}}function tua(a){a=a|0;var b=0,c=0,d=0;c=fb-32|0;fb=c;b=255;a:{if(Nj(x[a>>2],x[a+4>>2])>>>0<=49){b=$B(c,x[a+12>>2]);x[31737]=0;O(292,a|0,b|0);d=x[31737];x[31737]=0;if((d|0)==1){break a}Ek(b);ak(a,Nj(x[a>>2],x[a+4>>2])-1&255);b=Nj(x[a>>2],x[a+4>>2])-1|0}fb=c+32|0;return b&255}a=N()|0;Ek(b);Q(a|0);p()}function cha(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=E(0);if(b>>>0<=6){c=Pd(c,E(0));a:{b:{switch(b-1|0){case 0:c=ri(c);if(c==B[yb(a+4208|0,1)>>2]){break a}x[a+4236>>2]=0;B[a+4240>>2]=E(c*E(.5))+E(.5);break a;case 3:break b;default:break a}}c=E(ri(E(c*E(4)))*E(.25))}d=yb(a+4208|0,b),e=c,B[d>>2]=e;Vz(a)}}function Tea(a){a=a|0;var b=0;x[31737]=0;W(1002,a|0);b=x[31737];x[31737]=0;if((b|0)!=1){return cP(x[x[a+24>>2]+24>>2])|0}Y(T(0)|0)|0;x[31737]=0;V(989,12881,a|0,0,0);a=x[31737];x[31737]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function Lha(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=E(0);if(b>>>0<=6){c=Pd(c,E(0));a:{b:{switch(b-3|0){case 0:c=ri(c);if(c==B[yb(a+4208|0,3)>>2]){break a}x[a+4236>>2]=0;B[a+4240>>2]=E(c*E(.5))+E(.5);break a;case 1:break b;default:break a}}c=E(ri(E(c*E(4)))*E(.25))}d=yb(a+4208|0,b),e=c,B[d>>2]=e;Vz(a)}}function I_(a){var b=0;a:{if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=-28490681|y[a+68|0]!=13|(y[a+69|0]!=10|y[a+70|0]!=26)){break a}if(y[a+76|0]|((y[a+71|0]|y[a+72|0]<<8|(y[a+73|0]<<16|y[a+74|0]<<24))!=1397116231|y[a+75|0]!=1)){break a}b=((y[a+116|0]|y[a+117|0]<<8)-1&65535)>>>0<9}return b}function Fea(a,b){a=a|0;b=b|0;var c=0;x[31737]=0;W(1002,a|0);c=x[31737];x[31737]=0;if((c|0)!=1){return SO(x[a+24>>2],b)|0}Y(T(0)|0)|0;x[31737]=0;V(989,9817,a|0,0,0);a=x[31737];x[31737]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function zea(a){a=a|0;var b=0;x[31737]=0;W(1002,a|0);b=x[31737];x[31737]=0;if((b|0)!=1){return OO(x[x[a+24>>2]+24>>2])|0}Y(T(0)|0)|0;x[31737]=0;V(989,5816,a|0,0,0);a=x[31737];x[31737]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function Xea(a){a=a|0;var b=0;x[31737]=0;W(1002,a|0);b=x[31737];x[31737]=0;if((b|0)!=1){return gP(x[x[a+24>>2]+24>>2])|0}Y(T(0)|0)|0;x[31737]=0;V(989,8812,a|0,0,0);a=x[31737];x[31737]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function Vea(a){a=a|0;var b=0;x[31737]=0;W(1002,a|0);b=x[31737];x[31737]=0;if((b|0)!=1){return eP(x[x[a+24>>2]+24>>2])|0}Y(T(0)|0)|0;x[31737]=0;V(989,7165,a|0,0,0);a=x[31737];x[31737]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function Uea(a){a=a|0;var b=0;x[31737]=0;W(1002,a|0);b=x[31737];x[31737]=0;if((b|0)!=1){return dP(x[x[a+24>>2]+24>>2])|0}Y(T(0)|0)|0;x[31737]=0;V(989,5319,a|0,0,0);a=x[31737];x[31737]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function Sea(a){a=a|0;var b=0;x[31737]=0;W(1002,a|0);b=x[31737];x[31737]=0;if((b|0)!=1){return bP(x[x[a+24>>2]+24>>2])|0}Y(T(0)|0)|0;x[31737]=0;V(989,9346,a|0,0,0);a=x[31737];x[31737]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function Mea(a){a=a|0;var b=0;x[31737]=0;W(1002,a|0);b=x[31737];x[31737]=0;if((b|0)!=1){return Ao(x[x[a+24>>2]+24>>2])|0}Y(T(0)|0)|0;x[31737]=0;V(989,7133,a|0,0,0);a=x[31737];x[31737]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function Lea(a){a=a|0;var b=0;x[31737]=0;W(1002,a|0);b=x[31737];x[31737]=0;if((b|0)!=1){return xq(x[x[a+24>>2]+24>>2])|0}Y(T(0)|0)|0;x[31737]=0;V(989,6822,a|0,0,0);a=x[31737];x[31737]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function Kea(a){a=a|0;var b=0;x[31737]=0;W(1002,a|0);b=x[31737];x[31737]=0;if((b|0)!=1){return XO(x[x[a+24>>2]+24>>2])|0}Y(T(0)|0)|0;x[31737]=0;V(989,6940,a|0,0,0);a=x[31737];x[31737]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function Jea(a){a=a|0;var b=0;x[31737]=0;W(1002,a|0);b=x[31737];x[31737]=0;if((b|0)!=1){return WO(x[x[a+24>>2]+24>>2])|0}Y(T(0)|0)|0;x[31737]=0;V(989,7008,a|0,0,0);a=x[31737];x[31737]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function Iea(a){a=a|0;var b=0;x[31737]=0;W(1002,a|0);b=x[31737];x[31737]=0;if((b|0)!=1){return wq(x[x[a+24>>2]+24>>2])|0}Y(T(0)|0)|0;x[31737]=0;V(989,7480,a|0,0,0);a=x[31737];x[31737]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function AG(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;e=c+8|0;Sw(e,b);x[31737]=0;d=c+20|0;S(11,d|0,1,e|0);b=x[31737];x[31737]=0;a:{if((b|0)!=1){x[31737]=0;O(12,a|0,d|0);a=x[31737];x[31737]=0;if((a|0)==1){b=N()|0;Ub(d);break a}Ub(c+20|0);tb(c+8|0);fb=c+32|0;return}b=N()|0}tb(c+8|0);Q(b|0);p()}function uaa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;a:{if(!x[b+12>>2]){c=x[d>>2];break a}e=ib[x[b+16>>2]](x[b+8>>2],c,0,0)|0;c=x[d>>2];if((e|0)<0){break a}d=x[d+4>>2];e=c;while(1){if(!d){break a}f=ib[x[b+12>>2]](x[b+8>>2],e,d)|0;if(!f){break a}g=f+g|0;d=d-f|0;e=e+f|0;continue}}bc(a,c,g)}function tm(a,b){var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;d=Jb(b);e=c,f=Yc(x[b+4>>2],y[b+11|0]),x[e+12>>2]=f;x[c+8>>2]=x[a+4>>2]-1;Wg(d,d+x[Gb(c+12|0,c+8|0)>>2]|0,x[a>>2]);d=x[a>>2];e=c,f=Yc(x[b+4>>2],y[b+11|0]),x[e+12>>2]=f;a=x[a+4>>2];x[c+8>>2]=a-1;Vm(d+x[Gb(c+12|0,c+8|0)>>2]|0,a+d|0,78832);fb=c+16|0}function pr(a){var b=0,c=0;b=fb-32|0;fb=b;x[b+24>>2]=0;x[b+28>>2]=0;x[b+16>>2]=0;x[b+20>>2]=0;x[b+8>>2]=0;x[b+12>>2]=0;x[b>>2]=0;x[b+4>>2]=0;c=a+288|0;fC(c,zV(c),b);x[b+24>>2]=0;x[b+28>>2]=0;x[b+16>>2]=0;x[b+20>>2]=0;x[b+8>>2]=0;x[b+12>>2]=0;x[b>>2]=0;x[b+4>>2]=0;a=a+800|0;fC(a,sC(a),b);fb=b+32|0}function Yea(a){a=a|0;var b=0;x[31737]=0;W(1002,a|0);b=x[31737];x[31737]=0;if((b|0)!=1){return+OA(x[x[a+24>>2]+24>>2])}Y(T(0)|0)|0;x[31737]=0;V(989,10165,a|0,0,0);a=x[31737];x[31737]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function Rea(a){a=a|0;var b=0;x[31737]=0;W(1002,a|0);b=x[31737];x[31737]=0;if((b|0)!=1){return+aP(x[x[a+24>>2]+24>>2])}Y(T(0)|0)|0;x[31737]=0;V(989,15252,a|0,0,0);a=x[31737];x[31737]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function M3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;if(mh(a,x[b+8>>2],0)){Nx(b,c,d);return}f=x[a+12>>2];sI(x[a+16>>2],x[a+20>>2],b,c,d);e=a+24|0;a=(a+16|0)+(f<<3)|0;a:{if(e>>>0>=a>>>0){break a}while(1){sI(x[e>>2],x[e+4>>2],b,c,d);if(y[b+54|0]){break a}e=e+8|0;if(a>>>0>e>>>0){continue}break}}}function Gka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=yc(a,b,614);e=c+616|0;a=0;while(1){d=D(a,872);Kq(d+e|0,(b+d|0)+616|0);a=a+1|0;if((a|0)!=256){continue}break}a=zC(c+223848|0,b+223848|0);x[31737]=0;P(847,c+223860|0,b+223860|0)|0;b=x[31737];x[31737]=0;if((b|0)!=1){return c|0}b=N()|0;dc(a);Q(b|0);p()}function hE(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=fb-32|0;fb=f;x[f+8>>2]=c;g=f,h=kf(b),x[g+28>>2]=h;c=f+8|0;ug(c,b,x[Gb(c,f+28|0)>>2]);b=_e(c);x[31737]=0;aa(237,a|0,b|0,x[f+8>>2],d|0,e|0);a=x[31737];x[31737]=0;if((a|0)!=1){Kc(c);fb=f+32|0;return}a=N()|0;Kc(f+8|0);Q(a|0);p()}function aL(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=fb-16|0;fb=d;a=Nt(a);x[a+32>>2]=b;x[a>>2]=94908;e=d+12|0;bd(e,x[a+4>>2]);x[31737]=0;b=R(1192,x[d+12>>2])|0;f=x[31737];x[31737]=0;if((f|0)!=1){Zb(e);x[a+40>>2]=c;x[a+36>>2]=b;g=a,h=jo(b),v[g+44|0]=h;fb=d+16|0;return}b=N()|0;Zb(d+12|0);no(a);Q(b|0);p()}function lq(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;d=c+12|0;bd(d,a);x[31737]=0;a=R(1211,x[c+12>>2])|0;e=x[31737];x[31737]=0;a:{b:{if((e|0)==1){break b}x[31737]=0;V(1222,a|0,111776,111802,b|0);a=x[31737];x[31737]=0;if((a|0)==1){break b}Zb(d);fb=c+16|0;break a}a=N()|0;Zb(c+12|0);Q(a|0);p()}return b}function I0(a,b,c){var d=0,e=0;d=fb-32|0;fb=d;e=d+8|0;Wf(e,c);x[31737]=0;c=d+20|0;S(124,c|0,b|0,e|0);b=x[31737];x[31737]=0;a:{b:{if((b|0)!=1){x[31737]=0;O(12,a|0,c|0);a=x[31737];x[31737]=0;if((a|0)==1){break b}Ub(c);tb(e);fb=d+32|0;return}c=N()|0;break a}c=N()|0;Ub(d+20|0)}tb(d+8|0);Q(c|0);p()}function Cf(a){var b=0,c=0,d=0;a:{b:{b=a;if(!(b&3)){break b}if(!y[b|0]){return 0}while(1){b=b+1|0;if(!(b&3)){break b}if(y[b|0]){continue}break}break a}while(1){c=b;b=b+4|0;d=x[c>>2];if(!((d^-1)&d-16843009&-2139062144)){continue}break}while(1){b=c;c=b+1|0;if(y[b|0]){continue}break}}return b-a|0}function lh(a,b){var c=0,d=0,e=0,f=0;d=fb-16|0;fb=d;a:{if(!b){b=0;break a}c=b>>31;e=(c^b)-c|0;c=G(e);bg(d,e,0,0,0,c+81|0);e=0+x[d+8>>2]|0;c=(x[d+12>>2]^65536)+(16414-c<<16)|0;c=e>>>0<f>>>0?c+1|0:c;f=b&-2147483648|c;c=x[d+4>>2];b=x[d>>2]}x[a>>2]=b;x[a+4>>2]=c;x[a+8>>2]=e;x[a+12>>2]=f;fb=d+16|0}function d$(a){var b=0,c=0,d=0,e=0;if(!y[a+12|0]){c=fb-16|0;fb=c;b=vb(c+12|0,x[x[a+8>>2]>>2]);e=x[vb(c+8|0,x[x[a+4>>2]>>2])>>2];d=fb-16|0;fb=d;a=x[b>>2];x[d+12>>2]=a;while(1){if(pd(a,e)){b=fb-16|0;fb=b;x[b+12>>2]=a;c$(b+12|0,-1);fb=b+16|0;a=x[vC(d+12|0)>>2];continue}break}fb=d+16|0;fb=c+16|0}}function _K(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=fb-16|0;fb=d;a=kL(a);x[a+32>>2]=b;x[a>>2]=95276;e=d+12|0;bd(e,x[a+4>>2]);x[31737]=0;b=R(38,x[d+12>>2])|0;f=x[31737];x[31737]=0;if((f|0)!=1){Zb(e);x[a+40>>2]=c;x[a+36>>2]=b;g=a,h=jo(b),v[g+44|0]=h;fb=d+16|0;return}b=N()|0;Zb(d+12|0);Ct(a);Q(b|0);p()}function RW(a){var b=0;a:{if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=860902483){break a}if(Bb(y[a+4|0]|y[a+5|0]<<8)>>>0>2|y[a+6|0]>128){break a}if(Bb(y[a+200|0]|y[a+201|0]<<8)>>>0>3999){break a}if(!Bb(y[a+140|0]|y[a+141|0]<<8)){break a}b=(Bb(y[a+148|0]|y[a+149|0]<<8)|0)==50}return b}function xea(a){a=a|0;var b=0;x[31737]=0;W(1002,a|0);b=x[31737];x[31737]=0;if((b|0)!=1){return x[x[a+24>>2]+8>>2]}Y(T(0)|0)|0;x[31737]=0;V(989,10946,a|0,0,0);a=x[31737];x[31737]=0;if((a|0)!=1){Z();return-1}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function K0(a,b,c){var d=0,e=0,f=0;d=fb-32|0;fb=d;x[d+28>>2]=c;x[d+8>>2]=192;e=x[a>>2];f=x[a+8>>2];c=x[Gb(d+28|0,d+8|0)>>2];if(!Mb(e,f,c)){c=kf(a)}e=d+8|0;ow(e,b);f=gc(d+16|0,x[d+8>>2],c);lc(d,x[a>>2],x[a+8>>2],x[f>>2],x[f+4>>2]);ow(e,b);Rb(x[d+8>>2]+c|0,0,192-c|0);Vb(a,x[d+28>>2]);fb=d+32|0}function Bea(a){a=a|0;var b=0;x[31737]=0;W(1002,a|0);b=x[31737];x[31737]=0;if((b|0)!=1){return+C[x[a+24>>2]+16>>3]}Y(T(0)|0)|0;x[31737]=0;V(989,7642,a|0,0,0);a=x[31737];x[31737]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function qW(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;e=fb-16|0;fb=e;x[e+12>>2]=6553600;i=e,j=$b(b),x[i+8>>2]=j;f=+(d>>>0)/6553600;g=e+12|0;b=e+8|0;h=yr(f*+A[Gb(g,b)>>2]);x[e+8>>2]=6553600;i=e,j=$b(c),x[i+4>>2]=j;i=e,j=yr(f*+A[Gb(b,e+4|0)>>2]),x[i+12>>2]=j;x[e+8>>2]=d-h;vn(a,h,Gb(b,g));fb=e+16|0}function b1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;x[d+12>>2]=c;a:{if(!Mb(x[b>>2],x[b+8>>2],c<<1)){break a}wc(d+12|0,65535);xg(a,z[d+12>>1]);c=wb(x[a>>2]);x[d+4>>2]=c;a=wb(x[a+4>>2]);while(1){if(!Ib(c,a)){break a}HE(b,d+10|0);w[c>>1]=z[d+10>>1];c=x[Md(d+4|0)>>2];continue}}fb=d+16|0}function Tia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Qi(a,b,c,d);x[a>>2]=42348;b=Nb(a+4208|0);x[a+4228>>2]=0;x[a+4220>>2]=0;x[a+4224>>2]=0;x[a+4232>>2]=x[c+24620>>2];r0(a+4260|0,80,150,80,255);x[31737]=0;O(947,a+44|0,2);c=x[31737];x[31737]=0;if((c|0)!=1){return a|0}c=N()|0;vc(b);ag(a);Q(c|0);p()}function qx(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+16|0]=0;v[a+17|0]=0;v[a+18|0]=0;v[a+19|0]=0;v[a+20|0]=0;v[a+21|0]=0;v[a+22|0]=0;v[a+23|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a+12|0]=0;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0}function a$(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+14|0]=0;v[a+15|0]=0;v[a+16|0]=0;v[a+17|0]=0;v[a+18|0]=0;v[a+19|0]=0;v[a+20|0]=0;v[a+21|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a+12|0]=0;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0}function By(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-160|0;fb=e;x[e+60>>2]=b;x[e+20>>2]=b;x[e+24>>2]=-1;f=e+16|0;Ii(f,0,0);QK(e,f,d,1);d=x[e+8>>2];g=x[e+12>>2];f=x[e>>2];h=x[e+4>>2];if(c){x[c>>2]=x[e+136>>2]+((x[e+20>>2]-x[e+60>>2]|0)+b|0)}x[a+8>>2]=d;x[a+12>>2]=g;x[a>>2]=f;x[a+4>>2]=h;fb=e+160|0}function nB(a,b,c){var d=0;d=x[a+480180>>2];a:{if((d|0)!=1048576){if((d|0)!=4){break a}d=y[b+813|0];if(c){v[b+813|0]=d&15|c<<4;break a}c=(d&240)>>>4|0;break a}if(c){v[b+813|0]=c;break a}c=y[b+813|0]}b:{if(!(v[b+851|0]&1)|!x[b+700>>2]){break b}c=c&255;if(!c){break b}Ck(a,b,b+700|0,c<<2,0)}}function hO(a,b){a=a|0;b=b|0;var c=0;b=fb-16|0;fb=b;x[a+4>>2]=0;x[a>>2]=47700;a=ac(8);x[31737]=0;b=P(36,b+4|0,12149)|0;c=x[31737];x[31737]=0;a:{b:{if((c|0)!=1){pc(a,b);x[31737]=0;S(98,a|0,48540,1006);a=x[31737];x[31737]=0;if((a|0)!=1){break a}c=N()|0;tb(b);break b}c=N()|0;jc(a)}Q(c|0)}p()}function eQ(a){a=a|0;var b=0,c=0;c=fb-16|0;fb=c;b=x[a+4256>>2];x[a+4240>>2]=b<<1;x[31737]=0;x[c+12>>2]=0;S(953,a+4208|0,b<<2,c+12|0);b=x[31737];x[31737]=0;a:{if((b|0)==1){b=T(125048)|0;if((gb|0)!=($(125048)|0)){break a}Y(b|0)|0;x[a+4240>>2]=0;Z()}x[a+4244>>2]=0;fb=c+16|0;return}Q(b|0);p()}function ZF(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=x[a+92>>2];e=x[a+96>>2];if(d|e){while(1){if((c|0)==(g|0)){x[a+96>>2]=e;x[a+92>>2]=d}else{f=(g<<3)+b|0;h=x[f>>2];d=d-qd((qd(0-d|0,31)&255)+d|0,8)|0;x[f>>2]=h+d;h=x[f+4>>2];e=e-qd((qd(0-e|0,31)&255)+e|0,8)|0;x[f+4>>2]=h+e;g=g+1|0;continue}break}}}function Wea(a){a=a|0;var b=0;x[31737]=0;W(1002,a|0);b=x[31737];x[31737]=0;if((b|0)!=1){return fP(x[a+24>>2])|0}Y(T(0)|0)|0;x[31737]=0;V(989,9782,a|0,0,0);a=x[31737];x[31737]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function Mia(a,b){a=a|0;b=b|0;var c=0,d=0;a:{b:{c=x[a+20>>2];b=x[c+4>>2];if((Vc(b,x[c+8>>2])|0)!=8){break b}d=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);if((d|0)!=1869112133){break b}c=y[b+4|0]|y[b+5|0]<<8|(y[b+6|0]<<16|y[b+7|0]<<24);x[a+4260>>2]=d;x[a+4264>>2]=c;break a}$z(a,a)}qu(a)}function Ara(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-16|0;fb=d;sf(b);x[d+12>>2]=0;a:{if(!Lk(a,d+12|0)){break a}f=c;c=x[d+12>>2];if(f>>>0<c>>>0){break a}while(1){if((c|0)==(e|0)){e=1;break a}v[d+11|0]=0;if(mi(a,d+11|0)){Xp(b,v[d+11|0]);e=e+1|0;continue}break}e=0}fb=d+16|0;return e|0}function q_(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;a=qg(a);b=b+236|0;e=xr(b);a:{while(1){if((b|0)!=(e|0)){d=z[b>>1];w[c+14>>1]=d;if(d){x[31737]=0;S(402,c+4|0,a|0,c+14|0);d=x[31737];x[31737]=0;if((d|0)==1){break a}}b=b+2|0;continue}break}fb=c+16|0;return}b=N()|0;Tv(a);Q(b|0);p()}function oB(a,b,c){var d=0;d=x[a+480180>>2];a:{if((d|0)!=1048576){if((d|0)!=4){break a}d=y[b+814|0];if(c){v[b+814|0]=d&15|c<<4;break a}c=(d&240)>>>4|0;break a}if(c){v[b+813|0]=c;break a}c=y[b+813|0]}b:{if(!(v[b+851|0]&1)|!x[b+700>>2]){break b}c=c&255;if(!c){break b}Ck(a,b,b+700|0,c,0)}}function Eka(a,b){a=a|0;b=b|0;var c=0,d=0;a:{if(Gd(y[b+24|0])){a=qg(a);c=_i(x[b>>2]);d=Rf(b);x[31737]=0;S(850,a|0,c|0,d|0);c=x[31737];x[31737]=0;if((c|0)==1){break a}x[31737]=0;P(849,a+12|0,b+12|0)|0;b=x[31737];x[31737]=0;if((b|0)==1){break a}v[a+24|0]=1}return}b=N()|0;fT(a);Q(b|0);p()}function wC(a,b,c,d,e){var f=0;a:{f=x[a>>2];if(!je(f,x[a+20>>2])|c>>>0>=f>>>0|f-c>>>0<d>>>0){break a}sn(b);b=$o(b,a);x[b+20>>2]=0;x[b>>2]=d;if(!Eh(b)){break a}if(x[a>>2]!=(d|0)){gs(b+68|0)}yc(x[b+20>>2],x[a+20>>2]+c|0,d);x[b+8>>2]=e?d:0;x[b+4>>2]=0;w[b+34>>1]=z[b+34>>1]&65533|(e?2:0)}}function qH(a,b,c){var d=0,e=0;d=fb-32|0;fb=d;e=Fb(a+16|0);x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];x[a+8>>2]=x[b+8>>2];x[a+12>>2]=x[b+12>>2];x[31737]=0;b=P(c|0,d+8|0,b+16|0)|0;c=x[31737];x[31737]=0;if((c|0)!=1){a=d+20|0;Sh(a,b);Ab(e,a);tb(a);tb(b);fb=d+32|0;return}b=N()|0;Hh(a);Q(b|0);p()}function $M(a){var b=0,c=0,d=0,e=0;d=fb-16|0;fb=d;b=a+120|0;_t(y[b+20|0]);c=fb-16|0;fb=c;x[c+12>>2]=d+15;a=fb-16|0;fb=a;e=x[18391];x[a+8>>2]=x[18390];x[a+12>>2]=e;e=x[18389];x[a>>2]=x[18388];x[a+4>>2]=e;b=ib[x[tq(a,yk(y[b+20|0]))>>2]](c+12|0,b)|0;fb=a+16|0;fb=c+16|0;fb=d+16|0;return b}function rba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=fb-16|0;fb=d;c=d+4|0;zo(c,a);if(x[b>>2]){DZ(b);a=x[b>>2];at(b);Db(a);e=zb(b),f=0,x[e>>2]=f;x[b>>2]=0;x[b+4>>2]=0}x[b>>2]=x[c>>2];x[b+4>>2]=x[c+4>>2];a=zb(c);e=zb(b),f=x[a>>2],x[e>>2]=f;x[a>>2]=0;x[c>>2]=0;x[c+4>>2]=0;nf(c);fb=d+16|0}function ok(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=x[a+4>>2];e=x[a+12>>2];i=x[a+8>>2];d=x[a>>2];while(1){if((b|0)!=(f|0)){if(!d){x[a>>2]=8;c=i;if((e|0)!=(c|0)){c=e-1|0;x[a+12>>2]=c}d=8;e=c;c=y[c|0]}g=c;d=d-1|0;x[a>>2]=d;c=g>>>1|0;x[a+4>>2]=c;h=g&1|h<<1;f=f+1|0;continue}break}return h}function cR(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-16|0;fb=d;x[d+12>>2]=b;a:{if(Ug(a)>>>0>=b>>>0){f=x[a>>2];e=oc(f,x[a+4>>2]);x[d+8>>2]=e;bR(f,x[Gb(d+12|0,d+8|0)>>2],c);if(b>>>0>e>>>0){nA(a,b-e|0,c);break a}Ih(a,x[a>>2]+(b<<2)|0);break a}tr(a);qm(a,Mf(a,b));nA(a,b,c)}fb=d+16|0}function hfa(a){a=a|0;var b=0;x[31737]=0;W(1027,a|0);b=x[31737];x[31737]=0;a:{if((b|0)==1){Y(T(0)|0)|0;x[31737]=0;V(989,11990,a|0,0,0);a=x[31737];x[31737]=0;if((a|0)==1){break a}Z();a=0}return a|0}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function ai(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;d=fb-16|0;fb=d;e=fb-16|0;fb=e;c=e+4|0;x[c+4>>2]=1;g=c,h=Ec(16),x[g+8>>2]=h;b=ym(x[c+8>>2]);x[b>>2]=41240;g=Un(nc(b)),h=41372,x[g>>2]=h;b=d+8|0;f=Wn(c);Vn(b,nc(f),f);zm(c);fb=e+16|0;Ef(a,b);ke(b);fb=d+16|0;x[a+8>>2]=0;Nd(a+12|0);return a}function Qfa(a){a=a|0;var b=0;x[31737]=0;W(1002,a|0);b=x[31737];x[31737]=0;if((b|0)!=1){return x[a+16>>2]}Y(T(0)|0)|0;x[31737]=0;V(989,5690,a|0,0,0);a=x[31737];x[31737]=0;if((a|0)!=1){Z();return-1}a=N()|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function _D(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=fb-32|0;fb=e;x[e+8>>2]=c;f=e,g=kf(b),x[f+28>>2]=g;c=e+8|0;ug(c,b,x[Gb(c,e+28|0)>>2]);b=_e(c);x[31737]=0;V(344,a|0,b|0,x[e+8>>2],d|0);a=x[31737];x[31737]=0;if((a|0)!=1){Kc(c);fb=e+32|0;return}a=N()|0;Kc(e+8|0);Q(a|0);p()}function Zpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-16|0;fb=d;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);Rd(d+8|0,x[vb(d+4|0,a)>>2]);a:{if(b){x[31737]=0;O(642,a|0,b|0);e=x[31737];x[31737]=0;if((e|0)==1){break a}yp(a,b,c)}b=d+8|0;Qd(b);Yj(b);fb=d+16|0;return a|0}a=N()|0;Yj(d+8|0);Q(a|0);p()}function P7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=fb-16|0;fb=g;x[g+12>>2]=b;b=g+8|0;bd(b,x[d+28>>2]);x[31737]=0;d=R(1211,x[g+8>>2])|0;h=x[31737];x[31737]=0;if((h|0)!=1){Zb(b);gK(a,f+24|0,g+12|0,c,e,d);fb=g+16|0;return x[g+12>>2]}a=N()|0;Zb(g+8|0);Q(a|0);p()}function O7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=fb-16|0;fb=g;x[g+12>>2]=b;b=g+8|0;bd(b,x[d+28>>2]);x[31737]=0;d=R(1211,x[g+8>>2])|0;h=x[31737];x[31737]=0;if((h|0)!=1){Zb(b);fK(a,f+16|0,g+12|0,c,e,d);fb=g+16|0;return x[g+12>>2]}a=N()|0;Zb(g+8|0);Q(a|0);p()}function s1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-16|0;fb=d;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);Rd(d+8|0,x[vb(d+4|0,a)>>2]);a:{if(b){x[31737]=0;O(226,a|0,b|0);e=x[31737];x[31737]=0;if((e|0)==1){break a}XE(a,b,c)}b=d+8|0;Qd(b);ch(b);fb=d+16|0;return a|0}a=N()|0;ch(d+8|0);Q(a|0);p()}function UZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-16|0;fb=d;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);Rd(d+8|0,x[vb(d+4|0,a)>>2]);a:{if(b){x[31737]=0;O(461,a|0,b|0);e=x[31737];x[31737]=0;if((e|0)==1){break a}tD(a,b,c)}b=d+8|0;Qd(b);im(b);fb=d+16|0;return a|0}a=N()|0;im(d+8|0);Q(a|0);p()}function QP(a,b,c){v[a+12|0]=0;x[c>>2]=0;x[b>>2]=0;x[a+28>>2]=0;x[a+32>>2]=0;w[a+24>>1]=0;x[a+36>>2]=0;x[a+40>>2]=0;x[a+44>>2]=0;x[a+48>>2]=0;PP(a+60|0);PP(a+52|0);Hq(a+49956|0);Hq(a+58148|0);Hq(a+66340|0);Hq(a+74532|0);Rb(a+228|0,0,32768);Rb(a+32996|0,0,512);Rb(a+33508|0,0,16384)}function uja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-16|0;fb=d;c=Hf(a,c);$d(d,x[a+36>>2]);a:{b:{if(!c){Pc(d,a+32|0,5);e=-1;if(!Hb(x[x[d>>2]>>2],x[d+4>>2])){break b}break a}e=x[c+16>>2]}f=x[a+36>>2];c:{if(!((e|0)!=4&(e|0)!=-1)){Lk(f,b);break c}KN(f,b,e)}f=c}ff(a,f);fb=d+16|0}function rj(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;x[e+12>>2]=d;g=Nh(e+8|0,b);b=fb-16|0;fb=b;d=x[e+12>>2];x[b+12>>2]=d;x[b+8>>2]=d;f=-1;d=wt(0,0,c,d);a:{if((d|0)<0){break a}h=a;d=d+1|0;a=Ed(d);x[h>>2]=a;if(!a){break a}f=wt(a,d,c,x[b+12>>2])}fb=b+16|0;Mh(g);fb=e+16|0;return f}function p2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-32|0;fb=e;x[e+24>>2]=d;x[e+28>>2]=c;x[31737]=0;d=e+8|0;V(168,d|0,b|0,e+28|0,e+24|0);c=x[31737];x[31737]=0;if((c|0)!=1){c=e+16|0;Pp(c,x[e+8>>2],x[e+12>>2]);Ef(a,c);ke(c);ke(d);ke(b);fb=e+32|0;return}a=N()|0;ke(b);Q(a|0);p()}function mla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-16|0;fb=d;x[d+12>>2]=b;a:{if(dp(a)>>>0>=b>>>0){f=x[a>>2];e=Vc(f,x[a+4>>2]);x[d+8>>2]=e;Vh(f,x[Gb(d+12|0,d+8|0)>>2],c);if(b>>>0>e>>>0){Fp(a,b-e|0,c);break a}or(a,x[a>>2]+b|0);break a}_v(a);$k(a,bm(a,b));Fp(a,b,c)}fb=d+16|0}function Zp(a,b,c,d,e,f){var g=0,h=0,i=0;g=fb-16|0;fb=g;Kg(a+12|0,d);a:{if(!b){d=0;b=0;break a}if(b>>>0>=f>>>0){Zj();p()}d=Ec(D(b,e));x[g+12>>2]=b;x[g+8>>2]=d;d=x[g+12>>2];b=x[g+8>>2]}x[a>>2]=b;c=b+D(c,e)|0;x[a+8>>2]=c;x[a+4>>2]=c;h=nc(a),i=b+D(d,e)|0,x[h>>2]=i;fb=g+16|0;return a}function V7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=fb-16|0;fb=g;x[g+12>>2]=b;b=g+8|0;bd(b,x[d+28>>2]);x[31737]=0;d=R(28,x[g+8>>2])|0;h=x[31737];x[31737]=0;if((h|0)!=1){Zb(b);jK(a,f+24|0,g+12|0,c,e,d);fb=g+16|0;return x[g+12>>2]}a=N()|0;Zb(g+8|0);Q(a|0);p()}function U7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=fb-16|0;fb=g;x[g+12>>2]=b;b=g+8|0;bd(b,x[d+28>>2]);x[31737]=0;d=R(28,x[g+8>>2])|0;h=x[31737];x[31737]=0;if((h|0)!=1){Zb(b);iK(a,f+16|0,g+12|0,c,e,d);fb=g+16|0;return x[g+12>>2]}a=N()|0;Zb(g+8|0);Q(a|0);p()}function Ju(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;a:{if(!b){break a}i=Ob(a+1074312|0,73)?c- -64|0:c;c=120;g=Gj(a);j=g^-1;e=1;while(1){if(!c){break a}k=c;c=c>>>1|0;h=e+c|0;f=wh(a,h,i,d);if(!(f>>>0>b>>>0&j)&(!(!f|g)|b>>>0<=f>>>0)){continue}e=h+1|0;c=(c^-1)+k|0;continue}}return e}function Cra(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;x[c+12>>2]=b;a:{if(oc(x[a>>2],x[a+4>>2])>>>0>511){break a}if(!Dd(b)){break a}x[31737]=0;d=a;a=c+12|0;O(501,d|0,a|0);e=x[31737];x[31737]=0;d=b;if((e|0)!=1){break a}b=N()|0;og(a);Q(b|0);p()}og(c+12|0);fb=c+16|0;return d|0}function ri(a){var b=E(0),c=0,d=0;c=(q(a),j(2));d=c>>>23&255;if(d>>>0<=149){if(d>>>0<=125){return E(a*E(0))}a=(c|0)>=0?a:E(-a);b=E(E(E(a+E(8388608))+E(-8388608))-a);a:{if(b>E(.5)){a=E(E(a+b)+E(-1));break a}a=E(a+b);if(!(b<=E(-.5))){break a}a=E(a+E(1))}a=(c|0)>=0?a:E(-a)}return a}function maa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=ym(a);x[d>>2]=77940;a=uM(nc(d),rM(b));x[a>>2]=78272;g$(a+8|0,65536);c=a+20|0;Rb(c,0,192);e=a+212|0;while(1){x[c>>2]=0;x[c+4>>2]=0;v[c+8|0]=0;c=c+12|0;if((e|0)!=(c|0)){continue}break}Rb(e,0,64);x[a+276>>2]=b;x[a>>2]=78084;return d|0}function f3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=a+60|0;d=Qt(c);x[a>>2]=94368;x[d>>2]=94388;x[a+60>>2]=94428;x[a>>2]=94408;x[a+4>>2]=0;e=c;c=a+8|0;so(e,c);x[a>>2]=94368;x[d>>2]=94388;x[31737]=0;P(108,c|0,b|0)|0;b=x[31737];x[31737]=0;if((b|0)!=1){return a|0}a=N()|0;Bl(d);Q(a|0);p()}function Ss(a,b,c){var d=0,e=0,f=0;e=fb-16|0;fb=e;d=y[b|0];a:{if(!d){d=0;break a}b:{if(!y[b+1|0]){v[a|0]=d;break b}d=0;if(!eq(e+12|0,b,c)){break a}f=x[e+12>>2];b=Tx(f,c);c:{if((b|0)!=-1){break c}b=32;if((f|0)==8239){break c}if((f|0)!=160){break a}}v[a|0]=b}d=1}fb=e+16|0;return d}function PZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=fb+-64|0;fb=c;e=c+44|0;ug(e,a,32);a=x[c+44>>2];d=c+20|0;wg(d,2,_e(e),a);x[31737]=0;a=c+32|0;O(219,a|0,d|0);d=x[31737];x[31737]=0;if((d|0)!=1){d=c+12|0;Kn(d,b);tm(d,a);tb(a);Kc(e);fb=c- -64|0;break a}a=N()|0;Kc(c+44|0);Q(a|0);p()}}function TP(a,b){var c=0,d=0,e=0,f=0;c=fb-96|0;fb=c;TQ(b,c,c+96|0);b=0;while(1){if((b|0)==12){x[a+104>>2]=0;x[a+96>>2]=!(x[a+88>>2]|x[a+92>>2]);x[a+100>>2]=0;fb=c+96|0}else{d=b<<3;e=d+a|0;f=c+d|0;d=x[f+4>>2];x[e>>2]=x[f>>2];x[e+4>>2]=d&65535;b=b+1|0;continue}break}x[a+112>>2]=0}function SF(a,b,c,d){var e=0,f=0,g=0;b=x[a+1076>>2]+(b-(b&c?c<<1:0)|0)|0;x[a+1076>>2]=b;c=b+x[a+1080>>2]|0;x[a+1080>>2]=c;e=d;d=x[a+1068>>2];w[e+(d<<1)>>1]=y[a+1084|0]?c:b;x[a+1064>>2]=x[a+1064>>2]+1;f=a,g=_d(z[x[a+1060>>2]+34>>1])+d|0,x[f+1068>>2]=g;x[a+1072>>2]=x[a+1072>>2]-1}function jja(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-32|0;fb=c;x[c+12>>2]=-1;x[c+16>>2]=0;x[c+4>>2]=0;Fb(c+20|0);x[31737]=0;x[c+4>>2]=x[c+4>>2]&-1332|1058;x[c+8>>2]=1;d=a;a=c+4|0;S(80,d|0,b|0,a|0);b=x[31737];x[31737]=0;if((b|0)!=1){Hh(a);fb=c+32|0;return}a=N()|0;Hh(c+4|0);Q(a|0);p()}function LY(a,b,c,d){var e=0,f=0;e=fb-16|0;fb=e;x[e+12>>2]=a;a:{if(!(!c|b)){a=Ze(+(D(a,d)>>>0)*.25*1e4);break a}if(!(!a|!b)){wc(e+12|0,10);a=D(y[x[e+12>>2]+25216|0],1e4);break a}f=+(a>>>0);if(a-1>>>0<=9){a=Ze(733.8401379310345/f*1e4);break a}a=Ze(f/.264*1e4)}fb=e+16|0;return a}function o0(a){var b=0,c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;e=xb(a,31),f=0,v[e|0]=f;d=Li(a,Wo(a),0);v[c+15|0]=0;d=Vj(a,d);Vm(d+a|0,Wo(a),c+15|0);while(1){if((b|0)!=(d|0)){a:{if(v[xb(a,b)|0]>=32){if(y[xb(a,b)|0]!=127){break a}}e=xb(a,b),f=32,v[e|0]=f}b=b+1|0;continue}break}fb=c+16|0}function YZ(a){var b=0,c=0;b=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);a:{b:{if((b|0)!=1297108297){if((b|0)!=778924148){break a}if((y[a+34|0]|y[a+35|0]<<8)>>>0<=255){break b}break a}if((y[a+34|0]|y[a+35|0]<<8)>>>0>255){break a}}c=(y[a+36|0]|y[a+37|0]<<8)>>>0<4e3}return c}function We(a){var b=0,c=0;b=fb-32|0;fb=b;v[b+8|0]=0;x[b>>2]=0;x[b+4>>2]=4194432;kF(b+9|0);x[a>>2]=x[b>>2];c=x[b+8>>2];x[a+4>>2]=x[b+4>>2];x[a+8>>2]=c;c=x[b+16>>2];x[a+12>>2]=x[b+12>>2];x[a+16>>2]=c;c=x[b+24>>2];x[a+20>>2]=x[b+20>>2];x[a+24>>2]=c;v[a+28|0]=y[b+28|0];fb=b+32|0}function N7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;a=fb-16|0;fb=a;x[a+12>>2]=b;b=a+8|0;bd(b,x[d+28>>2]);x[31737]=0;d=R(1211,x[a+8>>2])|0;g=x[31737];x[31737]=0;if((g|0)!=1){Zb(b);eK(f+20|0,a+12|0,c,e,d);fb=a+16|0;return x[a+12>>2]}b=N()|0;Zb(a+8|0);Q(b|0);p()}function bn(a,b,c,d){var e=0,f=0,g=0;a:{f=D(b,872)+a|0;e=x[f+1075648>>2];if(!e){break a}if(!Qj(y[e+31|0])){break a}g=y[e+34|0]-1|0;if((g&255)>>>0>249){break a}a=x[vd(a+906300|0,g)>>2];if(!a){break a}ib[x[x[a>>2]+96>>2]](a,e,c,d,b);if(c>>>0>250){break a}w[f+1075834>>1]=65535}}function It(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;d=ac(16);if(!y[502241]){v[502241]=1}a=gc(c+8|0,a,126432);x[31737]=0;e=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=e;a=U(1178,d|0,c|0,b|0)|0;b=x[31737];x[31737]=0;if((b|0)!=1){da(a|0,124356,1179);p()}a=N()|0;jc(d);Q(a|0);p()}function yQ(a){a=a|0;var b=0,c=0;c=fb-16|0;fb=c;b=x[x[a+16>>2]+1074404>>2];x[31737]=0;x[c+12>>2]=0;S(953,a+4208|0,D(b,254)|0,c+12|0);b=x[31737];x[31737]=0;a:{if((b|0)==1){b=T(125048)|0;if((gb|0)!=($(125048)|0)){break a}Y(b|0)|0;Z()}x[a+4220>>2]=0;fb=c+16|0;return}Q(b|0);p()}function T7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;a=fb-16|0;fb=a;x[a+12>>2]=b;b=a+8|0;bd(b,x[d+28>>2]);x[31737]=0;d=R(28,x[a+8>>2])|0;g=x[31737];x[31737]=0;if((g|0)!=1){Zb(b);hK(f+20|0,a+12|0,c,e,d);fb=a+16|0;return x[a+12>>2]}b=N()|0;Zb(a+8|0);Q(b|0);p()}function CH(a,b,c,d,e,f){var g=0,h=0,i=0,j=0;g=fb-16|0;fb=g;x[g+12>>2]=c;c=g+12|0;wc(c,f);wc(c,65535);h=z[g+12>>1];xg(a,h);c=0;while(1){if((c|0)==(h|0)){fb=g+16|0}else{f=y[b+c|0];i=Wr(x[a>>2],x[a+4>>2],c),j=(d|0)==(f|0)?-1:(e|0)==(f|0)?-2:f,w[i>>1]=j;c=c+1|0;continue}break}}function loa(a,b){a=a|0;b=b|0;var c=0,d=0;a:{b:{c=y[a+11|0];c:{d:{if(Cd(c)){c=x[a+4>>2];d=ej(x[a+8>>2])-1|0;if((c|0)==(d|0)){break d}break c}d=1;c=Fh(c);if((c|0)!=1){break b}}hy(a,d,1,d,d,0);c=d}d=x[a>>2];Yd(a,c+1|0);break a}Me(a,c+1|0);d=a}a=(c<<2)+d|0;yd(a,b);yd(a+4|0,0)}function e0(a,b){var c=0,d=0,e=0;d=fb-16|0;fb=d;x[d+12>>2]=b;c=fb-16|0;fb=c;x[c+12>>2]=153391689;x[c+8>>2]=2147483647;e=Gb(c+12|0,c+8|0);fb=c+16|0;c=b;b=x[e>>2];if(c>>>0<=b>>>0){a=rE(a);if(a>>>0<b>>>1>>>0){x[d+8>>2]=a<<1;b=x[ad(d+8|0,d+12|0)>>2]}fb=d+16|0;return b}dd();p()}function Ila(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;a=SV(d+4|0,a+8|0,b);b=x[a>>2];a:{while(1){if(x[a+4>>2]==(b|0)){break a}x[31737]=0;O(786,b|0,c|0);b=x[31737];x[31737]=0;if((b|0)!=1){b=x[a>>2]+32|0;x[a>>2]=b;continue}break}b=N()|0;he(a);Q(b|0);p()}he(a);fb=d+16|0}function G$(a,b){var c=0,d=0,e=0;d=fb-16|0;fb=d;x[d+12>>2]=b;c=fb-16|0;fb=c;x[c+12>>2]=107374182;x[c+8>>2]=2147483647;e=Gb(c+12|0,c+8|0);fb=c+16|0;c=b;b=x[e>>2];if(c>>>0<=b>>>0){a=C$(a);if(a>>>0<b>>>1>>>0){x[d+8>>2]=a<<1;b=x[ad(d+8|0,d+12|0)>>2]}fb=d+16|0;return b}dd();p()}function rd(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=fb-32|0;fb=e;g=x[b+8>>2];f=x[b>>2];lf(e+16|0,c,d);c=x[x[f>>2]+28>>2];d=x[e+20>>2];x[e+8>>2]=x[e+16>>2];x[e+12>>2]=d;ib[c|0](e+24|0,f,g,e+8|0);lf(a,x[e+24>>2],x[e+28>>2]);x[b+8>>2]=x[b+8>>2]+x[a+4>>2];fb=e+32|0}function oM(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-32|0;fb=e;lf(e+24|0,b,c);b=Ef(e+16|0,d);x[31737]=0;c=x[b+4>>2];x[e+8>>2]=x[b>>2];x[e+12>>2]=c;jg(164,a,x[e+24>>2],x[e+28>>2],e+8|0);a=x[31737];x[31737]=0;if((a|0)!=1){ke(d);fb=e+32|0;return}a=N()|0;ke(d);Q(a|0);p()}function jpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=fb-160|0;fb=b;e=-1;c=fb-16|0;fb=c;d=b+14|0;pX(c+8|0,d);f=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(f|0)){gd(a,x[c+12>>2])}fb=c+16|0;a=(f|0)==(g|0);if(!a){oX(d)}if(a){e=qX(d)}fb=b+160|0;return e|0}function bua(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=fb-624|0;fb=b;e=-1;c=fb-16|0;fb=c;d=b+14|0;$$(c+8|0,d);f=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(f|0)){gd(a,x[c+12>>2])}fb=c+16|0;a=(f|0)==(g|0);if(!a){_$(d)}if(a){e=a0(d)}fb=b+624|0;return e|0}function Sna(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);Rd(c+8|0,x[vb(c+4|0,a)>>2]);a:{if(b){x[31737]=0;O(226,a|0,b|0);d=x[31737];x[31737]=0;if((d|0)==1){break a}Zq(a,b)}b=c+8|0;Qd(b);ch(b);fb=c+16|0;return a|0}a=N()|0;ch(c+8|0);Q(a|0);p()}function Nqa(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);Rd(c+8|0,x[vb(c+4|0,a)>>2]);a:{if(b){x[31737]=0;O(590,a|0,b|0);d=x[31737];x[31737]=0;if((d|0)==1){break a}jD(a,b)}b=c+8|0;Qd(b);ch(b);fb=c+16|0;return a|0}a=N()|0;ch(c+8|0);Q(a|0);p()}function EY(a,b){var c=0,d=0;a:{c=x[b>>2];d=x[b+20>>2];if(!je(c,d)){break a}if(x[a+20>>2]==(d|0)){x[a+20>>2]=0;c=x[b>>2]}wc(a,c);c=z[a+34>>1]&-2|w[b+34>>1]&1;w[a+34>>1]=c;w[a+34>>1]=c&65471|z[b+34>>1]&64;if(!Eh(a)){break a}yc(x[a+20>>2],x[b+20>>2],Vk(x[a>>2],z[a+34>>1]))}}function rqa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;a=EJ(c+4|0,a,b);b=x[a+4>>2];d=x[a+8>>2];a:{while(1){if((b|0)==(d|0)){break a}x[31737]=0;W(599,b|0);e=x[31737];x[31737]=0;if((e|0)!=1){b=b+24|0;x[a+4>>2]=b;continue}break}b=N()|0;hc(a);Q(b|0);p()}hc(a);fb=c+16|0}function oo(a,b,c){var d=0,e=0,f=0;a:{if(!b){d=a;break a}while(1){d=Uua(a,b,10,0);e=hb;a=Sua(d,e,246,0)+a|0;c=c-1|0;v[c|0]=a|48;f=b>>>0>9;a=d;b=e;if(f){continue}break}}if(d){while(1){c=c-1|0;a=(d>>>0)/10|0;v[c|0]=D(a,246)+d|48;b=d>>>0>9;d=a;if(b){continue}break}}return c}function fta(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=fb-160|0;fb=b;e=-1;c=fb-16|0;fb=c;d=b+3|0;H_(c+8|0,d);f=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(f|0)){gd(a,x[c+12>>2])}fb=c+16|0;a=(f|0)==(g|0);if(!a){G_(d)}if(a){e=I_(d)}fb=b+160|0;return e|0}function Xp(a,b){a=a|0;b=b|0;var c=0,d=0;a:{b:{c=y[a+11|0];c:{d:{if(Cd(c)){c=x[a+4>>2];d=ej(x[a+8>>2])-1|0;if((c|0)==(d|0)){break d}break c}d=10;c=Fh(c);if((c|0)!=10){break b}}Wm(a,d,1,d,d,0,0);c=d}d=x[a>>2];Yd(a,c+1|0);break a}Me(a,c+1|0);d=a}a=c+d|0;fd(a,b);fd(a+1|0,0)}function Toa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=fb-208|0;fb=b;e=-1;c=fb-16|0;fb=c;d=b+4|0;QW(c+8|0,d);f=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(f|0)){gd(a,x[c+12>>2])}fb=c+16|0;a=(f|0)==(g|0);if(!a){OW(d)}if(a){e=RW(d)}fb=b+208|0;return e|0}function RF(a,b,c,d){var e=0,f=0;b=x[a+1076>>2]+(b-(b&c?c<<1:0)|0)|0;x[a+1076>>2]=b;c=b+x[a+1080>>2]|0;x[a+1080>>2]=c;v[x[a+1068>>2]+d|0]=y[a+1084|0]?c:b;x[a+1064>>2]=x[a+1064>>2]+1;e=a,f=x[a+1068>>2]+_d(z[x[a+1060>>2]+34>>1])|0,x[e+1068>>2]=f;x[a+1072>>2]=x[a+1072>>2]-1}function P8(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;h=(e-d|0)+b|0;a:{while(1){if((d|0)!=(e|0)){a=-1;if((b|0)==(c|0)){break a}f=v[b|0];g=v[d|0];if((f|0)<(g|0)){break a}if((f|0)>(g|0)){return 1}else{d=d+1|0;b=b+1|0;continue}}break}a=(c|0)!=(h|0)}return a|0}function Ar(a,b,c){var d=0,e=0,f=0,g=0;f=fb-16|0;fb=f;d=fb-32|0;fb=d;Id(d+24|0,a,b);a=fb-16|0;fb=a;e=c;b=x[d+28>>2];c=x[d+24>>2];g=b-c|0;e=e-g|0;x[a+12>>2]=e;ml(e,c,g);Ac(d+16|0,b,a+12|0);fb=a+16|0;a=x[d+16>>2];x[d+12>>2]=x[d+20>>2];Ac(f+8|0,a,d+12|0);fb=d+32|0;fb=f+16|0}function yta(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=fb-32|0;fb=b;e=-1;c=fb-16|0;fb=c;d=b+10|0;Zv(c+8|0,d);f=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(f|0)){gd(a,x[c+12>>2])}fb=c+16|0;a=(f|0)==(g|0);if(!a){a$(d)}if(a){e=b$(d)}fb=b+32|0;return e|0}function xla(a,b){a=a|0;b=b|0;var c=0,d=0;a:{b:{c=y[a+11|0];c:{d:{if(Cd(c)){c=x[a+4>>2];d=ej(x[a+8>>2])-1|0;if((c|0)==(d|0)){break d}break c}d=10;c=Fh(c);if((c|0)!=10){break b}}ZB(a,d,1,d,d,0);c=d}d=x[a>>2];Yd(a,c+1|0);break a}Me(a,c+1|0);d=a}a=c+d|0;fd(a,b);fd(a+1|0,0)}function vra(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=fb-16|0;fb=b;e=-1;c=fb-16|0;fb=c;d=b+11|0;ek(c+8|0,d);f=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(f|0)){gd(a,x[c+12>>2])}fb=c+16|0;a=(f|0)==(g|0);if(!a){hZ(d)}if(a){e=iZ(d)}fb=b+16|0;return e|0}function WE(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;a=zw(c+4|0,a,b);b=x[a+4>>2];d=x[a+8>>2];a:{while(1){if((b|0)==(d|0)){break a}x[31737]=0;W(229,b|0);e=x[31737];x[31737]=0;if((e|0)!=1){b=b+20|0;x[a+4>>2]=b;continue}break}b=N()|0;hc(a);Q(b|0);p()}hc(a);fb=c+16|0}function Q_(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=fb-16|0;fb=d;x[d+12>>2]=c;c=d+12|0;wc(c,256);wc(c,65535);f=z[d+12>>1];xg(a,f);c=0;while(1){if((c|0)==(f|0)){fb=d+16|0}else{e=y[b+c|0];g=Wr(x[a>>2],x[a+4>>2],c),h=(e|0)==255?-1:(e|0)==254?-2:e,w[g>>1]=h;c=c+1|0;continue}break}}function Ex(a,b,c,d,e){var f=0,g=0;a:{f=fb+-64|0;fb=f;g=f+44|0;ug(g,a,e);a=x[f+44>>2];e=f+20|0;wg(e,d,_e(g),a);x[31737]=0;a=f+32|0;O(219,a|0,e|0);d=x[31737];x[31737]=0;if((d|0)!=1){d=f+12|0;gc(d,b,c);tm(d,a);tb(a);Kc(g);fb=f- -64|0;break a}a=N()|0;Kc(f+44|0);Q(a|0);p()}}function Ee(a){var b=0,c=0,d=0;o(+a);b=j(1)|0;j(0)|0;d=b>>>20&2047;if(d>>>0<=1074){if(d>>>0<=1021){return a*0}a=(b|0)>0|(b|0)>=0?a:-a;c=a+4503599627370496+-4503599627370496-a;a:{if(c>.5){a=a+c+-1;break a}a=a+c;if(!(c<=-.5)){break a}a=a+1}a=(b|0)>0|(b|0)>=0?a:-a}return a}function nF(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;d=c+12|0;bd(d,a);x[31737]=0;a=R(28,x[c+12>>2])|0;e=x[31737];x[31737]=0;a:{if((e|0)==1){break a}x[31737]=0;a=P(29,a|0,b|0)|0;b=x[31737];x[31737]=0;if((b|0)==1){break a}Zb(d);fb=c+16|0;return a}a=N()|0;Zb(c+12|0);Q(a|0);p()}function ku(a){var b=0,c=0,d=E(0);c=y[a+4232|0];if(c>>>0>=5){v[a+4232|0]=0;c=0}if(v[a+4233|0]<0){v[a+4233|0]=127}b=v[a+4234|0];if((b|0)<0){v[a+4234|0]=127;b=127}a:{if((c|0)==3){d=E(E(1)-Ce(E(2),E(-E((b+1&255)>>>0))));break a}d=Ce(E(2),E(-E((b&255)>>>0)))}B[a+4224>>2]=d}function iia(a){a=a|0;var b=0,c=0,d=0,e=0;b=fb-16|0;fb=b;x[b+12>>2]=a;x[b+8>>2]=4104;a=0;d=x[b+8>>2];a:{if(d>>>0<4096){break a}c=x[b+12>>2];e=c+7&-8;c=e-c|0;if(c>>>0>d-4096>>>0){break a}x[b+12>>2]=e;x[b+8>>2]=d-c;a=e}if(!a){_(6053,9030,88,7400);p()}fb=b+16|0;return a|0}function VW(a){var b=0,c=0,d=0,e=0;c=fb-16|0;fb=c;b=wb(x[a>>2]);x[c+12>>2]=b;e=wb(x[a+4>>2]);while(1){a:{d=Ib(b,e);if(!d){break a}a=z[b>>1];b:{if(!((a|0)!=255&(a|0)!=99)){w[b>>1]=65535;break b}if(a>>>0>63){break a}}b=x[Md(c+12|0)>>2];continue}break}fb=c+16|0;return d^1}function _j(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=wb(x[b>>2]);f=wb(x[b+4>>2]);e=fb-16|0;fb=e;x[e+12>>2]=d;while(1){a:{if(!Ib(d,f)){break a}if(J$(c,x[d>>2],x[d+4>>2])){break a}d=x[lm(e+12|0)>>2];continue}break}fb=e+16|0;if(mc(d,wb(x[b+4>>2]))){ai(a);return}qp(a,d)}function Xja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-48|0;fb=d;sf(b);e=d+28|0;ug(e,a,c);a=x[d+28>>2];c=d+4|0;wg(c,1,_e(e),a);x[31737]=0;a=d+16|0;O(219,a|0,c|0);c=x[31737];x[31737]=0;if((c|0)!=1){Ab(b,a);tb(a);Kc(e);fb=d+48|0;break a}a=N()|0;Kc(d+28|0);Q(a|0);p()}}function yaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;a:{if(y[b+40|0]){break a}b:{if(!x[b+28>>2]){break b}d=x[c+4>>2];f=x[c>>2];while(1){if(!d){break a}e=ib[x[b+28>>2]](x[b+24>>2],f,d)|0;if(!e){break b}g=e+g|0;d=d-e|0;f=f+e|0;continue}}v[b+40|0]=1}bc(a,x[c>>2],g)}function MF(a,b,c){var d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;e=x[a+4>>2];f=e+b|0;x[a+4>>2]=f;a:{b:{if(!e){g=f-1|0;break b}g=f-1|0;if((g^e-1)>>>0>31){break b}a=x[a>>2];break a}a=x[a>>2];x[a+((f>>>0>=33?g>>>5|0:0)<<2)>>2]=0}Dp(d+8|0,a,e);Qw(x[d+8>>2],x[d+12>>2],b,c);fb=d+16|0}function v0(a,b){var c=0,d=0;a:{b:{a=a-12|0;c:{if(a>>>0>31){break c}d=1<<a;c=1;if(d&-2145904587){break a}if(d&65792){break b}if((a|0)!=7){break c}b=b&240;c=1;if(!b|(b|0)==96|(b|0)==224){break a}}return 0}b=b-96|0;c=0;if(b>>>0>=144){break a}c=297>>>(b>>>4)&1}return c}function rM(a){var b=0,c=0,d=0;b=fb-48|0;fb=b;kg(x[x[a>>2]-12>>2]+a|0,0);$d(b+32|0,a);a=Hi(a,0,0,2);$d(b+16|0,a);c=x[b+44>>2];x[b+8>>2]=x[b+40>>2];x[b+12>>2]=c;c=x[b+36>>2];x[b>>2]=x[b+32>>2];x[b+4>>2]=c;c=x[b+28>>2];d=x[b+24>>2];Zm(a,b);a=Su(d,c);fb=b+48|0;return a}function n$(a){var b=0;if(!((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=320012546|(y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24))!=184619540|y[a+8|0]>1|((y[a+9|0]-1&255)>>>0>7|(y[a+10|0]|y[a+11|0]<<8)>>>0>4096))){b=(y[a+12|0]|y[a+13|0]<<8)>>>0<4097}return b}function cq(a,b,c){var d=0,e=0,f=0;d=a*a;f=d*(d*d)*(d*1.58969099521155e-10+-2.5050760253406863e-8)+(d*(d*27557313707070068e-22+-.0001984126982985795)+.00833333333332249);e=d*a;if(!c){return e*(d*f+-.16666666666666632)+a}return a-(d*(b*.5-f*e)-b+e*.16666666666666632)}function X8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;a:{if(!y[a+44|0]){c=(c|0)>0?c:0;while(1){if((c|0)==(d|0)){break a}if(((f=a,g=Pf(v[b|0]),e=x[x[a>>2]+52>>2],ib[e](f|0,g|0)|0)|0)==-1){return d|0}else{b=b+1|0;d=d+1|0;continue}}}c=Tk(b,1,c,x[a+32>>2])}return c|0}function Q$(a,b,c){var d=0,e=0;d=fb-16|0;fb=d;v[d+15|0]=1;v[d+14|0]=a>>>2;a=y[df(d+15|0,d+14|0)|0];e=b>>>0<2|a>>>0<15;if(!e){v[d+13|0]=1;v[d+12|0]=(((a+b|0)-2&65535)>>>0)/((b-1&65535)>>>0);a=y[df(d+13|0,d+12|0)|0]}fb=d+16|0;return(c?a<<4|(e?15:0):a&15|(e?-16:0))&255}function BJ(a){var b=0,c=0,d=0,e=0,f=0;b=fb-16|0;fb=b;x[a>>2]=0;x[a+4>>2]=0;e=sc(a+8|0),f=0,v[e+128|0]=f;c=b+8|0;Rd(c,x[vb(b+4|0,a)>>2]);x[31737]=0;O(1285,a|0,30);d=x[31737];x[31737]=0;if((d|0)!=1){Zq(a,30);Qd(c);zJ(c);fb=b+16|0;return a}a=N()|0;zJ(b+8|0);Q(a|0);p()}function Tq(a,b,c,d){var e=0,f=0,g=0;a:{e=Xl(a,b);if((e|0)==255){break a}g=x[a>>2];if(Mj(g)){break a}f=Hd(a+318|0,e);e=LU(e);if(v[xb(f,10)|0]&1|d){yh(g,x[a+4>>2],b,e- -64&65535,KU(c,y[xb(f,2)|0]))}if(d){break a}yh(x[a>>2],x[a+4>>2],b,e+67&65535,KU(c,y[xb(f,3)|0]))}}function Oha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{if(x[b+4>>2]!=8){break a}b=x[b>>2];d=y[b+1|0]<<8;e=y[b+2|0]<<16|y[b+3|0]<<24;if((y[b|0]|d|e)!=1869112133){break a}c=y[b+4|0]|y[b+5|0]<<8|(y[b+6|0]<<16|y[b+7|0]<<24);x[a+4228>>2]=e|(d|y[b|0]);x[a+4232>>2]=c;ku(a)}}function Dia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{if(x[b+4>>2]!=8){break a}b=x[b>>2];d=y[b+1|0]<<8;e=y[b+2|0]<<16|y[b+3|0]<<24;if((y[b|0]|d|e)!=1869112133){break a}c=y[b+4|0]|y[b+5|0]<<8|(y[b+6|0]<<16|y[b+7|0]<<24);x[a+4260>>2]=e|(d|y[b|0]);x[a+4264>>2]=c;qu(a)}}function tv(a,b){a:{b:{if((b|0)!=31){if((b|0)!=15){break b}b=0;if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))==1196314451){break b}break a}b=0;if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=825446227){break a}}b=Bb(y[a+4|0]|y[a+5|0]<<8)>>>0>177}return b}function YB(a,b,c){var d=0,e=0,f=0;d=fb-16|0;fb=d;a=jC(d+4|0,a,b);b=x[a+4>>2];e=x[a+8>>2];a:{while(1){if((b|0)==(e|0)){break a}x[31737]=0;O(786,b|0,c|0);f=x[31737];x[31737]=0;if((f|0)!=1){b=b+32|0;x[a+4>>2]=b;continue}break}b=N()|0;hc(a);Q(b|0);p()}hc(a);fb=d+16|0}function Xh(a,b){var c=0,d=0,e=0;a:{if(!(v[a+480180|0]&1|b)){break a}e=x[a+24616>>2]&524288;b=0;while(1){if((b|0)==127){break a}c=(b<<5)+a|0;w[c+480286>>1]=64;d=c+480280|0;x[d>>2]=x[d>>2]&-257;d=c+480284|0;c=(b&3)-1>>>0<2;w[d>>1]=e?c<<8:c?192:64;b=b+1|0;continue}}}function t9(a){a=a|0;var b=0,c=0,d=0;c=x[a+44>>2];b=x[a+24>>2];if(c>>>0<b>>>0){x[a+44>>2]=b;c=b}d=-1;a:{if(!(y[a+48|0]&8)){break a}b=x[a+16>>2];if(b>>>0<c>>>0){ko(a,x[a+8>>2],x[a+12>>2],c);b=x[a+16>>2]}a=x[a+12>>2];if(a>>>0>=b>>>0){break a}d=Pf(v[a|0])}return d|0}function Q0(a,b,c){var d=0,e=0,f=0,g=0;d=fb-48|0;fb=d;sf(b);f=d+28|0;ug(f,a,c);a=x[d+28>>2];e=d+4|0;wg(e,3,_e(f),a);x[31737]=0;g=d+16|0;O(219,g|0,e|0);e=x[31737];x[31737]=0;if((e|0)!=1){Ab(b,g);tb(g);Kc(f);fb=d+48|0;return!c|(a|0)!=0}a=N()|0;Kc(d+28|0);Q(a|0);p()}function jsa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-48|0;fb=d;e=d+28|0;ug(e,a,c);a=x[d+28>>2];c=d+4|0;wg(c,2,_e(e),a);x[31737]=0;a=d+16|0;O(219,a|0,c|0);c=x[31737];x[31737]=0;if((c|0)!=1){om(b,a);tb(a);Kc(e);fb=d+48|0;break a}a=N()|0;Kc(d+28|0);Q(a|0);p()}}function Tja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-48|0;fb=d;e=d+28|0;ug(e,a,c);a=x[d+28>>2];c=d+4|0;wg(c,1,_e(e),a);x[31737]=0;a=d+16|0;O(219,a|0,c|0);c=x[31737];x[31737]=0;if((c|0)!=1){ze(b,a);tb(a);Kc(e);fb=d+48|0;break a}a=N()|0;Kc(d+28|0);Q(a|0);p()}}function Lh(a,b,c,d,e,f){var g=0;g=fb-32|0;fb=g;x[g+12>>2]=-1;x[g+16>>2]=0;x[g+4>>2]=0;Fb(g+20|0);x[g+8>>2]=f;x[31737]=0;x[g+4>>2]=x[g+4>>2]&e|d;d=a;a=g+4|0;S(c|0,d|0,b|0,a|0);b=x[31737];x[31737]=0;if((b|0)!=1){Hh(a);fb=g+32|0;return}a=N()|0;Hh(g+4|0);Q(a|0);p()}function zt(a,b){var c=0,d=0,e=0;d=-1;a:{if((a|0)==-1){break a}e=x[b+76>>2]<0;b:{c=x[b+4>>2];c:{if(!c){Uy(b);c=x[b+4>>2];if(!c){break c}}if(x[b+44>>2]-8>>>0<c>>>0){break b}}if(e){break a}return-1}c=c-1|0;x[b+4>>2]=c;v[c|0]=a;x[b>>2]=x[b>>2]&-17;d=a&255}return d}function Z$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-48|0;fb=d;e=d+28|0;ug(e,a,c);a=x[d+28>>2];c=d+4|0;wg(c,2,_e(e),a);x[31737]=0;a=d+16|0;O(219,a|0,c|0);c=x[31737];x[31737]=0;if((c|0)!=1){zc(b,a);tb(a);Kc(e);fb=d+48|0;break a}a=N()|0;Kc(d+28|0);Q(a|0);p()}}function GP(a,b){var c=0,d=0;x[a+4>>2]=b;x[a>>2]=126956;x[a+20>>2]=0;x[a+24>>2]=0;c=(b>>>5|0)+((b&31)!=0)|0;x[a+12>>2]=c;d=(b>>>0)/(c>>>0)|0;x[a+8>>2]=d;x[a+32>>2]=d>>>0>=31?-1:-1>>>31-d|0;x[a+28>>2]=b>>>0>=c>>>0?-1>>>32-d|0:0;x[a+16>>2]=(D(c,d)-b|0)+c;return a}function _ha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;x[a+4>>2]=b;x[a>>2]=0;b=lu(a+8|0,d);x[31737]=0;P(967,a+20|0,c|0)|0;c=x[31737];x[31737]=0;if((c|0)!=1){x[a+32>>2]=0;x[a+36>>2]=0;v[a+42|0]=0;v[a+40|0]=0;v[a+41|0]=y[a+41|0]&224|25;return a|0}a=N()|0;Eb(b);Q(a|0);p()}function Cx(a,b,c,d,e){var f=0;f=fb-32|0;fb=f;x[f+12>>2]=-1;x[f+16>>2]=0;x[f+4>>2]=0;x[f+8>>2]=0;Fb(f+20|0);x[31737]=0;x[f+4>>2]=x[f+4>>2]&e|d;d=a;a=f+4|0;S(c|0,d|0,b|0,a|0);b=x[31737];x[31737]=0;if((b|0)!=1){Hh(a);fb=f+32|0;return}a=N()|0;Hh(f+4|0);Q(a|0);p()}function Cl(a){var b=0,c=0;a:{b=x[a+1396>>2];if((b|0)>24){break a}if(!b){x[a+1392>>2]=0}while(1){if(y[a+1376|0]?0:x[a+1384>>2]){break a}c=Pt(a);if((c|0)==-1){break a}b=x[a+1396>>2];x[a+1396>>2]=b+8;x[a+1392>>2]=x[a+1392>>2]+(c<<b);if((b|0)<17){continue}break}}}function Bn(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=a;c=OC(b);e=fb-16|0;fb=e;a:{if(c>>>0<1073741808){b:{if(jr(c)){Me(d,c);break b}Uj(e+8|0,yn(c)+1|0);f=x[e+8>>2];yd(d,f);of(d,x[e+12>>2]);Yd(d,c);d=f}yd(Yi(d,b,c)+(c<<2)|0,0);fb=e+16|0;break a}pf();p()}return a|0}function yH(a,b,c,d){var e=0;e=fb-16|0;fb=e;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);Rd(e+8|0,x[vb(e+4|0,a)>>2]);a:{if(b){x[31737]=0;O(d|0,a|0,b|0);d=x[31737];x[31737]=0;if((d|0)==1){break a}Fp(a,b,c)}b=e+8|0;Qd(b);cj(b);fb=e+16|0;return a}a=N()|0;cj(e+8|0);Q(a|0);p()}function h4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-16|0;fb=e;b=ho(e+4|0,c,d);c=HK(0,Jb(b),0);x[31737]=0;a=U(1345,a|0,c|0,0)|0;c=x[31737];x[31737]=0;if((c|0)!=1){HK(Jb(a),Jb(b),Cb(x[a+4>>2],y[a+11|0])+1|0);Ub(b);fb=e+16|0;return}a=N()|0;Ub(b);Q(a|0);p()}function Zn(a,b){var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;a:{if(!b){b=0;break a}d=b;b=G(b);bg(c,d,0,0,0,b+81|0);d=0+x[c+8>>2]|0;b=(x[c+12>>2]^65536)+(16414-b<<16)|0;f=e>>>0>d>>>0?b+1|0:b;e=x[c+4>>2];b=x[c>>2]}x[a>>2]=b;x[a+4>>2]=e;x[a+8>>2]=d;x[a+12>>2]=f;fb=c+16|0}function Yka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=fb-48|0;fb=c;e=c+28|0;ug(e,a,32);a=x[c+28>>2];d=c+4|0;wg(d,1,_e(e),a);x[31737]=0;a=c+16|0;O(219,a|0,d|0);d=x[31737];x[31737]=0;if((d|0)!=1){zc(b,a);tb(a);Kc(e);fb=c+48|0;break a}a=N()|0;Kc(c+28|0);Q(a|0);p()}}function XZ(a){var b=0,c=0,d=0,e=0;d=y[a+32|0]|y[a+33|0]<<8;e=y[a+38|0]|y[a+39|0]<<8;c=y[a+34|0]|y[a+35|0]<<8;b=c+(y[a+36|0]|y[a+37|0]<<8)|0;a=0;a=b>>>0<c>>>0?1:a;c=b;b=b+e|0;a=(c>>>0>b>>>0?a+1|0:a)<<2|b>>>30;c=d;d=b<<2;b=c+d|0;hb=b>>>0<d>>>0?a+1|0:a;return b}function SC(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=fb-1024|0;fb=e;d=fb-16|0;fb=d;PC(d+8|0,e);f=x[d+12>>2];lc(d,x[a>>2],x[a+8>>2],x[d+8>>2],x[d+12>>2]);g=x[d+4>>2];if((g|0)==(f|0)){Vb(a,x[d+12>>2])}fb=d+16|0;if((f|0)==(g|0)){h=QC(e,c)>>>0<=b>>>0}fb=e+1024|0;return h}function e4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-16|0;fb=e;b=si(e+4|0,c,d);c=JK(0,Jb(b),0);x[31737]=0;a=U(543,a|0,c|0,0)|0;c=x[31737];x[31737]=0;if((c|0)!=1){JK(Jb(a),Jb(b),Cb(x[a+4>>2],y[a+11|0])+1|0);tb(b);fb=e+16|0;return}a=N()|0;tb(b);Q(a|0);p()}function Q1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-48|0;fb=c;d=-1;e=a;a=c+12|0;a:{if(!$F(e,a)){break a}d=0;if(!_F(a)){break a}if(b){a=x[b>>2];if(!x[b+4>>2]&a>>>0<$b(y[c+16|0]|y[c+17|0]<<8|(y[c+18|0]<<16|y[c+19|0]<<24))-8>>>0){break a}}d=1}fb=c+48|0;return d|0}function LB(a,b,c,d){var e=0,f=0,g=0;e=ce(a);a:{if(e){f=ec(a);while(1){a=e;e=z[a+16>>1];g=x[a+20>>2];if(Vl(c,d,e,g)){f=a;e=x[a>>2];if(e){continue}break a}if(!Vl(e,g,c,d)){break a}f=a+4|0;e=x[a+4>>2];if(e){continue}break}break a}a=ec(a);f=a}x[b>>2]=a;return f}function jH(a,b,c,d,e){var f=0,g=0;a:{f=fb-48|0;fb=f;sf(b);g=f+28|0;ug(g,a,d);a=x[f+28>>2];d=f+4|0;wg(d,e,_e(g),a);x[31737]=0;a=f+16|0;S(600,a|0,c|0,d|0);c=x[31737];x[31737]=0;if((c|0)!=1){Ab(b,a);tb(a);Kc(g);fb=f+48|0;break a}a=N()|0;Kc(f+28|0);Q(a|0);p()}}function eB(a,b,c,d){var e=0,f=0,g=0;e=ce(a);a:{if(e){f=ec(a);while(1){a=e;e=y[a+16|0];g=x[a+20>>2];if(Fo(c,d,e,g)){f=a;e=x[a>>2];if(e){continue}break a}if(!Fo(e,g,c,d)){break a}f=a+4|0;e=x[a+4>>2];if(e){continue}break}break a}a=ec(a);f=a}x[b>>2]=a;return f}function T0(a,b,c){var d=0,e=0,f=0,g=0;d=fb-48|0;fb=d;f=d+28|0;ug(f,a,c);a=x[d+28>>2];e=d+4|0;wg(e,3,_e(f),a);x[31737]=0;g=d+16|0;O(219,g|0,e|0);e=x[31737];x[31737]=0;if((e|0)!=1){zc(b,g);tb(g);Kc(f);fb=d+48|0;return!c|(a|0)!=0}a=N()|0;Kc(d+28|0);Q(a|0);p()}function yra(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;sf(b);v[c+15|0]=0;a:{if(!mi(a,c+15|0)){break a}f=y[c+15|0];d=1;while(1){if((e&255)==(f|0)){break a}v[c+14|0]=0;if(mi(a,c+14|0)){Xp(b,v[c+14|0]);e=e+1|0;continue}break}d=0}fb=c+16|0;return d|0}function XI(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;a=vJ(a,c);x[a>>2]=113244;c=xk(Jb(b));x[a+8>>2]=c;a:{if(!c){a=d+4|0;Rm(a,17963,b);x[31737]=0;W(1325,a|0);b=x[31737];x[31737]=0;if((b|0)!=1){break a}b=N()|0;tb(a);Q(b|0);p()}fb=d+16|0;return a|0}p()}function L5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;a=yJ(a,c);x[a>>2]=112044;c=xk(Jb(b));x[a+8>>2]=c;a:{if(!c){a=d+4|0;Rm(a,17901,b);x[31737]=0;W(1325,a|0);b=x[31737];x[31737]=0;if((b|0)!=1){break a}b=N()|0;tb(a);Q(b|0);p()}fb=d+16|0;return a|0}p()}function J5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;a=xJ(a,c);x[a>>2]=112076;c=xk(Jb(b));x[a+8>>2]=c;a:{if(!c){a=d+4|0;Rm(a,18082,b);x[31737]=0;W(1325,a|0);b=x[31737];x[31737]=0;if((b|0)!=1){break a}b=N()|0;tb(a);Q(b|0);p()}fb=d+16|0;return a|0}p()}function oH(a,b,c){var d=0;d=fb-16|0;fb=d;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);Rd(d+8|0,x[vb(d+4|0,a)>>2]);a:{if(b){x[31737]=0;O(c|0,a|0,b|0);c=x[31737];x[31737]=0;if((c|0)==1){break a}cY(a,b)}b=d+8|0;Qd(b);cj(b);fb=d+16|0;return a}a=N()|0;cj(d+8|0);Q(a|0);p()}function fP(a){var b=0,c=0;b=x[a+24>>2];c=z[b+1074448>>1];if(c>>>0>=Oj(Xb(x[b+484360>>2],y[b+484376|0]))>>>0){return z[x[a+24>>2]+1074446>>1]}a=x[a+24>>2];b=z[_b(x[Xb(x[a+484360>>2],y[a+484376|0])>>2],c)>>1];return vp(x[a+484344>>2],x[a+484348>>2],b)?b:-1}function M8(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;a:{while(1){if((d|0)!=(e|0)){a=-1;if((b|0)==(c|0)){break a}f=x[b>>2];g=x[d>>2];if((f|0)<(g|0)){break a}if((f|0)>(g|0)){return 1}else{d=d+4|0;b=b+4|0;continue}}break}a=(b|0)!=(c|0)}return a|0}function Ela(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=b;d=fb-16|0;fb=d;b=Hf(a,c);$d(d,x[a+36>>2]);a:{b:{if(!b){Pc(d,a+32|0,5);c=-1;if(!Hb(x[x[d>>2]>>2],x[d+4>>2])){break b}break a}c=x[b+16>>2]}VB(x[a+36>>2],e,c);f=1;g=b}ff(a,g);fb=d+16|0;return f|0}function Uy(a){var b=0,c=0;b=x[a+72>>2];x[a+72>>2]=b-1|b;if(x[a+20>>2]!=x[a+28>>2]){ib[x[a+36>>2]](a,0,0)|0}x[a+28>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;b=x[a>>2];if(b&4){x[a>>2]=b|32;return-1}c=x[a+44>>2]+x[a+48>>2]|0;x[a+8>>2]=c;x[a+4>>2]=c;return b<<27>>31}function PH(a,b,c,d){var e=0,f=0,g=0,h=0;a:{f=fb-16|0;fb=f;e=f+4|0;x[e+4>>2]=1;g=e,h=Ec(d),x[g+8>>2]=h;d=x[e+8>>2];x[31737]=0;P(c|0,d|0,b|0)|0;b=x[31737];x[31737]=0;if((b|0)!=1){b=a;a=Wn(e);Vn(b,nc(a),a);zm(e);fb=f+16|0;break a}a=N()|0;zm(e);Q(a|0);p()}}function S$(a,b,c){var d=0,e=0;d=fb-16|0;fb=d;e=0;a:{if(!a){break a}b:{c:{if(a>>>0<=15){if(b>>>0<2|c){break c}break b}if(b>>>0>1){break b}}e=a|-16;break a}v[d+15|0]=1;v[d+14|0]=(a>>>0)/((b-1&255)>>>0);e=y[df(d+15|0,d+14|0)|0]}a=e;fb=d+16|0;return a&255}function rf(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=a;e=fb-16|0;fb=e;a:{if(b>>>0<2147483632){b:{if(Rk(b)){Me(d,b);break b}sg(e+8|0,Dh(b)+1|0);f=x[e+8>>2];yd(d,f);of(d,x[e+12>>2]);Yd(d,b);d=f}fd(hm(d,b,c)+b|0,0);fb=e+16|0;break a}pf();p()}return a|0}function mM(a){var b=0,c=0,d=0,e=0;if(!y[a+12|0]){b=fb-16|0;fb=b;d=vb(b+12|0,x[x[a+8>>2]>>2]);e=x[vb(b+8|0,x[x[a+4>>2]>>2])>>2];c=fb-16|0;fb=c;a=x[d>>2];x[c+12>>2]=a;while(1){if(pd(a,e)){Eb(Vp(a));a=x[qk(c+12|0)>>2];continue}break}fb=c+16|0;fb=b+16|0}}function kN(a){var b=0,c=0,d=0,e=0;if(!y[a+12|0]){b=fb-16|0;fb=b;d=vb(b+12|0,x[x[a+8>>2]>>2]);e=x[vb(b+8|0,x[x[a+4>>2]>>2])>>2];c=fb-16|0;fb=c;a=x[d>>2];x[c+12>>2]=a;while(1){if(pd(a,e)){Wj(Az(a));a=x[$q(c+12|0)>>2];continue}break}fb=c+16|0;fb=b+16|0}}function f4(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;a=fb-32|0;fb=a;b=si(a+20|0,b,c);x[31737]=0;c=U(1346,a+8|0,d|0,e|0)|0;d=x[31737];x[31737]=0;if((d|0)!=1){d=ni(Jb(b),Jb(c));tb(c);tb(b);fb=a+32|0;return((d|0)<0?-1:(d|0)!=0)|0}a=N()|0;tb(b);Q(a|0);p()}function dD(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;RY(a,b);cd(a,$b(y[b+8|0]|y[b+9|0]<<8|(y[b+10|0]<<16|y[b+11|0]<<24))+504|0);QY(a,d);a:{b=$b(y[b+32|0]|y[b+33|0]<<8|(y[b+34|0]<<16|y[b+35|0]<<24));if(!b){break a}if(!cd(a,b)){break a}fD(a,c);return}Rb(c,0,80)}function bba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=x[b>>2];e=x[b+8>>2];f=x[b+4>>2];a=0;a:while(1){if((a|0)!=(f|0)){g=(a<<2)+d|0;b=0;while(1)if((b|0)==(e|0)){a=a+1|0;continue a}else{c=x[g>>2]+(b<<3)|0;x[c>>2]=0;x[c+4>>2]=0;b=b+1|0;continue}}break}}function Yga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a=Qi(a,b,c,d);x[a>>2]=45024;b=a+4208|0;e=yb(b,0),f=1017370378,x[e>>2]=f;e=yb(b,1),f=0,x[e>>2]=f;x[31737]=0;O(947,a+44|0,2);b=x[31737];x[31737]=0;if((b|0)!=1){return a|0}b=N()|0;ag(a);Q(b|0);p()}function XG(){var a=0,b=0,c=0;b=fb-16|0;fb=b;a=Dc(b+4|0,14832);a:{if(!Yc(x[a+4>>2],y[a+11|0])){break a}c=1;if((Rg(a,14690)|0)!=-1){break a}if((Rg(a,16845)|0)!=-1){break a}if((Rg(a,13834)|0)!=-1){break a}c=(Rg(a,13877)|0)!=-1}tb(a);fb=b+16|0;return c|0}function $f(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=fb-16|0;fb=e;Kg(a+12|0,d);a:{if(!b){d=0;b=0;break a}Uj(e+8|0,b);d=x[e+12>>2];b=x[e+8>>2]}x[a>>2]=b;c=b+(c<<2)|0;x[a+8>>2]=c;x[a+4>>2]=c;f=nc(a),g=b+(d<<2)|0,x[f>>2]=g;fb=e+16|0;return a|0}function u5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;a=sJ(a,0);x[a>>2]=118152;c=Fb(a+12|0);d=Fb(a+24|0);e=Fb(a+36|0);f=Fb(a+48|0);b=Jb(b);x[31737]=0;O(1328,a|0,b|0);b=x[31737];x[31737]=0;if((b|0)!=1){return a|0}a=N()|0;tb(f);tb(e);tb(d);tb(c);Q(a|0);p()}function s5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;a=rJ(a,0);x[a>>2]=118256;c=Fb(a+12|0);d=Fb(a+24|0);e=Fb(a+36|0);f=Fb(a+48|0);b=Jb(b);x[31737]=0;O(1329,a|0,b|0);b=x[31737];x[31737]=0;if((b|0)!=1){return a|0}a=N()|0;tb(f);tb(e);tb(d);tb(c);Q(a|0);p()}function p5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;a=qJ(a,0);x[a>>2]=118360;c=Fb(a+16|0);d=Fb(a+28|0);e=Fb(a+40|0);f=Fb(a+52|0);b=Jb(b);x[31737]=0;O(1330,a|0,b|0);b=x[31737];x[31737]=0;if((b|0)!=1){return a|0}a=N()|0;Ub(f);Ub(e);Ub(d);tb(c);Q(a|0);p()}function n5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;a=pJ(a,0);x[a>>2]=118464;c=Fb(a+16|0);d=Fb(a+28|0);e=Fb(a+40|0);f=Fb(a+52|0);b=Jb(b);x[31737]=0;O(1331,a|0,b|0);b=x[31737];x[31737]=0;if((b|0)!=1){return a|0}a=N()|0;Ub(f);Ub(e);Ub(d);tb(c);Q(a|0);p()}function FK(a,b){var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;x[b>>2]=0;v[c+15|0]=0;mi(a,c+15|0);d=y[c+15|0];e=d>>>2|0;f=d&3;d=0;while(1){x[b>>2]=e;if((d|0)==(f|0)){fb=c+16|0}else{v[c+15|0]=0;mi(a,c+15|0);d=d+1|0;e=x[b>>2]|y[c+15|0]<<(d<<3)-2;continue}break}}function pE(a){var b=0,c=0,d=0,e=0;if(!y[a+12|0]){b=fb-16|0;fb=b;d=vb(b+12|0,x[x[a+8>>2]>>2]);e=x[vb(b+8|0,x[x[a+4>>2]>>2])>>2];c=fb-16|0;fb=c;a=x[d>>2];x[c+12>>2]=a;while(1){if(pd(a,e)){oE(a);a=x[ij(c+12|0)>>2];continue}break}fb=c+16|0;fb=b+16|0}}function nT(a,b,c,d){var e=0;e=-2147483648;e=!c|!(v[c+15|0]&1)?e:x[c+8>>2];a:{b:{if(!(!d|!(y[d+34|0]&32))){e=z[d+28>>1];break b}if((e|0)==-2147483648){break a}}Vq(b,e,a);if(!Ob(a+1074312|0,10)|y[a+480209|0]&64){break a}x[b+88>>2]=x[b+88>>2]&-257}}function eO(a,b,c){a=a|0;b=+b;c=c|0;var d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;f=d,g=oO(c),x[f+8>>2]=g;c=d+8|0;e=x[qe(d+12|0,c)>>2];x[31737]=0;b=+pa(1120,a|0,+b,e|0);a=x[31737];x[31737]=0;if((a|0)!=1){Uc(c);fb=d+16|0;return+b}a=N()|0;Uc(d+8|0);Q(a|0);p()}function EL(a,b){var c=0,d=0,e=0;o(+a);d=j(1)|0;e=j(0)|0;c=d>>>20&2047;if((c|0)!=2047){if(!c){if(a==0){c=0}else{a=EL(a*0x10000000000000000,b);c=x[b>>2]+-64|0}x[b>>2]=c;return a}x[b>>2]=c-1022;l(0,e|0);l(1,d&-2146435073|1071644672);a=+n()}return a}function rH(a,b,c,d){var e=0,f=0;a:{e=fb-48|0;fb=e;f=e+28|0;ug(f,a,d);a=x[e+28>>2];d=e+4|0;wg(d,c,_e(f),a);x[31737]=0;a=e+16|0;O(219,a|0,d|0);c=x[31737];x[31737]=0;if((c|0)!=1){ze(b,a);tb(a);Kc(f);fb=e+48|0;break a}a=N()|0;Kc(e+28|0);Q(a|0);p()}}function Era(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=fb-16|0;fb=e;while(1){a:{c=x[a>>2];if(oc(c,x[a+4>>2])>>>0>d>>>0){f=e+4|0;Bm(f,x[yb(c,d)>>2]+40|0);c=lr(f,b);tb(f);if(!c){break a}g=x[yb(x[a>>2],d)>>2]}fb=e+16|0;return g|0}d=d+1|0;continue}}function xba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-32|0;fb=d;e=d+4|0;Ax(e,c);c=d+16|0;x[c>>2]=b;_c(c+4|0,e);x[31737]=0;O(1131,a+4|0,c|0);a=x[31737];x[31737]=0;if((a|0)!=1){Wj(c);tb(e);fb=d+32|0;return}a=N()|0;Wj(d+16|0);tb(d+4|0);Q(a|0);p()}function wja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=fb-16|0;fb=e;c=Hf(a,c);$d(e,x[a+36>>2]);a:{b:{if(!c){Pc(e,a+32|0,5);f=-1;if(!Hb(x[x[e>>2]>>2],x[e+4>>2])){break b}break a}f=x[c+16>>2]}ib[d|0](x[a+36>>2],b,f);g=c}ff(a,g);fb=e+16|0}function p0(a,b,c){var d=0,e=0;d=fb-48|0;fb=d;sf(b);e=d+28|0;ug(e,a,c);a=x[d+28>>2];c=d+4|0;wg(c,2,_e(e),a);x[31737]=0;a=d+16|0;O(219,a|0,c|0);c=x[31737];x[31737]=0;if((c|0)!=1){Ab(b,a);tb(a);Kc(e);fb=d+48|0;return}a=N()|0;Kc(d+28|0);Q(a|0);p()}function hW(a,b){a=a|0;b=b|0;var c=0,d=0;d=fb-16|0;fb=d;c=d+4|0;x[c>>2]=a;a=x[a+4>>2];x[c+4>>2]=a;x[c+8>>2]=a+D(b,872);b=x[c+4>>2];a=x[c+8>>2];while(1){if((a|0)==(b|0)){hc(c);fb=d+16|0}else{eW(Rb(b,0,872));b=b+872|0;x[c+4>>2]=b;continue}break}}function RC(a,b,c){var d=0;d=fb-16|0;fb=d;w[d+12>>1]=c;w[d+14>>1]=b;b=wb(x[a>>2]);c=wb(x[a+4>>2]);a=fb-16|0;fb=a;x[a+12>>2]=b;while(1){if(Ib(b,c)){if(z[b>>1]==z[d+14>>1]){w[b>>1]=z[d+12>>1]}b=x[Md(a+12|0)>>2];continue}break}fb=a+16|0;fb=d+16|0}function BT(a,b){var c=0,d=0;a:{if(!(v[a+851|0]&1)){break a}c=x[a+104>>2];if(!c){break a}d=x[c>>2];if(!d){break a}x[a+76>>2]=d;x[a>>2]=0;x[a+4>>2]=d-1;c=x[a+88>>2];if(!b){x[a+88>>2]=c&-135|128;return}x[a+84>>2]=d;x[a+80>>2]=0;x[a+88>>2]=c|134}}function gr(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;c=fb-16|0;fb=c;d=vb(c+12|0,x[a+4>>2]);e=vb(c+8|0,x[a>>2]);f=vb(c+4|0,x[b+4>>2]);g=b,h=hX(x[d>>2],x[e>>2],x[f>>2]),x[g+4>>2]=h;Tb(a,b+4|0);Tb(a+4|0,b+8|0);Tb(zb(a),nc(b));x[b>>2]=x[b+4>>2];fb=c+16|0}function fx(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+16|0]=0;v[a+17|0]=0;v[a+18|0]=0;v[a+19|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a+12|0]=0;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0}function bs(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;c=fb-16|0;fb=c;d=vb(c+12|0,x[a+4>>2]);e=vb(c+8|0,x[a>>2]);f=vb(c+4|0,x[b+4>>2]);g=b,h=NF(x[d>>2],x[e>>2],x[f>>2]),x[g+4>>2]=h;Tb(a,b+4|0);Tb(a+4|0,b+8|0);Tb(zb(a),nc(b));x[b>>2]=x[b+4>>2];fb=c+16|0}function ada(a,b){a=a|0;b=b|0;var c=0;a:{if((a|0)==(b|0)){break a}c=x[a+4>>2];if(c){Db(c);x[a+4>>2]=0}if(ib[x[x[b>>2]+8>>2]](b)|0){b=ib[x[x[b>>2]+8>>2]](b)|0}else{b=22303}c=Ed(Cf(b)+1|0);x[a+4>>2]=c;if(!c){break a}yc(c,b,Cf(b)+1|0)}return a|0}function Yr(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;c=fb-16|0;fb=c;d=vb(c+12|0,x[a+4>>2]);e=vb(c+8|0,x[a>>2]);f=vb(c+4|0,x[b+4>>2]);g=b,h=OF(x[d>>2],x[e>>2],x[f>>2]),x[g+4>>2]=h;Tb(a,b+4|0);Tb(a+4|0,b+8|0);Tb(zb(a),nc(b));x[b>>2]=x[b+4>>2];fb=c+16|0}function Fl(a,b,c){var d=0,e=0,f=0,g=0,h=0;while(1){a:{if((a|0)!=(b|0)){e=x[c>>2];g=x[c+4>>2];d=fb-16|0;fb=d;f=qc(d+8|0,x[a>>2]);h=x[f+4>>2];x[d>>2]=x[f>>2];x[d+4>>2]=h;e=Ic(e,g,d);fb=d+16|0;if(!e){break a}}else{a=b}return a}a=a+8|0;continue}}function Dja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;d=-1;e=a;a=c+8|0;a:{if(!QG(e,a)){break a}d=0;if(!zR(a)){break a}if(b){if(x[b>>2]!=(y[c+16|0]|y[c+17|0]<<8|(y[c+18|0]<<16|y[c+19|0]<<24))|x[b+4>>2]){break a}}d=1}fb=c+32|0;return d|0}function osa(a){a=a|0;var b=0,c=0,d=0,e=0;b=fb-32|0;fb=b;v[b+30|0]=0;w[b+28>>1]=0;c=b+28|0;d=gc(b+8|0,c,3);lc(b+20|0,x[a>>2],x[a+8>>2],x[d>>2],x[d+4>>2]);a:{if(x[b+24>>2]!=3){break a}if(kd(c,14794,3)){break a}Vb(a,3);e=1}fb=b+32|0;return e|0}function noa(a){a=a|0;var b=0,c=0,d=0,e=0;b=fb-32|0;fb=b;w[b+28>>1]=0;x[b+24>>2]=0;c=b+24|0;d=gc(b+8|0,c,6);lc(b+16|0,x[a>>2],x[a+8>>2],x[d>>2],x[d+4>>2]);a:{if(x[b+20>>2]!=6){break a}if(kd(c,3856,6)){break a}Vb(a,6);e=1}fb=b+32|0;return e|0}function bq(a,b){var c=0,d=0,e=0,f=0;c=a*a;d=c*.5;e=1-d;f=1-e-d;d=c*c;return e+(f+(c*(c*(c*(c*2480158728947673e-20+-.001388888888887411)+.0416666666666666)+d*d*(c*(c*-11359647557788195e-27+2.087572321298175e-9)+-2.7557314351390663e-7))-a*b))}function Sb(){var a=0;a=x[31609];x[31737]=0;X(a|0);a=x[31737];x[31737]=0;a:{if((a|0)!=1){x[31737]=0;X(1347);a=x[31737];x[31737]=0;if((a|0)!=1){break a}}Y(T(0)|0)|0;x[31737]=0;X(1347);a=x[31737];x[31737]=0;if((a|0)!=1){break a}T(0)|0;Sb()}p()}function un(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=fb-16|0;fb=e;Kg(a+12|0,d);a:{if(!b){d=0;b=0;break a}sg(e+8|0,b);d=x[e+12>>2];b=x[e+8>>2]}x[a>>2]=b;c=b+c|0;x[a+8>>2]=c;x[a+4>>2]=c;f=nc(a),g=b+d|0,x[f>>2]=g;fb=e+16|0;return a|0}function ES(a,b){a=AS(a);AS(a+368680|0);if(b){zS(a,1);return}if(!y[495824]){ES(127120,1);v[495824]=1}Kk(258232,323768,a+131112|0);Kk(323768,389304,a+196648|0);Kk(389304,454840,a+262184|0);Kk(127144,258232,a+24|0);yc(a+327720|0,454840,40960)}function CT(a,b){var c=0,d=0;d=fb-16|0;fb=d;c=x[a+104>>2];a:{if(!c){break a}c=x[c>>2];if(!c){break a}x[a+76>>2]=c;x[a+88>>2]=x[a+88>>2]&-131|128;x[d+12>>2]=b<<8;x[d+8>>2]=c-1;b=c+(x[Gb(d+12|0,d+8|0)>>2]^-1)|0;x[a>>2]=0;x[a+4>>2]=b}fb=d+16|0}function tW(a){var b=0,c=0;a=a*4294967296;if(F(a)<0x8000000000000000){c=~~a>>>0;if(F(a)>=1){b=~~(a>0?H(J(a*2.3283064365386963e-10),4294967295):K((a-+(~~a>>>0>>>0))*2.3283064365386963e-10))>>>0}else{b=0}hb=b;return c}hb=-2147483648;return 0}function qh(a,b){var c=0,d=0,e=0;d=y[a+11|0];c=Cb(x[a+4>>2],d);a:{if((c|0)!=(Cb(x[b+4>>2],y[b+11|0])|0)){break a}a=Jb(a);b=Jb(b);if(!Cd(d)){while(1){e=!c;if(!c|y[a|0]!=y[b|0]){break a}b=b+1|0;a=a+1|0;c=c-1|0;continue}}e=!ty(a,b,c)}return e}function kQ(a,b,c){var d=0,e=0;if(E(F(a))<E(0x8000000000000000)){d=~~a>>>0}else{d=0}e=d&-2147483648;d=e?0-d|0:d;while(1){if(!((d|0)<0|(b|0)<=0)){b=b-1|0;d=d<<1;continue}break}b=(d>>>31|0)+b<<31-c|(d&2147483647)>>>c;return E((e?b^-1|e:b)|0)}function faa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=fb-16|0;fb=e;d=rv(e+4|0,a,d);f=x[d+4>>2];x[31737]=0;a=ba(1165,zb(a)|0,b|0,c|0,f|0)|0;b=x[31737];x[31737]=0;if((b|0)!=1){x[d+4>>2]=a;hc(d);fb=e+16|0;return}a=N()|0;hc(d);Q(a|0);p()}function Aba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=fb-16|0;fb=e;d=gv(e+4|0,a,d);f=x[d+4>>2];x[31737]=0;a=ba(1129,zb(a)|0,b|0,c|0,f|0)|0;b=x[31737];x[31737]=0;if((b|0)!=1){x[d+4>>2]=a;hc(d);fb=e+16|0;return}a=N()|0;hc(d);Q(a|0);p()}function ue(a,b){var c=0,d=0;c=x[a+4>>2];d=c+b|0;x[a+4>>2]=d;if(x[a+8>>2]>=(d|0)){d=x[a>>2]+(c>>3)|0;a=c&7;c=y[d|0]&255>>>a;a=a+b|0;b=0;while(1){if((a|0)>=9){a=a-8|0;b=c<<a|b;c=y[d+1|0];d=d+1|0;continue}break}a=c>>>8-a|b}else{a=0}return a}function tH(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;x[e+12>>2]=c;c=e+12|0;wc(c,d);wc(c,65535);d=z[e+12>>1];xg(a,d);c=0;while(1){if((c|0)==(d|0)){fb=e+16|0}else{f=y[b+c|0];g=Wr(x[a>>2],x[a+4>>2],c),h=f,w[g>>1]=h;c=c+1|0;continue}break}}function YW(a){var b=0,c=0;a:{if(y[a+29|0]!=2){break a}b=y[a+28|0];if((b|0)!=26&(b|0)!=2|y[a+30|0]!=2){break a}b=y[a+31|0];if(b>>>0>21|!(1<<b&3146753)|y[a+33|0]>64){break a}b=y[a+34|0];if(b>>>0>=65&(b|0)!=88){break a}c=WW(a+20|0)}return c}function V0(a,b,c){var d=0,e=0;d=fb-48|0;fb=d;e=d+28|0;ug(e,a,c);a=x[d+28>>2];c=d+4|0;wg(c,3,_e(e),a);x[31737]=0;a=d+16|0;O(219,a|0,c|0);c=x[31737];x[31737]=0;if((c|0)!=1){om(b,a);tb(a);Kc(e);fb=d+48|0;return}a=N()|0;Kc(d+28|0);Q(a|0);p()}function TT(a,b){var c=0;c=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);v[a|0]=c;v[a+1|0]=c>>>8;v[a+2|0]=c>>>16;v[a+3|0]=c>>>24;b=y[b+3|0]|y[b+4|0]<<8|(y[b+5|0]<<16|y[b+6|0]<<24);v[a+3|0]=b;v[a+4|0]=b>>>8;v[a+5|0]=b>>>16;v[a+6|0]=b>>>24}function zy(a,b){var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;w[b>>1]=0;v[c+15|0]=0;mi(a,c+15|0);d=y[c+15|0];e=d>>>1|0;f=d&1;d=0;while(1){w[b>>1]=e;if(d>>>0>=f>>>0){fb=c+16|0}else{v[c+15|0]=0;mi(a,c+15|0);e=z[b>>1]|y[c+15|0]<<7;d=1;continue}break}}function ix(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-16|0;fb=e;lf(e+8|0,b,c);x[31737]=0;Ma(166,a|0,x[e+8>>2],x[e+12>>2]);b=x[31737];x[31737]=0;if((b|0)!=1){x[a+8>>2]=0;Ef(a+12|0,d);ke(d);fb=e+16|0;return a|0}a=N()|0;ke(d);Q(a|0);p()}function VC(a,b,c,d){var e=0,f=0;e=fb-32|0;fb=e;f=x[b+12>>2];lf(e+16|0,c,d);c=x[x[b>>2]+28>>2];d=x[e+20>>2];x[e+8>>2]=x[e+16>>2];x[e+12>>2]=d;ib[c|0](e+24|0,b,f,e+8|0);lf(a,x[e+24>>2],x[e+28>>2]);x[b+12>>2]=x[b+12>>2]+x[a+4>>2];fb=e+32|0}function VB(a,b,c){var d=0;a:{switch(c+1|0){case 0:case 3:VU(a,b);return;default:break a}}d=fb-32|0;fb=d;x[d+28>>2]=c;w[d+26>>1]=0;x[d+12>>2]=2;c=d+16|0;pz(c,a,d+26|0,x[Gb(d+28|0,d+12|0)>>2]);hj(c,z[d+26>>1]);w[b>>1]=z[d+16>>1];fb=d+32|0}function wU(a){var b=0,c=0,d=0,e=0;c=fb-16|0;fb=c;b=x[a>>2];e=Ik(b,x[a+4>>2]);b=wb(b);x[c+12>>2]=b;d=+(e>>>0);a=wb(x[a+4>>2]);while(1){if(Ib(b,a)){C[b>>3]=C[b>>3]/d;C[b+8>>3]=C[b+8>>3]/d;b=x[Zo(c+12|0)>>2];continue}else{fb=c+16|0}break}}function vA(a,b){var c=0,d=0,e=0,f=0;c=a&16711680;d=c>>>8|0;e=c<<24;c=a&-16777216;f=c>>>24|0;c=e|c<<8;e=d|f|(a<<24|(a&65280)<<8);d=0;hb=e|(d|d);return((b&255)<<24|a>>>8)&-16777216|((b&16777215)<<8|a>>>24)&16711680|(b>>>8&65280|b>>>24)|c}function jT(a,b){var c=0,d=0;a:{if(!(y[a+89|0]&16)){break a}c=x[a+656>>2];if(!c){break a}c=x[c>>2];b:{if(c){d=a;a=x[a+696>>2]-(c<<1)|0;a=(a|0)>0?a:0;x[d+696>>2]=a;a=(D(a,x[b>>2])|0)/65536|0;break b}if(x[a+696>>2]){break a}a=0}x[b>>2]=a}}function O0(a){var b=0,c=0,d=0,e=0;c=y[a+2|0];b=c+(y[a+5|0]|y[a+6|0]<<8)|0;c=(b>>>0<c>>>0?1:d)<<1|b>>>31;d=b<<1;b=c;a=y[a+3|0]|y[a+4|0]<<8;c=a>>>30|0;e=d;d=a<<2;e=e+d|0;a=b+c|0;a=d>>>0>e>>>0?a+1|0:a;b=e+47|0;hb=b>>>0<47?a+1|0:a;return b}function AE(a,b,c){var d=0,e=0;d=(a&65535)>>>D(c,3)|0;a=y[b+12|0]&-4|d>>>2&1;e=a|d<<1&2;a:{b:{if(d&2){a=e;break b}v[b+12|0]=e&251;if(!(d>>>9-(c<<1)&1)|(d&3)!=1){break a}c=y[b+13|0]|y[b+14|0]<<8;v[b+15|0]=c;v[b+16|0]=c>>>8}v[b+12|0]=a|4}}function nv(a){var b=0;a:{if(y[a+4|0]|(y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=1414687062){break a}if(Bb(y[a+6|0]|y[a+7|0]<<8)>>>0>1){break a}if(Bb(y[a+12|0]|y[a+13|0]<<8)){break a}b=(Bb(y[a+16|0]|y[a+17|0]<<8)|0)==20}return b}function lua(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-32|0;fb=d;e=d+20|0;Mr(e,c);Cj(d+12|0,e);x[31737]=0;V(302,a|0,b|0,x[d+12>>2],x[d+16>>2]);a=x[31737];x[31737]=0;if((a|0)!=1){Eb(e);fb=d+32|0;break a}a=N()|0;Eb(d+20|0);Q(a|0);p()}}function eja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=b;d=fb-16|0;fb=d;b=Hf(a,c);$d(d,x[a+36>>2]);a:{b:{if(!b){Pc(d,a+32|0,5);c=-1;if(!Hb(x[x[d>>2]>>2],x[d+4>>2])){break b}break a}c=x[b+16>>2]}VB(x[a+36>>2],e,c);f=b}ff(a,f);fb=d+16|0}function Ypa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-32|0;fb=d;e=d+20|0;fr(e,c);Cj(d+12|0,e);x[31737]=0;V(302,a|0,b|0,x[d+12>>2],x[d+16>>2]);a=x[31737];x[31737]=0;if((a|0)!=1){Eb(e);fb=d+32|0;break a}a=N()|0;Eb(d+20|0);Q(a|0);p()}}function Vta(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;$w(c+8|0,b);d=x[c+12>>2];lc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;if((d|0)!=(e|0)){v[b+2|0]=0;v[b|0]=0;v[b+1|0]=0}}function Ii(a,b,c){var d=0,e=0,f=0,g=0;x[a+112>>2]=b;x[a+116>>2]=c;e=x[a+4>>2];d=x[a+44>>2]-e|0;x[a+120>>2]=d;x[a+124>>2]=d>>31;d=a;a=x[a+8>>2];f=a-e|0;g=f>>31;if(!(!(b|c)|((c|0)>=(g|0)&b>>>0>=f>>>0|(c|0)>(g|0)))){a=b+e|0}x[d+104>>2]=a}function Wra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-32|0;fb=d;e=d+20|0;Up(e,c);Cj(d+12|0,e);x[31737]=0;V(93,a|0,b|0,x[d+12>>2],x[d+16>>2]);a=x[31737];x[31737]=0;if((a|0)!=1){Eb(e);fb=d+32|0;break a}a=N()|0;Eb(d+20|0);Q(a|0);p()}}function Roa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-32|0;fb=d;e=d+20|0;e_(e,c);Cj(d+12|0,e);x[31737]=0;V(93,a|0,b|0,x[d+12>>2],x[d+16>>2]);a=x[31737];x[31737]=0;if((a|0)!=1){Eb(e);fb=d+32|0;break a}a=N()|0;Eb(d+20|0);Q(a|0);p()}}function $ra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-32|0;fb=d;e=d+20|0;Rv(e,c);Cj(d+12|0,e);x[31737]=0;V(93,a|0,b|0,x[d+12>>2],x[d+16>>2]);a=x[31737];x[31737]=0;if((a|0)!=1){Eb(e);fb=d+32|0;break a}a=N()|0;Eb(d+20|0);Q(a|0);p()}}function yV(a){var b=0,c=0,d=0;d=Wo(a);while(1){if((a|0)!=(d|0)){b=y[a|0];a:{b:{if((b-97&255)>>>0<=5){c=b-32|0;break b}if(!(b-88>>>0<2|b-120>>>0<2)){c=99;if((b|0)==75|(b|0)==107){break b}break a}c=122}v[a|0]=c}a=a+1|0;continue}break}}function l$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-32|0;fb=d;e=d+20|0;EE(e,c);Cj(d+12|0,e);x[31737]=0;V(93,a|0,b|0,x[d+12>>2],x[d+16>>2]);a=x[31737];x[31737]=0;if((a|0)!=1){Eb(e);fb=d+32|0;break a}a=N()|0;Eb(d+20|0);Q(a|0);p()}}function dV(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;h=x[a+4>>2];f=(h-d|0)+b|0;g=_h(e+4|0,a,c-f>>1);d=x[g+4>>2];a=f;while(1){if(a>>>0>=c>>>0){hc(g);Ar(b,f,h);fb=e+16|0}else{fj(d,z[a>>1]);d=d+2|0;x[g+4>>2]=d;a=a+2|0;continue}break}}function _E(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-32|0;fb=d;e=d+20|0;xw(e,c);Cj(d+12|0,e);x[31737]=0;V(93,a|0,b|0,x[d+12>>2],x[d+16>>2]);a=x[31737];x[31737]=0;if((a|0)!=1){Eb(e);fb=d+32|0;break a}a=N()|0;Eb(d+20|0);Q(a|0);p()}}function SG(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-32|0;fb=d;e=d+20|0;co(e,c);Cj(d+12|0,e);x[31737]=0;V(93,a|0,b|0,x[d+12>>2],x[d+16>>2]);a=x[31737];x[31737]=0;if((a|0)!=1){Eb(e);fb=d+32|0;break a}a=N()|0;Eb(d+20|0);Q(a|0);p()}}function ug(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Nb(a+8|0);x[31737]=0;S(170,a|0,b|0,c|0);c=x[31737];x[31737]=0;a:{if((c|0)!=1){a=x[a>>2];x[31737]=0;P(184,b|0,a|0)|0;a=x[31737];x[31737]=0;if((a|0)!=1){break a}}a=N()|0;dc(d);Q(a|0);p()}}function ksa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;kD(c+8|0,b);d=x[c+12>>2];lc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){Rb(b,0,4896)}return a|0}function KT(a,b,c){var d=0;d=x[b+48>>2]+1|0;x[b+52>>2]=d;a:{if(A[Wb(x[a+484344>>2],z[b+70>>1])+12>>2]>d>>>0){break a}if(!c){w[b+74>>1]=z[b+72>>1]+1}x[b+52>>2]=0;if(!Ob(a+1074312|0,63)){break a}a=x[b+56>>2];x[b+56>>2]=0;x[b+52>>2]=a}}function zZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=zn(a);e=Cb(x[a+4>>2],y[a+11|0]);a:{if(d-e>>>0>=c>>>0){if(!c){break a}d=Jb(a);Yi(d+(e<<2)|0,b,c);b=c+e|0;ng(a,b);yd(d+(b<<2)|0,0);return a|0}xI(a,d,(c-d|0)+e|0,e,e,0,c,b)}return a|0}function i$(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;h=x[a+4>>2];f=(h-d|0)+b|0;g=$l(e+4|0,a,c-f|0);d=x[g+4>>2];a=f;while(1){if(a>>>0>=c>>>0){hc(g);Ar(b,f,h);fb=e+16|0}else{Dl(d,y[a|0]);d=d+1|0;x[g+4>>2]=d;a=a+1|0;continue}break}}function c9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{if(!y[a+44|0]){c=(c|0)>0?c:0;while(1){if((c|0)==(d|0)){break a}if((ib[x[x[a>>2]+52>>2]](a,x[b>>2])|0)==-1){return d|0}else{b=b+4|0;d=d+1|0;continue}}}c=Tk(b,4,c,x[a+32>>2])}return c|0}function Zf(a,b,c){var d=0;a:{if(A[b+8>>2]<c>>>0){x[31737]=0;V(1150,17444,9126,435,6381);a=x[31737];x[31737]=0;if((a|0)==1){break a}p()}d=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=d;x[a+8>>2]=x[b+8>>2];x[a+12>>2]=c;return}T(0)|0;Sb();p()}function nC(a,b){var c=0,d=0,e=0,f=0;w[a+24>>1]=0;x[a+20>>2]=0;x[a>>2]=0;x[a+4>>2]=0;c=3546895/+(b>>>0);d=c*.25;a:{if(F(d)<2147483648){b=~~d;break a}b=-2147483648}x[a+16>>2]=b;e=a,f=tW(c-+(b<<2)),x[e+8>>2]=f;x[a+12>>2]=hb;return a}function jra(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;hD(c+8|0,b);d=x[c+12>>2];lc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){Rb(b,0,33)}return a|0}function fB(a,b,c){var d=0,e=0;d=ce(a);a:{if(d){e=ec(a);while(1){a=d;d=y[a+16|0];if(Go(c,d)){e=a;d=x[a>>2];if(d){continue}break a}if(!Go(d,c)){break a}e=a+4|0;d=x[a+4>>2];if(d){continue}break}break a}a=ec(a);e=a}x[b>>2]=a;return e}function dS(a){var b=0,c=0,d=0;c=fb-544|0;fb=c;a:{if(!(y[a+480210|0]&128)|!x[a+24668>>2]){break a}d=a+1298224|0;b=a+1074992|0;a=nC(c,x[a+24620>>2]);while(1){if((b|0)==(d|0)){break a}yc(b+112|0,a,538);b=b+872|0;continue}}fb=c+544|0}function t1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;yw(c+8|0,b);d=x[c+12>>2];lc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){Rb(b,0,65)}return a|0}function cba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=x[b>>2];d=x[b+8>>2];e=x[b+4>>2];a=0;a:while(1){if((a|0)!=(e|0)){f=(a<<2)+c|0;b=0;while(1)if((b|0)==(d|0)){a=a+1|0;continue a}else{x[x[f>>2]+(b<<2)>>2]=0;b=b+1|0;continue}}break}}function Kua(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;d=Mb(x[a>>2],x[a+8>>2],120);a:{if(!d){a=0;while(1){if((a|0)!=120){eh(a+b|0);a=a+1|0;continue}break}break a}bc(c+8|0,b,120);rd(c,a,x[c+8>>2],x[c+12>>2])}fb=c+16|0;return d|0}function vta(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;d=Mb(x[a>>2],x[a+8>>2],64);a:{if(!d){a=0;while(1){if((a|0)!=32){wp((a<<1)+b|0);a=a+1|0;continue}break}break a}iw(c+8|0,b);rd(c,a,x[c+8>>2],x[c+12>>2])}fb=c+16|0;return d|0}function Ri(a){var b=0,c=0,d=0,e=0;b=Zd(a);c=b&63;e=b<<24>>24;a:{if(!(b&64)){break a}b=6;while(1){d=Zd(a);c=(d&127)<<b|c;if(d<<24>>24>=0){break a}d=b>>>0<25;b=b+7|0;if(d){continue}break}}return(e|0)<0?(c|0)<0?-2147483648:0-c|0:c}function Eg(a,b){var c=0,d=0,e=0,f=0;d=z[a+22>>1];e=d+z[a+20>>1]|0;c=z[a+24>>1]<<17;while(1){if((d|0)==(e|0)){a=(c|0)/32768|0}else{f=c;c=((d&127)<<2)+a|0;c=f-D(x[yb(b,z[c+28>>1])>>2],w[c+26>>1])|0;d=d+1|0;continue}break}return a}function DR(a,b,c){var d=0,e=0,f=0,g=0;while(1){if((b|0)!=(c|0)){d=x[a>>2];e=x[a+4>>2];f=e>>>8|0;g=(e&255)<<24|d>>>8;d=(((y[b|0]^d)&255)<<3)+22336|0;e=x[d>>2];d=x[d+4>>2]^f;x[a>>2]=e^g;x[a+4>>2]=d;b=b+1|0;continue}break}return a}function v2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;f=x[d>>2];g=x[b+8>>2];if(g>>>0>c>>>0){x[e+12>>2]=g-c;x[e+8>>2]=x[d+4>>2];b=x[b+4>>2]+c|0;h=x[Gb(e+12|0,e+8|0)>>2];Wg(b,b+h|0,f)}bc(a,f,h);fb=e+16|0}function fE(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=x[a>>2];f=pm(e,x[a+4>>2]);while(1){a:{c=d&65535;if(c>>>0>=f>>>0){break a}c=gj(e,c);if(!Ib(x[c>>2],x[c+4>>2])){break a}d=d+1|0;continue}break}return(Ng(a,d&65535,b)?d:-1)&65535}function Qr(a){var b=0,c=0,d=0,e=0;c=fb-16|0;fb=c;b=fb-16|0;fb=b;Zr(b+8|0,c+15|0);d=x[b+12>>2];od(b,a,x[b+8>>2],x[b+12>>2]);e=x[b+4>>2];if((e|0)==(d|0)){gd(a,x[b+12>>2])}fb=b+16|0;fb=c+16|0;return((d|0)==(e|0)?y[c+15|0]:0)&255}function QR(a,b,c){var d=0,e=0,f=0,g=0,h=0;g=c;h=c>>31;c=0;while(1){if((b|0)!=(c|0)){d=x[a>>2];e=x[a+4>>2];f=(d+e|0)/2|0;d=d-e|0;d=Gc(Tua(Sua(d,d>>31,g,h),hb,256,0),hb);x[a+4>>2]=f-d;x[a>>2]=d+f;c=c+1|0;a=a+8|0;continue}break}}function QD(a,b,c,d){var e=0,f=0,g=0;e=fb-16|0;fb=e;Kg(a+12|0,d);a:{if(!b){d=0;b=0;break a}RE(e+8|0,b);d=x[e+12>>2];b=x[e+8>>2]}x[a>>2]=b;c=b+D(c,20)|0;x[a+8>>2]=c;x[a+4>>2]=c;f=nc(a),g=b+D(d,20)|0,x[f>>2]=g;fb=e+16|0;return a}function Dm(a,b,c,d){var e=0,f=0,g=0;e=fb-16|0;fb=e;Kg(a+12|0,d);a:{if(!b){d=0;b=0;break a}aH(e+8|0,b);d=x[e+12>>2];b=x[e+8>>2]}x[a>>2]=b;c=b+D(c,12)|0;x[a+8>>2]=c;x[a+4>>2]=c;f=nc(a),g=b+D(d,12)|0,x[f>>2]=g;fb=e+16|0;return a}function wpa(a,b){a=a|0;b=b|0;var c=0,d=0;b=fb-32|0;fb=b;d=b+20|0;c=-1;a:{if(!$D(a,d)){break a}c=0;if(!CX(d)){break a}c=-1;if(!nk(a,b+12|0)){break a}c=0;if(!x[b+16>>2]){break a}c=!(x[b+12>>2]&-2139062144)}fb=b+32|0;return c|0}function vla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;FU(c+8|0,b);d=x[c+12>>2];lc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){QB(b)}return a|0}function sqa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;if(th(178956970)>>>0<b>>>0){dd();p()}d=Ec(D(b,24));x[c+12>>2]=b;x[c+8>>2]=d;b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;e=zb(a),f=b+D(x[c+12>>2],24)|0,x[e>>2]=f;fb=c+16|0}function koa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;if(th(119304647)>>>0<b>>>0){dd();p()}d=Ec(D(b,36));x[c+12>>2]=b;x[c+8>>2]=d;b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;e=zb(a),f=b+D(x[c+12>>2],36)|0,x[e>>2]=f;fb=c+16|0}function Tua(a,b,c,d){var e=0,f=0,g=0,h=0;f=b^d;g=f>>31;e=b>>31;a=a^e;h=a-e|0;e=(b^e)-((a>>>0<e>>>0)+e|0)|0;a=d>>31;b=c^a;f=f>>31;a=Uua(h,e,b-a|0,(a^d)-((a>>>0>b>>>0)+a|0)|0)^f;b=a-f|0;hb=(g^hb)-((a>>>0<f>>>0)+g|0)|0;return b}function IT(a,b,c){var d=0,e=0,f=0;d=fb-16|0;fb=d;a:{if(!c){break a}x[b+40>>2]=c;if(!c|x[a+480180>>2]!=256){break a}x[d+12>>2]=c>>>4;x[d+8>>2]=1;e=b,f=x[ad(d+12|0,d+8|0)>>2],x[e+40>>2]=f;e=b,f=xC(c&255),x[e+44>>2]=f}fb=d+16|0}function zv(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;DX(c+8|0,b);d=x[c+12>>2];lc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){EX(b)}return a|0}function yZ(a,b,c,d){var e=0,f=0,g=0;e=fb-16|0;fb=e;Kg(a+12|0,d);a:{if(!b){d=0;b=0;break a}vZ(e+8|0,b);d=x[e+12>>2];b=x[e+8>>2]}x[a>>2]=b;c=b+D(c,6)|0;x[a+8>>2]=c;x[a+4>>2]=c;f=nc(a),g=b+D(d,6)|0,x[f>>2]=g;fb=e+16|0;return a}function vw(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;Hw(c+8|0,b);d=x[c+12>>2];lc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){LE(b)}return a|0}function sj(a,b,c){c=c&176;if((c|0)==32){return b}a:{if((c|0)!=16){break a}b:{c:{c=y[a|0];switch(c-43|0){case 0:case 2:break c;default:break b}}return a+1|0}if((c|0)!=48|(b-a|0)<2|(y[a+1|0]|32)!=120){break a}a=a+2|0}return a}function qaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=fb-16|0;fb=e;c=e+4|0;x[c+4>>2]=1;f=c,g=Ec(40),x[f+8>>2]=g;d=ym(x[c+8>>2]);x[d>>2]=78328;d=BM(nc(d));x[d+24>>2]=b;x[d>>2]=78476;b=a;a=Wn(c);Vn(b,nc(a),a);zm(c);fb=e+16|0}function ms(a,b,c,d){var e=0,f=0,g=0;e=fb-16|0;fb=e;Kg(a+12|0,d);a:{if(!b){d=0;b=0;break a}tG(e+8|0,b);d=x[e+12>>2];b=x[e+8>>2]}x[a>>2]=b;c=b+(c<<3)|0;x[a+8>>2]=c;x[a+4>>2]=c;f=nc(a),g=b+(d<<3)|0,x[f>>2]=g;fb=e+16|0;return a}function kk(a,b,c,d){var e=0,f=0,g=0;e=fb-16|0;fb=e;Kg(a+12|0,d);a:{if(!b){d=0;b=0;break a}Uw(e+8|0,b);d=x[e+12>>2];b=x[e+8>>2]}x[a>>2]=b;c=b+(c<<1)|0;x[a+8>>2]=c;x[a+4>>2]=c;f=nc(a),g=b+(d<<1)|0,x[f>>2]=g;fb=e+16|0;return a}function fv(a,b,c,d){var e=0,f=0,g=0;e=fb-16|0;fb=e;Kg(a+12|0,d);a:{if(!b){d=0;b=0;break a}TV(e+8|0,b);d=x[e+12>>2];b=x[e+8>>2]}x[a>>2]=b;c=b+(c<<5)|0;x[a+8>>2]=c;x[a+4>>2]=c;f=nc(a),g=b+(d<<5)|0,x[f>>2]=g;fb=e+16|0;return a}function YV(a,b,c,d){var e=0,f=0,g=0;e=fb-16|0;fb=e;Kg(a+12|0,d);a:{if(!b){d=0;b=0;break a}XV(e+8|0,b);d=x[e+12>>2];b=x[e+8>>2]}x[a>>2]=b;c=b+(c<<4)|0;x[a+8>>2]=c;x[a+4>>2]=c;f=nc(a),g=b+(d<<4)|0,x[f>>2]=g;fb=e+16|0;return a}function Rq(a,b,c){var d=0,e=0,f=0,g=0,h=0;f=131072/(C[Op(b)>>3]-C[a>>3]);b=0;while(1){if((b|0)!=2048){d=-Ee(f*C[Ue(a,b)>>3]);a:{if(F(d)<2147483648){e=~~d;break a}e=-2147483648}g=yb(c,b),h=e,x[g>>2]=h;b=b+1|0;continue}break}}function x$(a){if(!((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=1179011410|(y[a+8|0]|y[a+9|0]<<8|(y[a+10|0]<<16|y[a+11|0]<<24))!=1179472708)){return 1}return(y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))==1179472708}function psa(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;x[a+480180>>2]=b;vr(c,wr(a));d=x[c+12>>2];b=a+1074320|0;x[b>>2]=x[c+8>>2];x[b+4>>2]=d;b=x[c+4>>2];x[a+1074312>>2]=x[c>>2];x[a+1074316>>2]=b;Au(a+8|0,wr(a));fb=c+16|0}
function ae(a,b){var c=0,d=0,e=0,f=0,g=0;d=z[a+22>>1];g=d+z[a+20>>1]|0;c=d;while(1){a:{if((c|0)!=(g|0)){e=((c&127)<<2)+a|0;f=z[e+28>>1]+b|0;w[e+28>>1]=f;if((f&65535)>>>0<2048){break a}w[a+20>>1]=c-d}return}c=c+1|0;continue}}function Qta(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;if(th(715827882)>>>0<b>>>0){dd();p()}d=Ec(D(b,6));x[c+12>>2]=b;x[c+8>>2]=d;b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;e=zb(a),f=b+D(x[c+12>>2],6)|0,x[e>>2]=f;fb=c+16|0}function Qka(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;d=Mb(x[a>>2],x[a+8>>2],16);a:{if(!d){a=0;while(1){if((a|0)!=16){eh(a+b|0);a=a+1|0;continue}break}break a}bE(c+8|0,b);rd(c,a,x[c+8>>2],x[c+12>>2])}fb=c+16|0;return d|0}function Au(a,b){var c=0;a:{b:{c:{switch(b-2|0){default:c=42332;if((b|0)==16777216){break a}if((b|0)!=32){break b}c=42184;break a;case 2:c=42180;break a;case 1:break b;case 0:break c}}c=42176;break a}c=42172}x[a>>2]=x[c>>2]}function lr(a,b){var c=0,d=0;c=fb-32|0;fb=c;ee(c+24|0,a);ee(c+16|0,b);a=x[c+20>>2];x[c+8>>2]=x[c+16>>2];x[c+12>>2]=a;a=x[c+24>>2];b=x[c+28>>2];d=x[c+12>>2];if((b|0)==(d|0)){a=GZ(a,b,x[c+8>>2],d)}else{a=1}fb=c+32|0;return!a}function Ysa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;if(th(2147483647)>>>0<b>>>0){dd();p()}d=Ec(b<<1);x[c+12>>2]=b;x[c+8>>2]=d;b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;e=zb(a),f=b+(x[c+12>>2]<<1)|0,x[e>>2]=f;fb=c+16|0}function WV(a,b,c){var d=0,e=0,f=0;d=fb-16|0;fb=d;a:{if(!(c&32)){break a}c=zd(b);x[d+12>>2]=c;f=Df(b);while(1){if(!Ib(c,f)){break a}e=y[c|0];if((e-97&255)>>>0<=25){v[c|0]=e-32}c=x[le(d+12|0)>>2];continue}}_c(a,b);fb=d+16|0}function C_(a){var b=0,c=0,d=0;c=y[a+3|0];b=Sua(c>>>0<3?48:64,0,Bb(y[a+196|0]|y[a+197|0]<<8),0);d=b;b=Sua(Sua(Bb(y[a+198|0]|y[a+199|0]<<8),0,c>>>0<4?4:5,0),hb,Bb(y[a+200|0]|y[a+201|0]<<8),0);a=d+b|0;a=a+512|0;hb=0;return a}function Qpa(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;d=Mb(x[a>>2],x[a+8>>2],6);a:{if(!d){a=0;while(1){if((a|0)!=6){eh(a+b|0);a=a+1|0;continue}break}break a}TD(c+8|0,b);rd(c,a,x[c+8>>2],x[c+12>>2])}fb=c+16|0;return d|0}function Jt(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Mc(a);e=Cb(x[a+4>>2],y[a+11|0]);a:{if(d-e>>>0>=c>>>0){if(!c){break a}d=Jb(a);Cg(d+e|0,b,c);b=c+e|0;ng(a,b);fd(b+d|0,0);return a|0}dq(a,d,(c-d|0)+e|0,e,e,0,c,b)}return a|0}function BH(a,b,c,d,e){var f=0;f=fb-32|0;fb=f;x[f+24>>2]=a;x[f+28>>2]=b;x[f+16>>2]=d;x[f+20>>2]=e;x[f+8>>2]=c;x[f+12>>2]=0;a=J0(f+24|0,f+8|0);b=f+16|0;a=gq(x[b>>2],x[b+4>>2],x[a>>2],x[a+4>>2])?a:b;fb=f+32|0;return x[a>>2]}function yv(a,b){var c=0,d=0,e=0;if(x[a>>2]){n0(a);c=x[a>>2];rE(a);Db(c);d=zb(a),e=0,x[d>>2]=e;x[a>>2]=0;x[a+4>>2]=0}x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];c=zb(b);d=zb(a),e=x[c>>2],x[d>>2]=e;x[c>>2]=0;x[b>>2]=0;x[b+4>>2]=0}function Zt(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=fb-16|0;fb=c;d=x[b>>2];b=oc(d,x[b+4>>2]);a=0;while(1){if((a|0)==(b|0)){fb=c+16|0}else{x[c+12>>2]=0;e=sc(c+12|0);f=yb(d,a),g=x[e>>2],x[f>>2]=g;a=a+1|0;continue}break}}function dT(a,b){var c=0,d=0,e=0,f=0;x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];x[a+8>>2]=x[b+8>>2];d=zb(a);c=ec(a);a:{if(!x[d>>2]){x[a>>2]=c;break a}x[x[c>>2]+8>>2]=c;c=ec(b);x[b>>2]=c;x[c>>2]=0;e=zb(b),f=0,x[e>>2]=f}return a}function _W(a,b,c){var d=0;d=fb-16|0;fb=d;v[d+15|0]=a;a=0;if(!(c>>>0<25|b>>>0<25|(b>>>0>108|b>>>0>=c>>>0)|c>>>0>108)){v[d+14|0]=(z[(b<<1)+31102>>1]-z[(c<<1)+31102>>1]|0)/5;a=y[Qb(d+15|0,d+14|0)|0]}fb=d+16|0;return a&255}function LA(a,b){var c=0;c=x[b+24>>2];c=c>>>0<=1?1:c;x[a+24628>>2]=c>>>0>=512?512:c;a:{if(!(x[b+16>>2]!=x[a+24620>>2]|x[b+20>>2]!=x[a+24624>>2])){c=0;if(x[b+12>>2]==x[a+24616>>2]){break a}}c=1}yc(a+24604|0,b,40);_R(a,c)}function Jx(a,b,c,d,e){var f=0,g=0,h=0;f=fb-16|0;fb=f;g=Ef(f+8|0,d);x[31737]=0;h=x[g+4>>2];x[f>>2]=x[g>>2];x[f+4>>2]=h;a=jg(e,a,b,c,f);b=x[31737];x[31737]=0;if((b|0)!=1){ke(d);fb=f+16|0;return a}a=N()|0;ke(d);Q(a|0);p()}function Iha(a){a=a|0;var b=0;ib[x[x[a>>2]+132>>2]](a);Vz(a);x[a+4236>>2]=0;v[a+4202|0]=1;b=ib[x[x[a>>2]+196>>2]](a)|0;x[a+4328>>2]=0;x[a+4312>>2]=0;B[a+4240>>2]=b?E(.5):E(1);b=x[a+4256>>2];x[a+4324>>2]=b;x[a+4320>>2]=b}function zta(a){a=a|0;var b=0,c=0,d=0,e=0;b=fb-16|0;fb=b;if(th(1073741823)>>>0<=8191){dd();p()}c=Ec(32768);x[b+12>>2]=8192;x[b+8>>2]=c;c=x[b+8>>2];x[a+4>>2]=c;x[a>>2]=c;d=zb(a),e=c+(x[b+12>>2]<<2)|0,x[d>>2]=e;fb=b+16|0}function wra(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-16|0;fb=d;c=-1;a:{if(!nk(a,d+8|0)){break a}e=x[d+12>>2];c=0;if(!(x[d+8>>2]==(Jn(8994)|0)&e>>>0>255&e>>>0<260)){break a}c=ve(a,b,e>>>0<259?80:76,0)}fb=d+16|0;return c|0}function di(a,b,c){var d=0,e=0,f=0;d=fb-16|0;fb=d;bc(d+8|0,b,c);e=x[d+12>>2];lc(d,x[a>>2],x[a+8>>2],x[d+8>>2],x[d+12>>2]);f=x[d+4>>2];if((f|0)==(e|0)){Vb(a,x[d+12>>2])}fb=d+16|0;a=(e|0)==(f|0);if(!a){Rb(b,0,c)}return a}function dZ(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+16|0]=0;v[a+17|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a+12|0]=0;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0}function b$(a){var b=0;a:{if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=777268804){break a}if($b(y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24))-257>>>0<4294967053){break a}b=!Bb(y[a+8|0]|y[a+9|0]<<8)}return b}function Rda(a,b){a=a|0;b=b|0;var c=0;a=x[a+8>>2];a:{if(Ad(x[b+4>>2],y[b+11|0])){c=0}else{c=a;if(Ld(b,47408)){break a}c=a+88|0;if(Ld(b,47420)){break a}c=a+92|0;if(Ld(b,47432)){break a}c=Ld(b,47445)?a+96|0:0}}return c|0}function Pt(a){var b=0;a:{b=y[a+1376|0];b:{if(!b){b=-1;if(x[a+1384>>2]){break b}if(!dz(a)){break b}b=y[a+1376|0];if(!b){break a}}v[a+1376|0]=b-1;x[a+1400>>2]=x[a+1400>>2]+1;b=gf(a)}return b}_(15787,13274,1578,5429);p()}function AX(a){var b=0,c=0,d=0,e=0;c=fb-16|0;fb=c;d=vb(c+12|0,a);a=x[d>>2];if(x[a>>2]){e=x[a>>2];b=x[a+4>>2];while(1){if((b|0)!=(e|0)){b=b-56|0;er(b);continue}break}x[a+4>>2]=e;a=x[d>>2];b=x[a>>2];xX(a);Db(b)}fb=c+16|0}function vB(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0;f=x[b+480180>>2];if(f&64671904){b=y[(d&15)+42256|0];v[a+2|0]=0;w[a>>1]=b;return}g=a;a=(c&255)==4&(f|0)==4;c=(d&255)<<a<<4;em(g,(h=Ob(b+1074312|0,66)?0:c,i=c,j=e,j?h:i),a)}function PU(a,b){a:{if(y[a+76|0]==(b|0)){break a}v[a+76|0]=b;if(b){b=0;if(z[a+24>>1]==15){w[a+20>>1]=0;b=1}x[a+8>>2]=0;x[a+16>>2]=b;return}b:{switch(x[a+16>>2]+1|0){case 0:case 4:break a;default:break b}}x[a+16>>2]=3}}function FF(a,b){var c=0,d=0;c=fb-16|0;fb=c;a:{if(b>>>0<2){b:{if(!b){break b}if(!Mb(x[a>>2],x[a+8>>2],1)){break b}v[c+15|0]=0;fh(a,c+15|0);d=v[c+15|0]}fb=c+16|0;a=d<<24>>24;break a}_(11251,9095,325,14260);p()}return a}function ur(a,b,c){var d=0,e=0;e=z[a+480192>>1];a:{if(e){if(!Sc(b)|c>>>0>e>>>0){break a}c=x[((c<<2)+a|0)+900380>>2];if(!c){break a}d=z[_b(c+236|0,b-1|0)>>1];break a}d=c}return(z[a+480190>>1]>=(d&65535)>>>0?d:0)&65535}function Sua(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;e=c>>>16|0;f=a>>>16|0;j=D(e,f);g=c&65535;h=a&65535;i=D(g,h);f=(i>>>16|0)+D(f,g)|0;e=(f&65535)+D(e,h)|0;hb=(D(b,c)+j|0)+D(a,d)+(f>>>16)+(e>>>16)|0;return i&65535|e<<16}function xZ(a,b,c){var d=0,e=0,f=0;e=fb-16|0;fb=e;f=x[a+8>>2];d=e+4|0;x[d+8>>2]=a+8;x[d>>2]=f;x[d+4>>2]=D(b,6)+f;b=x[d>>2];while(1){if(x[d+4>>2]!=(b|0)){Ov(b,c);b=x[d>>2]+6|0;x[d>>2]=b;continue}break}he(d);fb=e+16|0}function vba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-16|0;fb=d;e=d+4|0;jN(e,c);a=x[a+1298472>>2];x[31737]=0;S(386,a|0,b|0,e|0);a=x[31737];x[31737]=0;if((a|0)!=1){tb(e);fb=d+16|0;return}a=N()|0;tb(d+4|0);Q(a|0);p()}function bz(a){var b=0;a:{b:{while(1){if(x[a+1380>>2]!=-1){break b}b=0;if(!Ot(a)){break a}if(!(v[a+1375|0]&1)){continue}break}fc(a,32);return 0}x[a+1396>>2]=0;x[a+1400>>2]=0;x[a+1384>>2]=0;v[a+1376|0]=0;b=1}return b}function IL(a,b){var c=0,d=0,e=0;c=fb-256|0;fb=c;if((b|0)>=2){x[(b<<2)+a>>2]=c;yc(c,x[a>>2],4);while(1){e=(d<<2)+a|0;d=d+1|0;yc(x[e>>2],x[(d<<2)+a>>2],4);x[e>>2]=x[e>>2]+4;if((b|0)!=(d|0)){continue}break}}fb=c+256|0}function rU(a,b){var c=0,d=0,e=0,f=0;e=C[a+48>>3];c=C[a+40>>3];C[a+48>>3]=c;f=C[a+64>>3];d=C[a+56>>3];C[a+64>>3]=d;C[a+40>>3]=b;b=e*C[a+16>>3]+(C[a>>3]*b+c*C[a+8>>3])-d*C[a+24>>3]-f*C[a+32>>3];C[a+56>>3]=b;return b}function sV(a){var b=0;b=w[a+784>>1];if(b){x[a+692>>2]=(b&32767)-1;if((b|0)<0){x[a+88>>2]=x[a+88>>2]|256}w[a+784>>1]=0}b=y[a+795|0];if(b){v[a+795|0]=0;v[a+838|0]=b-1}b=y[a+796|0];if(b){v[a+796|0]=0;v[a+837|0]=b-1}}function po(a,b){var c=0,d=0,e=0;c=a*a;d=c*a;e=c*c;a=d*e*(e*(c*.009465647849436732+.002974357433599673)+(c*.024528318116654728+.05338123784456704))+(d*(c*.13339200271297674+.3333313950307914)+a);return E(b?-1/a:a)}function VI(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=a;a=xk(Jb(b));x[d>>2]=a;a:{if(!a){a=c+4|0;Rm(a,17645,b);x[31737]=0;W(1325,a|0);b=x[31737];x[31737]=0;if((b|0)!=1){break a}b=N()|0;tb(a);Q(b|0);p()}fb=c+16|0;return}p()}function Kq(a,b){a=yc(a,b,88);x[a+88>>2]=x[b+88>>2];yc(a+92|0,b+92|0,576);x[a+668>>2]=x[b+668>>2];yc(a+672|0,b+672|0,52);iB(a+724|0,b+724|0);iB(a+732|0,b+732|0);iB(a+740|0,b+740|0);yc(a+748|0,b+748|0,123);return a}function Mra(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=fb-16|0;fb=e;c=Hf(a,c);$d(e,x[a+36>>2]);a:{if(!c){Pc(e,a+32|0,5);f=0;if(Hb(x[x[e>>2]>>2],x[e+4>>2])){break a}}LZ(x[a+36>>2],b,d,0);f=c}ff(a,f);fb=e+16|0}function _ja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;a:{if(Ug(a)>>>0<b>>>0){if(th(1073741823)>>>0<b>>>0){break a}d=zb(a);e=a;a=$f(c+12|0,b,oc(x[a>>2],x[a+4>>2]),d);Ym(e,a);_f(a)}fb=c+32|0;return}dd();p()}function XT(a){var b=0,c=0,d=0,e=0;c=fb-16|0;fb=c;d=vb(c+12|0,a);a=x[d>>2];if(x[a>>2]){e=x[a>>2];b=x[a+4>>2];while(1){if((b|0)!=(e|0)){b=b-7|0;continue}break}x[a+4>>2]=e;a=x[d>>2];b=x[a>>2];FB(a);Db(b)}fb=c+16|0}function UI(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=xk(Jb(b));x[a>>2]=d;a:{if(!d){a=c+4|0;Rm(a,17686,b);x[31737]=0;W(1325,a|0);b=x[31737];x[31737]=0;if((b|0)!=1){break a}b=N()|0;tb(a);Q(b|0);p()}fb=c+16|0;return a}p()}function ola(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;a:{if(Xn(a)>>>0<b>>>0){if(th(536870911)>>>0<b>>>0){break a}d=zb(a);e=a;a=ms(c+12|0,b,jh(x[a>>2],x[a+4>>2]),d);NB(e,a);ls(a)}fb=c+32|0;return}dd();p()}function hja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=fb-16|0;fb=e;c=Hf(a,c);$d(e,x[a+36>>2]);a:{if(!c){Pc(e,a+32|0,5);f=0;if(Hb(x[x[e>>2]>>2],x[e+4>>2])){break a}}_Q(d,x[a+36>>2],b);f=c}ff(a,f);fb=e+16|0}function fG(a,b,c){var d=0,e=0;d=fb-16|0;fb=d;if(c>>>0<2147483632){a:{if(Rk(c)){Me(a,c);break a}sg(d+8|0,Dh(c)+1|0);e=x[d+8>>2];yd(a,e);of(a,x[d+12>>2]);Yd(a,c);a=e}fd(Xg(a,b,c)+c|0,0);fb=d+16|0;return}pf();p()}function ela(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;a:{if(FB(a)>>>0<b>>>0){if(th(613566756)>>>0<b>>>0){break a}d=zb(a);e=a;a=WT(c+12|0,b,EB(x[a>>2],x[a+4>>2]),d);VT(e,a);UT(a)}fb=c+32|0;return}dd();p()}function aka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;a:{if(jl(a)>>>0<b>>>0){if(th(357913941)>>>0<b>>>0){break a}d=zb(a);e=a;a=Dm(c+12|0,b,Ud(x[a>>2],x[a+4>>2]),d);vx(e,a);zs(a)}fb=c+32|0;return}dd();p()}function _k(a){wc(a+16|0,x[a>>2]);wc(a+8|0,x[a>>2]);if(A[a+12>>2]>=A[a+16>>2]){x[a+12>>2]=0;x[a+16>>2]=0;w[a+34>>1]=z[a+34>>1]&65511}if(A[a+4>>2]>=A[a+8>>2]){x[a+4>>2]=0;x[a+8>>2]=0;w[a+34>>1]=z[a+34>>1]&65529}}function RY(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;UY(c+8|0,b);d=x[c+12>>2];lc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){TY(b)}return a}function Ooa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;a:{if(jl(a)>>>0<b>>>0){if(th(357913941)>>>0<b>>>0){break a}d=zb(a);e=a;a=Dm(c+12|0,b,Ud(x[a>>2],x[a+4>>2]),d);JW(e,a);IW(a)}fb=c+32|0;return}dd();p()}function OD(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;O_(c+8|0,b);d=x[c+12>>2];lc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){P_(b)}return a}function NY(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;a:{if(Nn(a)>>>0<b>>>0){if(th(2147483647)>>>0<b>>>0){break a}d=zb(a);e=a;a=kk(c+12|0,b,Zc(x[a>>2],x[a+4>>2]),d);Yr(e,a);jj(a)}fb=c+32|0;return}dd();p()}function Gu(a,b,c){var d=0,e=0;d=fb-16|0;fb=d;if(c>>>0<2147483632){a:{if(Rk(c)){Me(a,c);break a}sg(d+8|0,Dh(c)+1|0);e=x[d+8>>2];yd(a,e);of(a,x[d+12>>2]);Yd(a,c);a=e}fd(Cg(a,b,c)+c|0,0);fb=d+16|0;return}pf();p()}function $m(a,b){var c=E(0),d=0,e=0;c=E(1);d=w[a+28>>1];a:{if((d|0)>(b|0)){break a}e=x[a+4>>2];if((oc(e,x[a+8>>2])+d|0)-1<<16>>16<(b|0)){break a}c=B[yb(e,b-d|0)>>2];c=c<=E(10000000036274937e-31)?E(1):c}return c}function sia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;d=Ej(a);if(d){e=x[b+4>>2];b=x[b>>2];x[c+8>>2]=b;x[c+12>>2]=e;a=x[x[d>>2]+72>>2];x[c>>2]=b;x[c+4>>2]=e;a=ib[a|0](d,c)|0}else{a=1}fb=c+16|0;return a|0}function oaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=x[c>>2];c=x[c+4>>2];while(1){if(c){d=x[b+24>>2];g=th(c);Dj(d,e+f|0,g);d=x[x[b+24>>2]+4>>2];c=c-d|0;e=e+d|0;if((d|0)==(g|0)){continue}}break}bc(a,f,e)}function hL(a,b){a=a|0;b=b|0;var c=0,d=0;c=x[a>>2];a:{if(!c){break a}d=x[c+24>>2];b:{if((d|0)==x[c+28>>2]){b=ib[x[x[c>>2]+52>>2]](c,b)|0;break b}x[c+24>>2]=d+4;x[d>>2]=b}if(!mo(b)){break a}x[a>>2]=0}return a|0}function cN(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;f=e+8|0;vz(f,b);while(1){if(d){b=x[f+4>>2];h=th(d);Dj(b,c+g|0,h);b=x[x[f+4>>2]+4>>2];d=d-b|0;g=b+g|0;if((b|0)==(h|0)){continue}}break}bc(a,c,g);fb=e+16|0}function JA(a,b){var c=0,d=0;c=x[b+4>>2];x[a+24648>>2]=x[b>>2];x[a+24652>>2]=c;d=x[b+20>>2];c=a+24664|0;x[c>>2]=x[b+16>>2];x[c+4>>2]=d;d=x[b+12>>2];c=a+24656|0;x[c>>2]=x[b+8>>2];x[c+4>>2]=d;ZR(a+24648|0);dS(a)}function Nx(a,b,c){var d=0;d=x[a+16>>2];if(!d){x[a+36>>2]=1;x[a+24>>2]=c;x[a+16>>2]=b;return}a:{if((b|0)==(d|0)){if(x[a+24>>2]!=2){break a}x[a+24>>2]=c;return}v[a+54|0]=1;x[a+24>>2]=2;x[a+36>>2]=x[a+36>>2]+1}}function HJ(a,b,c){var d=0,e=0;e=fb-16|0;fb=e;d=fb-32|0;fb=d;Id(d+24|0,a,b);wn(d+16|0,x[d+24>>2],x[d+28>>2],c);a=kA(a,x[d+16>>2]);x[d+12>>2]=x[d+20>>2];Ac(e+8|0,a,d+12|0);fb=d+32|0;fb=e+16|0;return x[e+12>>2]}function Br(a,b,c){var d=0,e=0;e=fb-16|0;fb=e;d=fb-32|0;fb=d;Id(d+24|0,a,b);wn(d+16|0,x[d+24>>2],x[d+28>>2],c);a=e$(a,x[d+16>>2]);x[d+12>>2]=x[d+20>>2];Ac(e+8|0,a,d+12|0);fb=d+32|0;fb=e+16|0;return x[e+12>>2]}function Vga(a){a=a|0;var b=0;b=fb-16|0;fb=b;a:{if(!Ld(a,10281)){b=b+4|0;Rm(b,18232,a);a=Jb(b);x[31737]=0;O(67,44,a|0);a=x[31737];x[31737]=0;if((a|0)!=1){break a}a=N()|0;tb(b);Q(a|0);p()}fb=b+16|0;return}p()}function QC(a,b){var c=0,d=0,e=0,f=0;d=b?224:240;e=CG(a);a:while(1){if((a|0)!=(e|0)){f=td(a);b=a;while(1)if((b|0)==(f|0)){a=a+16|0;continue a}else{c=((y[xb(b,0)|0]&d)!=0)+c|0;b=b+4|0;continue}}break}return c}function GA(a,b,c){var d=0,e=0;d=x[b+656>>2];if(!d){return 0}d=Jw(d,c);a=a+1074312|0;if(!Ob(a,31)){e=Ob(a,93)^1}a:{if(!(v[TR(b,c)+6|0]&1)){a=0;if(!(v[d+12|0]&1)|e){break a}}a=mc(x[d>>2],x[d+4>>2])^1}return a}function ov(a,b,c){var d=0,e=0,f=0,g=0;e=fb-16|0;fb=e;d=fb-32|0;fb=d;Id(d+24|0,a,b);wn(d+16|0,x[d+24>>2],x[d+28>>2],c);a=x[d+16>>2];f=d,g=WD(c,x[d+20>>2]),x[f+12>>2]=g;Ac(e+8|0,a,d+12|0);fb=d+32|0;fb=e+16|0}function YS(a,b,c,d){var e=0,f=0;b=D(c,872)+b|0;e=x[b+704>>2];a:{if(!(!(e&67109888)|(d|0)!=1)|e&33554432){break a}b=z[b+1402>>1];b=(b?b-1|0:c)&65535;if(b>>>0>126){break a}f=y[((b<<5)+a|0)+480288|0]}return f}function VS(a,b){var c=0;c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;c=x[b+28>>2];x[a+24>>2]=x[b+24>>2];x[a+28>>2]=c;c=x[b+20>>2];x[a+16>>2]=x[b+16>>2];x[a+20>>2]=c;c=x[b+12>>2];x[a+8>>2]=x[b+8>>2];x[a+12>>2]=c}function Hoa(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;on(a,b);b=wb(x[a>>2]);x[c+12>>2]=b;a=wb(x[a+4>>2]);while(1){if(Ib(b,a)){d=y[b|0]+(d&255)|0;v[b|0]=d;b=x[le(c+12|0)>>2];continue}else{fb=c+16|0}break}}function FE(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+16|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a+12|0]=0;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0}function pla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=Nb(a);d=qg(a+12|0);v[a+32|0]=c;x[a+28>>2]=0;x[a+24>>2]=b;x[31737]=0;O(805,a|0,1);b=x[31737];x[31737]=0;if((b|0)!=1){return a|0}b=N()|0;kU(d);oU(a);Q(b|0);p()}function od(a,b,c,d){var e=0,f=0;e=fb-32|0;fb=e;f=x[b+12>>2];lf(e+16|0,c,d);c=x[x[b>>2]+28>>2];d=x[e+20>>2];x[e+8>>2]=x[e+16>>2];x[e+12>>2]=d;ib[c|0](e+24|0,b,f,e+8|0);lf(a,x[e+24>>2],x[e+28>>2]);fb=e+32|0}function dqa(a){a=a|0;var b=0,c=0,d=0;b=fb-32|0;fb=b;w[b+30>>1]=0;c=gc(b+8|0,b+30|0,2);lc(b+20|0,x[a>>2],x[a+8>>2],x[c>>2],x[c+4>>2]);if(!(x[b+24>>2]!=2|z[b+30>>1]!=21584)){Vb(a,2);d=1}fb=b+32|0;return d|0}function Yda(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;d=c+4|0;jN(d,b);a=x[a+1298472>>2];x[31737]=0;S(386,a|0,1,d|0);a=x[31737];x[31737]=0;if((a|0)!=1){tb(d);fb=c+16|0;return}a=N()|0;tb(c+4|0);Q(a|0);p()}function Jd(a,b){var c=0,d=0;c=fb-16|0;fb=c;a:{if(b>>>0<2){b:{if(!b){break b}if(!Mb(x[a>>2],x[a+8>>2],1)){break b}v[c+15|0]=0;fh(a,c+15|0);d=y[c+15|0]}fb=c+16|0;break a}_(11251,9095,325,14260);p()}return d}function Ci(a,b,c){var d=0,e=0,f=0;d=fb-16|0;fb=d;bc(d+8|0,b,c);e=x[d+12>>2];lc(d,x[a>>2],x[a+8>>2],x[d+8>>2],x[d+12>>2]);f=x[d+4>>2];if((f|0)==(e|0)){Vb(a,x[d+12>>2])}fb=d+16|0;if((e|0)!=(f|0)){Rb(b,0,c)}}function ula(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{if(!Mb(x[a>>2],x[a+8>>2],27)){a=0;while(1){if((a|0)!=27){eh(a+b|0);a=a+1|0;continue}break}break a}FU(c+8|0,b);rd(c,a,x[c+8>>2],x[c+12>>2])}fb=c+16|0}function _ta(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{if(!Mb(x[a>>2],x[a+8>>2],64)){a=0;while(1){if((a|0)!=64){eh(a+b|0);a=a+1|0;continue}break}break a}iw(c+8|0,b);rd(c,a,x[c+8>>2],x[c+12>>2])}fb=c+16|0}function SO(a,b){var c=0,d=0;c=-1;a:{if((b|0)<0){break a}d=x[a+24>>2];if(Oj(Xb(x[d+484360>>2],y[d+484376|0]))>>>0<=b>>>0){break a}a=x[a+24>>2];c=z[_b(x[Xb(x[a+484360>>2],y[a+484376|0])>>2],b)>>1]}return c}function RU(a){var b=0,c=0,d=0;b=z[a+20>>1];w[a+28>>1]=z[a+22>>1]<<1|(y[x[a+16>>2]+3842|0]?b>>>9|0:b>>>8&1);b=0;while(1){if((b|0)!=4){c=(b<<2)+a|0;d=x[c>>2];if(d){To(d);QU(x[c>>2])}b=b+1|0;continue}break}}function iG(a){var b=0;if(!((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=808603728|(y[a+4|0]-16&255)>>>0<249|((y[a+5|0]-16&255)>>>0<249|(y[a+6|0]-16&255)>>>0<249))){b=(y[a+7|0]-9&255)>>>0<7}return b}function Yf(a,b,c,d,e){var f=0;f=fb-256|0;fb=f;if(!(e&73728|(c|0)<=(d|0))){d=c-d|0;c=d>>>0<256;Rb(f,b&255,c?d:256);if(!c){while(1){Kf(a,f,256);d=d-256|0;if(d>>>0>255){continue}break}}Kf(a,f,d)}fb=f+256|0}function T3(a){a=a|0;var b=0;a:{b:{if(!a){break b}b=ol(a);if(vI(b,-1)|y[b+13|0]){break b}b=x[b+8>>2];if(b){x[31737]=0;R(b|0,a|0)|0;b=x[31737];x[31737]=0;if((b|0)==1){break a}}jc(a)}return}T(0)|0;Sb();p()}function Qga(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=fb-16|0;fb=f;b=Gc(Tua(Sua(d,d>>31,b,0),hb,1e3,0),hb);x[a+16>>2]=0;x[a+12>>2]=b+c;cQ(a,e);b=x[a+12>>2];x[f+12>>2]=0;cR(a,b,f+12|0);fb=f+16|0}function Cw(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{if(!Mb(x[a>>2],x[a+8>>2],32)){a=0;while(1){if((a|0)!=32){eh(a+b|0);a=a+1|0;continue}break}break a}PE(c+8|0,b);rd(c,a,x[c+8>>2],x[c+12>>2])}fb=c+16|0}function vo(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;a:{if(dp(a)>>>0<b>>>0){if(th(-1)>>>0<b>>>0){break a}d=zb(a);e=a;a=un(c+12|0,b,Vc(x[a>>2],x[a+4>>2]),d);gr(e,a);tn(a)}fb=c+32|0;return}dd();p()}function tja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-16|0;fb=d;c=Hf(a,c);$d(d,x[a+36>>2]);a:{if(!c){Pc(d,a+32|0,5);e=0;if(Hb(x[x[d>>2]>>2],x[d+4>>2])){break a}}QZ(x[a+36>>2],b,a);e=c}ff(a,e);fb=d+16|0}function te(a,b){var c=0,d=0,e=0;b=b+7&-8;x[a+8>>2]=b+x[a+8>>2];d=x[a+80>>2];a:{if(d){c=b;b=x[a+88>>2];e=c+b|0;c=0;if((e|0)>x[a+92>>2]){break a}x[a+88>>2]=e;return b+d|0}if(!b){return 0}c=Ed(b)}return c}function ida(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;a=x[a+4>>2];b=lg(d+4|0,b);x[31737]=0;V(1018,a|0,b|0,c|0,1);a=x[31737];x[31737]=0;if((a|0)!=1){tb(b);fb=d+16|0;return}a=N()|0;tb(b);Q(a|0);p()}function YY(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;TD(c+8|0,b);b=x[c+12>>2];lc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)|0}function QN(a,b){a=a|0;b=b|0;var c=0;a=Kj(a);x[a+4>>2]=0;x[a>>2]=47680;if(ib[x[x[b>>2]+8>>2]](b)|0){b=ib[x[x[b>>2]+8>>2]](b)|0}else{b=22303}c=Ed(Cf(b)+1|0);x[a+4>>2]=c;if(c){yc(c,b,Cf(b)+1|0)}return a|0}function K9(a,b){a=a|0;b=b|0;var c=0,d=0;a:{c=x[b+52>>2];if(c&16){d=x[b+48>>2];c=x[b+28>>2];if(d>>>0<c>>>0){x[b+48>>2]=c;d=c}si(a,x[b+24>>2],d);break a}if(c&8){si(a,x[b+12>>2],x[b+20>>2]);break a}Fb(a)}}function $na(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;if((b|0)>=0){d=2147483647;a=ev(a);if(a>>>0<=1073741822){x[c+12>>2]=a<<1;x[c+8>>2]=b+31&-32;d=x[ad(c+12|0,c+8|0)>>2]}fb=c+16|0;return d|0}dd();p()}function $h(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;dl(c+8|0,b);b=x[c+12>>2];lc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)|0}function u0(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{if(!Mb(x[a>>2],x[a+8>>2],8)){a=0;while(1){if((a|0)!=8){eh(a+b|0);a=a+1|0;continue}break}break a}dl(c+8|0,b);rd(c,a,x[c+8>>2],x[c+12>>2])}fb=c+16|0}function qi(a){var b=0,c=0,d=0,e=0;b=fb-16|0;fb=b;c=2;if(a>>>0>=2){x[b+12>>2]=a>>>1;x[b+8>>2]=a^-1;d=b,e=x[Gb(b+12|0,b+8|0)>>2]+a|0,x[d+12>>2]=e;x[b+8>>2]=-1;c=x[Gb(b+12|0,b+8|0)>>2]}fb=b+16|0;return c}function dK(a,b,c,d,e,f){var g=0,h=0,i=0;g=fb-16|0;fb=g;v[g+15|0]=0;v[g+14|0]=f;v[g+13|0]=e;v[g+12|0]=37;if(f){tg(g+13|0,g+14|0)}h=c,i=(fa(b|0,Vc(b,x[c>>2])|0,g+12|0,d|0,a|0)|0)+b|0,x[h>>2]=i;fb=g+16|0}function kca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;b=x[b+4>>2];c=lg(d+4|0,c);x[31737]=0;S(1004,a|0,b|0,c|0);a=x[31737];x[31737]=0;if((a|0)!=1){tb(c);fb=d+16|0;return}a=N()|0;tb(c);Q(a|0);p()}function c3(a,b){a=a|0;b=b|0;var c=0;a=Nt(a);x[a>>2]=93688;c=Fb(a+32|0);x[a+44>>2]=0;x[a+48>>2]=8;x[31737]=0;O(113,a|0,b|0);b=x[31737];x[31737]=0;if((b|0)!=1){return a|0}b=N()|0;tb(c);no(a);Q(b|0);p()}function aia(a){a=a|0;var b=0,c=0,d=0;b=fb-32|0;fb=b;a:{if(Ug(a)>>>0<=12){if(th(1073741823)>>>0<=12){break a}c=zb(a);d=a;a=$f(b+12|0,13,oc(x[a>>2],x[a+4>>2]),c);Ym(d,a);_f(a)}fb=b+32|0;return}dd();p()}function VX(a,b){a=a|0;b=b|0;var c=0,d=0;d=x[a>>2];c=65535;a:{if(!He(d,x[a+4>>2],b)){break a}d=fE(a,x[gj(d,b)+12>>2]);c=65535;if((d|0)==65535){break a}c=x[a>>2];a=gj(c,b);uR(gj(c,d),a);c=d}return c|0}function QS(a,b,c){var d=0,e=0;d=Mc(a);e=Cb(x[a+4>>2],y[a+11|0]);a:{if(d-e>>>0>=c>>>0){if(!c){break a}d=Jb(a);Xg(d+e|0,b,c);b=c+e|0;ng(a,b);fd(b+d|0,0);return a}Yq(a,d,(c-d|0)+e|0,e,e,0,c,b)}return a}function Bl(a){a=a|0;var b=0;x[a>>2]=94884;x[31737]=0;O(114,a|0,0);b=x[31737];x[31737]=0;if((b|0)!=1){Zb(a+28|0);Db(x[a+32>>2]);Db(x[a+36>>2]);Db(x[a+48>>2]);Db(x[a+60>>2]);return a|0}T(0)|0;Sb();p()}function AJ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;if(th(1073741823)>>>0<b>>>0){dd();p()}iJ(c+8|0,hq(a),b);b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;d=zb(a),e=b+(x[c+12>>2]<<2)|0,x[d>>2]=e;fb=c+16|0}function A9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-16|0;fb=d;f=x[x[b>>2]+20>>2];e=x[c+12>>2];x[d+8>>2]=x[c+8>>2];x[d+12>>2]=e;e=x[c+4>>2];x[d>>2]=x[c>>2];x[d+4>>2]=e;ib[f|0](a,b,d,8);fb=d+16|0}function tx(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-16|0;fb=e;x[e+12>>2]=d;d=Cb(x[b+4>>2],y[b+11|0]);if(d>>>0<c>>>0){jn();p()}b=Jb(b);x[e+8>>2]=d-c;Gu(a,b+c|0,x[Gb(e+12|0,e+8|0)>>2]);fb=e+16|0}function q$(a){var b=0;a:{if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=443372356|y[a+4|0]!=32|(!y[a+46|0]|(y[a+45|0]-17&255)>>>0<240)){break a}if(!y[a+47|0]){break a}b=y[a+49|0]<101}return b}function i3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-16|0;fb=e;x[e+12>>2]=d;d=Cb(x[b+4>>2],y[b+11|0]);if(d>>>0<c>>>0){jn();p()}b=Jb(b);x[e+8>>2]=d-c;fG(a,b+c|0,x[Gb(e+12|0,e+8|0)>>2]);fb=e+16|0}function C0(a,b){var c=0;c=fb-16|0;fb=c;a:{if(!Mb(x[a>>2],x[a+8>>2],512)){a=0;while(1){if((a|0)!=128){Hn((a<<2)+b|0);a=a+1|0;continue}break}break a}xE(c+8|0,b);rd(c,a,x[c+8>>2],x[c+12>>2])}fb=c+16|0}function Dw(a,b){var c=0;c=fb-16|0;fb=c;a:{if(!Mb(x[a>>2],x[a+8>>2],256)){a=0;while(1){if((a|0)!=256){eh(a+b|0);a=a+1|0;continue}break}break a}bc(c+8|0,b,256);rd(c,a,x[c+8>>2],x[c+12>>2])}fb=c+16|0}function uU(a,b,c,d,e,f){x[a+40>>2]=0;x[a+44>>2]=0;C[a+32>>3]=f;C[a+24>>3]=e;C[a+16>>3]=d;C[a+8>>3]=c;C[a>>3]=b;x[a+48>>2]=0;x[a+52>>2]=0;x[a+56>>2]=0;x[a+60>>2]=0;a=a- -64|0;x[a>>2]=0;x[a+4>>2]=0}function l_(a,b,c){var d=0,e=0;d=fb-16|0;fb=d;a=Tg(d+4|0,a,b);b=x[a+4>>2];e=x[a+8>>2];while(1){if((b|0)==(e|0)){hc(a);fb=d+16|0}else{gp(b,z[c>>1]|z[c+2>>1]<<16);b=b+4|0;x[a+4>>2]=b;continue}break}}function be(a,b){var c=0,d=0,e=0;d=z[a+24>>1];if((d|0)!=(b&65535)){c=z[a+22>>1]-1&127;w[a+22>>1]=c;e=z[a+20>>1];if(e>>>0<=127){w[a+20>>1]=e+1}c=(c<<2)+a|0;w[c+26>>1]=b-d;w[c+28>>1]=0;w[a+24>>1]=b}}function N_(a){var b=0,c=0,d=0;a:{if(kd(a,22292,11)){break a}c=a+215|0;a=a+63|0;while(1){b=(a|0)==(c|0);if(b|y[a+16|0]>3|y[a+17|0]>3){break a}d=a;a=a+19|0;if(y[d+18|0]<16){continue}break}}return b}function Cda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-16|0;fb=d;e=x[a+4>>2];a=x[b+4>>2];b=x[b>>2];x[d+8>>2]=b;x[d+12>>2]=a;f=x[c>>2];c=x[c+4>>2];x[d>>2]=b;x[d+4>>2]=a;Mz(e,d,f,c,1);fb=d+16|0}function Bs(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;if(b){d=Mc(a);e=Cb(x[a+4>>2],y[a+11|0]);if(d-e>>>0<b>>>0){Wm(a,d,(b-d|0)+e|0,e,e,0,0)}d=Jb(a);hm(d+e|0,b,c);b=b+e|0;ng(a,b);fd(b+d|0,0)}return a|0}function Bj(a){var b=0;b=32767;a:{if(a>=E(32766.5)){break a}b=32768;if(a<=E(-32767.5)){break a}a=E(a+E(.5));b:{if(E(F(a))<E(2147483648)){b=~~a;break b}b=-2147483648}b=b+(b>>15)|0}return b<<16>>16}function tqa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;if(th(1073741823)>>>0<b>>>0){dd();p()}LF(c+8|0,b);b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;d=zb(a),e=b+(x[c+12>>2]<<2)|0,x[d>>2]=e;fb=c+16|0}function r$(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;iw(c+8|0,b);d=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){gd(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){aw(b)}return a}function nk(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;dl(c+8|0,b);d=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){gd(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){el(b)}return a}function mY(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;a:{if(!Sn(b,a)|!c){break a}nh(d+8|0,a);a=0;while(1){if(a>>>0>=4){break a}b=x[d+8>>2];tg(xb(b,a),xb(b,a|1));a=a+2|0;continue}}fb=d+16|0}function kP(a,b){var c=E(0),d=E(0);if(!((b|0)<0|z[a+480188>>1]<=b>>>0)){a=D(b,872)+a|0;c=E(E(y[a+1075834|0])*E(.0078125));d=E(c*c);c=E(E(y[a+1075835|0])*E(.0078125));c=E(M(E(d+E(c*c))))}return c}function gaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;if(th(357913941)>>>0<b>>>0){dd();p()}aH(c+8|0,b);b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;d=zb(a),e=b+D(x[c+12>>2],12)|0,x[d>>2]=e;fb=c+16|0}function gS(a){var b=0,c=0;a=a+906300|0;c=Ak(a);while(1){if((a|0)!=(c|0)){b=x[a>>2];a:{if(!b){break a}if(!(ib[x[x[b>>2]+120>>2]](b)|0)){break a}ib[x[x[b>>2]+100>>2]](b)}a=a+160|0;continue}break}}function cX(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;ex(c+8|0,b);d=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){gd(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){fx(b)}return a}function ZW(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;O_(c+8|0,b);d=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){gd(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){P_(b)}return a}function X$(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;hw(c+8|0,b);d=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){gd(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){kE(b)}return a}function Rja(a,b){a=a|0;b=b|0;var c=0;b=fb-16|0;fb=b;c=-1;a:{if(!nk(a,b+8|0)){break a}c=0;if(!FR(x[b+8>>2],x[b+12>>2])){break a}c=-1;if(!eF(a,b+4|0)){break a}c=ER(x[b+4>>2])}fb=b+16|0;return c|0}function QG(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;NG(c+8|0,b);d=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){gd(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){qx(b)}return a}function Jr(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a+12|0]=0;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0}function HX(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;DX(c+8|0,b);d=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){gd(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){EX(b)}return a}function $F(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;fs(c+8|0,b);d=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){gd(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){gs(b)}return a}function $D(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;Fr(c+8|0,b);d=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){gd(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){w$(b)}return a}function qm(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;if(th(1073741823)>>>0<b>>>0){dd();p()}Uj(c+8|0,b);b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;d=zb(a),e=b+(x[c+12>>2]<<2)|0,x[d>>2]=e;fb=c+16|0}function k1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;if(th(214748364)>>>0<b>>>0){dd();p()}RE(c+8|0,b);b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;d=zb(a),e=b+D(x[c+12>>2],20)|0,x[d>>2]=e;fb=c+16|0}function ila(a){a=a|0;var b=0,c=0,d=0,e=0;b=fb-16|0;fb=b;if(th(2147483647)>>>0<=2303){dd();p()}Uw(b+8|0,2304);c=x[b+8>>2];x[a+4>>2]=c;x[a>>2]=c;d=zb(a),e=(x[b+12>>2]<<1)+c|0,x[d>>2]=e;fb=b+16|0}function cE(a,b){var c=0;c=fb-16|0;fb=c;x[c+12>>2]=1;x[c+8>>2]=a>>>4;b=Yb(128/(D(x[Ye(c+12|0,c+8|0)>>2],b)|0)|0,1,15);v[c+7|0]=1;v[c+6|0]=a&15;a=df(c+7|0,c+6|0);fb=c+16|0;return y[a|0]|b<<4&240}function Kia(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=0,f=E(0);d=fb-16|0;fb=d;e=d,f=E(E(ib[x[x[a>>2]+48>>2]](a,b))+c),B[e+12>>2]=f;NT(d+12|0,E(0),E(1));ib[x[x[a>>2]+44>>2]](a,b,B[d+12>>2]);fb=d+16|0}function GC(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;if(th(2147483647)>>>0<b>>>0){dd();p()}Uw(c+8|0,b);b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;d=zb(a),e=b+(x[c+12>>2]<<1)|0,x[d>>2]=e;fb=c+16|0}function tU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;if(th(536870911)>>>0<b>>>0){dd();p()}tG(c+8|0,b);b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;d=zb(a),e=b+(x[c+12>>2]<<3)|0,x[d>>2]=e;fb=c+16|0}function qU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;if(th(268435455)>>>0<b>>>0){dd();p()}XV(c+8|0,b);b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;d=zb(a),e=b+(x[c+12>>2]<<4)|0,x[d>>2]=e;fb=c+16|0}function eq(a,b,c){var d=0;d=fb-16|0;fb=d;if(y[b|0]){x[d+8>>2]=0;x[d+12>>2]=0;b=ey(d+4|0,b,Cf(b),d+8|0,c);if(b>>>0<=4294967293){x[a>>2]=x[d+4>>2]}a=b>>>0<4294967294}else{a=0}fb=d+16|0;return a}function cM(a,b){var c=0,d=0,e=0,f=E(0),g=E(0),h=0;b=(b|0)>0?b:0;h=a+2304|0;while(1){if((b|0)!=(d|0)){c=d<<2;e=c+a|0;f=B[e>>2];c=c+h|0;g=B[c>>2];B[e>>2]=f+g;B[c>>2]=f-g;d=d+1|0;continue}break}}function XS(a,b,c){var d=0,e=0;d=fb-16|0;fb=d;a=ks(d+4|0,a,b);b=x[a+4>>2];e=x[a+8>>2];while(1){if((b|0)==(e|0)){hc(a);fb=d+16|0}else{WS(b,x[c>>2],x[c+4>>2]);b=b+8|0;x[a+4>>2]=b;continue}break}}function QZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-16|0;fb=d;pg(a,d+14|0);e=z[d+14>>1];mS(b,e);c=0;while(1){if((c|0)==(e|0)){PA(b);fb=d+16|0}else{Lk(a,yb(x[b>>2],c));c=c+1|0;continue}break}}function NZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;if(th(715827882)>>>0<b>>>0){dd();p()}vZ(c+8|0,b);b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;d=zb(a),e=b+D(x[c+12>>2],6)|0,x[d>>2]=e;fb=c+16|0}function BL(a){var b=0,c=0,d=0;d=x[a>>2];while(1){c=v[d|0];if(Oh(c)){d=d+1|0;x[a>>2]=d;if(b>>>0<=214748364){c=c-48|0;b=D(b,10);b=(c|0)>(b^2147483647)?-1:c+b|0}else{b=-1}continue}break}return b}function vaa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=fb-16|0;fb=e;f=x[d+4>>2];g=x[d>>2];x[e+8>>2]=g;x[e+12>>2]=f;d=x[x[b>>2]+40>>2];x[e>>2]=g;x[e+4>>2]=f;ib[d|0](a,b,c,e);fb=e+16|0}function ika(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;e=z[a+28>>1];w[d+12>>1]=e;f=d,g=(oc(x[a+4>>2],x[a+8>>2])+e|0)-1|0,w[f+14>>1]=g;a=eR(a,b,c,d+12|0);fb=d+16|0;return a|0}function ZI(a){a=a|0;var b=0,c=0,d=0;x[a>>2]=112024;d=a+8|0;while(1){b=x[a+8>>2];if(oc(b,x[a+12>>2])>>>0>c>>>0){b=x[yb(b,c)>>2];if(b){Am(b)}c=c+1|0;continue}break}tb(a+152|0);dy(d);return a|0}function NA(a,b){var c=0;a=AW(a,b);v[a+12|0]=y[b+12|0];c=y[b+13|0]|y[b+14|0]<<8|(y[b+15|0]<<16|y[b+16|0]<<24);v[a+13|0]=c;v[a+14|0]=c>>>8;v[a+15|0]=c>>>16;v[a+16|0]=c>>>24;v[a+17|0]=y[b+17|0]}function lk(a,b){var c=0,d=0;c=fb-16|0;fb=c;x[c+12>>2]=b;d=b;b=th(2147483647);if(d>>>0<=b>>>0){a=Nn(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[ad(c+8|0,c+12|0)>>2]}fb=c+16|0;return b}dd();p()}function lc(a,b,c,d,e){var f=0;f=fb-32|0;fb=f;lf(f+16|0,d,e);d=x[x[b>>2]+28>>2];e=x[f+20>>2];x[f+8>>2]=x[f+16>>2];x[f+12>>2]=e;ib[d|0](f+24|0,b,c,f+8|0);lf(a,x[f+24>>2],x[f+28>>2]);fb=f+32|0}function Mf(a,b){var c=0,d=0;c=fb-16|0;fb=c;x[c+12>>2]=b;d=b;b=th(1073741823);if(d>>>0<=b>>>0){a=Ug(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[ad(c+8|0,c+12|0)>>2]}fb=c+16|0;return b}dd();p()}function Lj(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;a:{d=Xl(a,b);if((d|0)==255){break a}Dk(a,b);Tq(a,b,0,0);if(!c){break a}e=_b(a+26|0,d),f=65535,w[e>>1]=f;a=xb(a+62|0,b);v[a|0]=y[a|0]|128}}function qG(a,b){var c=0,d=0;c=fb-16|0;fb=c;x[c+12>>2]=b;d=b;b=th(119304647);if(d>>>0<=b>>>0){a=cx(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[ad(c+8|0,c+12|0)>>2]}fb=c+16|0;return b}dd();p()}function oD(a,b){var c=0,d=0;c=fb-16|0;fb=c;x[c+12>>2]=b;d=b;b=th(715827882);if(d>>>0<=b>>>0){a=cw(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[ad(c+8|0,c+12|0)>>2]}fb=c+16|0;return b}dd();p()}function ns(a,b){var c=0,d=0;c=fb-16|0;fb=c;x[c+12>>2]=b;d=b;b=th(536870911);if(d>>>0<=b>>>0){a=Xn(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[ad(c+8|0,c+12|0)>>2]}fb=c+16|0;return b}dd();p()}function hN(){var a=0,b=0,c=0,d=0;a=fb-16|0;fb=a;b=Ec(1298480);x[31737]=0;c=R(1133,b|0)|0;d=x[31737];x[31737]=0;if((d|0)!=1){b=yf(a+12|0,c);fb=a+16|0;return x[b>>2]}a=N()|0;Db(b);Q(a|0);p()}function _q(a,b){var c=0,d=0;c=fb-16|0;fb=c;x[c+12>>2]=b;d=b;b=th(134217727);if(d>>>0<=b>>>0){a=ap(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[ad(c+8|0,c+12|0)>>2]}fb=c+16|0;return b}dd();p()}function ZV(a,b){var c=0,d=0;c=fb-16|0;fb=c;x[c+12>>2]=b;d=b;b=th(268435455);if(d>>>0<=b>>>0){a=hv(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[ad(c+8|0,c+12|0)>>2]}fb=c+16|0;return b}dd();p()}function YJ(a,b){var c=0,d=0;c=fb-16|0;fb=c;x[c+12>>2]=b;d=b;b=th(178956970);if(d>>>0<=b>>>0){a=at(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[ad(c+8|0,c+12|0)>>2]}fb=c+16|0;return b}dd();p()}function Wp(a,b){var c=0,d=0;c=fb-16|0;fb=c;x[c+12>>2]=b;d=b;b=th(357913941);if(d>>>0<=b>>>0){a=jl(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[ad(c+8|0,c+12|0)>>2]}fb=c+16|0;return b}dd();p()}function RD(a,b){var c=0,d=0;c=fb-16|0;fb=c;x[c+12>>2]=b;d=b;b=th(214748364);if(d>>>0<=b>>>0){a=TE(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[ad(c+8|0,c+12|0)>>2]}fb=c+16|0;return b}dd();p()}function FD(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;d=c,e=(sq(b)+-4.8737671609324025)*(a&32768?28.85390081777927:34.624680981335125),C[d+8>>3]=e;OT(c+8|0,127);a=fm(C[c+8>>3]);fb=c+16|0;return a}function zE(a,b){var c=0,d=0;c=fb-16|0;fb=c;ek(c+8|0,b);b=x[c+12>>2];lc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function z$(a,b){var c=0,d=0;c=fb-16|0;fb=c;hw(c+8|0,b);b=x[c+12>>2];lc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function yu(a){var b=0;x[31737]=0;a=R(856,a|0)|0;b=x[31737];x[31737]=0;a:{if((b|0)==1){Y(T(0)|0)|0;x[31737]=0;X(26);b=x[31737];x[31737]=0;a=0;if((b|0)==1){break a}}return a}T(0)|0;Sb();p()}function yE(a,b){var c=0,d=0;c=fb-16|0;fb=c;Pr(c+8|0,b);b=x[c+12>>2];lc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function t$(a,b){var c=0,d=0;c=fb-16|0;fb=c;iw(c+8|0,b);b=x[c+12>>2];lc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function sA(a,b){var c=0,d=0;d=fb-32|0;fb=d;c=zb(a);c=$f(d+12|0,Mf(a,oc(x[a>>2],x[a+4>>2])+1|0),oc(x[a>>2],x[a+4>>2]),c);Co(x[c+8>>2],x[b>>2]);x[c+8>>2]=x[c+8>>2]+4;Ym(a,c);_f(c);fb=d+32|0}function s$(a,b){var c=0,d=0;c=fb-16|0;fb=c;Fr(c+8|0,b);b=x[c+12>>2];lc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function qZ(a,b){var c=0,d=0;c=fb-16|0;fb=c;pZ(c+8|0,b);b=x[c+12>>2];lc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function nR(a,b){var c=0,d=0;c=fb-16|0;fb=c;x[c+12>>2]=b;d=b;b=th(82595524);if(d>>>0<=b>>>0){a=Bu(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[ad(c+8|0,c+12|0)>>2]}fb=c+16|0;return b}dd();p()}function lF(a){var b=0;b=x[a+72>>2];x[a+72>>2]=b-1|b;b=x[a>>2];if(b&8){x[a>>2]=b|32;return-1}x[a+4>>2]=0;x[a+8>>2]=0;b=x[a+44>>2];x[a+28>>2]=b;x[a+20>>2]=b;x[a+16>>2]=b+x[a+48>>2];return 0}function jG(a,b){var c=0,d=0;c=fb-16|0;fb=c;NG(c+8|0,b);b=x[c+12>>2];lc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function iX(a){var b=0,c=0,d=0;c=y[a+32|0]|y[a+33|0]<<8;b=y[a+36|0]|y[a+37|0]<<8;a=y[a+34|0]|y[a+35|0]<<8;b=b+a|0;a=(a>>>0>b>>>0|d)<<1|b>>>31;b=b<<1;c=b+c|0;hb=b>>>0>c>>>0?a+1|0:a;return c}function gx(a,b){var c=0,d=0;c=fb-16|0;fb=c;ex(c+8|0,b);b=x[c+12>>2];lc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function gY(a,b){var c=0,d=0;c=fb-16|0;fb=c;Cv(c+8|0,b);b=x[c+12>>2];lc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function fh(a,b){var c=0,d=0;c=fb-16|0;fb=c;Zr(c+8|0,b);b=x[c+12>>2];lc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function aG(a,b){var c=0,d=0;c=fb-16|0;fb=c;fs(c+8|0,b);b=x[c+12>>2];lc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function Sn(a,b){var c=0,d=0;c=fb-16|0;fb=c;nh(c+8|0,b);b=x[c+12>>2];lc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function S0(a,b){var c=0,d=0;c=fb-16|0;fb=c;R0(c+8|0,b);b=x[c+12>>2];lc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function OK(a,b,c,d){a:{if(!a){break a}b:{switch(b+2|0){case 0:v[a|0]=c;return;case 1:w[a>>1]=c;return;case 2:case 3:x[a>>2]=c;return;case 5:break b;default:break a}}x[a>>2]=c;x[a+4>>2]=d}}function O$(a,b){var c=0,d=0;c=fb-16|0;fb=c;bE(c+8|0,b);b=x[c+12>>2];lc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function NX(a,b){var c=0,d=0;c=fb-16|0;fb=c;aD(c+8|0,b);b=x[c+12>>2];lc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function NC(a,b){var c=0,d=0;c=fb-16|0;fb=c;TC(c+8|0,b);b=x[c+12>>2];lc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function KB(a,b,c,d){var e=0,f=0,g=0;e=c-b|0;a:{if((e|0)<=9){g=e;e=D(32-G(d|1)|0,1233)>>>12|0;f=61;if((g|0)<(e+(A[(e<<2)+123824>>2]<=d>>>0)|0)){break a}}c=GB(b,d);f=0}x[a+4>>2]=f;x[a>>2]=c}function JV(a){var b=0,c=0,d=0;c=y[a+64|0]|y[a+65|0]<<8;b=y[a+72|0]|y[a+73|0]<<8;a=y[a+70|0]|y[a+71|0]<<8;b=b+a|0;a=(a>>>0>b>>>0|d)<<2|b>>>30;b=b<<2;c=b+c|0;hb=b>>>0>c>>>0?a+1|0:a;return c}function Ip(a,b){var c=0,d=0;c=fb-16|0;fb=c;Hp(c+8|0,b);b=x[c+12>>2];lc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function Dx(a,b,c){var d=0;d=fb-16|0;fb=d;bc(d+8|0,b,c);b=x[d+12>>2];lc(d,x[a>>2],x[a+8>>2],x[d+8>>2],x[d+12>>2]);c=x[d+4>>2];if((b|0)==(c|0)){Vb(a,x[d+12>>2])}fb=d+16|0;return(b|0)==(c|0)}function yz(a,b,c,d,e,f,g,h,i){var j=0;j=fb-16|0;fb=j;Sg(j,b,c,d,e,f,g,h,i^-2147483648);d=x[j>>2];c=x[j+4>>2];b=x[j+12>>2];x[a+8>>2]=x[j+8>>2];x[a+12>>2]=b;x[a>>2]=d;x[a+4>>2]=c;fb=j+16|0}function lM(a,b){var c=0,d=0;d=fb-32|0;fb=d;c=zb(a);c=un(d+12|0,bm(a,Vc(x[a>>2],x[a+4>>2])+1|0),Vc(x[a>>2],x[a+4>>2]),c);Dl(x[c+8>>2],y[b|0]);x[c+8>>2]=x[c+8>>2]+1;gr(a,c);tn(c);fb=d+32|0}function bV(a){a=a|0;var b=0,c=0;b=fb-32|0;fb=b;v[a+16|0]=0;c=$B(b,x[a+12>>2]);x[31737]=0;O(785,a|0,c|0);a=x[31737];x[31737]=0;if((a|0)!=1){Ek(c);fb=b+32|0;return}a=N()|0;Ek(c);Q(a|0);p()}function Vf(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb+-64|0;fb=c;d=pA(c+12|0,a);x[31737]=0;S(200,a|0,b|0,d|0);a=x[31737];x[31737]=0;if((a|0)!=1){Bk(d);fb=c- -64|0;return}a=N()|0;Bk(d);Q(a|0);p()}function CV(a){var b=0,c=0;a:{b:{c=a&240;if((c|0)!=192){if((c|0)==240){break b}b=3;if((c|0)!=208){break a}}b=2;break a}a=a+15&255;b=1;if(a>>>0>2){break a}b=131842>>>(a<<3)|0}return b&255}function ni(a,b){var c=0,d=0;c=y[a|0];d=y[b|0];a:{if(!c|(d|0)!=(c|0)){break a}while(1){d=y[b+1|0];c=y[a+1|0];if(!c){break a}b=b+1|0;a=a+1|0;if((c|0)==(d|0)){continue}break}}return c-d|0}function fga(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=fb-16|0;fb=f;x[f+8>>2]=x[a+8>>2];g=x[a+4>>2];x[f>>2]=x[a>>2];x[f+4>>2]=g;a=yP(f,b,c,d,0,0,0,0,e);fb=f+16|0;return a|0}function R8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=x[a+84>>2];d=c+256|0;f=Kz(e,0,d);d=f?f-e|0:d;c=c>>>0>d>>>0?d:c;yc(b,e,c);b=e+d|0;x[a+84>>2]=b;x[a+8>>2]=b;x[a+4>>2]=c+e;return c|0}function Qe(a,b){var c=0,d=0;c=fb-16|0;fb=c;x[c+8>>2]=x[b+8>>2];d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;b=x[c+4>>2];x[a>>2]=x[c>>2];x[a+4>>2]=b;x[a+8>>2]=x[c+8>>2];v[a+12|0]=0;fb=c+16|0}function Lk(a,b){var c=0,d=0;c=fb-32|0;fb=c;x[c+28>>2]=0;Ux(c+8|0,c+28|0);d=c+20|0;Sm(d,a,x[c+8>>2],x[c+12>>2]);a=x[c+24>>2];Qm(d,x[c+28>>2]);x[b>>2]=x[c+20>>2];fb=c+32|0;return(a|0)==4}function GZ(a,b,c,d){var e=0;e=fb-16|0;fb=e;x[e+12>>2]=b;x[e+8>>2]=d;c=_G(a,c,x[Gb(e+12|0,e+8|0)>>2]);a:{if(c){break a}c=0;if((b|0)==(d|0)){break a}c=b>>>0<d>>>0?-1:1}fb=e+16|0;return c}function F_(a,b,c,d){var e=0;e=fb-16|0;fb=e;x[e+12>>2]=b;x[e+8>>2]=d;c=ty(a,c,x[Gb(e+12|0,e+8|0)>>2]);a:{if(c){break a}c=0;if((b|0)==(d|0)){break a}c=b>>>0<d>>>0?-1:1}fb=e+16|0;return c}function xo(a){var b=0,c=0;b=fb-16|0;fb=b;a:{if(!ZM(y[a+20|0])){x[31737]=0;O(1140,b+15|0,a|0);c=x[31737];x[31737]=0;if((c|0)==1){break a}}v[a+20|0]=255;fb=b+16|0;return}T(0)|0;Sb();p()}function iba(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;d=x[18399];x[c+8>>2]=x[18398];x[c+12>>2]=d;d=x[18397];x[c>>2]=x[18396];x[c+4>>2]=d;ib[x[tq(c,yk(y[b+20|0]))>>2]](a,b);fb=c+16|0}function X7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=fb-16|0;fb=g;x[g+8>>2]=624576549;x[g+12>>2]=1394948685;h=a;a=g+16|0;b=wk(h,b,c,d,e,f,g+8|0,a);fb=a;return b|0}function Dk(a,b){var c=0,d=0,e=0;a:{c=Xl(a,b);if((c|0)==255){break a}if(Mj(x[a>>2])){break a}e=a+8|0;d=xb(e,c);v[d|0]=y[d|0]&223;d=bv(c);c=xb(e,c);yh(x[a>>2],x[a+4>>2],b,d|176,y[c|0])}}function hsa(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;d=Mb(x[a>>2],x[a+8>>2],12);a:{if(!d){v[c|0]=0;Vh(b,12,c);break a}Fr(c+8|0,b);rd(c,a,x[c+8>>2],x[c+12>>2])}fb=c+16|0;return d|0}function bH(a,b){var c=0,d=0;d=fb-32|0;fb=d;c=zb(a);c=Dm(d+12|0,Wp(a,Ud(x[a>>2],x[a+4>>2])+1|0),Ud(x[a>>2],x[a+4>>2]),c);As(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+12;vx(a,c);zs(c);fb=d+32|0}function Wt(a){var b=0,c=0,d=0;c=1;while(1){if(c){c=0;b=x[a+4>>2];d=((b<<2)+(Ow(x[a>>2],1)^270549120)|0)+2019860093|0;x[a>>2]=d;b=b+D(Ow(d,16),5)|0;x[a+4>>2]=b;continue}break}return b}function yp(a,b,c){var d=0,e=0;d=fb-16|0;fb=d;a=_h(d+4|0,a,b);b=x[a+4>>2];e=x[a+8>>2];while(1){if((b|0)==(e|0)){hc(a);fb=d+16|0}else{fj(b,z[c>>1]);b=b+2|0;x[a+4>>2]=b;continue}break}}function nA(a,b,c){var d=0,e=0;d=fb-16|0;fb=d;a=Tg(d+4|0,a,b);b=x[a+4>>2];e=x[a+8>>2];while(1){if((b|0)==(e|0)){hc(a);fb=d+16|0}else{zk(b,B[c>>2]);b=b+4|0;x[a+4>>2]=b;continue}break}}function bm(a,b){var c=0,d=0;c=fb-16|0;fb=c;x[c+12>>2]=b;d=b;b=th(-1);if(d>>>0<=b>>>0){a=dp(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[ad(c+8|0,c+12|0)>>2]}fb=c+16|0;return b}dd();p()}function XE(a,b,c){var d=0,e=0;d=fb-16|0;fb=d;a=Tg(d+4|0,a,b);b=x[a+4>>2];e=x[a+8>>2];while(1){if((b|0)==(e|0)){hc(a);fb=d+16|0}else{Co(b,x[c>>2]);b=b+4|0;x[a+4>>2]=b;continue}break}}function Wh(a,b){var c=0;b=Tc(b);c=x[a+8>>2];if(oc(c,x[a+12>>2])>>>0>b>>>0){a=x[yb(c,b)>>2]!=0}else{a=0}if(!a){a=Kj(ac(4));x[a>>2]=125504;da(a|0,125640,1187);p()}return x[yb(c,b)>>2]}function Rl(a){var b=0;a=ri(a);b=2147483647;a:{if(a>=E(2147483648)){break a}b=-2147483648;if(a<=E(-2147483648)){break a}b=~~a;if(E(F(a))<E(2147483648)){break a}b=-2147483648}return b}function Q7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=a;h=b;a=ib[x[x[a+8>>2]+20>>2]](a+8|0)|0;b=Jb(a);return vk(g,h,c,d,e,f,b,b+(Cb(x[a+4>>2],y[a+11|0])<<2)|0)|0}function OP(a){var b=0,c=0;if(!a){return 1}if((a|0)>=-99999){b=+(a|0)*3.321928094887362/2e3;c=b+.5;a:{if(F(c)<2147483648){a=~~c;break a}a=-2147483648}b=Di(b-+(a|0))}else{b=0}return b}function msa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;mZ(b,c);c=Mb(x[a>>2],x[a+8>>2],c<<2);if(c){lZ(d+8|0,x[b>>2],x[b+4>>2]);rd(d,a,x[d+8>>2],x[d+12>>2])}fb=d+16|0;return c|0}function moa(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;d=Mb(x[a>>2],x[a+8>>2],4);a:{if(!d){v[c|0]=0;u$(b,4,c);break a}nh(c+8|0,b);rd(c,a,x[c+8>>2],x[c+12>>2])}fb=c+16|0;return d|0}function Pm(a,b){x[a+28>>2]=0;w[a+24>>1]=65535;x[a+16>>2]=0;x[a+20>>2]=0;x[a+4>>2]=0;x[a+8>>2]=0;v[a|0]=0;x[a+32>>2]=11;x[a+36>>2]=b;Nb(a+40|0);Nb(a+52|0);Rb(a- -64|0,0,48);return a}function LP(a,b,c,d,e){a=a|0;b=b|0;c=+c;d=d|0;e=e|0;var f=0,g=0;f=fb-16|0;fb=f;x[f+8>>2]=x[a+8>>2];g=x[a+4>>2];x[f>>2]=x[a>>2];x[f+4>>2]=g;c=KP(f,b,c,d,e,0,0,0,0);fb=f+16|0;return+c}function Fp(a,b,c){var d=0,e=0;d=fb-16|0;fb=d;a=$l(d+4|0,a,b);b=x[a+4>>2];e=x[a+8>>2];while(1){if((b|0)==(e|0)){hc(a);fb=d+16|0}else{Dl(b,y[c|0]);b=b+1|0;x[a+4>>2]=b;continue}break}}function $r(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;if((b|0)<0){dd();p()}LF(c+8|0,(b-1>>>5|0)+1|0);b=x[c+8>>2];x[a+4>>2]=0;x[a>>2]=b;d=zb(a),e=x[c+12>>2],x[d>>2]=e;fb=c+16|0}function r2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;x[d+12>>2]=c;c=0;a=ib[x[x[a>>2]+24>>2]](a)|0;if(a>>>0>b>>>0){x[d+8>>2]=a-b;c=x[Gb(d+12|0,d+8|0)>>2]}fb=d+16|0;return c|0}function Xt(a){var b=0,c=0,d=0;b=fb-16|0;fb=b;x[b+12>>2]=12;while(1){x[b+8>>2]=32;if(A[Gb(b+12|0,b+8|0)>>2]<=c>>>0){fb=b+16|0;a=d&4095}else{c=c+15|0;d=Ho(a);continue}break}return a}function MB(a){var b=0,c=0;b=x[a>>2];c=x[b>>2];a:{if(!c){while(1){c=Uh(b);b=x[b+8>>2];if(c){continue}break}break a}while(1){b=c;c=x[b+4>>2];if(c){continue}break}}x[a>>2]=b;return a}function Eu(a,b){var c=0;a=IS(a);x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];x[a+8>>2]=x[b+8>>2];x[a+12>>2]=x[b+12>>2];x[a+16>>2]=x[b+16>>2];c=x[b+28>>2];x[a+24>>2]=x[b+24>>2];x[a+28>>2]=c}function C2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;wG(b,c);c=Mb(x[a>>2],x[a+8>>2],c<<3);if(c){vG(d+8|0,x[b>>2],x[b+4>>2]);rd(d,a,x[d+8>>2],x[d+12>>2])}fb=d+16|0;return c|0}function $k(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;if(th(-1)>>>0<b>>>0){dd();p()}sg(c+8|0,b);b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;d=zb(a),e=b+x[c+12>>2]|0,x[d>>2]=e;fb=c+16|0}function poa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;zW(b,c);if(Mb(x[a>>2],x[a+8>>2],c<<8)){c=x[b>>2];bc(d+8|0,c,Th(c,x[b+4>>2])<<8);rd(d,a,x[d+8>>2],x[d+12>>2])}fb=d+16|0}function ET(a,b,c,d){a:{if((a|0)!=67108864){break a}a=D(d,872)+c|0;x[a+704>>2]=x[a+704>>2]&-129;a=d^1;if(a>>>0>=(b&65535)>>>0){break a}a=D(a,872)+c|0;x[a+704>>2]=x[a+704>>2]&-129}}function B2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;d=!b|(b>>>0>d>>>0|a>>>0>=d>>>0|d-a>>>0<b>>>0);a:{if(d){break a}a=a+b|0;if(Vc(x[c>>2],x[c+4>>2])>>>0>=a>>>0){break a}Nk(c,a)}return!d|0}function f6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;while(1){if((b|0)!=(c|0)){a=x[b>>2];if(a>>>0<=127){a=x[(a<<2)+112160>>2]}else{a=0}x[d>>2]=a;d=d+4|0;b=b+4|0;continue}break}return c|0}function Xz(a){var b=0,c=0,d=0;C[a+4272>>3]=C[a+4280>>3];c=a;d=a+4296|0;a=0;while(1){if(a>>>0<32){a=a+15|0;b=Ho(d)|b<<15;continue}break}C[c+4280>>3]=+(b|0)*-4.656612873077393e-10}function UR(a){var b=0,c=0,d=0;b=fb-16|0;fb=b;while(1){x[b+12>>2]=7;x[b+8>>2]=32;if(A[Gb(b+12|0,b+8|0)>>2]<=c>>>0){fb=b+16|0;a=d&127}else{c=c+15|0;d=Ho(a);continue}break}return a}function Ov(a,b){var c=0;c=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);v[a|0]=c;v[a+1|0]=c>>>8;v[a+2|0]=c>>>16;v[a+3|0]=c>>>24;b=y[b+4|0]|y[b+5|0]<<8;v[a+4|0]=b;v[a+5|0]=b>>>8}function Koa(a,b){a=a|0;b=b|0;var c=0,d=0;b=fb-16|0;fb=b;d=b+8|0;c=-1;a:{if(!nk(a,d)){break a}c=0;if(!BW(d)){break a}c=-1;if(!kh(a,4)){break a}c=aX(a)>>>31|0}fb=b+16|0;return c|0}function Jh(a,b,c){a:{if(b>>>0<=c>>>0){a=ac(8);x[31737]=0;b=R(189,a|0)|0;c=x[31737];x[31737]=0;if((c|0)!=1){break a}b=N()|0;jc(a);Q(b|0);p()}return y[a+c|0]}da(b|0,24488,163);p()}function dU(a,b,c,d){var e=0,f=0;e=fb-16|0;fb=e;while(1){if(c){f=Vl(z[c+16>>1],x[c+20>>2],a,b);d=f?d:c;c=x[(f?c+4|0:c)>>2];continue}break}a=vb(e+12|0,d);fb=e+16|0;return x[a>>2]}function _ra(a,b){a=a|0;b=b|0;var c=0;c=fb-32|0;fb=c;x[c+24>>2]=0;x[c+28>>2]=0;x[c+16>>2]=0;x[c+20>>2]=0;x[c+8>>2]=0;x[c+12>>2]=0;x[c>>2]=0;x[c+4>>2]=0;PZ(b,c);OZ(a,c);fb=c+32|0}function _l(a,b){var c=0,d=0,e=0;x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];c=zb(b);d=zb(a),e=x[c>>2],x[d>>2]=e;x[c>>2]=0;x[b>>2]=0;x[b+4>>2]=0;return a}function W7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=a;h=b;a=ib[x[x[a+8>>2]+20>>2]](a+8|0)|0;b=Jb(a);return wk(g,h,c,d,e,f,b,Cb(x[a+4>>2],y[a+11|0])+b|0)|0}function Jga(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=0,f=E(0);if(b>>>0<=12){c=Pd(c,E(0));d=a+4208|0;if((b|0)==12){c=E(ri(E(c*E(3)))/E(3));b=12}e=yb(d,b),f=c,B[e>>2]=f;v[a+5046|0]=1}}function Ej(a){var b=0,c=0;b=x[a+20>>2];b=um(y[b+28|0]|y[b+29|0]<<8|(y[b+30|0]<<16|y[b+31|0]<<24));if(!(b>>>0>249|y[a+4200|0]>=b>>>0)){c=x[vd(x[a+16>>2]+906300|0,b)>>2]}return c}function tD(a,b,c){var d=0,e=0;d=fb-16|0;fb=d;a=Ir(d+4|0,a,b);b=x[a+4>>2];e=x[a+8>>2];while(1){if((b|0)==(e|0)){hc(a);fb=d+16|0}else{Ov(b,c);b=b+6|0;x[a+4>>2]=b;continue}break}}function s3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=fb-16|0;fb=e;a=x[a+4>>2];f=x[b+4>>2];b=x[b>>2];x[e>>2]=b;x[e+4>>2]=f;x[e+8>>2]=b;x[e+12>>2]=f;Nz(a,e,c,d,1);fb=e+16|0}function jp(a){var b=0,c=0;b=x[31492];c=a+7&-8;a=b+c|0;a:{if(a>>>0<=b>>>0?c:0){break a}if(a>>>0>jb()<<16>>>0){if(!(eb(a|0)|0)){break a}}x[31492]=a;return b}x[31612]=48;return-1}function _ia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=fb-16|0;fb=e;f=x[c>>2];if(f>>>0<Vc(a,b)>>>0){a=yl(e+4|0,xb(a,f),z[c+20>>1]);g=Gy(d,a);Eb(a)}fb=e+16|0;return g|0}function Aaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;x[d+12>>2]=c;nz(a,b,c);c=0;a=x[a+16>>2];if(a>>>0>b>>>0){x[d+8>>2]=a-b;c=x[Gb(d+8|0,d+12|0)>>2]}fb=d+16|0;return c|0}function zq(a){var b=0;b=x[a+24>>2];x[31737]=0;W(857,b|0);b=x[31737];x[31737]=0;if((b|0)!=1){Td(a+68|0);nf(a+36|0);Hl(a+32|0);vh(a+24|0);uh(a+4|0);return Uc(a)}T(0)|0;Sb();p()}function uta(a,b){a=a|0;b=b|0;if(!s$(a,b)){v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b+6|0]=0;v[b+7|0]=0;v[b+8|0]=0;v[b+9|0]=0;v[b+10|0]=0;v[b+11|0]=0}}function tY(a){var b=0,c=0,d=0;b=x[a>>2];if(x[b>>2]){d=x[b>>2];c=x[b+4>>2];while(1){if((c|0)!=(d|0)){c=c-24|0;ub(c);continue}break}x[b+4>>2]=d;a=x[a>>2];b=x[a>>2];at(a);Db(b)}}function t3(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;a=x[a+4>>2];d=x[b>>2];b=x[b+4>>2];x[c>>2]=d;x[c+4>>2]=b;x[c+8>>2]=d;x[c+12>>2]=b;a=sP(a,c,1);fb=c+16|0;gb=hb;return a|0}function lN(a){var b=0,c=0,d=0;b=x[a>>2];if(x[b>>2]){d=x[b>>2];c=x[b+4>>2];while(1){if((c|0)!=(d|0)){c=c-16|0;Wj(c);continue}break}x[b+4>>2]=d;a=x[a>>2];b=x[a>>2];hv(a);Db(b)}}function VH(a){var b=0,c=0,d=0;b=x[a>>2];if(x[b>>2]){d=x[b>>2];c=x[b+4>>2];while(1){if((c|0)!=(d|0)){c=c-12|0;Eb(c);continue}break}x[b+4>>2]=d;a=x[a>>2];b=x[a>>2];jl(a);Db(b)}}function yja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;x[d+12>>2]=b;while(1){if(Ib(b,c)){x[d+8>>2]=x[b>>2];MA(a,d+8|0);b=x[Je(d+12|0)>>2];continue}else{fb=d+16|0}break}}function KN(a,b,c){var d=0;d=fb-32|0;fb=d;x[d+28>>2]=c;x[d+24>>2]=0;x[d+12>>2]=4;c=d+16|0;pz(c,a,d+24|0,x[Gb(d+28|0,d+12|0)>>2]);Qm(c,x[d+24>>2]);x[b>>2]=x[d+16>>2];fb=d+32|0}function pc(a,b){a=a|0;b=b|0;var c=0;a=Kj(a);x[a+4>>2]=0;x[a>>2]=47680;c=Ed(Yc(x[b+4>>2],y[b+11|0])+1|0);x[a+4>>2]=c;if(c){yc(c,Jb(b),Yc(x[b+4>>2],y[b+11|0])+1|0)}return a|0}function F4(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;while(1){if((b|0)!=(c|0)){f=Tx(x[b>>2],x[a+8>>2]);v[e|0]=(f|0)==-1?d:f;e=e+1|0;b=b+4|0;continue}break}return c|0}function xca(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;a=x[a+4>>2];d=x[b+4>>2];b=x[b>>2];x[c>>2]=b;x[c+4>>2]=d;x[c+8>>2]=b;x[c+12>>2]=d;e=tP(a,c,1);fb=c+16|0;return+e}function uw(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;Nk(b,c);if(Mb(x[a>>2],x[a+8>>2],c)){c=x[b>>2];bc(d+8|0,c,Vc(c,x[b+4>>2]));rd(d,a,x[d+8>>2],x[d+12>>2])}fb=d+16|0}function oY(a,b){var c=0,d=0;c=fb-16|0;fb=c;Cv(c+8|0,b);b=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){gd(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function jD(a,b){var c=0,d=0;c=fb-16|0;fb=c;a=Tg(c+4|0,a,b);b=x[a+4>>2];d=x[a+8>>2];while(1){if((b|0)==(d|0)){hc(a);fb=c+16|0}else{Hn(b);b=b+4|0;x[a+4>>2]=b;continue}break}}function cY(a,b){var c=0,d=0;c=fb-16|0;fb=c;a=$l(c+4|0,a,b);b=x[a+4>>2];d=x[a+8>>2];while(1){if((b|0)==(d|0)){hc(a);fb=c+16|0}else{JX(b);b=b+1|0;x[a+4>>2]=b;continue}break}}function Zq(a,b){var c=0,d=0;c=fb-16|0;fb=c;a=Tg(c+4|0,a,b);b=x[a+4>>2];d=x[a+8>>2];while(1){if((b|0)==(d|0)){hc(a);fb=c+16|0}else{HV(b);b=b+4|0;x[a+4>>2]=b;continue}break}}function QE(a,b){var c=0,d=0;c=fb-16|0;fb=c;a=_h(c+4|0,a,b);b=x[a+4>>2];d=x[a+8>>2];while(1){if((b|0)==(d|0)){hc(a);fb=c+16|0}else{Vw(b);b=b+2|0;x[a+4>>2]=b;continue}break}}function Og(a,b,c,d){var e=0;a=((b|0)/8|0)+a|0;e=Jh(x[d>>2],x[d+4>>2],a);return((Jh(x[d>>2],x[d+4>>2],a+1|0)<<8|e<<16|Jh(x[d>>2],x[d+4>>2],a+2|0))<<(b&7)&16777215)>>>24-c|0}function Fz(a,b){var c=0,d=0;if(b>>>0<2147483632){if(Rk(b)){x[a>>2]=0;x[a+4>>2]=0;x[a+8>>2]=0;Me(a,b);return a}c=Dh(b)+1|0;d=Ec(c);of(a,c);yd(a,d);Yd(a,b);return a}pf();p()}function $E(a,b){var c=0,d=0;c=fb-16|0;fb=c;nh(c+8|0,b);b=x[c+12>>2];od(c,a,x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){gd(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function mi(a,b){a=a|0;b=b|0;var c=0;c=fb-32|0;fb=c;v[c+31|0]=0;Cj(c+8|0,c+31|0);Sm(c+20|0,a,x[c+8>>2],x[c+12>>2]);a=x[c+24>>2];v[b|0]=y[c+31|0];fb=c+32|0;return(a|0)==1|0}function d6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a:{while(1){if((c|0)==(d|0)){break a}a=x[c>>2];if(!(a>>>0>127|!(x[(a<<2)+112160>>2]&b))){c=c+4|0;continue}break}d=c}return d|0}function ZG(a){var b=0;a:{b:{if(a>>>0>=18285141){if(a>>>0>18350591){break b}b=1;if((a|0)!=18350080){break a}}return 0}b=0;if((a|0)==18350592){break a}b=(a&255)!=0}return b}function V_(a){var b=0;a:{if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=-28163770){break a}if(kd(a+44|0,18475,3)){break a}b=(y[a+47|0]|y[a+48|0]<<8)>>>0>97}return b}function $3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;ib[x[x[a>>2]+12>>2]](d+8|0,a,b);a=x[d+8>>2];b=x[c>>2];c=mc(x[d+12>>2],x[c+4>>2]);fb=d+16|0;return(a|0)==(b|0)&c}function sF(a,b,c){var d=0;d=fb-16|0;fb=d;a=Gp(d+4|0,a+8|0,b);b=x[a>>2];while(1){if((b|0)!=x[a+4>>2]){fj(b,z[c>>1]);b=x[a>>2]+2|0;x[a>>2]=b;continue}break}he(a);fb=d+16|0}function qf(a,b,c){var d=0,e=0,f=0;d=fb-16|0;fb=d;x[d+8>>2]=c;x[d+4>>2]=31;e=d,f=m0(b,c),x[e+12>>2]=f;c=b;b=sE(d+4|0);Wg(c,c+b|0,a);e=xb(a,b),f=0,v[e|0]=f;o0(a);fb=d+16|0}function iH(a,b){var c=0,d=0,e=0;c=x[a>>2];if(x[c>>2]){e=x[c>>2];d=x[c+4>>2];while(1){if((d|0)!=(e|0)){d=d-b|0;continue}break}x[c+4>>2]=e;a=x[a>>2];b=x[a>>2];zb(a);Db(b)}}function Yca(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;a=x[a+4>>2];d=x[b+4>>2];b=x[b>>2];x[c>>2]=b;x[c+4>>2]=d;x[c+8>>2]=b;x[c+12>>2]=d;a=uP(a,c,1);fb=c+16|0;return a|0}function Wta(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;dl(c+8|0,b);b=x[c+12>>2];lc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);if((b|0)==x[c+4>>2]){Vb(a,x[c+12>>2])}fb=c+16|0}function Aka(){var a=0,b=0,c=0;a=fb-16|0;fb=a;b=Ec(1);x[31737]=0;X(58);c=x[31737];x[31737]=0;if((c|0)!=1){b=yf(a+12|0,b);fb=a+16|0;return x[b>>2]}a=N()|0;Db(b);Q(a|0);p()}function sZ(a,b,c){var d=0;d=fb-16|0;fb=d;a=yC(d+4|0,a+8|0,b);b=x[a>>2];while(1){if((b|0)!=x[a+4>>2]){Dl(b,y[c|0]);b=x[a>>2]+1|0;x[a>>2]=b;continue}break}he(a);fb=d+16|0}function s2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=ib[x[x[a>>2]+24>>2]](a)|0;a:{if(!c){d=1;if((a|0)==(b|0)){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function pg(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-32|0;fb=c;w[c+30>>1]=0;rk(c+8|0,c+30|0);d=c+20|0;Sm(d,a,x[c+8>>2],x[c+12>>2]);hj(d,z[c+30>>1]);w[b>>1]=z[c+20>>1];fb=c+32|0}function mW(a){var b=0,c=0,d=0;b=x[a>>2];if(x[b>>2]){d=x[b>>2];c=x[b+4>>2];while(1){if((c|0)!=(d|0)){c=c-36|0;continue}break}x[b+4>>2]=d;a=x[a>>2];b=x[a>>2];cx(a);Db(b)}}function e6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;while(1){a:{if((c|0)!=(d|0)){a=x[c>>2];if(a>>>0>127|!(x[(a<<2)+112160>>2]&b)){break a}}else{c=d}return c|0}c=c+4|0;continue}}function Psa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;a:{if(a){ib[x[x[a>>2]+8>>2]](a,b,c);break a}if((b|0)>=6){break a}pS(d,9169,10907,172,42);OG(d,b,c)}fb=d+16|0}function Ix(a,b,c,d,e){var f=0;a:{f=yu(4332);if(f){x[31737]=0;ha(e|0,f|0,a|0,b|0,c|0,d|0)|0;a=x[31737];x[31737]=0;if((a|0)==1){break a}}return f}a=N()|0;Db(f);Q(a|0);p()}function wT(a,b,c){var d=0;d=c&15;if(d){v[b+824|0]=d}c=c&240;if(c){v[b+823|0]=c>>>4}x[b+88>>2]=x[b+88>>2]|131072;if(!(!d|!Ob(a+1074312|0,80))){v[b+824|0]=y[b+824|0]<<2}}function oT(a,b){a=a|0;b=b|0;var c=0,d=0;c=Mc(a);d=Cb(x[a+4>>2],y[a+11|0]);if((c|0)==(d|0)){ZB(a,c,1,c,c,0)}c=Jb(a);hm(c+d|0,1,b);b=d+1|0;ng(a,b);fd(b+c|0,0);return a|0}function Mm(a){a=a<<24|(a&65280)<<8|(a>>>8&65280|a>>>24);a=a>>>4&252645135|(a&252645135)<<4;a=a>>>2&858993459|(a&858993459)<<2;return a>>>1&1431655765|(a&1431655765)<<1}function MA(a,b){a=a|0;b=b|0;var c=0;if(A[a+4>>2]<A[zb(a)>>2]){c=fb-16|0;fb=c;a=Tg(c+4|0,a,1);Co(x[a+4>>2],x[b>>2]);x[a+4>>2]=x[a+4>>2]+4;hc(a);fb=c+16|0;return}sA(a,b)}function IV(a,b,c,d){a=gc(a,b,c);b=x[a+4>>2];a:{if((d|0)>=0){b=b+d|0;c=x[a>>2]+(b>>>3&536870908)|0;break a}b=b+d|0;c=x[a>>2]+((b-31|0)/32<<2)|0}x[a>>2]=c;x[a+4>>2]=b&31}function Dka(a,b){a=a|0;b=b|0;var c=0;a=qg(a);c=_i(x[b>>2]);b=Rf(b);x[31737]=0;S(851,a|0,c|0,b|0);b=x[31737];x[31737]=0;if((b|0)!=1){return a|0}b=N()|0;gT(a);Q(b|0);p()}function y5(a,b,c){a=a|0;b=b|0;c=c|0;a=uJ(a,c);x[a>>2]=113484;b=Jb(b);x[31737]=0;O(1326,a|0,b|0);b=x[31737];x[31737]=0;if((b|0)!=1){return a|0}b=N()|0;$x(a);Q(b|0);p()}function w5(a,b,c){a=a|0;b=b|0;c=c|0;a=tJ(a,c);x[a>>2]=113524;b=Jb(b);x[31737]=0;O(1327,a|0,b|0);b=x[31737];x[31737]=0;if((b|0)!=1){return a|0}b=N()|0;ay(a);Q(b|0);p()}function qka(){var a=0,b=0,c=0;a=fb-16|0;fb=a;b=Dc(a+4|0,10281);x[31737]=0;W(62,b|0);c=x[31737];x[31737]=0;if((c|0)!=1){tb(b);fb=a+16|0;return}a=N()|0;tb(b);Q(a|0);p()}function nr(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;d=Mb(x[a>>2],x[a+8>>2],4);a:{if(!d){lD(b);break a}nh(c+8|0,b);rd(c,a,x[c+8>>2],x[c+12>>2])}fb=c+16|0;return d|0}function dM(a){var b=0,c=0;a:{if(y[a|0]!=255){break a}b=y[a+1|0];if(!(b&6)|(b&240)!=240&(b&254)!=226){break a}a=y[a+2|0];if((a&240)==240){break a}c=(a&12)!=12}return c}function Av(a){var b=0,c=0,d=0,e=0;while(1){a:{if((b|0)==32){e=c;break a}d=y[a+b|0];if((d-1&255)>>>0<31|((c^1)&1?0:d)){break a}b=b+1|0;c=!d|c;continue}break}return e&1}function Ada(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-16|0;fb=d;a=x[a+4>>2];e=x[b+4>>2];b=x[b>>2];x[d>>2]=b;x[d+4>>2]=e;x[d+8>>2]=b;x[d+12>>2]=e;Pz(a,d,c,1);fb=d+16|0}function $ca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-16|0;fb=d;b=x[b+4>>2];e=x[c+4>>2];c=x[c>>2];x[d>>2]=c;x[d+4>>2]=e;x[d+8>>2]=c;x[d+12>>2]=e;rP(a,b,d,1);fb=d+16|0}function vda(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0;d=fb-16|0;fb=d;a=x[a+4>>2];e=x[b+4>>2];b=x[b>>2];x[d>>2]=b;x[d+4>>2]=e;x[d+8>>2]=b;x[d+12>>2]=e;Oz(a,d,c,1);fb=d+16|0}function kd(a,b,c){var d=0,e=0,f=0;a:{if(!c){break a}while(1){d=y[a|0];e=y[b|0];if((d|0)==(e|0)){b=b+1|0;a=a+1|0;c=c-1|0;if(c){continue}break a}break}f=d-e|0}return f}function eI(a,b,c){var d=0;a:{if(!a){a=ac(8);x[31737]=0;c=R(c|0,a|0)|0;d=x[31737];x[31737]=0;if((d|0)!=1){break a}b=N()|0;jc(a);Q(b|0);p()}return}da(c|0,b|0,1006);p()}function Xoa(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-48|0;fb=c;d=-1;a:{if(!ZW(a,c)){break a}d=0;if(!YW(c)){break a}d=ve(a,b,XW(y[c+31|0],y[c+33|0]),hb)}fb=c+48|0;return d|0}function WM(a,b){var c=0,d=0;c=fb-16|0;fb=c;a=$l(c+4|0,a,b);b=x[a+4>>2];d=x[a+8>>2];while(1){if((b|0)==(d|0)){hc(a);fb=c+16|0}else{b=b+1|0;x[a+4>>2]=b;continue}break}}function Upa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;wG(b,c);if(Mb(x[a>>2],x[a+8>>2],c<<3)){vG(d+8|0,x[b>>2],x[b+4>>2]);rd(d,a,x[d+8>>2],x[d+12>>2])}fb=d+16|0}function f2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;x[d+12>>2]=c;c=0;a=x[a+16>>2];if(a>>>0>b>>>0){x[d+8>>2]=a-b;c=x[Gb(d+12|0,d+8|0)>>2]}fb=d+16|0;return c|0}function eD(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;mZ(b,c);if(Mb(x[a>>2],x[a+8>>2],c<<2)){lZ(d+8|0,x[b>>2],x[b+4>>2]);rd(d,a,x[d+8>>2],x[d+12>>2])}fb=d+16|0}function bi(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=is(b);d=Mc(a);if(c>>>0<=d>>>0){_u(a,Ui(Jb(a),b,c),c);break a}e=a;a=Cb(x[a+4>>2],y[a+11|0]);Yq(e,d,c-d|0,a,0,a,c,b)}}function Vda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Cb(x[b+4>>2],y[b+11|0]);e=a;a=Cb(x[c+4>>2],y[c+11|0]);b=Xg(Jb(Fz(e,d+a|0)),Jb(b),d)+d|0;hm(Xg(b,Jb(c),a)+a|0,1,0)}function Baa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;nz(a,b,c);a=x[a+16>>2];a:{if(!c){d=1;if((a|0)==(b|0)){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function $W(a,b){var c=0;c=fb-32|0;fb=c;MX(c+24|0,a);ee(c+16|0,b);a=x[c+20>>2];x[c+8>>2]=x[c+16>>2];x[c+12>>2]=a;a=Ic(x[c+24>>2],x[c+28>>2],c+8|0);fb=c+32|0;return a}function xV(a){var b=0,c=0;a:{if(y[a|0]!=255){break a}b=y[a+1|0];if(!(b&6)|(b&224)!=224|(b&24)==8){break a}a=y[a+2|0];if((a&12)==12){break a}c=(a&240)!=240}return c}function t2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;x[d+12>>2]=c;c=0;a=x[a+8>>2];if(a>>>0>b>>>0){x[d+8>>2]=a-b;c=x[Gb(d+12|0,d+8|0)>>2]}fb=d+16|0;return c|0}function gV(a,b,c,d){var e=0;e=fb-32|0;fb=e;Id(e+24|0,b,c);wn(e+16|0,x[e+24>>2],x[e+28>>2],d);b=fV(b,x[e+16>>2]-b>>1);x[e+12>>2]=x[e+20>>2];Ac(a,b,e+12|0);fb=e+32|0}function _X(a){if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))==1297239878){a=(y[a+8|0]|y[a+9|0]<<8|(y[a+10|0]<<16|y[a+11|0]<<24))==1279545165}else{a=0}return a}function Usa(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{if(!Mb(x[b>>2],x[b+8>>2],12)){w[c>>1]=0;d_(a,6,c);break a}Fr(c+8|0,a);rd(c,b,x[c+8>>2],x[c+12>>2])}fb=c+16|0}function Q9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-16|0;fb=e;a=Yy(Pa(x[a+60>>2],b|0,c|0,d&255,e+8|0)|0);fb=e+16|0;hb=a?-1:x[e+12>>2];return(a?-1:x[e+8>>2])|0}function FZ(a,b,c){var d=0,e=0,f=0;d=fb-16|0;fb=d;b=ec(b);a=Bh(a,Ec(32),Mg(d+8|0,b));b=x[a>>2]+16|0;w[b>>1]=z[x[c>>2]>>1];Fb(b+4|0);e=ec(a),f=1,v[e+4|0]=f;fb=d+16|0}function CX(a){if(!((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=541938512|(y[a+8|0]|y[a+9|0]<<8|(y[a+10|0]<<16|y[a+11|0]<<24))!=1162627398)){return 1}return 0}function oL(a,b){var c=0,d=0,e=0,f=0;c=x[a+24>>2];if((c|0)==x[a+28>>2]){return e=a,f=Pf(b),d=x[x[a>>2]+52>>2],ib[d](e|0,f|0)|0}x[a+24>>2]=c+1;v[c|0]=b;return Pf(b)}function PT(a,b){a=a|0;b=b|0;var c=0;if(A[a+4>>2]<A[zb(a)>>2]){c=fb-16|0;fb=c;a=rv(c+4|0,a,1);As(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+12;hc(a);fb=c+16|0;return}bH(a,b)}function Ld(a,b){var c=0;c=fb-32|0;fb=c;ee(c+24|0,a);a=qc(c+16|0,b);b=x[a+4>>2];x[c+8>>2]=x[a>>2];x[c+12>>2]=b;a=Ic(x[c+24>>2],x[c+28>>2],c+8|0);fb=c+32|0;return a}function II(a,b,c){var d=0,e=0;d=zn(a);if(d>>>0>=c>>>0){e=b;b=c<<2;d=ml(Jb(a),e,b);ng(a,c);yd(b+d|0,0);return}e=a;a=Cb(x[a+4>>2],y[a+11|0]);xI(e,d,c-d|0,a,0,a,c,b)}function Fpa(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{if(!Mb(x[b>>2],x[b+8>>2],8)){w[c>>1]=0;d_(a,4,c);break a}dl(c+8|0,a);rd(c,b,x[c+8>>2],x[c+12>>2])}fb=c+16|0}function xpa(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{if(!Mb(x[b>>2],x[b+8>>2],5)){v[c|0]=0;Vh(a,5,c);break a}ek(c+8|0,a);rd(c,b,x[c+8>>2],x[c+12>>2])}fb=c+16|0}function jX(a){var b=0;if(!((y[a+44|0]|y[a+45|0]<<8|(y[a+46|0]<<16|y[a+47|0]<<24))!=1297236819|y[a+29|0]!=16)){b=((y[a+42|0]|y[a+43|0]<<8)-1&65535)>>>0<2}return b}function eW(a){x[a>>2]=0;x[a+4>>2]=0;x[a+88>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;nC(a+112|0,48e3);x[a+668>>2]=0;mC(a+724|0);mC(a+732|0);mC(a+740|0);bh(a+788|0);return a}function Pd(a,b){var c=0,d=0,e=0,f=E(0);c=fb-16|0;fb=c;x[c+8>>2]=1065353216;B[c+12>>2]=b;e=c,f=cg(a),B[e+4>>2]=f;d=Lv(c+4|0,c+12|0,c+8|0);fb=c+16|0;return B[d>>2]}function wM(a,b){var c=0,d=0;c=Vc(x[a+4>>2],x[a+8>>2]);b=x[a+16>>2]+b|0;if(c>>>0<b>>>0){d=a+4|0;a:{if(c){a=qi(c);if(b>>>0<=a>>>0){break a}}a=xM(b,65536)}Nk(d,a)}}function sm(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{if(!Mb(x[b>>2],x[b+8>>2],4)){v[c|0]=0;Vh(a,4,c);break a}nh(c+8|0,a);rd(c,b,x[c+8>>2],x[c+12>>2])}fb=c+16|0}function sE(a){var b=0,c=0;a:{c=yb(a,3);if((c|0)==(a|0)){break a}b=a;while(1){b=b+4|0;if((c|0)==(b|0)){break a}a=qE(x[b>>2],x[a>>2])?b:a;continue}}return x[a>>2]}function hka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;d=c,e=th(b),x[d+12>>2]=e;x[c+8>>2]=0;d=a,e=x[dk(c+12|0,c+8|0,42336)>>2],x[d+36>>2]=e;Cq(a);fb=c+16|0}function h3(a,b){a=a|0;b=b|0;var c=0;if(A[a+4>>2]<A[zb(a)>>2]){c=fb-16|0;fb=c;a=wx(c+4|0,a);As(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+12;hc(a);fb=c+16|0;return}bH(a,b)}function g9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-16|0;fb=e;x[e>>2]=c;x[e+4>>2]=d;x[e+8>>2]=c;x[e+12>>2]=d;a=cL(a,e,b);x[a>>2]=94564;fb=e+16|0;return a|0}function __(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{if(!Mb(x[b>>2],x[b+8>>2],6)){v[c|0]=0;Vh(a,6,c);break a}TD(c+8|0,a);rd(c,b,x[c+8>>2],x[c+12>>2])}fb=c+16|0}function Xq(a){x[a+8>>2]=0;x[a+12>>2]=0;x[a>>2]=128;x[a+4>>2]=256;x[a+32>>2]=363;x[a+36>>2]=952;x[a+16>>2]=48e3;x[a+20>>2]=2;x[a+24>>2]=128;x[a+28>>2]=0;return a}function Ppa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-80|0;fb=d;e=d+14|0;c=-1;a:{if(!X$(a,e)){break a}c=0;if(!TX(e)){break a}c=ve(a,b,SX(e),hb)}fb=d+80|0;return c|0}function Hda(a,b){a=a|0;b=b|0;var c=0;a=ac(8);x[31737]=0;b=P(1057,a|0,12113)|0;c=x[31737];x[31737]=0;if((c|0)!=1){da(b|0,125408,163);p()}b=N()|0;jc(a);Q(b|0);p()}function H4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;while(1){if((b|0)!=(c|0)){e=d,f=JI(v[b|0],x[a+8>>2]),x[e>>2]=f;d=d+4|0;b=b+1|0;continue}break}return c|0}function G3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;x[d+12>>2]=x[c>>2];a=ib[x[x[a>>2]+16>>2]](a,b,d+12|0)|0;if(a){x[c>>2]=x[d+12>>2]}fb=d+16|0;return a|0}function Ec(a){a=a|0;var b=0;a=a>>>0<=1?1:a;a:{while(1){b=Ed(a);if(b){break a}b=x[125561];if(b){ib[b|0]();continue}break}da(An(ac(4))|0,125048,34);p()}return b|0}function wia(a){a=a|0;var b=0;b=fb-16|0;fb=b;HQ(b+8|0,a,0);if(x[b+12>>2]){a=x[a+20>>2];x[a+148>>2]=-1;GQ(a+4|0,wb(x[b+8>>2]),Wk(x[b+8>>2],x[b+12>>2]))}fb=b+16|0}function rS(a){var b=0,c=0,d=0;b=x[a+112>>2];if((b|0)>=11){b=378;while(1){if(b|c){qS(a);d=b;b=b-1|0;c=c-!d|0;continue}break}b=0}x[a+112>>2]=b+1;a=qS(a);return a}function jA(a,b){var c=0;c=fb-16|0;fb=c;a=Ln(c+4|0,a+8|0,b);b=x[a>>2];while(1){if((b|0)!=x[a+4>>2]){HV(b);b=x[a>>2]+4|0;x[a>>2]=b;continue}break}he(a);fb=c+16|0}function KE(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;x[c+12>>2]=-1;if(fh(a,c+11|0)){x[c+4>>2]=y[c+11|0];d=Q0(a,b,x[Gb(c+4|0,c+12|0)>>2])}fb=c+16|0;return d|0}function ID(a){var b=0,c=0;b=fb-16|0;fb=b;w[b+14>>1]=a;Gf(b+14|0,4095);a=z[b+14>>1];c=HD(Di(+((a&255)>>>0)*.00390625)*32768);fb=b+16|0;return c>>>15-(a>>>8|0)|0}function $0(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;x[c+12>>2]=-1;if(fh(a,c+11|0)){x[c+4>>2]=y[c+11|0];d=T0(a,b,x[Gb(c+4|0,c+12|0)>>2])}fb=c+16|0;return d|0}function zla(a,b){a=a|0;b=b|0;a=sc(a);v[a+534|0]=0;x[a+4>>2]=0;x[31737]=0;O(791,a|0,b|0);b=x[31737];x[31737]=0;if((b|0)!=1){return a|0}b=N()|0;Nl(a);Q(b|0);p()}function ml(a,b,c){var d=0;if(a>>>0<b>>>0){return yc(a,b,c)}if(c){d=a+c|0;b=b+c|0;while(1){d=d-1|0;b=b-1|0;v[d|0]=y[b|0];c=c-1|0;if(c){continue}break}}return a}function Ot(a){var b=0;a:{if((gf(a)|0)!=79){break a}if((gf(a)|0)!=103){break a}if((gf(a)|0)!=103){break a}b=(gf(a)|0)==83}if(!b){fc(a,30);return 0}return XL(a)}function KS(a,b){var c=0;c=fb-32|0;fb=c;a=we(c+8|0,a,b);a=Du(c+16|0,x[a>>2],x[a+4>>2]);a=we(c+24|0,x[a>>2],x[a+4>>2]);b=x[a>>2];fb=c+32|0;hb=x[a+4>>2];return b}function Iw(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{if(!Mb(x[b>>2],x[b+8>>2],2)){v[c|0]=0;tF(a,c);break a}Hp(c+8|0,a);rd(c,b,x[c+8>>2],x[c+12>>2])}fb=c+16|0}function BW(a){if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))==1299020115){a=($b(y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24))|0)==1}else{a=0}return a}function $H(a,b,c){var d=E(0);a:{if((b|0)<0|z[a+480188>>1]<=b>>>0){break a}a=D(b,872)+a|0;if(!(v[a+1075081|0]&1)){break a}d=E(E(y[a+c|0])*E(.0078125))}return d}function iN(a,b){var c=0;c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;c=x[b+20>>2];x[a+16>>2]=x[b+16>>2];x[a+20>>2]=c;c=x[b+12>>2];x[a+8>>2]=x[b+8>>2];x[a+12>>2]=c}function hG(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=Nb(a+8|0);x[31737]=0;S(170,a|0,b|0,c|0);a=x[31737];x[31737]=0;if((a|0)!=1){break a}a=N()|0;dc(d);Q(a|0);p()}}function Cn(a){var b=0;b=2147483647;a:{if(a>=2147483647){break a}b=-2147483648;if(a<=-2147483648){break a}if(F(a)<2147483648){return~~a}b=-2147483648}return b}function xS(){var a=0,b=0,c=0,d=0;a=fb-16|0;fb=a;b=a+12|0;while(1){if(c>>>0<32){c=c+48|0;d=TA(126992);continue}break}x[b>>2]=d;Ho(b);fb=a+16|0;return x[b>>2]}function x6(a){a=a|0;if(y[500576]){return x[125143]}if(!y[501736]){v[501736]=1}wd(501712,121060);wd(501724,121072);v[500576]=1;x[125143]=501712;return 501712}function qC(a){var b=0;a=Ee(a);b=32767;a:{if(a>=32767){break a}b=32768;if(a<=-32768){break a}b=~~a;if(F(a)<2147483648){break a}b=-2147483648}return b<<16>>16}function aja(a){a=a|0;var b=0;b=fb-16|0;fb=b;Pc(b+4|0,a+32|0,4);if(!Hb(x[x[b+4>>2]>>2],x[b+8>>2])){oy(a)}a=vb(b+12|0,wb(x[a+52>>2]));fb=b+16|0;return x[a>>2]}function a9(a,b){a=a|0;b=b|0;var c=0,d=0;b=GD(x[b>>2]);x[a+36>>2]=b;c=a,d=Kh(b),x[c+44>>2]=d;c=a,d=jo(x[a+36>>2]),v[c+53|0]=d;if(x[a+44>>2]>=9){io(5563);p()}}function VP(a){a=a|0;var b=0;x[a+4240>>2]=0;x[a+4244>>2]=0;b=a+4264|0;x[b>>2]=0;x[b+4>>2]=0;b=a+4256|0;x[b>>2]=0;x[b+4>>2]=0;a=a+4248|0;x[a>>2]=0;x[a+4>>2]=0}function V8(a,b){a=a|0;b=b|0;var c=0,d=0;b=Ky(x[b>>2]);x[a+36>>2]=b;c=a,d=Kh(b),x[c+44>>2]=d;c=a,d=jo(x[a+36>>2]),v[c+53|0]=d;if(x[a+44>>2]>=9){io(5563);p()}}function KC(a,b,c){var d=0;d=fb-16|0;fb=d;x[d+12>>2]=a;c=c&65535;while(1){if(!(!Ib(a,b)|(c|0)==z[a>>1])){a=x[Md(d+12|0)>>2];continue}break}fb=d+16|0;return a}function K8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=0;while(1){if((b|0)!=(c|0)){a=x[b>>2]+(a<<4)|0;d=a&-268435456;a=(d|d>>>24)^a;b=b+4|0;continue}break}return a|0}function $ia(a){a=a|0;var b=0;b=fb-16|0;fb=b;Pc(b+4|0,a+32|0,4);if(!Hb(x[x[b+4>>2]>>2],x[b+8>>2])){oy(a)}a=vb(b+12|0,wb(x[a+56>>2]));fb=b+16|0;return x[a>>2]}function sr(a){var b=0,c=0,d=0,e=0;c=x[a+4>>2];b=x[c>>2];x[a+4>>2]=b;if(b){Dn(b,a)}b=x[a+8>>2];x[c+8>>2]=b;d=b+(Uh(a)?0:4)|0,e=c,x[d>>2]=e;x[c>>2]=a;Dn(a,c)}function qr(a){var b=0,c=0,d=0,e=0;c=x[a>>2];b=x[c+4>>2];x[a>>2]=b;if(b){Dn(b,a)}b=x[a+8>>2];x[c+8>>2]=b;d=b+(Uh(a)?0:4)|0,e=c,x[d>>2]=e;x[c+4>>2]=a;Dn(a,c)}function jR(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;while(1){if((b|0)==(c|0)){fb=d+16|0}else{x[d+12>>2]=x[b>>2];MA(a,d+12|0);b=b+4|0;continue}break}}function foa(a,b){a=a|0;b=b|0;var c=0,d=0;d=fb-48|0;fb=d;c=-1;a:{if(!ZW(a,d)){break a}c=0;if(!QV(d)){break a}c=ve(a,b,PV(y[d+47|0]),hb)}fb=d+48|0;return c|0}function aI(a,b,c){var d=E(0);a:{if((b|0)<0|z[a+480188>>1]<=b>>>0){break a}a=D(b,872)+a|0;if(v[a+1075081|0]&1){break a}d=E(E(y[a+c|0])*E(.0078125))}return d}function Vb(a,b){a=a|0;b=b|0;var c=0;c=Mb(x[a>>2],x[a+8>>2],b);a:{if(c){b=x[a+8>>2]+b|0;break a}b=x[a>>2];b=ib[x[x[b>>2]+24>>2]](b)|0}x[a+8>>2]=b;return c|0}function Se(a,b){var c=0;c=x[a>>2];x[a>>2]=b;a:{if(c){a=x[ec(a)>>2];x[31737]=0;W(a|0,c|0);a=x[31737];x[31737]=0;if((a|0)==1){break a}}return}T(0)|0;Sb();p()}function N8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=0;while(1){if((b|0)!=(c|0)){a=v[b|0]+(a<<4)|0;d=a&-268435456;a=(d|d>>>24)^a;b=b+1|0;continue}break}return a|0}function q6(a){a=a|0;if(y[500568]){return x[125141]}if(!y[501704]){v[501704]=1}id(501680,13958);id(501692,13937);v[500568]=1;x[125141]=501680;return 501680}function Mla(a,b){a=a|0;b=b|0;a=Nb(a);v[a+16|0]=0;x[a+12>>2]=b;x[31737]=0;W(784,a|0);b=x[31737];x[31737]=0;if((b|0)!=1){return a|0}b=N()|0;_B(a);Q(b|0);p()}function Hu(a,b){var c=0,d=0,e=E(0);c=fb-16|0;fb=c;B[c+12>>2]=b;x[c+8>>2]=0;x[c+4>>2]=1065353216;d=a,e=B[Lv(c+12|0,c+8|0,c+4|0)>>2],B[d+144>>2]=e;fb=c+16|0}function s0(a,b,c){var d=0;b=b-a>>2;while(1){if((b|0)>0){d=x[c>>2];v[a|0]=d;v[a+1|0]=d>>>8;v[a+2|0]=d>>>16;v[a+3|0]=d>>>24;b=b-1|0;a=a+4|0;continue}break}}function nj(a,b,c,d,e){a:{e=yu(e);if(e){x[31737]=0;ba(d|0,e|0,a|0,b|0,c|0)|0;a=x[31737];x[31737]=0;if((a|0)==1){break a}}return e}a=N()|0;Db(e);Q(a|0);p()}function ir(a,b){var c=0,d=0;a:{if(!a){break a}c=Sua(a,0,b,0);d=hb;if((a|b)>>>0<65536){break a}c=d?-1:c}a=Ed(c);if(!(!a|!(y[a-4|0]&3))){Rb(a,0,c)}return a}function hz(a,b){var c=0;while(1){c=(b|0)>=120?120:b;a=E(a*E(B[((c&3)<<2)+82288>>2]*E(1073741824>>>(c>>2)|0)));b=b-c|0;if((b|0)>0){continue}break}return a}function g2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=x[a+16>>2];a:{if(!c){d=1;if((a|0)==(b|0)){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function b_(a,b){var c=0;c=Sua(b&65535,0,384,0);b=a&65535;a=b>>>30|0;b=b<<2;c=c+b|0;a=a+hb|0;a=b>>>0>c>>>0?a+1|0:a;b=c+256|0;hb=b>>>0<256?a+1|0:a;return b}function Fj(a,b,c,d){var e=0;e=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=e;e=x[b+12>>2];x[a+8>>2]=x[b+8>>2];x[a+12>>2]=e;C[a>>3]=C[a>>3]-c;C[a+8>>3]=C[a+8>>3]-d}function Fi(a){var b=0,c=0;b=a*a;c=b*a;return E(c*(b*b)*(b*2718311493989822e-21+-.00019839334836096632)+(c*(b*.008333329385889463+-.16666666641626524)+a))}function zga(a){a=a|0;var b=0,c=E(0);v[a+4202|0]=1;b=a,c=zB(E(E(E(E(A[x[a+16>>2]+24620>>2])/E(3))+E(-80))/E(15920)),E(0),E(1)),B[b+4272>>2]=c;XP(a);VP(a)}function u2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=x[a+8>>2];a:{if(!c){d=1;if((a|0)==(b|0)){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function b3(a,b,c){a=a|0;b=b|0;c=c|0;a=Ds(a,x[b+28>>2]);cH(b+28|0,c);x[31737]=0;O(114,b|0,1);b=x[31737];x[31737]=0;if((b|0)==1){b=N()|0;Zb(a);Q(b|0);p()}}function FY(a,b,c,d){var e=0;e=fb-32|0;fb=e;Id(e+24|0,b,c);wn(e+16|0,x[e+24>>2],x[e+28>>2],d);b=x[e+16>>2];x[e+12>>2]=x[e+20>>2];Ac(a,b,e+12|0);fb=e+32|0}function ro(a,b){var c=0,d=0;b=b+7&-8;d=x[a+80>>2];a:{if(d){b=x[a+92>>2]-b|0;c=0;if((b|0)<x[a+88>>2]){break a}x[a+92>>2]=b;return b+d|0}c=Ed(b)}return c}function ah(a){var b=0,c=0;b=x[a>>2];c=x[b+4>>2];a:{if(!c){while(1){if(!Uh(b)){b=x[b+8>>2];continue}break}b=x[b+8>>2];break a}b=h_(c)}x[a>>2]=b;return a}function GX(a){var b=0;if(!((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=441273424|y[a+5|0]!=16|(y[a+54|0]-33&255)>>>0<224)){b=y[a+4|0]>95}return b}function X5(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;while(1){if((b|0)!=(c|0)){a=x[b>>2];v[e|0]=a>>>0<128?a:d;e=e+1|0;b=b+4|0;continue}break}return c|0}function Voa(a,b){a=a|0;b=b|0;var c=0,d=0;d=fb+-64|0;fb=d;c=-1;a:{if(!r$(a,d)){break a}c=0;if(!TW(d)){break a}c=ve(a,b,SW(d),hb)}fb=d- -64|0;return c|0}function Fn(a,b){var c=0,d=0,e=0;_v(a);x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];c=zb(b);d=zb(a),e=x[c>>2],x[d>>2]=e;x[c>>2]=0;x[b>>2]=0;x[b+4>>2]=0;return a}function AW(a,b){var c=0,d=0,e=0;tr(a);x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];c=zb(b);d=zb(a),e=x[c>>2],x[d>>2]=e;x[c>>2]=0;x[b>>2]=0;x[b+4>>2]=0;return a}function so(a,b){x[a+20>>2]=0;x[a+24>>2]=b;x[a+12>>2]=0;x[a+4>>2]=4098;x[a+8>>2]=6;x[a+16>>2]=!b;Rb(a+32|0,0,40);uL(a+28|0);x[a+72>>2]=0;x[a+76>>2]=-1}function eX(a,b,c,d){var e=0;e=c&4;a:{if((b&255)!=4){b=e?16:8;break a}b=16;if(e){break a}b=8;if(c&2){break a}Xc(a,8,1,0,10);return}Xc(a,b,c&2|1,0,d^1)}function cd(a,b){a=a|0;b=b|0;var c=0,d=0;a:{if(A[a+8>>2]<b>>>0){d=x[a>>2];c=0;if(!(ib[x[x[d>>2]+32>>2]](d,0,b)|0)){break a}}x[a+8>>2]=b;c=1}return c|0}function Lta(a,b){a=a|0;b=b|0;var c=0,d=0;d=fb+-64|0;fb=d;c=-1;a:{if(!r$(a,d)){break a}c=0;if(!q$(d)){break a}c=ve(a,b,p$(d),0)}fb=d- -64|0;return c|0}function KO(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;h=fb-32|0;fb=h;i=h+8|0;iM(i,b,c,d,e,f,g);_c(a,h+20|0);en(i);fb=h+32|0}function CZ(a,b,c){var d=0;d=fb-32|0;fb=d;x[d+28>>2]=c;v[d+27|0]=0;x[d+12>>2]=1;pz(d+16|0,a,d+27|0,x[Gb(d+28|0,d+12|0)>>2]);v[b|0]=y[d+27|0];fb=d+32|0}function yT(a,b,c){var d=0,e=0;x[b+56>>2]=0;d=b,e=Ko(a,z[b+70>>1],x[b+48>>2],c,0),w[d+68>>1]=e;if(!(!(y[a+480180|0]&5)|x[b+60>>2]==-1)){x[b+60>>2]=0}}function vu(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=fb-16|0;fb=e;d=Tg(e+4|0,a,d);f=d,g=sR(zb(a),b,c,x[d+4>>2]),x[f+4>>2]=g;hc(d);fb=e+16|0}function o$(a,b){var c=0;c=fb-16|0;fb=c;a:{if(!Mb(x[b>>2],x[b+8>>2],8)){v[c|0]=0;Vh(a,8,c);break a}dl(c+8|0,a);rd(c,b,x[c+8>>2],x[c+12>>2])}fb=c+16|0}function ax(a,b){var c=0;c=fb-16|0;fb=c;a:{if(!Mb(x[b>>2],x[b+8>>2],3)){v[c|0]=0;Vh(a,3,c);break a}$w(c+8|0,a);rd(c,b,x[c+8>>2],x[c+12>>2])}fb=c+16|0}function Iq(a,b,c){var d=0;a:{if(b&67109888){break a}if(!Ij(c)){break a}b=y[c+34|0];if((b+5&255)>>>0<6){break a}d=x[vd(a+906300|0,b-1|0)>>2]}return d}function CJ(a){x[a>>2]=0;x[a+4>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;w[a+20>>1]=0;x[a+16>>2]=-1;x[a+8>>2]=0;x[a+12>>2]=0;x[a>>2]=0}function ut(a){if(a>>>0<=254){a=(a+1&127)>>>0>32}else{a=(a&65534)!=65534&a-65532>>>0<1048580|(a-57344>>>0<8185|a>>>0<8232|a-8234>>>0<47062)}return a}function oh(a,b){var c=0;if(Cd(y[a+11|0])){c=x[a>>2];ej(x[a+8>>2]);Db(c)}c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;x[a+8>>2]=x[b+8>>2];Me(b,0);yd(b,0)}function cpa(a,b){a=a|0;b=b|0;var c=0,d=0;d=fb-96|0;fb=d;c=-1;a:{if(!HX(a,d)){break a}c=0;if(!jX(d)){break a}c=ve(a,b,iX(d),hb)}fb=d+96|0;return c|0}function aR(a){var b=0,c=0;b=fb-16|0;fb=b;B[b+12>>2]=F(a);x[b+8>>2]=646978941;x[b+4>>2]=1259902592;c=Lv(b+12|0,b+8|0,b+4|0);fb=b+16|0;return B[c>>2]}function YG(){var a=0,b=0,c=0;b=fb-16|0;fb=b;a=Dc(b+4|0,14832);if(Yc(x[a+4>>2],y[a+11|0])){c=(Rg(a,13959)|0)!=-1}else{c=0}tb(a);fb=b+16|0;return c|0}function X9(a,b,c){a=a|0;b=b|0;c=c|0;a:{a=lg(a,b);x[31737]=0;P(71,a+12|0,c|0)|0;b=x[31737];x[31737]=0;if((b|0)!=1){break a}b=N()|0;tb(a);Q(b|0);p()}}function Ww(a,b,c,d,e){var f=0;while(1){if((d|0)!=(f|0)){B[b>>2]=E(x[a>>2])*e;B[c>>2]=E(x[a+4>>2])*e;f=f+1|0;c=c+4|0;a=a+8|0;b=b+4|0;continue}break}}function P5(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;while(1){if((b|0)!=(c|0)){a=v[b|0];v[e|0]=(a|0)<0?d:a;e=e+1|0;b=b+1|0;continue}break}return c|0}function JI(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=Nh(c+12|0,b);b=a&255;if(b>>>0>=128){b=(a|0)==-1?-1:x[x[124243]>>2]?-1:a&57343}Mh(d);fb=c+16|0;return b}function Bpa(a,b){a=a|0;b=b|0;var c=0,d=0;d=fb-96|0;fb=d;c=-1;a:{if(!HX(a,d)){break a}c=0;if(!GX(d)){break a}c=ve(a,b,FX(d),hb)}fb=d+96|0;return c|0}function zs(a){var b=0,c=0;c=x[a+4>>2];while(1){b=x[a+8>>2];if((b|0)!=(c|0)){b=b-12|0;x[a+8>>2]=b;Eb(b);continue}break}c=x[a>>2];if(c){ys(a);Db(c)}}function wX(a){var b=0,c=0;c=x[a+4>>2];while(1){b=x[a+8>>2];if((b|0)!=(c|0)){b=b-56|0;x[a+8>>2]=b;er(b);continue}break}c=x[a>>2];if(c){nc(a);Db(c)}}function lR(a){var b=0,c=0;c=x[a+4>>2];while(1){b=x[a+8>>2];if((b|0)!=(c|0)){b=b-52|0;x[a+8>>2]=b;Bk(b);continue}break}c=x[a>>2];if(c){nc(a);Db(c)}}function dx(a){var b=0,c=0;c=x[a+4>>2];while(1){b=x[a+8>>2];if((b|0)!=(c|0)){b=b-36|0;x[a+8>>2]=b;Mp(b);continue}break}c=x[a>>2];if(c){nc(a);Db(c)}}function c0(a){var b=0,c=0;c=x[a+4>>2];while(1){b=x[a+8>>2];if((b|0)!=(c|0)){b=b-28|0;x[a+8>>2]=b;Fd(b);continue}break}c=x[a>>2];if(c){nc(a);Db(c)}}function Yv(a){var b=0,c=0;c=x[a+4>>2];while(1){b=x[a+8>>2];if((b|0)!=(c|0)){b=b-20|0;x[a+8>>2]=b;ub(b);continue}break}c=x[a>>2];if(c){nc(a);Db(c)}}function XB(a){var b=0,c=0;c=x[a+4>>2];while(1){b=x[a+8>>2];if((b|0)!=(c|0)){b=b-32|0;x[a+8>>2]=b;Ek(b);continue}break}c=x[a>>2];if(c){ys(a);Db(c)}}function Vq(a,b,c){a:{if(!Ob(c+1074312|0,102)){break a}c=z[a+692>>1]+1|0;w[a+784>>1]=c;if(!(v[a+89|0]&1)){break a}w[a+784>>1]=c|32768}x[a+692>>2]=b}function Q3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;if(mh(a,x[b+8>>2],f)){Px(b,c,d,e);return}a=x[a+8>>2];ib[x[x[a>>2]+20>>2]](a,b,c,d,e,f)}function OA(a){if(y[a+480224|0]==2){return+A[a+1074420>>2]/1e4}return+A[a+24620>>2]/(+A[a+1074404>>2]*+(D(x[a+1074408>>2],x[a+1074416>>2])>>>0))*60}function HK(a,b,c){var d=0,e=0,f=0,g=0;d=OC(b);if(d>>>0<c>>>0){IK(a,b,d+1|0);return d}if(c){e=a;a=c-1|0;f=IK(e,b,a)+(a<<2)|0,g=0,x[f>>2]=g}return d}function GS(a,b){var c=0,d=0;c=fb-16|0;fb=c;b=we(c+8|0,Sua(b,b>>31,500654080,20),hb);d=x[b>>2];b=x[b+4>>2];fb=c+16|0;x[a>>2]=d;x[a+4>>2]=b;return a}function w$(a){v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0}function oI(a){var b=0,c=0;c=a>>>23&255;b=0;a:{if(c>>>0<127){break a}b=2;if(c>>>0>150){break a}c=1<<150-c;b=0;if(c-1&a){break a}b=a&c?1:2}return b}function lja(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-32|0;fb=c;w[c+30>>1]=b;b=c+30|0;Hp(c+20|0,b);d=x[c+20>>2];Hp(c+12|0,b);yl(a,d,x[c+16>>2]);fb=c+32|0}function ff(a,b){var c=0;c=fb-16|0;fb=c;a:{if(!b){Pc(c+8|0,a+32|0,5);if(Hb(x[x[c+8>>2]>>2],x[c+12>>2])){break a}}x[a+28>>2]=x[a+28>>2]+1}fb=c+16|0}function f9(a,b){a=a|0;b=b|0;var c=0,d=0;c=x[a+40>>2];while(1){if(c){c=c-1|0;d=c<<2;ib[x[x[a+32>>2]+d>>2]](b,a,x[d+x[a+36>>2]>>2]);continue}break}}function Wga(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=0,f=E(0);if(b>>>0<=1){c=Pd(c,E(0));if((b|0)==1){d=1;c=ri(c)}e=yb(a+4208|0,d),f=c,B[e>>2]=f;dQ(a)}}function TB(a,b,c){var d=0,e=0,f=0;d=Xl(a,b);if((d|0)!=255){e=_b(a+26|0,d),f=c,w[e>>1]=f;a=a+62|0;e=xb(a,b),f=255,v[e|0]=f;e=xb(a,c),f=d,v[e|0]=f}}function M_(a,b){var c=0;c=Sua(b&255,0,9,0);b=a&255;a=b>>>31|0;b=b<<1;c=c+b|0;a=a+hb|0;a=b>>>0>c>>>0?a+1|0:a;b=c+11|0;hb=b>>>0<11?a+1|0:a;return b}function JU(a){var b=0,c=0,d=0;d=y[a+26|0];b=d+27|0;while(1){if((c|0)==(d|0)){a=b&65535}else{b=y[(a+c|0)+27|0]+b|0;c=c+1|0;continue}break}return a}function IP(a,b){a=a|0;b=b|0;var c=0,d=0;d=fb-16|0;fb=d;c=du(Ec(12));x[c+8>>2]=b;x[c+4>>2]=a;x[c>>2]=47580;a=yf(d+12|0,c);fb=d+16|0;return x[a>>2]}function Gs(a,b,c,d){var e=0;e=ac(8);x[31737]=0;a=P(d|0,e|0,a|0)|0;d=x[31737];x[31737]=0;if((d|0)!=1){da(a|0,c|0,b|0);p()}a=N()|0;jc(e);Q(a|0);p()}function FX(a){var b=0,c=0,d=0,e=0;d=y[a+4|0];e=y[a+92|0];c=y[a+94|0]|y[a+95|0]<<8;b=c+y[a+93|0]|0;a=0;b=b+e|0;a=(b<<2)+d|0;a=a-96|0;hb=0;return a}function vt(a){var b=0,c=0,d=0;if(!a){return 0}d=99008;while(1){b=d;c=x[b>>2];if(c){d=b+4|0;if((a|0)!=(c|0)){continue}}break}return((c?b:0)|0)!=0}function pP(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;h=fb-32|0;fb=h;i=h+8|0;iM(i,b,c,d,e,f,g);_c(a,i);en(i);fb=h+32|0}function kG(a){a=a|0;var b=0;a=Fb(a);x[31737]=0;R(169,a+12|0)|0;b=x[31737];x[31737]=0;if((b|0)!=1){sc(a+32|0);return a|0}b=N()|0;tb(a);Q(b|0);p()}function bj(a,b){var c=0;c=x[a>>2];if(Zc(c,x[a+4>>2])>>>0>b>>>0){a=x[a+24>>2];a=He(x[a+484344>>2],x[a+484348>>2],z[_b(c,b)>>1])}else{a=0}return a}function LE(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+7|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0}function JB(a){var b=0,c=0;b=fb-16|0;fb=b;x[b+12>>2]=a;c=b+12|0;a=1;while(1){if((a|0)>0){ah(c);a=a-1|0;continue}break}fb=b+16|0;return x[b+12>>2]}function Bla(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-32|0;fb=c;v[c+31|0]=b;b=c+31|0;Zr(c+20|0,b);d=x[c+20>>2];Zr(c+12|0,b);yl(a,d,x[c+16>>2]);fb=c+32|0}function rq(a,b){var c=0;a:{if(!dM(b)|(y[b+1|0]^y[a+1|0])>>>0>1){break a}b=y[b+2|0];a=y[a+2|0];if((b^a)&12){break a}c=b>>>0<16^a>>>0>15}return c}function pua(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;x[c+12>>2]=-1;if(fh(a,c+11|0)){x[c+4>>2]=y[c+11|0];p0(a,b,x[Gb(c+4|0,c+12|0)>>2])}fb=c+16|0}function NP(a,b){var c=0;if(a>.999999){c=0}else{a=a*a;b=jf(31415.926535897932/b);c=Zi(32768/(1-a)*(1-(a*b+M((a+a)*(1-b)-a*a*(1-b*b)))))}return c}function Jy(a){var b=0,c=0;b=fb-16|0;fb=b;c=-1;a:{if(Uy(a)){break a}if((ib[x[a+32>>2]](a,b+15|0,1)|0)!=1){break a}c=y[b+15|0]}fb=b+16|0;return c}function rT(a,b){v[a+840|0]=b;v[a+812|0]=b;v[a+811|0]=b;v[a+809|0]=b;v[a+807|0]=b;v[a+806|0]=b;v[a+833|0]=b;v[a+826|0]=b>>>4;v[a+827|0]=b<<2&60}function iga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if(!b){Gz(a,0,0,0,0,0,0,c,d);return}Gz(a,x[b>>2],x[b+4>>2],x[b+8>>2],x[b+12>>2],x[b+24>>2],b,c,d)}function f1(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;x[c+12>>2]=-1;if(fh(a,c+11|0)){x[c+4>>2]=y[c+11|0];V0(a,b,x[Gb(c+4|0,c+12|0)>>2])}fb=c+16|0}function Tk(a,b,c,d){var e=0;e=D(b,c);a:{if(x[d+76>>2]<0){a=IE(a,e,d);break a}a=IE(a,e,d)}if((e|0)==(a|0)){return b?c:0}return(a>>>0)/(b>>>0)|0}function aF(a,b){var c=0;a:{if(!(y[a+2|0]|y[a+3|0]<<8)|(!y[a|0]|!y[a+1|0])){break a}c=1;if(b>>>0<9){break a}c=(y[a+4|0]-1&255)>>>0<32}return c}function Xpa(a,b){a=a|0;b=b|0;a:{if(a>>>0>=515){a=Pg(b);Pg(b);break a}a=hh(b);hh(b)}while(1){if(a){if(a&1){Vb(b,260)}a=a>>>1|0;continue}break}}function Rm(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Cf(b);e=a;a=Cb(x[c+4>>2],y[c+11|0]);b=Cg(Jb(Fz(e,d+a|0)),b,d)+d|0;hm(Cg(b,Jb(c),a)+a|0,1,0)}function NL(a,b,c,d,e,f){var g=0,h=0;g=x[a+32>>2];if(!y[a+23|0]){x[(c<<2)+g>>2]=b;return}h=g;g=d<<2;x[h+g>>2]=b;v[x[a+8>>2]+d|0]=e;x[f+g>>2]=c}function GY(a){var b=0;if(!(kd(a,15112,3)|(y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24))-2147483647>>>0<2147484072)){b=y[a+3|0]<6}return b}function Em(a,b){var c=0,d=0;d=x[a+4>>2];c=x[a+8>>2];while(1){if((c|0)!=(d|0)){c=c-b|0;x[a+8>>2]=c;continue}break}b=x[a>>2];if(b){nc(a);Db(b)}}function ag(a){a=a|0;var b=0;x[a>>2]=42824;x[x[a+20>>2]>>2]=0;b=x[a+16>>2];x[b+946300>>2]=x[b+946300>>2]-1;x[a+20>>2]=0;DQ(a+44|0);return a|0}function Y$(a,b,c){var d=0;d=fb-16|0;fb=d;sm(d+12|0,b);x[d+8>>2]=y[d+12|0]|y[d+13|0]<<8|(y[d+14|0]<<16|y[d+15|0]<<24);ip(a,d+8|0,c);fb=d+16|0}function Xu(a,b){var c=0,d=0;d=ck(a,b);while(1){a:{c=d;if(!(c&65535)){c=0;break a}d=c-1|0;if(!He(a,b,d&65535)){continue}}break}return c&65535}function UV(a){var b=0,c=0;c=x[a+4>>2];b=x[a+8>>2];while(1){if((b|0)!=(c|0)){b=b-32|0;x[a+8>>2]=b;continue}break}b=x[a>>2];if(b){ys(a);Db(b)}}function Tu(a,b){var c=0;c=fb-16|0;fb=c;ee(c+8|0,a);ee(c,b);b=x[c>>2];a=F_(x[c+8>>2],x[c+12>>2],b,x[c+4>>2]);fb=c+16|0;return Cd(a?a>>31|1:0)}function Qn(a,b){var c=0;a=Un(a);x[a>>2]=78736;c=x[b+8>>2];x[a+4>>2]=x[b+4>>2];x[a+8>>2]=c;v[a+16|0]=y[b+16|0];x[a+12>>2]=x[b+12>>2];return a}function MR(a,b){var c=0;c=fb-16|0;fb=c;ee(c+8|0,a);ee(c,b);b=x[c>>2];a=GZ(x[c+8>>2],x[c+12>>2],b,x[c+4>>2]);fb=c+16|0;return Cd(a?a>>31|1:0)}function IW(a){var b=0,c=0;c=x[a+4>>2];b=x[a+8>>2];while(1){if((b|0)!=(c|0)){b=b-12|0;x[a+8>>2]=b;continue}break}b=x[a>>2];if(b){ys(a);Db(b)}}function Ei(a){var b=0;a=a*a;b=a*a;return E(a*b*(a*2439044879627741e-20+-.001388676377460993)+(b*.04166662332373906+(a*-.499999997251031+1)))}function iE(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;w[c+14>>1]=1;d=c,e=km(a,b),w[d+12>>1]=e;a=pe(c+14|0,c+12|0);fb=c+16|0;return z[a>>1]-1&65535}function Tx(a,b){var c=0;c=fb-16|0;fb=c;b=Nh(c+12|0,b);if(a>>>0>=128){a=(a&-128)!=57216?-1:x[x[124243]>>2]?-1:a&255}Mh(b);fb=c+16|0;return a}function JO(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=fb-32|0;fb=g;h=g+8|0;jM(h,b,c,d,e,f);_c(a,g+20|0);en(h);fb=g+32|0}function w_(a){var b=0,c=0,d=0;b=fb-16|0;fb=b;c=b,d=$b(a),x[c+12>>2]=d;x[b+8>>2]=236;a=ad(b+12|0,b+8|0);fb=b+16|0;hb=0;return x[a>>2]-216|0}function nf(a){var b=0,c=0,d=0;d=fb-16|0;fb=d;b=vb(d+12|0,a);c=x[b>>2];if(x[c>>2]){DZ(c);b=x[b>>2];c=x[b>>2];at(b);Db(c)}fb=d+16|0;return a}function Ne(a,b,c){v[a+11|0]=c;v[a+10|0]=b;v[a+12|0]=y[a+12|0]&251;w[a+8>>1]=65535;x[a>>2]=0;x[a+4>>2]=0;v[a+12|0]=y[a+12|0]&252|1;return a}function Lb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-16|0;fb=d;if(b>>>0>=122){Wq(12226);p()}e=d+8|0;Kb(e,a,b);If(e,c);fb=d+16|0;return a|0}function Kw(a,b){var c=0;a:{if(!b){break a}if(!Mb(x[a>>2],x[a+8>>2],b)){break a}if(b>>>0<=1){c=CF(a,1);break a}c=hh(a);Vb(a,b-2|0)}return c}function Ap(a,b){var c=0;a:{if(!b){break a}if(!Mb(x[a>>2],x[a+8>>2],b)){break a}if(b>>>0<=3){c=DF(a,b);break a}c=Pg(a);Vb(a,b-4|0)}return c}function Ab(a,b){var c=0;if(Cd(y[a+11|0])){Db(x[a>>2])}c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;x[a+8>>2]=x[b+8>>2];Me(b,0);fd(b,0);return a}function uL(a){var b=0,c=0;x[31737]=0;c=ca(1180)|0;b=x[31737];x[31737]=0;if((b|0)!=1){b=a;a=x[c>>2];x[b>>2]=a;fl(a);return}T(0)|0;Sb();p()}function sI(a,b,c,d,e){var f=0;f=c;c=0;a:{if(!d){break a}c=b>>8;if(!(b&1)){break a}c=Mx(x[d>>2],c)}ib[x[x[a>>2]+28>>2]](a,f,c+d|0,b&2?e:2)}function h6(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;a=fb-16|0;fb=a;x[a+12>>2]=e;x[a+8>>2]=d-c;b=Gb(a+12|0,a+8|0);fb=a+16|0;return x[b>>2]}function VO(a,b,c){var d=0,e=0;d=Mc(a);if(d>>>0>=c>>>0){_u(a,Ui(Jb(a),b,c),c);return}e=a;a=Cb(x[a+4>>2],y[a+11|0]);dq(e,d,c-d|0,a,0,a,c,b)}function Pl(a){var b=0,c=0,d=0;b=fb-16|0;fb=b;c=x[a+24>>2];d=x[a+40>>2];x[b+12>>2]=1;a=ad(a+20|0,b+12|0);fb=b+16|0;return D(x[a>>2],c+d|0)}function xC(a){a=50-(D(y[(a>>>4|0)+29952|0],a&15)>>>4|0)|0;a=a>>>0>23863?65536:23863/(a>>>0)|0;return Gc((a+119315e4>>>0)/(a<<1>>>0)|0,0)}function via(a,b){a=a|0;b=b|0;var c=0;b=fb-16|0;fb=b;c=x[a+20>>2];re(b,x[c+4>>2],x[c+8>>2]);FQ(a,gc(b+8|0,x[b>>2],x[b+4>>2]),0);fb=b+16|0}function k$(a){var b=0,c=0,d=0;c=fb-16|0;fb=c;b=c+13|0;ax(b,a);a=y[xb(b,0)|0];d=y[xb(b,1)|0];b=y[xb(b,2)|0];fb=c+16|0;return d<<8|a|b<<16}function ik(a,b,c){var d=0,e=0,f=0;d=fb-16|0;fb=d;v[d+15|0]=b;v[d+14|0]=127;e=a,f=y[Qb(d+15|0,d+14|0)|0]|(c?-128:0),v[e+21|0]=f;fb=d+16|0}function hk(a,b,c){var d=0,e=0,f=0;d=fb-16|0;fb=d;v[d+15|0]=b;v[d+14|0]=127;e=a,f=y[Qb(d+15|0,d+14|0)|0]|(c?-128:0),v[e+22|0]=f;fb=d+16|0}function ed(a){var b=0;b=fb-16|0;fb=b;x[b+12>>2]=a;x[b+8>>2]=-32768;x[b+4>>2]=32767;a=Ye(b+8|0,ud(b+12|0,b+4|0));fb=b+16|0;return w[a>>1]}function ala(a){a=a|0;var b=0;b=x[a>>2];if(ib[x[x[b>>2]+32>>2]](b,0,32)|0){a=x[a>>2];a=ib[x[x[a>>2]+32>>2]](a,32,1)^1}else{a=0}return a|0}function QO(a,b){var c=0,d=0;a:{if(!St(b)){break a}c=x[a+484344>>2];if(!He(c,x[a+484348>>2],b&65535)){break a}d=x[Wb(c,b)+12>>2]}return d}function AQ(a,b){var c=0;c=x[b+4>>2];if(x[a>>2]==(b|0)){x[a>>2]=c}a=x[b+8>>2];if(c){x[c+8>>2]=a}if(a){x[a+4>>2]=c}x[b+4>>2]=0;x[b+8>>2]=0}function AC(a,b){var c=0,d=0;x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];x[a+8>>2]=x[b+8>>2];x[b>>2]=0;x[b+4>>2]=0;c=zb(b),d=0,x[c>>2]=d;return a}function L4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;while(1){if((b|0)!=(c|0)){d=b,e=Cy(x[b>>2]),x[d>>2]=e;b=b+4|0;continue}break}return c|0}function KH(a,b,c){var d=0;while(1){if((a|0)!=(b|0)){d=x[a>>2];if(d>>>0<=127){d=x[(d<<2)+c>>2]}x[a>>2]=d;a=a+4|0;continue}break}return b}function J4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;while(1){if((b|0)!=(c|0)){d=b,e=Dy(x[b>>2]),x[d>>2]=e;b=b+4|0;continue}break}return c|0}function qY(a){w[a+10>>1]=0;w[a+12>>1]=0;w[a+8>>1]=1084;x[a>>2]=0;x[a+4>>2]=40;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0;v[a+16|0]=0;return a}function oP(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=fb-32|0;fb=g;h=g+8|0;jM(h,b,c,d,e,f);_c(a,h);en(h);fb=g+32|0}function gd(a,b){var c=0,d=0,e=0;c=kh(a,b);if(c){x[a+12>>2]=x[a+12>>2]+b;return c}d=a,e=ib[x[x[a>>2]+24>>2]](a)|0,x[d+12>>2]=e;return c}function WC(a){var b=0;b=Bb(y[a+26|0]|y[a+27|0]<<8);return((y[a+24|0]>15)+(y[a+25|0]>64)|0)+(Bb(y[a+22|0]|y[a+23|0]<<8)<<1>>>0<b>>>0)|0}function OS(a,b,c,d){var e=0;e=a+1074376|0;pB(a,e,b,c,d);e=0-y[(D(b,872)+e|0)+1428|0]|0;if(d){c=0}else{c=Iu(x[a+480180>>2])}Eo(a,b,e,c)}function O9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=b;b=x[b>>2]+7&-8;x[c>>2]=b+16;d=a,e=yx(x[b>>2],x[b+4>>2],x[b+8>>2],x[b+12>>2]),C[d>>3]=e}function v4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;while(1){if((b|0)!=(c|0)){d=b,e=xl(y[b|0]),v[d|0]=e;b=b+1|0;continue}break}return c|0}function tn(a){var b=0,c=0;c=x[a+4>>2];b=x[a+8>>2];while(1){if((b|0)!=(c|0)){b=b-1|0;x[a+8>>2]=b;continue}break}a=x[a>>2];if(a){Db(a)}}function t4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;while(1){if((b|0)!=(c|0)){d=b,e=yt(y[b|0]),v[d|0]=e;b=b+1|0;continue}break}return c|0}function nia(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(!(!d|!Sc(c&255))){IQ(a,8,E(0))}a=Ej(a);if(a){ib[x[x[a>>2]+96>>2]](a,b,c,d,e)}}function ica(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=eu(x[a+32>>2],b,c,d,2);if(a>>>0<=15){a=y[a+42240|0]}else{a=0}return(a>>>0<5?a+1|0:0)|0}function hca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=eu(x[a+32>>2],b,c,d,3);if(a>>>0<=46){a=y[a+42192|0]}else{a=0}return(a>>>0<5?a+1|0:0)|0}function bp(a){var b=0,c=0;c=fb-16|0;fb=c;b=vb(c+12|0,a);a=x[b>>2];if(x[a>>2]){aZ(a,x[a>>2]);a=x[b>>2];b=x[a>>2];bZ(a);Db(b)}fb=c+16|0}function Qua(a,b){a=a|0;b=b|0;x[a+4>>2]=b;v[a|0]=0;b=x[x[b>>2]-12>>2]+b|0;if(!x[b+16>>2]){b=x[b+72>>2];if(b){xp(b)}v[a|0]=1}return a|0}function LW(a){var b=0,c=0;c=fb-16|0;fb=c;b=vb(c+12|0,a);a=x[b>>2];if(x[a>>2]){FW(a,x[a>>2]);a=x[b>>2];b=x[a>>2];jl(a);Db(b)}fb=c+16|0}function Fka(a,b){a=a|0;b=b|0;a=hB(a);x[31737]=0;O(848,a|0,b|0);b=x[31737];x[31737]=0;if((b|0)==1){b=N()|0;Lq(a);Q(b|0);p()}return a|0}function Du(a,b,c){var d=0;d=fb-16|0;fb=d;b=we(d+8|0,Sua(b,c,1e6,0),hb);c=x[b>>2];b=x[b+4>>2];fb=d+16|0;x[a>>2]=c;x[a+4>>2]=b;return a}function bda(a,b){a=a|0;b=b|0;var c=0;if((a|0)!=(b|0)){c=x[a+4>>2];if(c){Db(c);x[a+4>>2]=0}x[a+4>>2]=x[b+4>>2];x[b+4>>2]=0}return a|0}function wi(a,b,c){v[a|0]=b;v[a+1|0]=b>>>8;v[a+2|0]=b>>>16;v[a+3|0]=b>>>24;v[a+4|0]=c;v[a+5|0]=c>>>8;v[a+6|0]=c>>>16;v[a+7|0]=c>>>24}function uY(a){var b=0;b=fb-16|0;fb=b;x[b+12>>2]=a;x[b+8>>2]=-128;x[b+4>>2]=127;a=Ye(b+8|0,ud(b+12|0,b+4|0));fb=b+16|0;return v[a|0]}function jha(a,b,c){a=a|0;b=b|0;c=E(c);var d=0;if(b>>>0<=4){c=Pd(c,E(0));d=((b<<2)+a|0)+4220|0;if((b|0)==4){c=ri(c)}B[d>>2]=c;fQ(a)}}function dla(a,b){a=a|0;b=b|0;a=yE(a,b);if(!a){v[b+6|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b|0]=0;v[b+1|0]=0}return a|0}function JH(a,b,c){var d=0;while(1){if((a|0)!=(b|0)){d=v[a|0];if((d|0)>=0){d=x[(d<<2)+c>>2]}v[a|0]=d;a=a+1|0;continue}break}return b}function oi(a,b){var c=0,d=0;c=x[a>>2];d=x[a+4>>2];b=x[a+16>>2]+b|0;a=x[a+12>>2];b=(b|0)%(a|0)|0;return B[Oc(c,d,(b>>31&a)+b|0)>>2]}function dg(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;if(b>>>0>=122){Wq(12191);p()}d=c+8|0;Kb(d,a,b);If(d,0);fb=c+16|0;return a|0}function Qy(a){a=a|0;var b=0;b=x[a+12>>2];if((b|0)==x[a+16>>2]){return ib[x[x[a>>2]+40>>2]](a)|0}x[a+12>>2]=b+1;return Pf(v[b|0])|0}function PS(a,b,c,d){var e=0;e=a+1074376|0;qB(a,e,b,c,d);e=y[(D(b,872)+e|0)+1427|0];if(d){c=0}else{c=Iu(x[a+480180>>2])}Eo(a,b,e,c)}function Kt(a,b){var c=0,d=0;a:{if(b>>>0<=31){d=x[a>>2];c=a+4|0;break a}b=b-32|0;c=a}c=x[c>>2];x[a>>2]=d<<b;x[a+4>>2]=c<<b|d>>>32-b}function pi(a,b){var c=0,d=0,e=0;o(+a);c=j(1)|0;d=j(0)|0;o(+b);e=j(1)|0;j(0)|0;l(0,d|0);l(1,c&2147483647|e&-2147483648);return+n()}function Mt(a,b){var c=0,d=0;c=x[a+4>>2];a:{if(b>>>0<=31){d=x[a>>2];break a}b=b-32|0;d=c;c=0}x[a+4>>2]=c>>>b;x[a>>2]=c<<32-b|d>>>b}function Ika(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;if(b>>>0>=250){Wq(12226);p()}d=c+8|0;Kb(d,a,b);fp(d);fb=c+16|0;return a|0}function I9(a){a=a|0;var b=0;if((ib[x[x[a>>2]+36>>2]](a)|0)!=-1){b=a;a=x[a+12>>2];x[b+12>>2]=a+1;a=Pf(v[a|0])}else{a=-1}return a|0}function cZ(a,b){var c=0;c=fb-16|0;fb=c;a=Tg(c+4|0,a,1);gp(x[a+4>>2],z[b>>1]|z[b+2>>1]<<16);x[a+4>>2]=x[a+4>>2]+4;hc(a);fb=c+16|0}function ML(a,b){a:{if(a&255){a=1;if((b|0)!=255){break a}_(14279,13274,1180,5734);p()}if((b|0)==255){return 0}a=b>>>0>10}return a}function Ch(a){var b=0;b=fb-16|0;fb=b;x[b+12>>2]=a;x[b+8>>2]=0;x[b+4>>2]=255;a=Ye(b+8|0,ud(b+12|0,b+4|0));fb=b+16|0;return y[a|0]}function xT(a,b,c,d){a:{if(d>>>0>=64){d=-1;if(y[a+480180|0]&2){break a}}x[b+56>>2]=0;d=Ko(a,z[b+70>>1],x[b+48>>2],c,0)}return d}function w9(a){a=a|0;var b=0;if((ib[x[x[a>>2]+36>>2]](a)|0)!=-1){b=a;a=x[a+12>>2];x[b+12>>2]=a+4;a=x[a>>2]}else{a=-1}return a|0}function ke(a){var b=0;a=x[a+4>>2];if(a){if(Am(a)){a:{b=a+8|0;if(x[b>>2]){if((hx(b)|0)!=-1){break a}}ib[x[x[a>>2]+16>>2]](a)}}}}function kH(a,b,c,d){a=Nb(a);x[31737]=0;S(d|0,a|0,b|0,c|0);b=x[31737];x[31737]=0;if((b|0)!=1){return a}b=N()|0;vc(a);Q(b|0);p()}function iK(a,b,c,d,e,f){a=ib[x[x[a+8>>2]+4>>2]](a+8|0)|0;a=mt(c,d,a,a+288|0,f,e,0)-a|0;if((a|0)<=287){x[b>>2]=((a|0)/12|0)%12}}function fK(a,b,c,d,e,f){a=ib[x[x[a+8>>2]+4>>2]](a+8|0)|0;a=it(c,d,a,a+288|0,f,e,0)-a|0;if((a|0)<=287){x[b>>2]=((a|0)/12|0)%12}}function cz(a,b,c){var d=0;d=x[a+32>>2];if(A[a+40>>2]<d+c>>>0){x[a+96>>2]=1;return 0}yc(b,d,c);x[a+32>>2]=x[a+32>>2]+c;return 1}function Z5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;while(1){if((b|0)!=(c|0)){x[d>>2]=v[b|0];d=d+4|0;b=b+1|0;continue}break}return c|0}function OB(a,b){var c=0;c=x[a+484360>>2];b=b&255;if(Nj(c,x[a+484364>>2])>>>0<=b>>>0){return Xb(c,y[a+484376|0])}return Tj(c,b)}function DH(a,b,c){var d=0;d=fb-16|0;fb=d;x[d+8>>2]=a;x[d+12>>2]=b;x[d>>2]=c;x[d+4>>2]=0;a=_r(d+8|0,d);fb=d+16|0;return x[a>>2]}function BC(a,b){var c=0;c=fb-16|0;fb=c;a=gc(c+8|0,(b>>>3&536870908)+a|0,1<<b);a=Hb(x[x[a>>2]>>2],x[a+4>>2]);fb=c+16|0;return a}function yr(a){var b=0;b=-1;a:{if(a>=4294967295){break a}b=0;if(a<=0){break a}if(a<4294967296&a>=0){return~~a>>>0}b=0}return b}function uC(a){var b=0,c=0;c=fb-16|0;fb=c;a=vb(c+12|0,a);b=x[a>>2];if(x[b>>2]){KW(b);a=x[a>>2];b=x[a>>2];jl(a);Db(b)}fb=c+16|0}function tS(a){var b=0,c=0;c=fb-16|0;fb=c;a=vb(c+12|0,a);b=x[a>>2];if(x[b>>2]){Cu(b);a=x[a>>2];b=x[a>>2];Bu(a);Db(b)}fb=c+16|0}function qv(a){var b=0,c=0;c=fb-16|0;fb=c;a=vb(c+12|0,a);b=x[a>>2];if(x[b>>2]){VV(b);a=x[a>>2];b=x[a>>2];lC(a);Db(b)}fb=c+16|0}function oU(a){var b=0,c=0;c=fb-16|0;fb=c;a=vb(c+12|0,a);b=x[a>>2];if(x[b>>2]){jU(b);a=x[a>>2];b=x[a>>2];jl(a);Db(b)}fb=c+16|0}function nu(a){var b=0;b=C[a+4248>>3]/+A[x[a+16>>2]+24620>>2];C[a+4264>>3]=b;if(y[a+4240|0]){C[a+4264>>3]=b*(C[a+4288>>3]/60)}}function nS(a){var b=0,c=0;c=fb-16|0;fb=c;a=vb(c+12|0,a);b=x[a>>2];if(x[b>>2]){Rp(b);a=x[a>>2];b=x[a>>2];cx(a);Db(b)}fb=c+16|0}function mu(a){var b=0,c=0;c=fb-16|0;fb=c;a=vb(c+12|0,a);b=x[a>>2];if(x[b>>2]){dA(b);a=x[a>>2];b=x[a>>2];cA(a);Db(b)}fb=c+16|0}function ie(a){var b=0,c=0;c=fb-16|0;fb=c;a=vb(c+12|0,a);b=x[a>>2];if(x[b>>2]){n0(b);a=x[a>>2];b=x[a>>2];rE(a);Db(b)}fb=c+16|0}function gH(a,b,c){a=ri(a);a:{if(a>=b){break a}c=0;if(a<=E(0)){break a}if(a<E(4294967296)&a>=E(0)){c=~~a>>>0;break a}}return c}function gG(a,b){var c=0;c=x[b+4>>2];if(c){bc(a,c,x[b>>2]);return}c=x[b+8>>2];b=x[b+12>>2];if(!mc(c,b)){re(a,c,b);return}Nd(a)}function _B(a){var b=0,c=0;c=fb-16|0;fb=c;a=vb(c+12|0,a);b=x[a>>2];if(x[b>>2]){aV(b);a=x[a>>2];b=x[a>>2];ap(a);Db(b)}fb=c+16|0}function Xi(a){var b=0,c=0;c=fb-16|0;fb=c;a=vb(c+12|0,a);b=x[a>>2];if(x[b>>2]){iY(b);a=x[a>>2];b=x[a>>2];ap(a);Db(b)}fb=c+16|0}function TU(a,b,c,d,e){x[a+12>>2]=e;x[a+8>>2]=d;x[a+4>>2]=c;x[a>>2]=b;if(b){Yd(b,a)}if(c){Yd(c,a)}if(d){Yd(d,a)}if(e){Yd(e,a)}}function R5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;while(1){if((b|0)!=(c|0)){v[d|0]=y[b|0];d=d+1|0;b=b+1|0;continue}break}return c|0}function CS(a){var b=0,c=0;c=fb-16|0;fb=c;a=vb(c+12|0,a);b=x[a>>2];if(x[b>>2]){gw(b);a=x[a>>2];b=x[a>>2];C$(a);Db(b)}fb=c+16|0}function yI(a,b,c,d){var e=0,f=0,g=0;e=fb-16|0;fb=e;d=Tg(e+4|0,a,d);f=d,g=sR(hq(a),b,c,x[d+4>>2]),x[f+4>>2]=g;hc(d);fb=e+16|0}function wn(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;f=b;b=c-b|0;g=e,h=ml(d,f,b)+b|0,x[g+12>>2]=h;Ac(a,c,e+12|0);fb=e+16|0}function oO(a){a=a|0;var b=0,c=0;b=fb-16|0;fb=b;c=du(Ec(8));x[c+4>>2]=a;x[c>>2]=48528;a=yf(b+12|0,c);fb=b+16|0;return x[a>>2]}function gN(a){a=a|0;var b=0,c=0;b=fb-16|0;fb=b;c=TM(Ec(8));x[c+4>>2]=a;x[c>>2]=73608;a=yf(b+12|0,c);fb=b+16|0;return x[a>>2]}function TG(a){a=a|0;var b=0;a=Fb(a);x[31737]=0;O(131,a|0,13785);b=x[31737];x[31737]=0;if((b|0)==1){b=N()|0;tb(a);Q(b|0);p()}}function Sx(a,b){var c=0,d=0,e=0,f=0;c=Cf(b);d=Ec(c+13|0);x[d+8>>2]=0;x[d+4>>2]=c;x[d>>2]=c;e=a,f=yc(nc(d),b,c+1|0),x[e>>2]=f}function Sr(a,b){return xn(y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24),y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))?b:a}function O3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if(mh(a,x[b+8>>2],0)){Nx(b,c,d);return}a=x[a+8>>2];ib[x[x[a>>2]+28>>2]](a,b,c,d)}function jK(a,b,c,d,e,f){a=ib[x[x[a+8>>2]>>2]](a+8|0)|0;a=mt(c,d,a,a+168|0,f,e,0)-a|0;if((a|0)<=167){x[b>>2]=((a|0)/12|0)%7}}function gK(a,b,c,d,e,f){a=ib[x[x[a+8>>2]>>2]](a+8|0)|0;a=it(c,d,a,a+168|0,f,e,0)-a|0;if((a|0)<=167){x[b>>2]=((a|0)/12|0)%7}}function cm(a,b){var c=0;a:{if(A[a+12>>2]<b>>>0){c=0;if(!(ib[x[x[a>>2]+32>>2]](a,0,b)|0)){break a}}x[a+12>>2]=b;c=1}return c}function Rc(a,b,c){var d=0;d=a;a=c&31;if((c&63)>>>0>=32){c=b>>31;a=b>>a}else{c=b>>a;a=((1<<a)-1&b)<<32-a|d>>>a}hb=c;return a}function OY(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;w[c+14>>1]=b;if((km(x[a>>2],x[a+4>>2])|0)!=65535){M0(a,c+14|0)}fb=c+16|0}function MT(a){tB(a);x[a>>2]=0;x[a+4>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;a=qg(a);qg(a+12|0);v[a+24|0]=1}function Kl(a,b,c,d){var e=0;e=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=e;e=x[b+12>>2];x[a+8>>2]=x[b+8>>2];x[a+12>>2]=e;xA(a,c,d)}function Fg(a,b,c){var d=0;d=4;a:{b:{switch(b-1|0){case 0:d=c;break a;case 1:break b;default:break a}}d=c?3:2}return Ro(a,d)}function rr(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;return ib[x[x[a>>2]+12>>2]](a,b,c,d,e,f,g,h)|0}function bQ(a){a=a|0;var b=0,c=0;b=a+4960|0;c=a+4504|0;while(1){b=vc(b-24|0);if((c|0)!=(b|0)){continue}break}return ag(a)|0}function Vha(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=0;if(b>>>0<=2){d=(a+b|0)+4232|0,e=zh(E(Pd(c,E(0))*E(127))),v[d|0]=e;ku(a)}}function Pia(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=0;if(b>>>0<=3){d=(a+b|0)+4264|0,e=zh(E(Pd(c,E(0))*E(255))),v[d|0]=e;qu(a)}}function op(a){x[a+32>>2]=0;x[a+24>>2]=0;x[a+28>>2]=0;x[a>>2]=0;x[a+4>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[a+16>>2]=0;return a}function eH(a,b){x[a>>2]=b;uL(a+4|0);x[a+24>>2]=0;x[a+28>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;return a}function SK(a,b,c,d,e,f,g,h,i){x[a>>2]=b;x[a+4>>2]=c;x[a+8>>2]=d;x[a+12>>2]=e&65535|(i>>>16&32768|(e&2147418112)>>>16)<<16}function KR(a,b){var c=0;if(!(y[a|0]!=y[b|0]|C[a+8>>3]!=C[b+8>>3]|y[a+16|0]!=y[b+16|0])){c=x[a+20>>2]==x[b+20>>2]}return c}function Fu(a,b,c){c=c&255;while(1){a:{if(!b){a=0;break a}if(mc(y[a|0],c)){break a}b=b-1|0;a=a+1|0;continue}break}return a}function FC(a){x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+28>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;return a}function qt(a){if(a>>>0<=131071){a=y[(a>>>3&31|y[(a>>>8|0)+103664|0]<<5)+103664|0]>>>(a&7)&1}else{a=a>>>0<196606}return a}function ne(a,b){return(y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))==(y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24))}function Kp(a,b,c){var d=0;a:{if(b>>>0>c>>>0){break a}d=x[a>>2];if(d>>>0>=b>>>0){b=c;if(d>>>0<=b>>>0){break a}}x[a>>2]=b}}function Fe(a,b,c){var d=0;a:{if((b|0)>(c|0)){break a}d=x[a>>2];if((d|0)>=(b|0)){b=c;if((d|0)<=(b|0)){break a}}x[a>>2]=b}}function rY(a,b){var c=0;c=fb-16|0;fb=c;a:{if(!kh(a,4)){lD(b);break a}nh(c+8|0,b);VC(c,a,x[c+8>>2],x[c+12>>2])}fb=c+16|0}function qF(a,b){var c=0;c=Sua(b&255,0,1536,0);b=hb;a=Sua(a&255,0,25,0);c=a+c|0;b=hb+b|0;hb=a>>>0>c>>>0?b+1|0:b;return c}function ph(a,b,c,d,e){var f=0;f=fb-16|0;fb=f;x[f+12>>2]=e;c=Nh(f+8|0,c);a=wt(a,b,d,x[f+12>>2]);Mh(c);fb=f+16|0;return a}function oW(a){var b=0;if(!(y[a+35|0]&2)){a=a+68|0;b=9;while(1){if(b){x[a>>2]=268435456;b=b-1|0;a=a+4|0;continue}break}}}function mV(a,b,c,d,e,f,g){v[a+17|0]=g;v[a+16|0]=f;x[a+12>>2]=e;x[a+8>>2]=d;x[a+4>>2]=c;x[a>>2]=b;if(d){jV(a,1);jV(a,0)}}function lV(a,b,c,d,e,f,g){v[a+17|0]=g;v[a+16|0]=f;x[a+12>>2]=e;x[a+8>>2]=d;x[a+4>>2]=c;x[a>>2]=b;if(d){kV(a,1);kV(a,0)}}function iL(a){var b=0;b=x[a+12>>2];if((b|0)==x[a+16>>2]){return ib[x[x[a>>2]+40>>2]](a)|0}x[a+12>>2]=b+4;return x[b>>2]}function WW(a){var b=0,c=0;while(1){b=c;if((b|0)!=8){c=b+1|0;if((y[a+b|0]-32&255)>>>0<95){continue}}break}return(b|0)==8}function IY(a,b,c,d){var e=0,f=0,g=0;e=fb-16|0;fb=e;a=Tg(e+4|0,a,d);f=a,g=zr(b,c,x[a+4>>2]),x[f+4>>2]=g;hc(a);fb=e+16|0}function mT(a,b,c,d){var e=0,f=0;if(c&255){e=a,f=Yb(x[a>>2]+((D(c<<24>>24,(d^-1|-256)+b|0)|0)/2|0)|0,0,256),x[e>>2]=f}}function m3(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=b;b=0;return ib[a|0](h|b,c,d,e,b|f,g)|0}function lla(a){a=a|0;var b=0,c=0;b=fb-16|0;fb=b;c=yf(b+12|0,Rb(Ec(6668),0,6668));fb=b+16|0;x[a>>2]=x[c>>2];return a|0}function gga(a){a=a|0;var b=0;b=fb-16|0;fb=b;if(a){a=qc(b+8|0,a);a=Rz(x[a>>2],x[a+4>>2])}else{a=0}fb=b+16|0;return a|0}function gf(a){var b=0;b=x[a+32>>2];a:{if(b>>>0>=A[a+40>>2]){x[a+96>>2]=1;a=0;break a}x[a+32>>2]=b+1;a=y[b|0]}return a}function d_(a,b,c){var d=0;while(1){if(b){d=y[c|0]|y[c+1|0]<<8;v[a|0]=d;v[a+1|0]=d>>>8;b=b-1|0;a=a+2|0;continue}break}}function dF(a){var b=0;b=0;a:{if(kd(a,14249,3)){break a}a=y[a+3|0];b=1;if((a|0)==1){break a}b=(a-8&255)>>>0<7}return b}function cu(a){a=a|0;var b=0;x[a>>2]=47740;Yd(a,0);b=x[a+8>>2];if(b){ib[x[x[b>>2]+4>>2]](b)}x[a+8>>2]=0;return Um(a)|0}function TX(a){var b=0;if(!(kd(a,13926,3)|y[a+3|0]>31|(v[a+27|0]<0|y[a+32|0]>64))){b=(y[a+33|0]-1&255)>>>0<32}return b}function Li(a,b,c){c=c&255;while(1){a:{if((a|0)!=(b|0)){if((c|0)!=y[a|0]){break a}}else{a=b}return a}a=a+1|0;continue}}function $u(a){var b=0,c=0,d=0;d=a*a;a=0;b=1;c=1;while(1){a=a+2;c=d*c/(a*a);b=b+c;if(b*1e-7<c){continue}break}return b}function yha(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=E(0);if(b>>>0<=5){c=Pd(c,E(0));d=yb(a+4208|0,b),e=c,B[d>>2]=e;lQ(a)}}function xi(a){var b=0;while(1){a:{if((b|0)!=47){if(y[b+42272|0]!=(a|0)){break a}}else{b=0}return b}b=b+1|0;continue}}function vga(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=E(0);if(b>>>0<=3){c=Pd(c,E(0));d=yb(a+4208|0,b),e=c,B[d>>2]=e;UP(a)}}function qha(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=E(0);if(b>>>0<=4){c=Pd(c,E(0));d=yb(a+4208|0,b),e=c,B[d>>2]=e;hQ(a)}}function oK(a,b,c){var d=0;d=fb-16|0;fb=d;x[d+12>>2]=c;b=Nh(d+8|0,b);a=NK(a,9278,x[d+12>>2]);Mh(b);fb=d+16|0;return a}function mH(a,b,c){a=Ee(a);a:{if(a>=b){break a}c=0;if(a<=0){break a}if(a<4294967296&a>=0){c=~~a>>>0;break a}}return c}function d9(a,b){a=a|0;b=b|0;var c=0,d=0;ib[x[x[a>>2]+24>>2]](a)|0;b=GD(x[b>>2]);x[a+36>>2]=b;c=a,d=jo(b),v[c+44|0]=d}function Y8(a,b){a=a|0;b=b|0;var c=0,d=0;ib[x[x[a>>2]+24>>2]](a)|0;b=Ky(x[b>>2]);x[a+36>>2]=b;c=a,d=jo(b),v[c+44|0]=d}function Cga(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=E(0);if(b>>>0<=2){c=Pd(c,E(0));d=yb(a+4208|0,b),e=c,B[d>>2]=e;XP(a)}}function tV(a){x[a+700>>2]=0;w[a+842>>1]=0;x[a+688>>2]=0;x[a>>2]=0;x[a+4>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[a+16>>2]=0}function n0(a){var b=0,c=0;c=x[a>>2];b=x[a+4>>2];while(1){if((b|0)!=(c|0)){b=b-28|0;Fd(b);continue}break}x[a+4>>2]=c}function Xl(a,b){a=a+62|0;if(v[xb(a,b)|0]<0){return 255}if(y[xb(a,b)|0]!=255){a=y[xb(a,b)|0]&127}else{a=255}return a}function Rp(a){var b=0,c=0;c=x[a>>2];b=x[a+4>>2];while(1){if((b|0)!=(c|0)){b=b-36|0;Mp(b);continue}break}x[a+4>>2]=c}function IK(a,b,c){var d=0;if(c){d=a;while(1){x[d>>2]=x[b>>2];d=d+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}return a}function H8(a){a=a|0;var b=0,c=0;c=x[a+4>>2];b=x[a>>2];a=x[a+8>>2];b=b+(a>>1)|0;if(a&1){c=x[c+x[b>>2]>>2]}ib[c|0](b)}function Eh(a){var b=0;sn(a);b=mv(x[a>>2],cl(z[a+34>>1]));x[a+20>>2]=b;if(!b){return 0}return Vk(x[a>>2],z[a+34>>1])}function vR(a){var b=0,c=0,d=0;if(x[a>>2]){M$(a);b=x[a>>2];cw(a);Db(b);c=zb(a),d=0,x[c>>2]=d;x[a>>2]=0;x[a+4>>2]=0}}function tr(a){var b=0,c=0,d=0;if(x[a>>2]){Nf(a);b=x[a>>2];Ug(a);Db(b);c=zb(a),d=0,x[c>>2]=d;x[a>>2]=0;x[a+4>>2]=0}}function th(a){var b=0;b=fb-16|0;fb=b;x[b+12>>2]=a;x[b+8>>2]=2147483647;a=Gb(b+12|0,b+8|0);fb=b+16|0;return x[a>>2]}function hV(a){var b=0,c=0,d=0;if(x[a>>2]){kj(a);b=x[a>>2];Nn(a);Db(b);c=zb(a),d=0,x[c>>2]=d;x[a>>2]=0;x[a+4>>2]=0}}function fU(a){var b=0,c=0,d=0;if(x[a>>2]){JG(a);b=x[a>>2];Xn(a);Db(b);c=zb(a),d=0,x[c>>2]=d;x[a>>2]=0;x[a+4>>2]=0}}function Yta(a,b){a=a|0;b=b|0;var c=0,d=0;b=fb-80|0;fb=b;c=-1;d=a;a=b+14|0;if(X$(d,a)){c=W$(a)}fb=b+80|0;return c|0}function zua(a,b){a=a|0;b=b|0;var c=0,d=0;b=fb-16|0;fb=b;c=-1;d=a;a=b+8|0;if(nk(d,a)){c=z0(a)}fb=b+16|0;return c|0}function yc(a,b,c){var d=0;if(c){d=a;while(1){v[d|0]=y[b|0];d=d+1|0;b=b+1|0;c=c-1|0;if(c){continue}break}}return a}function r0(a,b,c,d,e){v[a+4|0]=b;v[a|0]=69;v[a+1|0]=99;v[a+2|0]=104;v[a+3|0]=111;v[a+7|0]=e;v[a+6|0]=d;v[a+5|0]=c}function pM(a,b){var c=0;c=fb-16|0;fb=c;a=$l(c+4|0,a,1);Dl(x[a+4>>2],y[b|0]);x[a+4>>2]=x[a+4>>2]+1;hc(a);fb=c+16|0}function fqa(a,b){a=a|0;b=b|0;var c=0,d=0;b=fb-16|0;fb=b;c=-1;d=a;a=b+4|0;if($D(d,a)){c=_X(a)}fb=b+16|0;return c|0}function Vqa(a,b){a=a|0;b=b|0;var c=0,d=0;b=fb-16|0;fb=b;c=-1;d=a;a=b+8|0;if(nk(d,a)){c=GY(a)}fb=b+16|0;return c|0}function KL(a,b,c){var d=0,e=0,f=0;e=c*c;C[a>>3]=e;f=c;d=c*134217729;c=d+(c-d);d=f-c;C[b>>3]=d*d+((c+c)*d+(c*c-e))}function vT(a,b){var c=0;c=b&15;if(c){v[a+827|0]=c<<2}b=b&240;if(b){v[a+826|0]=b>>>4}x[a+88>>2]=x[a+88>>2]|262144}function lL(a,b){a=a|0;b=b|0;var c=0;c=x[a>>2];a:{if(!c){break a}if(!mc(oL(c,b),-1)){break a}x[a>>2]=0}return a|0}function jt(a,b){a:{if((a|0)==(b|0)){break a}while(1){b=b-4|0;if(b>>>0<=a>>>0){break a}Tb(a,b);a=a+4|0;continue}}}function jS(a,b){var c=0;c=fb-16|0;fb=c;a=gC(c+4|0,a);Co(x[a+4>>2],x[b>>2]);x[a+4>>2]=x[a+4>>2]+4;hc(a);fb=c+16|0}function gQ(a){a=a|0;x[a+4244>>2]=0;x[a+4248>>2]=0;x[a+4228>>2]=0;x[a+4232>>2]=0;a=a+4252|0;x[a>>2]=0;x[a+4>>2]=0}function Xda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(a){c=a;a=ib[x[x[b>>2]+8>>2]](b)|0;d=c,e=Bg(a?a:22303),x[d>>2]=e}}function PR(a,b){var c=0,d=0;c=x[a+4>>2];d=x[b+4>>2];if((c|0)==(d|0)){a=OR(x[a>>2],c,x[b>>2],d)}else{a=1}return!a}function Ol(a,b){var c=0;c=b&15;if(c){v[a+824|0]=c<<2}b=b&240;if(b){v[a+823|0]=b>>>4}x[a+88>>2]=x[a+88>>2]|131072}function Hm(a,b){a:{if((a|0)==(b|0)){break a}while(1){b=b-1|0;if(b>>>0<=a>>>0){break a}tg(a,b);a=a+1|0;continue}}}function oQ(a){var b=0,c=0;c=x[a+4>>2];b=x[a+8>>2];while(1){if((b|0)!=(c|0)){b=b-4|0;x[a+8>>2]=b;continue}break}}function ry(a,b,c){while(1){a:{if((a|0)!=(b|0)){if(x[a>>2]!=(c|0)){break a}}else{a=b}return a}a=a+4|0;continue}}function bN(a,b,c){while(1){a:{if((a|0)!=(b|0)){if(!Ld(c,x[a>>2])){break a}}else{a=b}return a}a=a+8|0;continue}}function _A(a,b){var c=0;c=fb-16|0;fb=c;a=we(c+8|0,Tua(a,b,1e6,0),hb);b=x[a>>2];fb=c+16|0;hb=x[a+4>>2];return b}function Ql(a,b){var c=0;c=1;a:{switch((b&255)-4|0){default:c=(a&255)==11;break;case 0:case 2:break a}}return c}function IJ(a,b){var c=0;c=Jb(a);if(c>>>0<=b>>>0){a=(Cb(x[a+4>>2],y[a+11|0])<<2)+c>>>0>=b>>>0}else{a=0}return a}function pt(a){if(a>>>0<=131071){a=y[(a>>>3&31|y[(a>>>8|0)+107568|0]<<5)+107568|0]>>>(a&7)&1}else{a=0}return a}function mh(a,b,c){if(!c){return x[a+4>>2]==x[b+4>>2]}if((a|0)==(b|0)){return 1}return!ni(x[a+4>>2],x[b+4>>2])}function jm(a){var b=0;b=fb-16|0;fb=b;x[b+12>>2]=a;x[b+8>>2]=65535;a=Gb(b+12|0,b+8|0);fb=b+16|0;return z[a>>1]}function gR(a){var b=0;b=fb-16|0;fb=b;x[b+12>>2]=a;x[b+8>>2]=32767;a=Gb(b+12|0,b+8|0);fb=b+16|0;return w[a>>1]}function ew(a,b){var c=0;c=fb-16|0;fb=c;x[c+12>>2]=(D(a,b)>>>0)/255;Fe(c+12|0,0,15);fb=c+16|0;return y[c+12|0]}function Uha(a,b){a=a|0;b=b|0;var c=E(0);if(b>>>0<=2){c=E(E(y[(a+b|0)+4232|0])/E(127))}else{c=E(0)}return E(c)}function Oia(a,b){a=a|0;b=b|0;var c=E(0);if(b>>>0<=3){c=E(E(y[(a+b|0)+4264|0])/E(255))}else{c=E(0)}return E(c)}function KW(a){var b=0,c=0;c=x[a>>2];b=x[a+4>>2];while(1){if((b|0)!=(c|0)){b=b-12|0;continue}break}x[a+4>>2]=c}function Jn(a){a=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);return a<<24|(a&65280)<<8|(a>>>8&65280|a>>>24)}function If(a,b){var c=0;c=x[a+4>>2];if(b){a=x[a>>2];x[a>>2]=x[a>>2]|c;return}a=x[a>>2];x[a>>2]=x[a>>2]&(c^-1)}function EH(a,b){var c=0,d=0;c=a+68|0;a=0;while(1){if((a|0)!=9){d=yb(c,a);a=a+1|0;x[d>>2]=a<<b;continue}break}}function c4(){if(y[500444]){return x[125110]}Ds(500436,x[zH()>>2]);v[500444]=1;x[125110]=500436;return 500436}function Z1(a){a=a|0;var b=0,c=0,d=0;b=fb-16|0;fb=b;c=-1;d=a;a=b+8|0;if(nk(d,a)){c=iG(a)}fb=b+16|0;return c|0}function TR(a,b){a:{switch(b-1|0){default:return a+724|0;case 0:return a+732|0;case 1:break a}}return a+740|0}function Sl(a,b,c,d){var e=0;e=fb-16|0;fb=e;x[e+12>>2]=d;x[e+8>>2]=c;gc(a,b,x[Gb(e+12|0,e+8|0)>>2]);fb=e+16|0}function Lx(a,b,c,d,e,f,g){var h=0;h=b>>8;if(b&1){h=Mx(x[e>>2],h)}ib[x[x[a>>2]+20>>2]](a,c,d,e+h|0,b&2?f:2,g)}function Jk(a,b){var c=0;c=fb-16|0;fb=c;x[c+12>>2]=a;a=c+12|0;x[a>>2]=x[a>>2]+(b<<2);fb=c+16|0;return x[a>>2]}function IS(a){x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+28>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[a+16>>2]=0;return a}function F2(a){a=a|0;var b=0,c=0,d=0;b=fb-32|0;fb=b;c=-1;d=a;a=b+8|0;if(QG(d,a)){c=PG(a)}fb=b+32|0;return c|0}function Bq(a,b){var c=0;c=fb-32|0;fb=c;nh(c+16|0,b);Sm(c+24|0,a,x[c+16>>2],x[c+20>>2]);nh(c+8|0,b);fb=c+32|0}function $v(a){var b=0;b=fb-16|0;fb=b;w[b+14>>1]=a;w[b+12>>1]=255;a=Nc(b+14|0,b+12|0);fb=b+16|0;return y[a|0]}function qL(a){var b=0;b=x[a+12>>2];if((b|0)==x[a+16>>2]){return ib[x[x[a>>2]+36>>2]](a)|0}return Pf(v[b|0])}function hK(a,b,c,d,e){b=qj(b,c,d,e,4);if(!(y[d|0]&4)){x[a>>2]=((b|0)<69?b+2e3|0:b>>>0<100?b+1900|0:b)-1900}}function eK(a,b,c,d,e){b=pj(b,c,d,e,4);if(!(y[d|0]&4)){x[a>>2]=((b|0)<69?b+2e3|0:b>>>0<100?b+1900|0:b)-1900}}function QU(a){var b=0;b=x[a+4>>2];w[a+70>>1]=y[((z[b+20>>1]>>>6|z[b+22>>1]<<4)&65535)+27472|0]>>>z[a+68>>1]}function yi(a){var b=0;b=fb-16|0;fb=b;x[b+12>>2]=a;x[b+8>>2]=255;a=Gb(b+12|0,b+8|0);fb=b+16|0;return y[a|0]}function ux(a){var b=0;b=fb-16|0;fb=b;x[b+12>>2]=a;x[b+12>>2]=x[b+12>>2]+12;fb=b+16|0;return Vp(x[b+12>>2])}function rea(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;return _H(a,b,c,d,e,f,g,12993,1084)|0}function pA(a,b){a=Nb(a);x[a+20>>2]=0;x[a+12>>2]=0;x[a+16>>2]=0;Nb(a+24|0);Fb(a+36|0);x[a+48>>2]=b;return a}function jea(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;return _H(a,b,c,d,e,f,g,13061,1091)|0}function jY(a,b){v[a+6|0]=255;x[a+16>>2]=0;w[a+4>>1]=0;x[a>>2]=0;if(b>=0){C[a+8>>3]=b;x[a+16>>2]=3}return a}function cra(a,b){a=a|0;b=b|0;if(!YY(a,b)){v[b+4|0]=0;v[b+5|0]=0;v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0}}function cga(){var a=0;a=fb-16|0;fb=a;if($a(a+12|0,4)|0){It(x[31612],12726);p()}fb=a+16|0;return x[a+12>>2]}function Vl(a,b,c,d){a=a&65535;c=c&65535;a=(a|0)!=(c|0)?a>>>0<c>>>0?-1:1:0;if(Sj(a)){a=eU(b,d)}return Cd(a)}function AV(a,b){a=a|0;b=b|0;var c=0;c=Cb(x[a+4>>2],y[a+11|0]);if(c>>>0<b>>>0){Bs(a,b-c|0,0);return}BU(a,b)}function $L(a,b,c,d){B[d+4>>2]=a+c;a=E(a+E(c*E(-.5)));b=E(b*E(.8660253882408142));B[d+8>>2]=a-b;B[d>>2]=b+a}function XW(a,b){var c=0;c=b&255;b=c>>>24|0;a=a&255?1120:1056;c=a+(c<<8)|0;hb=a>>>0>c>>>0?b+1|0:b;return c}function Ou(a){var b=0,c=0;while(1){if(b>>>0>=8){a=c<<24>>24}else{b=b+15|0;c=Ho(a);continue}break}return a}function Lz(a,b){var c=0;c=Jb(a);if(c>>>0<=b>>>0){a=Cb(x[a+4>>2],y[a+11|0])+c>>>0>=b>>>0}else{a=0}return a}function Jw(a,b){a:{switch(b-1|0){default:return a+48|0;case 0:return a+68|0;case 1:break a}}return a+88|0}function zl(a){var b=0;b=x[a+12>>2];if((b|0)==x[a+16>>2]){return ib[x[x[a>>2]+36>>2]](a)|0}return x[b>>2]}function nI(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=a;a=0;return Hz(g|a,b,c,d,a|e,f)|0}function _I(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;x[e>>2]=c;x[h>>2]=f;return 3}function W$(a){return(y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))==1179468868&(y[a+4|0]-1&255)>>>0<10}function Rs(a,b,c,d,e,f){var g=0;g=b>>8;if(b&1){g=Mx(x[d>>2],g)}ib[x[x[a>>2]+24>>2]](a,c,d+g|0,b&2?e:2,f)}function RN(a,b){a=a|0;b=b|0;a=Kj(a);x[a+4>>2]=0;x[a>>2]=47680;x[a+4>>2]=x[b+4>>2];x[b+4>>2]=0;return a|0}function Oua(a){a=a|0;var b=0;b=x[a+76>>2];if(mc(-1,b)){b=nF(x[a+28>>2],32);x[a+76>>2]=b}return b<<24>>24}function Ob(a,b){var c=0;c=fb-16|0;fb=c;XF(c+8|0,a,b);a=Hb(x[x[c+8>>2]>>2],x[c+12>>2]);fb=c+16|0;return a}function sS(a,b){var c=0;c=x[a+4>>2];while(1){if((b|0)!=(c|0)){c=c-52|0;Bk(c);continue}break}x[a+4>>2]=b}function q0(a,b){a=wm(a,x[b>>2],x[b+4>>2]);x[a+8>>2]=x[b+8>>2];wm(a+12|0,x[b+12>>2],x[b+16>>2]);return a}function nda(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;return HO(x[a+4>>2],b,c,d,e,f,g)|0}function ll(a,b){var c=0;c=fb-16|0;fb=c;x[c+12>>2]=a;x[c+12>>2]=x[c+12>>2]-b;fb=c+16|0;return x[c+12>>2]}function kz(a,b,c){b=(D(D(iz(a),jz(a,b)),125)>>>0)/(gM(a,b)>>>0)|0;a=(a&6)==6?b&134217724:b;return a?a:c}function jda(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;return AO(x[a+4>>2],b,c,d,e,f,g)|0}function iU(a,b){var c=0;c=x[a+4>>2];while(1){if((b|0)!=(c|0)){c=c-12|0;tf(c);continue}break}x[a+4>>2]=b}function SE(a,b){var c=0;c=x[a+4>>2];while(1){if((b|0)!=(c|0)){c=c-20|0;ub(c);continue}break}x[a+4>>2]=b}function Pb(a,b,c){var d=0;c=c+x[a+4>>2]|0;d=b;b=x[a>>2]+b|0;c=d>>>0>b>>>0?c+1|0:c;x[a>>2]=b;x[a+4>>2]=c}function NT(a,b,c){var d=E(0);a:{if(b>c){break a}d=B[a>>2];if(!(d<b)){b=c;if(!(d>b)){break a}}B[a>>2]=b}}function KX(a){var b=0;a=a&15;b=0;a:{if(!a){break a}b=12-a|0;if(a>>>0<=12){break a}b=24-a|0}return b&255}function Fda(a){a=a|0;var b=0;b=fb-16|0;fb=b;ee(b+8|0,a);a=Rz(x[b+8>>2],x[b+12>>2]);fb=b+16|0;return a|0}function FW(a,b){var c=0;c=x[a+4>>2];while(1){if((b|0)!=(c|0)){c=c-12|0;uC(c);continue}break}x[a+4>>2]=b}function $U(a,b){var c=0;c=x[a+4>>2];while(1){if((b|0)!=(c|0)){c=c-32|0;Ek(c);continue}break}x[a+4>>2]=b}function vj(a){a:{a=a&74;if(a){if((a|0)==64){return 8}if((a|0)!=8){break a}return 16}return 0}return 10}function dv(a,b){b=Sua(a,a>>31,b,b>>31);a=hb;b=b+5e5|0;a=b>>>0<5e5?a+1|0:a;return Gc(Tua(b,a,1e6,0),hb)}function OT(a,b){var c=0,d=0;a:{if(b<0){break a}c=C[a>>3];if(!(c<0)){d=b;if(!(b<c)){break a}}C[a>>3]=d}}function DJ(a){var b=0,c=0;b=fb-16|0;fb=b;a=Nh(b+12|0,a);c=x[x[124243]>>2];Mh(a);fb=b+16|0;return c?4:1}function sp(a){a=a|0;var b=0,c=0;b=fb-16|0;fb=b;if(Sn(a,b+12|0)){c=$b(x[b+12>>2])}fb=b+16|0;return c|0}function Uk(a){a=a|0;var b=0,c=0;b=fb-16|0;fb=b;if(Ip(a,b+14|0)){c=Bb(z[b+14>>1])}fb=b+16|0;return c|0}function e_(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;d=c,e=Bb(b&65535),w[d+14>>1]=e;Rv(a,c+14|0);fb=c+16|0}function _v(a){var b=0,c=0;if(x[a>>2]){ep(a);Db(x[a>>2]);b=zb(a),c=0,x[b>>2]=c;x[a>>2]=0;x[a+4>>2]=0}}function Vv(a){a=a|0;var b=0;w[a+34>>1]=0;b=a+43|0;Vm(b,b+22|0,78832);x[a+20>>2]=0;ld(a,0);return a|0}function Rb(a,b,c){var d=0;if(c){d=a;while(1){v[d|0]=b;d=d+1|0;c=c-1|0;if(c){continue}break}}return a}function KV(a){if(((y[a+68|0]|y[a+69|0]<<8)-128&65535)>>>0>=65409){a=kd(a,18332,17)}else{a=1}return!a}function DS(a){a=Fb(a);Fb(a+12|0);Fb(a+24|0);Fb(a+36|0);Fb(a+48|0);Fc(a+60|0,0);x[a+64>>2]=0;return a}function tf(a){var b=0,c=0;b=fb-16|0;fb=b;a=x[vb(b+12|0,a)>>2];c=x[a>>2];if(c){zb(a);Db(c)}fb=b+16|0}function pia(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;a=Ej(a);if(a){ib[x[x[a>>2]+88>>2]](a,b,c,d,e)}}function g6(a,b,c){a=a|0;b=b|0;c=c|0;if(c>>>0<=127){a=(x[(c<<2)+112160>>2]&b)!=0}else{a=0}return a|0}function el(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0}function _9(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;U0(c+8|0,b);Ep(a,x[c+8>>2],x[c+12>>2]);fb=c+16|0}function ZD(a,b){if(b>>>0<=126){We(((b<<5)+a|0)+480280|0);Uo((D(b,872)+a|0)+1074992|0,a,b,67108864)}}function WH(a,b,c){var d=0;d=fb-16|0;fb=d;c=Dc(d+4|0,c);a=pc(a,c);tb(c);x[a>>2]=b;fb=d+16|0;return a}function MV(a){ie(a+140|0);ub(a+120|0);ub(a+100|0);ub(a+80|0);ub(a+60|0);ub(a+40|0);ub(a+20|0);ub(a)}function J1(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;Kn(c+8|0,b);Ep(a,x[c+8>>2],x[c+12>>2]);fb=c+16|0}function IZ(a,b){var c=0;c=x[a>>2];x[a>>2]=b;if(c){HZ(c+52|0);tb(c+40|0);vc(c+16|0);vc(c+4|0);Db(c)}}function I1(a,b){a=a|0;b=b|0;x[a>>2]=0;x[a+4>>2]=0;Fc(a+8|0,0);$r(a,127);MF(a,127,y[b|0]);return a|0}function Hqa(a){a=a|0;var b=0;b=fb-16|0;fb=b;a=Ip(a,b+14|0);fb=b+16|0;return(a?z[b+14>>1]:0)<<16>>16}function Hg(a,b,c){var d=0;d=x[a>>2];c=x[a+4>>2]-(c+(d>>>0<b>>>0)|0)|0;b=d-b|0;x[a>>2]=b;x[a+4>>2]=c}function DE(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0}function AS(a){x[a+20>>2]=0;v[a+16|0]=7;x[a+8>>2]=1889785610;x[a+12>>2]=1072630333;v[a|0]=3;return a}function lia(a,b,c){a=a|0;b=b|0;c=c|0;a=Ej(a);if(!a){return 0}return ib[x[x[a>>2]+104>>2]](a,b,c)|0}function lU(a,b,c){var d=0;d=fb-16|0;fb=d;a=vb(d+12|0,dU(b,c,ce(a),ec(a)));fb=d+16|0;return x[a>>2]}function iJ(a,b,c){a:{if(!(y[b+120|0]|c>>>0>30)){v[b+120|0]=1;break a}b=MY(c)}x[a+4>>2]=c;x[a>>2]=b}function ey(a,b,c,d,e){var f=0;f=fb-16|0;fb=f;e=Nh(f+12|0,e);a=xt(a,b,c,d);Mh(e);fb=f+16|0;return a}function ei(a,b,c){var d=0;d=x[a+4>>2];while(1){if((b|0)!=(d|0)){d=d-c|0;continue}break}x[a+4>>2]=b}function eS(a,b){if(b>>>0<=255){a=x[((b<<2)+a|0)+900380>>2];a=a?a+492|0:22303}else{a=22303}return a}function _c(a,b){var c=0;c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;x[a+8>>2]=x[b+8>>2];RG(b);return a}function Sda(a,b){a=a|0;b=b|0;var c=0;b=Jb(b);c=x[a+4>>2];if(c){ib[c|0](b,x[a+8>>2]);return}iu(b,a)}function IF(a,b,c,d,e,f,g){a=vb(a,b);vb(a+4|0,c);vb(a+8|0,d);vb(a+12|0,e);vb(a+16|0,f);vb(a+20|0,g)}function Gi(a,b,c,d,e){var f=0;f=fb-16|0;fb=f;e=Nh(f+12|0,e);a=DK(a,b,c,d);Mh(e);fb=f+16|0;return a}function Lw(a){a=a|0;var b=0;b=fb-16|0;fb=b;a=fh(a,b+15|0);fb=b+16|0;return(a?y[b+15|0]:0)<<24>>24}function xra(a){a=a|0;var b=0;b=fb-16|0;fb=b;a=Sn(a,b+12|0);fb=b+16|0;return E(a?B[b+12>>2]:E(0))}function vea(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return dI(a,b,c,d,e,f,10664,1081)|0}function mw(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;d=a;a=Dc(c+4|0,b);_c(d,a);tb(a);fb=c+16|0}function ig(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;d=a;a=tc(c+4|0,b);_c(d,a);tb(a);fb=c+16|0}function gfa(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return dI(a,b,c,d,e,f,10709,1054)|0}function ct(a,b){a=a|0;b=b|0;b=x[b+68>>2];v[a|0]=b;v[a+1|0]=b>>>8;v[a+2|0]=b>>>16;v[a+3|0]=b>>>24}function ZJ(a,b){a=a|0;b=b|0;b=x[b+64>>2];v[a|0]=b;v[a+1|0]=b>>>8;v[a+2|0]=b>>>16;v[a+3|0]=b>>>24}function TJ(a,b){a=a|0;b=b|0;b=x[b+72>>2];v[a|0]=b;v[a+1|0]=b>>>8;v[a+2|0]=b>>>16;v[a+3|0]=b>>>24}function Od(){var a=0;if(y[500420]){return x[125104]}a=xk(14337);v[500420]=1;x[125104]=a;return a}function AR(a,b){var c=0;c=fb-16|0;fb=c;a=we(c+8|0,a,b);b=x[a>>2];fb=c+16|0;hb=x[a+4>>2];return b}function pz(a,b,c,d){var e=0;e=fb-16|0;fb=e;bc(e+8|0,c,d);cN(a,b,x[e+8>>2],x[e+12>>2]);fb=e+16|0}function aA(a,b,c){b=b-a>>2;while(1){if((b|0)>0){x[a>>2]=x[c>>2];b=b-1|0;a=a+4|0;continue}break}}function Sm(a,b,c,d){var e=0;e=fb-16|0;fb=e;lf(e+8|0,c,d);cN(a,b,x[e+8>>2],x[e+12>>2]);fb=e+16|0}function MD(a,b){var c=0;c=fb-16|0;fb=c;x[c+12>>2]=a;a=J_(c+12|0,0-b|0);fb=c+16|0;return x[a>>2]}function Iua(a,b){a=a|0;b=b|0;if(!zE(a,b)){v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b|0]=0}}function F9(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;ib[x[x[a>>2]+24>>2]](a,b,c,d,e,f)|0}function E9(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;ib[x[x[a>>2]+16>>2]](a,b,c,d,e,f)|0}function D9(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;ib[x[x[a>>2]+28>>2]](a,b,c,d,e,f)|0}function C9(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;ib[x[x[a>>2]+20>>2]](a,b,c,d,e,f)|0}function B9(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;ib[x[x[a>>2]+44>>2]](a,b,c,d,e,f)|0}function vca(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;pP(a,x[b+4>>2],c,d,e,f,g)}function qca(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;KO(a,x[b+4>>2],c,d,e,f,g)}function o9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ib[x[x[b>>2]+16>>2]](a,b,x[c+8>>2],x[c+12>>2],0,d)}function jba(a){a=a|0;var b=0;b=fb-16|0;fb=b;a=yf(b+12|0,_l(Ec(12),a));fb=b+16|0;return x[a>>2]}function Xw(a,b){a=cG(a,x[b>>2],x[b+4>>2]);x[a+8>>2]=x[b+8>>2];cG(a+12|0,x[b+12>>2],x[b+16>>2])}function UX(a){var b=0,c=0;b=1;c=x[a>>2];a:{if((c|0)>0){b=120;if(c>>>0<121){break a}}x[a>>2]=b}}function Q2(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;d=c+4|0;WI(d,b);Sh(a,d);tb(d);fb=c+16|0}function L0(a,b){a=a|0;b=b|0;if(!zE(a,b)){v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0}}function I3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;if(mh(a,x[b+8>>2],f)){Px(b,c,d,e)}}function $ja(a,b){a=a|0;b=b|0;Ri(a);Ri(a);a:{if(b>>>0>=60){Vb(a,4);break a}Ri(a)}return Ri(a)|0}function mca(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;oP(a,x[x[b+4>>2]+24>>2],c,d,e,f)}function lca(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;JO(a,x[x[b+4>>2]+24>>2],c,d,e,f)}function aX(a){var b=0,c=0;b=fb-16|0;fb=b;if($E(a,b+12|0)){c=$b(x[b+12>>2])}fb=b+16|0;return c}function a0(a){var b=0;if(!(kd(a,24740,20)|(y[a+25|0]-9&255)>>>0<248)){b=v[a+47|0]>=0}return b}function Zd(a){a=a|0;var b=0;b=fb-16|0;fb=b;a=fh(a,b+15|0);fb=b+16|0;return(a?y[b+15|0]:0)&255}function R$(a,b){return(Yb((D(a>>>4|0,b)>>>0)/15|0,1,15)<<4|Yb((D(a&15,b)>>>0)/15|0,1,15))&255}function OL(a){var b=0;b=+((a&2097151)>>>0);return E(pk(+E((a|0)<0?-b:b),(a>>>21&1023)-788|0))}function JD(a){var b=0,c=0;b=fb-16|0;fb=b;if(Ip(a,b+14|0)){c=xe(w[b+14>>1])}fb=b+16|0;return c}function EK(a){var b=0;b=x[124243];if(a){x[124243]=(a|0)==-1?500228:a}return(b|0)==500228?-1:b}function pqa(a){a=a|0;var b=0,c=0;b=fb-32|0;fb=b;c=a;a=ai(b+12|0);DY(c,a,0,0);ub(a);fb=b+32|0}function pca(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return eu(x[x[a+4>>2]+24>>2],b,c,d,e)|0}function iZ(a){return(y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))==1279544644&y[a+4|0]<32}function Zs(a){a=a|0;var b=0;x[a>>2]=112108;b=x[a+8>>2];if(!(!b|!y[a+12|0])){Db(b)}return a|0}function Vm(a,b,c){b=b-a|0;while(1){if((b|0)>0){v[a|0]=y[c|0];b=b-1|0;a=a+1|0;continue}break}}function Um(a){a=a|0;var b=0;x[a>>2]=47700;b=x[a+4>>2];if(b){Db(zq(b))}x[a+4>>2]=0;return a|0}function Ic(a,b,c){var d=0;d=x[c+4>>2];if((d|0)==(b|0)){a=F_(a,b,x[c>>2],d)}else{a=1}return!a}function y9(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;return ib[x[x[a>>2]+32>>2]](a,b,c,d,e)|0}function uf(a,b){var c=0;c=fb-16|0;fb=c;x[c+12>>2]=a;a=XU(c+12|0,b);fb=c+16|0;return x[a>>2]}function qA(a){var b=0;b=fb-16|0;fb=b;x[b+12>>2]=a;HY(b+12|0,-1);fb=b+16|0;return x[b+12>>2]}function oE(a){var b=0;b=fb-16|0;fb=b;x[b+12>>2]=a;i0(b+12|0,-1);fb=b+16|0;return x[b+12>>2]}function fV(a,b){var c=0;c=fb-16|0;fb=c;x[c+12>>2]=a;a=eV(c+12|0,b);fb=c+16|0;return x[a>>2]}function OC(a){var b=0,c=0;c=a;while(1){b=c;c=b+4|0;if(x[b>>2]){continue}break}return b-a>>2}function z0(a){return(y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))==810369604&y[a+4|0]<4}function wJ(a,b){a=xd(a,b);v[a+12|0]=0;x[a+8>>2]=0;x[a>>2]=112108;x[a+8>>2]=112160;return a}function sB(a){var b=0;x[a+84>>2]=0;x[a+88>>2]=0;b=x[a+80>>2];x[a+92>>2]=b;x[a+96>>2]=b<<12}function qga(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;Gz(a,b,c,d,e,0,0,f,g)}function hh(a){var b=0;b=fb-16|0;fb=b;a=Ip(a,b+14|0);fb=b+16|0;return(a?z[b+14>>1]:0)&65535}function h5(a,b){a=a|0;b=b|0;a=xd(a,0);VI(a+8|0,b);x[a>>2]=117140;x[a>>2]=117424;return a|0}function gg(a){var b=0,c=0;while(1){c=b&65535;if(c>>>0<127){ZD(a,c);b=b+1|0;continue}break}}function fy(a,b,c){var d=0;d=fb-16|0;fb=d;c=Nh(d+12|0,c);a=Vy(a,b);Mh(c);fb=d+16|0;return a}function e5(a,b){a=a|0;b=b|0;a=xd(a,0);VI(a+8|0,b);x[a>>2]=117296;x[a>>2]=117540;return a|0}function UE(a){var b=0;b=x[a>>2];if(x[b>>2]){SE(b,x[b>>2]);a=x[a>>2];b=x[a>>2];TE(a);Db(b)}}function Rpa(a){a=a|0;var b=0;b=fb-16|0;fb=b;a=$h(a,b+8|0);fb=b+16|0;return+(a?C[b+8>>3]:0)}function ON(a,b,c,d,e){if(!((b|0)==(c|0)|(d|0)>=0)){v[b|0]=45;d=NN(d);b=b+1|0}UU(a,b,c,d,e)}function LD(a){var b=0;b=fb-16|0;fb=b;x[b+12>>2]=0;Au(b+12|0,a);fb=b+16|0;return x[b+12>>2]}function HF(a,b){if((a&4088)>>>0>=520){b=Ow(0-Vua(b^1230262859,25)|0,4)^1247037516}return b}function ria(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Ej(a);if(a){ib[x[x[a>>2]+76>>2]](a,b,c,d)}}function qia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Ej(a);if(a){ib[x[x[a>>2]+84>>2]](a,b,c,d)}}function pL(a){var b=0;b=x[a>>2];if(b){if(!mc(qL(b),-1)){return!x[a>>2]}x[a>>2]=0}return 1}function ox(a,b){a=a|0;b=b|0;b=b-1|0;if(b>>>0<=4){b=x[(b<<2)+22312>>2]}else{b=9758}tc(a,b)}function oia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Ej(a);if(a){ib[x[x[a>>2]+92>>2]](a,b,c,d)}}function cQ(a,b){var c=0;c=x[a+12>>2];if((c|0)>0){x[a+20>>2]=(x[a+16>>2]+(b+c|0)|0)%(c|0)}}function cG(a,b,c){var d=0;d=fb-16|0;fb=d;b=wm(d+8|0,b,c);GG(b,a);ke(b);fb=d+16|0;return a}function Fm(a,b,c){var d=E(0);if(b>>>0<=c>>>0){d=B[yb(a+4208|0,b)>>2]}else{d=E(0)}return d}function Dh(a){var b=0;if(a>>>0>=11){b=a+16&-16;a=b-1|0;a=(a|0)==11?b:a}else{a=10}return a}function vq(a){a=a|0;var b=0;x[a>>2]=47680;b=x[a+4>>2];if(b){Db(b);x[a+4>>2]=0}return a|0}function nx(){var a=0,b=0;a=fb-16|0;fb=a;b=yf(a+12|0,Nb(Ec(12)));fb=a+16|0;return x[b>>2]}function lA(a,b){if((a|0)>=0){return(a>>>0)%(b>>>0)|0}return(((a^-1)>>>0)%(b>>>0)^-1)+b|0}function is(a){var b=0;while(1){if(!mc(y[a|0],0)){a=a+1|0;b=b+1|0;continue}break}return b}function iF(a){var b=0;b=a&255;a=b>>>21|0;b=(b<<11)+2624|0;hb=b>>>0<2624?a+1|0:a;return b}function a3(a,b,c){a=a|0;b=b|0;c=c|0;ib[x[x[b>>2]+8>>2]](b,c);Ds(a,x[b+4>>2]);cH(b+4|0,c)}function Vua(a,b){var c=0,d=0;c=b&31;d=(-1>>>c&a)<<c;c=a;a=0-b&31;return d|(c&-1<<a)>>>a}
function Ll(a,b,c){a=a+1074992|0;return x[(a+D(b,872)|0)+680>>2]>x[(a+D(c,872)|0)+680>>2]}function J$(a,b,c){var d=0;d=fb-16|0;fb=d;wi(d+8|0,b,c);fb=d+16|0;return x[d+8>>2]==(a|0)}function GU(a,b,c){while(1){if((b|0)!=(c|0)){EU(a,y[b|0]);b=b+1|0;continue}break}return a}function Fy(a,b,c,d){var e=0;e=fb-16|0;fb=e;x[e+12>>2]=d;a=wt(a,b,c,d);fb=e+16|0;return a}function yn(a){var b=0;if(a>>>0>=2){b=SY(a+1|0);a=b-1|0;a=(a|0)==2?b:a}else{a=1}return a}function tia(a,b){a=a|0;b=b|0;a=Ej(a);if(!a){return 1}return ib[x[x[a>>2]+68>>2]](a,b)|0}function tJ(a,b){a=xd(a,b);x[a+8>>2]=46;x[a+12>>2]=44;x[a>>2]=113400;Fb(a+16|0);return a}function oJ(a,b){a=xd(a,b);b=a+8|0;x[b>>2]=121092;x[a>>2]=116076;x[b>>2]=116124;return a}function nJ(a,b){a=xd(a,b);b=a+8|0;x[b>>2]=121128;x[a>>2]=116340;x[b>>2]=116388;return a}function mn(a,b){var c=0;c=fb-16|0;fb=c;a=vb(c+12|0,(b<<1)+a|0);fb=c+16|0;return x[a>>2]}function jw(a,b){var c=0;c=fb-16|0;fb=c;a=vb(c+12|0,D(b,6)+a|0);fb=c+16|0;return x[a>>2]}function bT(a,b){var c=0;c=y[a+851|0];if(c&1){v[a+851|0]=c|64;x[a+852>>2]=x[a+852>>2]+b}}function _t(a){if(ZM(a)){a=ac(4);x[a>>2]=0;a=Kj(a);x[a>>2]=124572;da(a|0,124608,34);p()}}function WB(a,b){a=_l(a,b);_c(a+12|0,b+12|0);w[a+28>>1]=z[b+28>>1];x[a+24>>2]=x[b+24>>2]}function MX(a,b){var c=0;c=fb-16|0;fb=c;Kn(c+8|0,b);AZ(a,x[c+8>>2],x[c+12>>2]);fb=c+16|0}function Fx(a,b,c,d){var e=0;e=x[b>>2];x[a+8>>2]=b;x[a>>2]=e;x[a+4>>2]=(c<<d)+e;return a}function BS(a){var b=0;b=a+4e4|0;while(1){b=UA(b-160|0);if((b|0)!=(a|0)){continue}break}}function zD(a){var b=0;b=BV(a);while(1){if((a|0)!=(b|0)){o0(a);a=a+32|0;continue}break}}function ws(a,b,c,d){if(!((b|0)==(c|0)|(d|0)>=0)){v[b|0]=45;d=NN(d);b=b+1|0}KB(a,b,c,d)}function uea(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return cI(a,b,c,d,e,12449,1082)|0}function jL(a){var b=0;b=x[a>>2];if(b){if(!mo(zl(b))){return!x[a>>2]}x[a>>2]=0}return 1}function j2(a){a=a|0;var b=0;b=x[a+4>>2];return(ib[x[x[b>>2]+20>>2]](b)|0)+x[a+12>>2]|0}function hm(a,b,c){var d=0;d=fb-16|0;fb=d;v[d+15|0]=c;Vh(a,b,d+15|0);fb=d+16|0;return a}function ffa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return cI(a,b,c,d,e,12549,1055)|0}function bh(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;return a}function MK(a,b){var c=0;c=fb-16|0;fb=c;x[c+12>>2]=b;a=NK(a,11204,b);fb=c+16|0;return a}function Lv(a,b,c){var d=E(0);d=B[a>>2];if(!Kv(d,B[b>>2])){b=Kv(B[c>>2],d)?c:a}return b}function Jq(a,b,c){a=Pl(a)-x[a+16>>2]|0;if(a>>>0>=2){c=E(E(E(c-b)/E(a>>>0))+b)}return c}function DW(a,b,c){var d=0;d=x[b>>2];x[a+8>>2]=b;x[a>>2]=d;x[a+4>>2]=D(c,12)+d;return a}function Am(a){var b=0;b=hx(a+4|0);if((b|0)==-1){ib[x[x[a>>2]+8>>2]](a)}return(b|0)==-1}function zc(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=c+8|0;Kn(d,a);tm(d,b);fb=c+16|0;return a}function qea(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return ZH(a,b,c,d,e,9642,1085)|0}function iu(a,b){a=a|0;b=b|0;b=fb-16|0;fb=b;x[b>>2]=a;zP(18483,b);hu(125984);fb=b+16|0}function iea(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return ZH(a,b,c,d,e,9714,1092)|0}function PV(a){var b=0;b=a&255;a=b>>>27|0;b=(b<<5)+259|0;hb=b>>>0<259?a+1|0:a;return b}function P2(){var a=0;a:{if(ZG(20054022)){break a}if(YG()){break a}a=XG()^1}return a|0}function KU(a,b){return(a>>>0<=62?63-(D((b^-1)&63,(a?a+1|0:0)&255)>>>6|0)|b&192:b)&255}function HG(a,b){var c=0;c=fb-16|0;fb=c;b=Ef(c+8|0,b);GG(b,a);ke(b);fb=c+16|0;return a}function EE(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;v[c+15|0]=b;xw(a,c+15|0);fb=c+16|0}function A0(a,b,c){v[a+2|0]=1;b=b&15;if(c){b=y[b+24688|0]}else{b=(b<<2)+4|0}v[a+4|0]=b}function $5(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;ib[x[x[b>>2]+16>>2]](a,b,c,d,e,8)}function wv(a,b){a:{if(b){break a}if(a>>>0<=3){a=a|-16;break a}a=a>>>2|0}return a&255}function m8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return NH(b,c,d,e,f,1)|0}function kJ(a){var b=0;b=x[a>>2];if(x[b>>2]){Nf(b);a=x[a>>2];cy(hq(a),x[a>>2],Ug(a))}}function k8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return NH(b,c,d,e,f,0)|0}function c8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return LH(b,c,d,e,f,1)|0}function a8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return LH(b,c,d,e,f,0)|0}function Wg(a,b,c){var d=0;d=fb-16|0;fb=d;FY(d+8|0,a,b,c);fb=d+16|0;return x[d+12>>2]}function V5(a,b){a=a|0;b=b|0;if((b|0)>=0){b=x[((b&255)<<2)+97984>>2]}return b<<24>>24}function U9(a,b){a=a|0;b=b|0;a=z[a>>1];b=z[b>>1];return(a>>>0<b>>>0?-1:a>>>0>b>>>0)|0}function T9(a,b){a=a|0;b=b|0;a=x[a>>2];b=x[b>>2];return(a>>>0<b>>>0?-1:a>>>0>b>>>0)|0}function T5(a,b){a=a|0;b=b|0;if((b|0)>=0){b=x[((b&255)<<2)+96448>>2]}return b<<24>>24}function OJ(a,b){var c=0,d=0;Se(a,me(b));b=ec(b);c=ec(a),d=x[b>>2],x[c>>2]=d;return a}function Mu(a,b){if(!(v[b+851|0]&1&x[a+480180>>2]==8)){HA(a,b,0);HA(a,b,1);HA(a,b,2)}}function KK(a){return(a|0)!=0&(a|0)!=121532&(a|0)!=121556&(a|0)!=500144&(a|0)!=500168}function Iv(a,b){var c=0;c=fb-16|0;fb=c;w[c+14>>1]=b;Fv(a+236|0,128,c+14|0);fb=c+16|0}function tC(a,b){var c=0;c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;x[a+8>>2]=x[b+8>>2]}function oda(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return GO(x[a+4>>2],b,c,d,e)|0}function kf(a){a=a|0;var b=0;b=x[a>>2];return(ib[x[x[b>>2]+24>>2]](b)|0)-x[a+8>>2]|0}function kda(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return zO(x[a+4>>2],b,c,d,e)|0}function iW(a,b,c,d,e,f){a=vb(a,b);vb(a+4|0,c);vb(a+8|0,d);vb(a+12|0,e);vb(a+16|0,f)}function gy(a){a=a|0;x[a>>2]=113312;if(x[a+8>>2]!=(Od()|0)){ul(x[a+8>>2])}return a|0}function dk(a,b,c){var d=0;d=x[a>>2];if(!cr(d,x[b>>2])){b=cr(x[c>>2],d)?c:a}return b}function bga(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return xP(a,b,c,d,0,0,0,0,e)|0}function Yg(a,b,c){var d=0;d=C[a>>3];if(!LV(d,C[b>>3])){b=LV(C[c>>3],d)?c:a}return b}function Pg(a){var b=0;b=fb-16|0;fb=b;a=Sn(a,b+12|0);fb=b+16|0;return a?x[b+12>>2]:0}function Ho(a){var b=0;b=a;a=x[a>>2];x[b>>2]=D(a,214013)+2531011;return a>>>16&32767}function He(a,b,c){if(vp(a,b,c)){a=gj(a,c);a=Ib(x[a>>2],x[a+4>>2])}else{a=0}return a}function G4(a,b,c){a=a|0;b=b|0;c=c|0;a=Tx(b,x[a+8>>2]);return((a|0)==-1?c:a)<<24>>24}function wW(a){var b=0;b=x[a>>2];if(x[b>>2]){$V(b);a=x[a>>2];b=x[a>>2];hv(a);Db(b)}}function oR(a){var b=0;b=x[a>>2];if(x[b>>2]){Nf(b);a=x[a>>2];b=x[a>>2];Ug(a);Db(b)}}function nq(a){a=a|0;x[a+56>>2]=94224;x[a>>2]=94204;Et(a+4|0);Bl(a+56|0);return a|0}function k0(a,b,c){a=a|0;b=b|0;c=c|0;return j0(a,b,Jb(c),Cb(x[c+4>>2],y[c+11|0]))|0}function jz(a,b){return y[(D(a>>>1&3,15)+D(a>>>3&1,45)+((b&240)>>>4)|0)+81185|0]<<1}function i7(a){a=a|0;iq(x[a+8>>2]);a=x[a+8>>2];if(!a){return 1}return(DJ(a)|0)==1|0}function gm(a,b){var c=0,d=0,e=0;c=x[a+24>>2];d=a,e=Ze(Di(b)*+(c>>>0)),x[d+24>>2]=e}function gha(a){a=a|0;v[a+4202|0]=1;x[a+4256>>2]=x[x[a+16>>2]+24620>>2];fQ(a);eQ(a)}function ge(a){var b=0;b=fb-16|0;fb=b;x[b+12>>2]=48664;Ac(a,48560,b+12|0);fb=b+16|0}function gU(a){var b=0;b=x[a>>2];x[a>>2]=0;if(b){if(y[ec(a)+4|0]){hU(b+16|0)}Db(b)}}function Wk(a,b){var c=0;c=fb-16|0;fb=c;a=vb(c+12|0,a+b|0);fb=c+16|0;return x[a>>2]}function TA(a){var b=0;b=fb-16|0;fb=b;vb(b+12|0,a+116|0);a=rS(a);fb=b+16|0;return a}function QF(a){var b=0;b=x[a>>2];if(x[b>>2]){kj(b);a=x[a>>2];b=x[a>>2];Nn(a);Db(b)}}function N$(a){var b=0;b=x[a>>2];if(x[b>>2]){M$(b);a=x[a>>2];b=x[a>>2];cw(a);Db(b)}}function LR(a){var b=0;b=x[a>>2];x[a>>2]=0;if(b){if(y[ec(a)+4|0]){Eb(b+16|0)}Db(b)}}function KG(a){var b=0;b=x[a>>2];if(x[b>>2]){JG(b);a=x[a>>2];b=x[a>>2];Xn(a);Db(b)}}function Gia(a){a=a|0;v[a+4202|0]=1;x[a+4232>>2]=x[x[a+16>>2]+24620>>2];qu(a);KQ(a)}function Ff(a){a=a|0;x[a+60>>2]=94388;x[a>>2]=94368;Et(a+8|0);Bl(a+60|0);return a|0}function Ef(a,b){x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];x[b>>2]=0;x[b+4>>2]=0;return a}function EZ(a){var b=0;b=x[a>>2];x[a>>2]=0;if(b){if(y[ec(a)+4|0]){Wj(b+16|0)}Db(b)}}function uT(a,b){var c=0;c=b&15;if(c){v[a+830|0]=c}b=b&240;if(b){v[a+829|0]=b>>>4}}function iv(a,b){a=Bb(a&65535);b=Bb(b&65535);return(a|0)!=(b|0)?a>>>0<b>>>0?-1:1:0}function a7(){var a=0,b=0,c=0;a=xd(501792,1);x[a>>2]=113312;b=a,c=Od(),x[b+8>>2]=c}function _p(a,b,c,d){x[a>>2]=b;b=x[b+4>>2];x[a+4>>2]=b;x[a+8>>2]=b+(c<<d);return a}function Yp(a,b,c,d){x[a>>2]=b;b=x[b+4>>2];x[a+4>>2]=b;x[a+8>>2]=b+D(c,d);return a}function RL(a,b){b=x[a+32>>2]+b|0;x[a+32>>2]=b;if(b>>>0>=A[a+40>>2]){x[a+96>>2]=1}}function zP(a,b){var c=0;c=fb-16|0;fb=c;x[c+12>>2]=b;DL(125984,a,b,0,0);fb=c+16|0}function yC(a,b,c){var d=0;d=x[b>>2];x[a+8>>2]=b;x[a>>2]=d;x[a+4>>2]=c+d;return a}function rg(a){var b=0;b=fb-16|0;fb=b;a=vb(b+12|0,ec(a));fb=b+16|0;return x[a>>2]}function gda(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return gI(a,b,c,d,e,1122)|0}function bR(a,b,c){while(1){if(b){B[a>>2]=B[c>>2];b=b-1|0;a=a+4|0;continue}break}}function _i(a){var b=0;b=fb-16|0;fb=b;a=vb(b+12|0,wb(a));fb=b+16|0;return x[a>>2]}function Rf(a){var b=0;b=fb-16|0;fb=b;a=vb(b+12|0,rg(a));fb=b+16|0;return x[a>>2]}function QV(a){if((y[a+14|0]-53&255)>>>0>=252){a=kd(a,15655,14)}else{a=1}return!a}function Pda(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return Ms(a,b,c,d,e,1107)|0}function Oda(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return Ms(a,b,c,d,e,1109)|0}function Ns(a,b,c,d){if(b>>>0>=d>>>0){Zj();p()}c=Ec(D(b,c));x[a+4>>2]=b;x[a>>2]=c}function Nda(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return Ms(a,b,c,d,e,1111)|0}function KF(a,b,c){while(1){if(b){x[a>>2]=x[c>>2];b=b-1|0;a=a+4|0;continue}break}}function Fv(a,b,c){while(1){if(b){w[a>>1]=z[c>>1];b=b-1|0;a=a+2|0;continue}break}}function $o(a,b){a=yc(a,b,34);w[a+34>>1]=z[b+34>>1];yc(a+36|0,b+36|0,68);return a}function wP(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return gI(a,b,c,d,e,1001)|0}function qO(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return Ls(a,b,c,d,e,1106)|0}function nO(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return Ls(a,b,c,d,e,1108)|0}function n3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=ib[a|0](b,c,d)|0;gb=hb;return a|0}function mO(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return Ls(a,b,c,d,e,1110)|0}function lO(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return Ls(a,b,c,d,e,1026)|0}function dO(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return Hx(a,b,c,d,e,1107)|0}function cO(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return Is(a,b,c,d,e,1107)|0}function bO(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return Hx(a,b,c,d,e,1109)|0}function aO(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return Is(a,b,c,d,e,1109)|0}function ZN(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return Is(a,b,c,d,e,1111)|0}function Sk(a,b){var c=0;c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;ic(a+8|0,b+8|0)}function Kfa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return Ms(a,b,c,d,e,1e3)|0}function BM(a){a=Un(a);x[a>>2]=77884;Nb(a+4|0);v[a+20|0]=0;x[a+16>>2]=0;return a}function $X(a){var b=0;while(1){if((b|0)!=512){eh(a+b|0);b=b+1|0;continue}break}}function $N(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return Hx(a,b,c,d,e,1111)|0}function zi(a){return(mk(x[a>>2],x[a+4>>2])|0)!=(0-mk(x[a+12>>2],x[a+16>>2])|0)}function ysa(a,b,c){a=a|0;b=b|0;c=c|0;_c(a,zZ(b,Jb(c),Cb(x[c+4>>2],y[c+11|0])))}function w6(a){a=a|0;if(!y[500672]){Bn(500660,113628);v[500672]=1}return 500660}function v6(a){a=a|0;if(!y[500704]){Bn(500692,113712);v[500704]=1}return 500692}function u6(a){a=a|0;if(!y[500608]){Bn(500596,113556);v[500608]=1}return 500596}function u$(a,b,c){while(1){if(b){v[a|0]=y[c|0];b=b-1|0;a=a+1|0;continue}break}}function t6(a){a=a|0;if(!y[500640]){Bn(500628,113592);v[500640]=1}return 500628}function qg(a){var b=0,c=0;sc(a+4|0);Fc(a+8|0,0);b=a,c=ec(a),x[b>>2]=c;return a}function q3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;ib[a|0](b,c,d,e,f)}function paa(a){a=a|0;a=x[a+24>>2];return sM(x[(x[x[a>>2]-12>>2]+a|0)+16>>2])^1}function kK(){var a=0;a=fb-16|0;x[a+8>>2]=0;x[a+12>>2]=1048576;return C[a+8>>3]}function iS(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=c+4|0;HC(d,1,b);Cc(a,d);fb=c+16|0}function eg(a){var b=0;b=xb(a,2);return y[xb(a,1)|0]<<8|y[b|0]<<16|y[xb(a,0)|0]}function YN(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return Is(a,b,c,d,e,1e3)|0}function Ub(a){var b=0;if(Cd(y[a+11|0])){b=x[a>>2];ej(x[a+8>>2]);Db(b)}return a}function Sba(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=+e;return vN(a-88|0,b,c,d,e)|0}function Jf(a,b,c){if((c|0)>=0){a=(x[((c&255)<<2)+a>>2]&b)!=0}else{a=0}return a}function Id(a,b,c){var d=0;d=fb-16|0;fb=d;x[d+12>>2]=c;vn(a,b,d+12|0);fb=d+16|0}function Gx(a,b,c,d){if(b>>>0>=d>>>0){Zj();p()}c=Ec(b<<c);x[a+4>>2]=b;x[a>>2]=c}function GH(a,b){x[a>>2]=b;Ub(a+52|0);Ub(a+40|0);Ub(a+28|0);tb(a+16|0);return a}function FH(a,b){x[a>>2]=b;tb(a+48|0);tb(a+36|0);tb(a+24|0);tb(a+12|0);return a}function EU(a,b){var c=0;c=a;a=x[a>>2];x[c>>2]=a<<8^x[((a>>>24^b)<<2)+27612>>2]}function Bx(a,b){b=a+b|0;while(1){b=tb(b-12|0);if((b|0)!=(a|0)){continue}break}}function tw(a,b){return Ze(Di((+(a|0)*128+ +(b|0))*.0006510416666666666)*8363)}function p6(a){a=a|0;if(!y[500656]){Dc(500644,13633);v[500656]=1}return 500644}function m6(a){a=a|0;if(!y[500624]){Dc(500612,13827);v[500624]=1}return 500612}function lD(a){var b=0;while(1){if((b|0)!=4){eh(a+b|0);b=b+1|0;continue}break}}function k3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return ib[a|0](b,c,d,e)|0}function f$(a,b){a=a|0;b=b|0;if(x[a+4>>2]!=x[zb(a)>>2]){pM(a,b);return}lM(a,b)}function _o(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0}function X3(a,b,c){a=a|0;b=b|0;c=c|0;if(!y[502240]){v[502240]=1}gc(a,c,126428)}function W4(a,b){a=a|0;b=b|0;a=Kj(a);x[a>>2]=125100;Sx(a+4|0,Jb(b));return a|0}function Uw(a,b){var c=0;if((b|0)<0){Zj();p()}c=Ec(b<<1);x[a+4>>2]=b;x[a>>2]=c}function Rca(a,b){a=a|0;b=b|0;a=x[a+4>>2];return PO(x[a+24>>2],B[a+48>>2],b)|0}function CA(a,b){a=a|0;b=b|0;if(x[a+4>>2]!=x[zb(a)>>2]){jS(a,b);return}sA(a,b)}function zj(a,b,c){if(x[a+80>>2]){x[a+92>>2]=x[a+92>>2]+(c+7&-8);return}Db(b)}function ze(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=c+8|0;Pw(d,a);tm(d,b);fb=c+16|0}function xB(a){var b=0;if(!(y[a+2|0]|(y[a|0]|y[a+1|0]))){b=!y[a+3|0]}return b}function wb(a){var b=0;b=fb-16|0;fb=b;a=vb(b+12|0,a);fb=b+16|0;return x[a>>2]}function uJ(a,b){a=xd(a,b);w[a+8>>1]=11310;x[a>>2]=113360;Fb(a+12|0);return a}function sf(a){if(Cd(y[a+11|0])){fd(x[a>>2],0);Yd(a,0);return}fd(a,0);Me(a,0)}function pea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return _n(a,b,c,d,12950,1086)|0}function om(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=c+8|0;U0(d,a);tm(d,b);fb=c+16|0}function o6(a){a=a|0;if(!y[500688]){Dc(500676,9269);v[500688]=1}return 500676}function nea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return _n(a,b,c,d,13024,1088)|0}function n6(a){a=a|0;if(!y[500592]){Dc(500580,5265);v[500592]=1}return 500580}function lS(a,b){a=a|0;b=b|0;if(A[a+4>>2]<A[zb(a)>>2]){jS(a,b);return}sA(a,b)}function iha(a,b){a=a|0;b=b|0;return E(b>>>0<=4?B[((b<<2)+a|0)+4220>>2]:E(0))}function hA(a,b){if((a|0)>=0){return(a|0)%(b|0)|0}return((a^-1)%(b|0)^-1)+b|0}function gA(a,b){if((a|0)>=0){return(a|0)/(b|0)|0}return((a+1|0)/(b|0)|0)-1|0}function _T(a){x[a>>2]=0;x[a+4>>2]=0;x[a>>2]=-2078137563;x[a+4>>2]=-873292572}function Xj(a){var b=0;b=fb-16|0;fb=b;a=yf(b+12|0,a);fb=b+16|0;return x[a>>2]}function Ru(a,b){var c=0;c=a;a=(b>>>0)/1e6|0;return AB(Ul(c,a),D(a,-1e6)+b|0)}function N3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if(mh(a,x[b+8>>2],0)){Nx(b,c,d)}}function Gj(a){if(Ob(a+1074312|0,7)){a=En(x[a+480180>>2])^1}else{a=0}return a}function Cba(a,b){a=a|0;b=b|0;xp(x[a+4>>2]);nG(sG(x[a+4>>2],b));xp(x[a+4>>2])}function CB(a,b){var c=0;c=a;a=(b>>>0)/100|0;return Ul(Ul(c,a),D(a,-100)+b|0)}function AB(a,b){var c=0;c=a;a=(b>>>0)/1e4|0;return CB(Ul(c,a),D(a,-1e4)+b|0)}function tea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return _n(a,b,c,d,9436,1083)|0}function rK(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ib[x[x[a>>2]+32>>2]](a,b,c,d)|0}function oea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return _n(a,b,c,d,9597,1087)|0}function nK(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ib[x[x[a>>2]+48>>2]](a,b,c,d)|0}function lea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return _n(a,b,c,d,9675,1089)|0}function kea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return _n(a,b,c,d,9467,1090)|0}function gL(a,b,c,d,e,f,g,h){return ib[x[x[a>>2]+16>>2]](a,b,c,d,e,f,g,h)|0}
function fe(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=x[b+8>>2];Vb(b,c);kx(a,b,d,c)}function _e(a){var b=0;b=fb-16|0;fb=b;Rn(b+8|0,a);fb=b+16|0;return x[b+8>>2]}function ZS(a,b,c){var d=0;return!b|!(y[a+35|0]&4?!a|(c|0)!=1:1)?d:y[b+34|0]}function wQ(a){a=a|0;x[a>>2]=44796;vc(a+4276|0);vc(a+4264|0);return ag(a)|0}function rC(a,b){return(+(a>>>0)+ +(b|0)*4294967296)*2.3283064365386963e-10}function o8(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return OH(b,c,d,e,1)|0}function lda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return BO(x[a+4>>2],b,c,d)|0}
function l8(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return OH(b,c,d,e,0)|0}function h_(a){var b=0;while(1){b=a;a=x[a>>2];if(a){continue}break}return b}function h9(a,b,c){a=a|0;b=b|0;c=c|0;if((c|0)!=1){dL(a,c);return}Dc(a,7920)}function gM(a,b){a=a^-1;return x[(b&12)+81188>>2]>>>(a>>>3&1)>>>(a>>>4&1)|0}function e8(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return MH(b,c,d,e,1)|0}function c6(a,b){a=a|0;b=b|0;if(b>>>0<=127){b=x[(b<<2)+97984>>2]}return b|0}function b8(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return MH(b,c,d,e,0)|0}function a6(a,b){a=a|0;b=b|0;if(b>>>0<=127){b=x[(b<<2)+96448>>2]}return b|0}function Gh(a,b){var c=0;c=a;a=x[a+8>>2];b=a-b|0;x[c+8>>2]=a>>>0>=b>>>0?b:0}function CU(a,b){b=1/(1/(b*6.283185307179586/3546895)+1);uU(a,b,0,0,b+-1,0)}function $l(a,b,c){x[a>>2]=b;b=x[b+4>>2];x[a+4>>2]=b;x[a+8>>2]=b+c;return a}function zG(a,b){a=a|0;b=b|0;a=Kj(a);x[a>>2]=125100;Sx(a+4|0,b);return a|0}function uda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return FO(x[a+4>>2],b,c,d)|0}function tda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return DO(x[a+4>>2],b,c,d)|0}function rda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return EO(x[a+4>>2],b,c,d)|0}function qda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return CO(x[a+4>>2],b,c,d)|0}function pda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return IO(x[a+4>>2],b,c,d)|0}function gi(a,b,c){x[a+8>>2]=b;x[a+12>>2]=c;x[a>>2]=0;x[a+4>>2]=0;return a}function fia(a,b){a=a|0;b=b|0;a=x[a+20>>2];v[a+24|0]=y[a+24|0]&253|(b?2:0)}function _3(a,b,c){a=a|0;b=b|0;c=c|0;return mc(a,x[b+4>>2])&x[b>>2]==(c|0)}function Hk(a){var b=0;b=z[a+172>>1];a=z[a+156>>1];return(NV(a)?b:a)&65535}function yj(a,b,c){a=a|0;b=b|0;c=c|0;return ib[x[x[a>>2]+12>>2]](a,b,c)|0}function yG(a,b){a=Ef(a,b);x[a+8>>2]=x[b+8>>2];Ef(a+12|0,b+12|0);return a}function vz(a,b){var c=0,d=0;c=vb(a,x[x[b>>2]-12>>2]+b|0),d=b,x[c+4>>2]=d}function vc(a){var b=0;b=fb-16|0;fb=b;oR(vb(b+12|0,a));fb=b+16|0;return a}function sG(a,b){a=a|0;b=b|0;return BF(a,Jb(b),Cb(x[b+4>>2],y[b+11|0]))|0}function rp(a,b,c){a=a|0;b=b|0;c=c|0;return ib[x[x[a>>2]+48>>2]](a,b,c)|0}function kY(a,b){v[a+6|0]=255;x[a+16>>2]=b;w[a+4>>1]=0;x[a>>2]=0;return a}function hd(a,b){a=HG(a,b);x[a+8>>2]=x[b+8>>2];HG(a+12|0,b+12|0);return a}function dc(a){var b=0;b=fb-16|0;fb=b;TZ(vb(b+12|0,a));fb=b+16|0;return a}function Xc(a,b,c,d,e){v[a+3|0]=e;v[a+2|0]=d;v[a+1|0]=c;v[a|0]=b;return a}function Tra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=c,e=Ap(a,b),x[d>>2]=e}function Sra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=c,e=Kw(a,b),w[d>>1]=e}function Mb(a,b,c){a=a|0;b=b|0;c=c|0;return ib[x[x[a>>2]+32>>2]](a,b,c)|0}function Jb(a){var b=0,c=0,d=0;return b=x[a>>2],c=a,d=Cd(y[a+11|0]),d?b:c}function JF(a,b){while(1){if(b){x[a>>2]=0;b=b-1|0;a=a+4|0;continue}break}}function xL(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;gi(a,-1,-1)}function Qm(a,b){v[a|0]=b;v[a+1|0]=b>>>8;v[a+2|0]=b>>>16;v[a+3|0]=b>>>24}function Iy(a,b){var c=0;c=Qt(a+4|0);x[a>>2]=95016;x[c>>2]=95036;so(c,b)}function Hy(a,b){var c=0;c=XK(a+4|0);x[a>>2]=95384;x[c>>2]=95404;so(c,b)}function rQ(a){a=a|0;return E(E(E(B[yb(a+4208|0,5)>>2]*E(198))+E(-99)))}function qc(a,b){var c=0,d=0;x[a>>2]=b;c=a,d=Cf(b),x[c+4>>2]=d;return a}function fq(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;x[e>>2]=c;return 3}function fda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return UH(a,b,c,d,1001)|0}function dda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return UH(a,b,c,d,1122)|0}function dE(a,b,c){var d=0;d=(b|0)/(c|0)|0;x[a>>2]=d;x[a+4>>2]=b-D(c,d)}function SU(a,b){x[a+4>>2]=0;x[a+8>>2]=0;x[a>>2]=b?b:49716;x[a+12>>2]=0}function Mda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Js(a,b,c,d,1113)|0}function Mc(a){if(Cd(y[a+11|0])){a=ej(x[a+8>>2])-1|0}else{a=10}return a}function LU(a){if(a>>>0<=8){return y[a+27600|0]}return y[a+27591|0]|256}function Kda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Js(a,b,c,d,1115)|0}function K$(a,b,c){a=a&255;return a>>>0>=(b&255)>>>0&a>>>0<=(c&255)>>>0}function Jda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Js(a,b,c,d,1117)|0}function JK(a,b,c){var d=0;d=c;c=Cf(b);if(d>>>0>c>>>0){tO(a,b)}return c}function Ida(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Js(a,b,c,d,1119)|0}function F3(a){a=a|0;if(!a){return 0}return(gB(a,124656,124800)|0)!=0|0}function EN(a){a=a|0;return+(+A[x[a+32>>2]+480240>>2]*152587890625e-16)}function Aua(a){a=a|0;x[a+16>>2]=x[a+16>>2]|1;if(v[a+20|0]&1){ua();p()}}function $y(a){return((Ph(a)+(Ph(a)<<8)|0)+(Ph(a)<<16)|0)+(Ph(a)<<24)|0}function $oa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;lH(a,b,c,d,e,134)}function zn(a){if(Cd(y[a+11|0])){a=ej(x[a+8>>2])-1|0}else{a=1}return a}function vsa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;lH(a,b,c,d,e,92)}function tt(a){return a>>>0<32|a-127>>>0<33|(a&-2)==8232|a-65529>>>0<3}function qD(a,b){if(b){qD(a,x[b>>2]);qD(a,x[b+4>>2]);Wj(b+16|0);Db(b)}}function pD(a,b){if(b){pD(a,x[b>>2]);pD(a,x[b+4>>2]);Wj(b+16|0);Db(b)}}function kv(a,b){a=a&255;b=b&255;return(a|0)!=(b|0)?a>>>0<b>>>0?-1:1:0}function kO(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Ks(a,b,c,d,1112)|0}function jO(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Ks(a,b,c,d,1114)|0}function iO(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Ks(a,b,c,d,1116)|0}function iB(a,b){x[a>>2]=x[b>>2];w[a+4>>1]=z[b+4>>1];v[a+6|0]=y[b+6|0]}function hs(a){x[a>>2]=0;x[a+4>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;return a}function hi(a,b){a=a|0;b=b|0;v[a|0]=2;v[a+1|0]=3;v[a+2|0]=0;v[a+3|0]=4}function gO(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Ks(a,b,c,d,1118)|0}function Zj(){var a=0;a=An(ac(4));x[a>>2]=124984;da(a|0,125060,34);p()}function XN(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Hs(a,b,c,d,1113)|0}function WN(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Hs(a,b,c,d,1115)|0}function VN(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Hs(a,b,c,d,1117)|0}function UN(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Hs(a,b,c,d,1119)|0}function Sqa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Jx(a,b,c,d,587)|0}function Qq(a,b){if(b){Qq(a,x[b>>2]);Qq(a,x[b+4>>2]);hU(b+16|0);Db(b)}}function Ox(a,b,c){if(!(x[a+28>>2]==1|x[a+4>>2]!=(b|0))){x[a+28>>2]=c}}function DB(a,b){if(b){DB(a,x[b>>2]);DB(a,x[b+4>>2]);en(b+16|0);Db(b)}}function AA(a,b){if(b){AA(a,x[b>>2]);AA(a,x[b+4>>2]);Eb(b+16|0);Db(b)}}function $B(a,b){a=Nb(a);Fb(a+12|0);w[a+28>>1]=0;x[a+24>>2]=b;return a}function qq(a){if(y[a+2|0]&2){a=(y[a+1|0]&6)==6?4:1}else{a=0}return a}function pS(a,b,c,d,e){x[a+12>>2]=e;x[a+8>>2]=d;x[a+4>>2]=c;x[a>>2]=b}function o3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;ib[a|0](b,c,d,e)}function nU(a,b,c){if(He(a,b,c)){a=x[Wb(a,c)+12>>2]}else{a=1}return a}function m$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Jx(a,b,c,d,340)|0}function lx(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Jx(a,b,c,d,164)|0}function jW(a,b,c,d,e){a=vb(a,b);vb(a+4|0,c);vb(a+8|0,d);vb(a+12|0,e)}function eN(a,b){var c=0;c=x[a>>2];x[a>>2]=b;if(c){xo(c+120|0);Db(c)}}function by(a){a=a|0;if(x[a+8>>2]!=(Od()|0)){ul(x[a+8>>2])}return a|0}function TZ(a){var b=0;b=x[a>>2];if(x[b>>2]){ep(b);Db(x[x[a>>2]>>2])}}function o7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;lg(a,f)}function n7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;jq(a,f)}function l3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return ib[a|0](b,c,d)|0}function XY(a,b){x[a>>2]=x[b>>2];w[a+4>>1]=z[b+4>>1];ic(a+8|0,b+8|0)}function I8(a){a=a|0;var b=0;b=x[125112]+1|0;x[125112]=b;x[a+4>>2]=b}function kI(a,b,c,d,e,f,g){return Ja(a|0,b|0,c|0,d|0,e|0,f|0,g|0)|0}function hZ(a){v[a+4|0]=0;v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0}function aT(a,b){x[a+852>>2]=x[a+852>>2]+b;v[a+851|0]=y[a+851|0]|64}function _r(a,b){return Nw(x[b>>2],x[b+4>>2],x[a>>2],x[a+4>>2])?b:a}function Wr(a,b,c){if(Zc(a,b)>>>0<=c>>>0){Ew();p()}return(c<<1)+a|0}function Oc(a,b,c){if(oc(a,b)>>>0<=c>>>0){Ew();p()}return(c<<2)+a|0}function Kk(a,b,c){var d=0;d=fb-16|0;fb=d;FY(d+8|0,a,b,c);fb=d+16|0}function J0(a,b){return gq(x[b>>2],x[b+4>>2],x[a>>2],x[a+4>>2])?b:a}function Im(a,b){return b?a<<24|(a&65280)<<8|(a>>>8&65280|a>>>24):a}function FO(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return YH(a,b,c,d,4)|0}function EO(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return YH(a,b,c,d,2)|0}function DO(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return XH(a,b,c,d,4)|0}function CO(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return XH(a,b,c,d,2)|0}function yga(a,b,c){a=a|0;b=b|0;c=c|0;return nj(a,b,c,981,86224)|0}function sg(a,b){a=a|0;b=b|0;var c=0;c=Ec(b);x[a+4>>2]=b;x[a>>2]=c}function oV(a,b){var c=0,d=0;c=vb(a,x[b>>2]),d=y[b+4|0],v[c+4|0]=d}function nd(a){a=(a|0)>=32767?32767:a;return(a|0)<=-32768?-32768:a}function cy(a,b,c){a:{if((a|0)==(b|0)){v[b+120|0]=0;break a}Db(b)}}function Y5(a,b,c){a=a|0;b=b|0;c=c|0;return(b>>>0<128?b:c)<<24>>24}function Wda(a,b){a=a|0;b=b|0;if(!x[31737]){x[31737]=a;x[31738]=b}}function V4(a,b){a=a|0;b=b|0;a=XI(a,b,1);x[a>>2]=121260;return a|0}function Uj(a,b){a=a|0;b=b|0;var c=0;c=MY(b);x[a+4>>2]=b;x[a>>2]=c}function A4(a,b){a=a|0;b=b|0;a=YI(a,b,1);x[a>>2]=121164;return a|0}function up(a,b){x[a>>2]=x[(x[x[b>>2]-12>>2]+b|0)+24>>2];return a}function uo(a,b){if(A[a+4>>2]<A[zb(a)>>2]){pM(a,b);return}lM(a,b)}function uk(a,b){a=a|0;b=b|0;return ib[x[x[a>>2]+52>>2]](a,b,0)|0}function tha(a,b,c){a=a|0;b=b|0;c=c|0;return nj(a,b,c,974,4276)|0}function qta(a,b){a=a|0;b=b|0;a=Xv(a,b);x[a>>2]=125256;return a|0}function mha(a,b,c){a=a|0;b=b|0;c=c|0;return nj(a,b,c,975,4268)|0}function mI(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return uO(a,b,c,d)|0}function k2(a){a=a|0;a=x[a+4>>2];return ib[x[x[a>>2]+16>>2]](a)|0}function ak(a,b){if(Lg(x[a>>2],x[a+4>>2])>>>0>b>>>0){v[a+16|0]=b}}function Zga(a,b,c){a=a|0;b=b|0;c=c|0;return nj(a,b,c,977,4228)|0}function Xha(a,b,c){a=a|0;b=b|0;c=c|0;return nj(a,b,c,970,4236)|0}function Vs(a){a=a|0;x[a>>2]=113192;ul(x[a+16>>2]);return Zs(a)|0}function Uia(a,b,c){a=a|0;b=b|0;c=c|0;return nj(a,b,c,946,4268)|0}function Qp(a,b,c){a=Ef(a,b);x[a+8>>2]=0;Ef(a+12|0,c);ke(c);ke(b)}function Pga(a,b,c){a=a|0;b=b|0;c=c|0;return nj(a,b,c,978,5048)|0}function Nla(a,b){a=a|0;b=b|0;a=Xv(a,b);x[a>>2]=125308;return a|0}function JL(a,b){a=HL(a-1|0);if(!a){a=HL(b);a=a?a+32|0:0}return a}function Fga(a,b,c){a=a|0;b=b|0;c=c|0;return nj(a,b,c,980,4276)|0}function Dha(a,b,c){a=a|0;b=b|0;c=c|0;return nj(a,b,c,973,4280)|0}function DY(a,b,c,d){a=Ge(a,b);w[a+22>>1]=d;w[a+20>>1]=c;return a}function Cm(a,b){a=a|0;b=b|0;return ib[x[x[a>>2]+32>>2]](a,0,b)|0}function Cia(a,b,c){a=a|0;b=b|0;c=c|0;return nj(a,b,c,954,4304)|0}function CN(a){a=a|0;return+(+x[x[a+32>>2]+1074456>>2]*.00390625)}function Bh(a,b,c){a=vb(a,b);j_(a+4|0,x[c>>2],x[c+4>>2]);return a}function zY(a){var b=0;b=fb-16|0;fb=b;tY(vb(b+12|0,a));fb=b+16|0}function y_(a,b){a=a|0;b=b|0;a=Xv(a,b);x[a>>2]=125120;return a|0}function xW(a){var b=0;b=fb-16|0;fb=b;mW(vb(b+12|0,a));fb=b+16|0}function uca(a,b){a=a|0;b=b|0;return E(lP(x[x[a+4>>2]+24>>2],b))}function tz(a){var b=0;b=fb-16|0;fb=b;lN(vb(b+12|0,a));fb=b+16|0}function tca(a,b){a=a|0;b=b|0;return E(kP(x[x[a+4>>2]+24>>2],b))}function sca(a,b){a=a|0;b=b|0;return E(hP(x[x[a+4>>2]+24>>2],b))}function sW(a){var b=0;b=fb-16|0;fb=b;fW(vb(b+12|0,a));fb=b+16|0}function pn(a){var b=0;b=fb-16|0;fb=b;wW(vb(b+12|0,a));fb=b+16|0}function oga(a,b){a=a|0;b=b|0;if(!b){return 3}x[b>>2]=a;return 0}function oca(a,b){a=a|0;b=b|0;return E(jP(x[x[a+4>>2]+24>>2],b))}function nca(a,b){a=a|0;b=b|0;return E(iP(x[x[a+4>>2]+24>>2],b))}function md(a){var b=0;b=fb-16|0;fb=b;QF(vb(b+12|0,a));fb=b+16|0}function l2(a){a=a|0;a=x[a+4>>2];return ib[x[x[a>>2]+8>>2]](a)|0}function iq(a){var b=0;b=fb-16|0;fb=b;Mh(Nh(b+12|0,a));fb=b+16|0}function hr(a,b,c){a=Bb(a&65535);return(a|0)>=(b|0)&(a|0)<=(c|0)}function gq(a,b,c,d){return a>>>0<c>>>0&(b|0)<=(d|0)|(b|0)<(d|0)}function dy(a){var b=0;b=fb-16|0;fb=b;kJ(vb(b+12|0,a));fb=b+16|0}function YP(a){return E(E(B[yb(a+4208|0,11)>>2]*E(19980))+E(20))}function YA(a){tb(a+48|0);tb(a+36|0);tb(a+24|0);tb(a+12|0);tb(a)}function Td(a){var b=0;b=fb-16|0;fb=b;VH(vb(b+12|0,a));fb=b+16|0}function Qk(a){var b=0;b=fb-16|0;fb=b;N$(vb(b+12|0,a));fb=b+16|0}function Qc(a){var b=0;b=fb-16|0;fb=b;UE(vb(b+12|0,a));fb=b+16|0}function MW(a){var b=0;b=fb-16|0;fb=b;GW(vb(b+12|0,a));fb=b+16|0}function EG(a,b,c){a=Un(a);x[a+8>>2]=c;x[a+4>>2]=b;x[a>>2]=78736}function Ae(a){var b=0;b=fb-16|0;fb=b;KG(vb(b+12|0,a));fb=b+16|0}function zx(a){var b=0;b=fb-16|0;B[b+12>>2]=a;return B[b+12>>2]}function yy(a,b){a=a|0;b=b|0;return ib[x[x[a>>2]+12>>2]](a,b)|0}function rm(a,b){a=a|0;b=b|0;return ib[x[x[a>>2]+28>>2]](a,b)|0}function g7(a){a=a|0;a=x[a+8>>2];if(!a){return 1}return DJ(a)|0}function fla(a,b){a=a|0;b=b|0;a=eZ(a,b);if(!a){dZ(b)}return a|0}function bu(a,b){var c=0;c=G(a)+32|0;a=G(b);return(a|0)==32?c:a}function ZP(a){return E(E(B[yb(a+4208|0,0)>>2]*E(1e4))+E(-1e4))}function Uc(a){var b=0;b=x[a>>2];x[a>>2]=0;if(b){ru(b)}return a}function Re(a,b,c,d){x[a+8>>2]=d;x[a+4>>2]=c;x[a>>2]=b;return a}function Qs(a){var b=0;b=fb-16|0;C[b+8>>3]=a;return C[b+8>>3]*a}function Osa(a,b){a=a|0;b=b|0;a=g_(a,b);if(!a){f_(b)}return a|0}function Nw(a,b,c,d){return(b|0)==(d|0)&a>>>0<c>>>0|b>>>0<d>>>0}function Fo(a,b,c,d){a=kv(a,c);if(Sj(a)){a=eU(b,d)}return Cd(a)}function Bg(a){var b=0;b=ir(Cf(a)+1|0,1);if(b){tO(b,a)}return b}function At(a,b){a=a|0;b=b|0;return ib[x[x[a>>2]+44>>2]](a,b)|0}function Aca(a,b){a=a|0;b=b|0;return QO(x[x[a+4>>2]+24>>2],b)|0}function yD(a,b){a=a|0;b=b|0;a=qZ(a,b);if(!a){mD(b)}return a|0}function ss(a,b){a=a|0;b=b|0;a=jG(a,b);if(!a){qx(b)}return a|0}function sl(a){return wb(Jb(a)+(Cb(x[a+4>>2],y[a+11|0])<<2)|0)}function sda(a,b,c){a=a|0;b=b|0;c=c|0;return+yO(x[a+4>>2],b,c)}function pQ(a){a=a|0;return Gk(E(B[yb(a+4208|0,4)>>2]*E(4)))|0}function m0(a,b){if(!b){return-1}b=yq(a,b,0);return b?b-a|0:-1}function lp(a,b){a=a|0;b=b|0;a=s$(a,b);if(!a){w$(b)}return a|0}function kh(a,b){return ib[x[x[a>>2]+32>>2]](a,x[a+12>>2],b)|0}function fha(a,b,c){a=a|0;b=b|0;c=c|0;return Ix(a,b,c,0,976)|0}function fX(a){return y[a+15|0]<<12|y[a+14|0]<<4|y[a+13|0]<<20}function fS(a,b){return b>>>0>=4e3?22303:((b<<5)+a|0)+946304|0}function ds(a,b){var c=0;c=b+1|0;x[a>>2]=x[a>>2]>(c|0)?c:b+2|0}function bx(a,b){a=_c(a,b);ic(a+12|0,b+12|0);qe(a+32|0,b+32|0)}function aS(a,b,c,d){w[a+4>>1]=c;v[a+6|0]=b;x[a>>2]=d;return a}function _ga(a,b,c){a=a|0;b=b|0;c=c|0;return Ix(a,b,c,1,976)|0}function Zw(a,b){a=a|0;b=b|0;a=aG(a,b);if(!a){gs(b)}return a|0}function Ur(a,b){a=a|0;b=b|0;a=Sn(a,b);if(!a){Hn(b)}return a|0}function Sp(a,b){a=a|0;b=b|0;a=gx(a,b);if(!a){fx(b)}return a|0}function QT(a,b){a=a|0;b=b|0;a=O$(a,b);if(!a){Jr(b)}return a|0}function Nha(a,b,c){a=a|0;b=b|0;c=c|0;return Ix(a,b,c,0,972)|0}function N0(a,b){a=a|0;b=b|0;a=yE(a,b);if(!a){DE(b)}return a|0}function G7(a,b){a=a|0;b=b|0;_S(a,Qy(x[b>>2])<<24>>24,x[b>>2])}function FS(a,b,c,d){w[a>>1]=b;v[a+2|0]=y[c|0];v[a+3|0]=y[d|0]}function Er(a,b){a=a|0;b=b|0;a=t$(a,b);if(!a){aw(b)}return a|0}function Bi(a,b){a=a|0;b=b|0;a=$h(a,b);if(!a){el(b)}return a|0}function yba(a,b){a=a|0;b=b|0;x[a>>2]=x[b>>2];lg(a+4|0,b+4|0)}function xM(a,b){a=(a+b|0)-1|0;return a-((a>>>0)%(b>>>0)|0)|0}function wm(a,b,c){x[a+4>>2]=c;x[a>>2]=b;if(c){fl(c)}return a}function vI(a,b){var c=0;c=a;a=x[a>>2]+b|0;x[c>>2]=a;return a}function uka(a){a=a|0;a=Xv(a,22303);x[a>>2]=125200;return a|0}function uS(a,b){var c=0;c=x[a>>2];x[a>>2]=b;if(c){Db(Nl(c))}}function p$(a){return(y[a+47|0]+y[a+45|0]|0)+(y[a+46|0]<<5)|0}function ota(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;nH(a,b,c,d,364)}function mia(a){a=a|0;a=Ej(a);if(a){ib[x[x[a>>2]+100>>2]](a)}}function dsa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;nH(a,b,c,d,475)}function dm(a){var b=0;b=x[a>>2];x[a>>2]=0;if(b){ec(a);Db(b)}}function MY(a){if(a>>>0>=1073741824){Zj();p()}return Ec(a<<2)}function LG(a,b){var c=0;c=x[a>>2];x[a>>2]=b;if(c){Db(dc(c))}}function Eha(a){a=a|0;return E(E(B[yb(a+4208|0,6)>>2]*E(20)))}function $ta(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;uH(a,b,c,d,134)}function $b(a){return a<<24|(a&65280)<<8|(a>>>8&65280|a>>>24)}function zI(a){a=a|0;x[a>>2]=112044;ul(x[a+8>>2]);return a|0}function ym(a){a=FG(a,0);x[a+8>>2]=0;x[a>>2]=121400;return a}function yS(a){x[a>>2]=0;Nb(a+4|0);Rb(a+16|0,0,144);return a}function xj(a){var b=0;o(+a);b=j(1)|0;j(0)|0;return b>>>20|0}function qQ(a){a=a|0;return E(E(B[yb(a+4208|0,2)>>2]*E(10)))}function ih(a,b,c,d){hb=b-((a>>>0<c>>>0)+d|0)|0;return a-c|0}function fsa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;uH(a,b,c,d,92)}function c2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;bc(a,x[d>>2],0)}function Yz(a){a=a|0;x[a+32>>2]=0;x[a+28>>2]=x[a+28>>2]&-7|2}function Ys(a){a=a|0;x[a>>2]=113244;ul(x[a+8>>2]);return a|0}function Xv(a,b){a=Kj(a);x[a>>2]=125080;Sx(a+4|0,b);return a}function Tb(a,b){var c=0;c=x[a>>2];x[a>>2]=x[b>>2];x[b>>2]=c}function RR(a,b){var c=0;c=z[a>>1];w[a>>1]=z[b>>1];w[b>>1]=c}function HL(a){var b=0,c=0,d=0;return b=Rua(a),c=0,d=a,d?b:c}function GN(a){a=a|0;return+(65536/+A[x[a+32>>2]+480244>>2])}function Et(a){a=a|0;x[a>>2]=93688;tb(a+32|0);return no(a)|0}function BY(a){var b=0;b=x[a+100>>2];x[a+100>>2]=0;return b}
function AI(a){a=a|0;x[a>>2]=112076;ul(x[a+8>>2]);return a|0}function $ga(a){a=a|0;return E(E(B[yb(a+4208|0,6)>>2]*E(4)))}function yqa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;jH(a,b,c,d,3)}function yq(a,b,c){if(!b){return 0}return fu(a,c<<24>>24,b)}function xA(a,b,c){C[a>>3]=C[a>>3]+b;C[a+8>>3]=C[a+8>>3]+c}
function uM(a,b){a=Un(a);x[a+4>>2]=b;x[a>>2]=77420;return a}function tba(a){a=a|0;Iz(a,2,100);ak(x[a+24>>2]+484360|0,0)}function sz(a,b,c,d,e,f){return RH(a,b,c,d,e,f,73668,74464)}function rz(a,b,c,d,e,f){return RH(a,b,c,d,e,f,74544,75308)}function pC(a,b){if(b){pC(a,x[b>>2]);pC(a,x[b+4>>2]);Db(b)}}function p3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ib[a|0](b,c,d)}function oC(a,b){if(b){oC(a,x[b>>2]);oC(a,x[b+4>>2]);Db(b)}}function nN(a,b){a=a|0;b=+b;TH(a,b,1e4,1074420,9379,512,32)}function hx(a){var b=0;b=a;a=x[a>>2]-1|0;x[b>>2]=a;return a}function hT(a){var b=0;b=x[a>>2];x[a>>2]=0;if(b){Db(jB(b))}}function gka(a,b,c){a=a|0;b=b|0;c=c|0;return kH(a,b,c,63)|0}function fw(a,b,c){a=a|0;b=b|0;c=c|0;return yH(a,b,c,323)|0}function cqa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;jH(a,b,c,d,2)}function cF(a){return!kd(a,14245,3)&(y[a+3|0]-10&255)>>>0<5}function bD(a,b){if(b){bD(a,x[b>>2]);bD(a,x[b+4>>2]);Db(b)}}function b6(a,b,c){a=a|0;b=b|0;c=c|0;return KH(b,c,97984)|0}function _w(a,b){return QS(a,Jb(b),Cb(x[b+4>>2],y[b+11|0]))}function _5(a,b,c){a=a|0;b=b|0;c=c|0;return KH(b,c,96448)|0}function Xy(a,b){return Jt(a,Jb(b),Cb(x[b+4>>2],y[b+11|0]))}function VM(a,b){a=a|0;b=b|0;return Vj(x[b>>2],x[b+4>>2])|0}function UM(a,b){a=a|0;b=b|0;return Sd(x[b>>2],x[b+4>>2])|0}function U5(a,b,c){a=a|0;b=b|0;c=c|0;return JH(b,c,97984)|0}function Ts(a,b){var c=0,d=0;c=a,d=xk(b),x[c>>2]=d;return a}function S5(a,b,c){a=a|0;b=b|0;c=c|0;return JH(b,c,96448)|0}function Nh(a,b){var c=0,d=0;c=a,d=EK(b),x[c>>2]=d;return a}function N1(a){a=a|0;a=BG(a,13438);x[a>>2]=24508;return a|0}function Lu(a,b){if(b){Lu(a,x[b>>2]);Lu(a,x[b+4>>2]);Db(b)}}function Ku(a,b){if(b){Ku(a,x[b>>2]);Ku(a,x[b+4>>2]);Db(b)}}function H0(a,b,c){a=a|0;b=b|0;c=c|0;return yH(a,b,c,263)|0}function Gr(a){return x[a+20>>2]+(x[a+8>>2]-x[a+24>>2]|0)|0}function Fba(a,b,c){a=a|0;b=b|0;c=c|0;_c(a,j0(c,0,b,Cf(b)))}function El(a){var b=0;b=x[a>>2];x[a>>2]=0;if(b){Db(nf(b))}}function ED(a,b){if(b){ED(a,x[b>>2]);ED(a,x[b+4>>2]);Db(b)}}function DD(a,b){if(b){DD(a,x[b>>2]);DD(a,x[b+4>>2]);Db(b)}}function Bo(a,b){return(((a<<12&b>>31)+b|0)/4096|0)%(a|0)|0}function BZ(a){if(xn(-1,a)^1){a=xn(a,0)^1}else{a=0}return a}function z2(a){a=a|0;a=BG(a,8720);x[a>>2]=28916;return a|0}function wz(a){return(Jb(a)+Cb(x[a+4>>2],y[a+11|0])|0)-1|0}function lI(a,b,c){b=La(1011,a|0,b|0,c|0)|0;hb=gb;return b}function ko(a,b,c,d){x[a+16>>2]=d;x[a+12>>2]=c;x[a+8>>2]=b}function fp(a){var b=0;b=x[a>>2];x[b>>2]=x[b>>2]|x[a+4>>2]}function e9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;hb=0;return 0}function d4(a){a=a|0;a=y_(a,7956);x[a>>2]=40312;return a|0}function XO(a){return Oj(Xb(x[a+484360>>2],y[a+484376|0]))}function Q5(a,b,c){a=a|0;b=b|0;c=c|0;return((b|0)<0?c:b)|0}function Ep(a,b,c){a=a|0;b=b|0;c=c|0;si(a,b,Li(b,b+c|0,0))}function yea(a,b){a=a|0;b=b|0;return $n(a,b,11959,1076)|0}function wea(a,b){a=a|0;b=b|0;return $n(a,b,11927,1077)|0}function ng(a,b){if(Cd(y[a+11|0])){Yd(a,b);return}Me(a,b)}function jd(a,b,c,d){return Wc(a,D(z[b+480188>>1],c)+d|0)}function h0(a,b){v[a|0]=y[b|0];v[a+1|0]=y[b+1|0];return a}function ez(a,b){return x[((a>>>24^b)<<2)+495840>>2]^a<<8}function efa(a,b){a=a|0;b=b|0;return $n(a,b,11895,1056)|0}function dN(a,b){var c=0;c=x[a>>2];x[a>>2]=b;if(c){ru(c)}}function ay(a){a=a|0;x[a>>2]=113400;tb(a+16|0);return a|0}function _f(a){var b=0;oQ(a);b=x[a>>2];if(b){Uz(a);Db(b)}}function Xo(a){x[a>>2]=0;x[a+4>>2]=0;Fc(a+8|0,0);return a}function WL(a){while(1){if((Pt(a)|0)!=-1){continue}break}}function SA(a,b){var c=0;c=x[a>>2];x[a>>2]=b;if(c){Db(c)}}function Qra(a,b,c){a=a|0;b=b|0;c=c|0;si(a,b,Vc(b,c)+b|0)}function Pea(a,b){a=a|0;b=b|0;return $n(a,b,11798,1063)|0}function Oq(a){return((a-65&255)>>>0<26?a+32|0:a)<<24>>24}function Oea(a,b){a=a|0;b=b|0;return fI(a,b,13410,1064)|0}function My(a,b,c){x[a+28>>2]=c;x[a+20>>2]=b;x[a+24>>2]=b}function LF(a,b){var c=0;c=Ec(b<<2);x[a+4>>2]=b;x[a>>2]=c}function Gea(a,b){a=a|0;b=b|0;return $n(a,b,11833,1071)|0}function Gc(a,b){return BH(a,b,2147483647,-2147483648,-1)}function Eea(a,b){a=a|0;b=b|0;return $n(a,b,11863,1073)|0}function Df(a){return wb(Jb(a)+Cb(x[a+4>>2],y[a+11|0])|0)}function DN(a,b){a=a|0;b=+b;TH(a,b,256,1074456,11768,1,0)}function AK(a,b,c){a=a|0;b=b|0;c=c|0;Gu(a,b,c);return a|0}function $x(a){a=a|0;x[a>>2]=113360;tb(a+12|0);return a|0}function yla(a,b,c){a=a|0;b=b|0;c=c|0;return Mb(a,b,c)|0}function wL(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;gi(a,-1,-1)}function tg(a,b){var c=0;c=y[a|0];v[a|0]=y[b|0];v[b|0]=c}function jx(a){a=a|0;x[a>>2]=125100;rI(a+4|0);return a|0}function iC(a,b){Tb(a,b);Tb(a+4|0,b+4|0);Tb(zb(a),zb(b))}function eT(a,b){a=dT(a,b);dT(a+12|0,b+12|0);v[a+24|0]=1}function cH(a,b){fl(x[b>>2]);Am(x[a>>2]);x[a>>2]=x[b>>2]}function bha(a){a=a|0;return B[yb(a+4208|0,1)>>2]<E(1)|0}function aga(a,b){a=a|0;b=b|0;return fI(a,b,6432,1004)|0}function Z_(a){a=a|0;x[a>>2]=125080;rI(a+4|0);return a|0}function W9(a,b,c){a=a|0;b=b|0;c=c|0;return Ed(D(b,c))|0}function UD(a,b){v[x[a>>2]]=y[b|0];v[x[a+4>>2]]=y[b+1|0]}function Sga(a){a=a|0;dQ(a);v[a+4202|0]=1;x[a+4224>>2]=0}function Qh(a,b,c){v[a|0]=y[a|0]|b;x[a+4>>2]=x[a+4>>2]|c}function PB(a,b){C[a>>3]=C[a>>3]*b;C[a+8>>3]=C[a+8>>3]*b}function Hv(a){vc(a+88|0);vc(a+68|0);vc(a+48|0);return a}function Hn(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0}function Gha(a){a=a|0;return B[yb(a+4208|0,3)>>2]<E(1)|0}function Aj(a){return gf(a)|gf(a)<<8|gf(a)<<16|gf(a)<<24}function A2(a,b,c){a=a|0;b=b|0;c=c|0;kx(a,b,x[b+8>>2],c)}function zda(a,b,c){a=a|0;b=b|0;c=c|0;Iz(x[a+4>>2],b,c)}function xG(a){a=a|0;x[a>>2]=41616;ke(a+4|0);return a|0}function vn(a,b,c){x[a>>2]=b;x[a+4>>2]=x[c>>2];return a}function rI(a){a=il(x[a>>2]);if((hx(a+8|0)|0)<0){Db(a)}}function qM(a){a=a|0;x[a>>2]=78272;dc(a+8|0);return a|0}function no(a){a=a|0;x[a>>2]=93560;Zb(a+4|0);return a|0}function jg(a,b,c,d,e){return Na(a|0,b|0,c|0,d|0,e|0)|0}function jJ(a){var b=0;b=x[a>>2];x[a>>2]=0;if(b){Am(b)}}function fM(a,b,c){x[a+4>>2]=0;x[a>>2]=b;x[a+8>>2]=c<<3}function _ka(a,b,c){a=a|0;b=b|0;c=c|0;dH(a,b,c,838,837)}function _ca(a,b,c){a=a|0;b=b|0;c=c|0;ZO(a,x[b+4>>2],c)}function ZT(a){var b=0;b=x[a>>2];x[a>>2]=0;if(b){Db(b)}}function Yt(a){a=a|0;x[a>>2]=48748;tz(a+4|0);return a|0}function Wn(a){var b=0;b=x[a+8>>2];x[a+8>>2]=0;return b}function WO(a){return Xu(x[a+484344>>2],x[a+484348>>2])}function Uka(a,b,c){a=a|0;b=b|0;c=c|0;iI(a,b,c,842,843)}function Oja(a,b,c){a=a|0;b=b|0;c=c|0;dH(a,b,c,914,913)}function Nb(a){x[a>>2]=0;x[a+4>>2]=0;sc(a+8|0);return a}function Kd(a,b,c){return a>>>0<b>>>0?b:a>>>0<c>>>0?a:c}function KD(a){a=a&255;return Sc(a)^1|(a-49&255)>>>0<36}function ER(a){return(a|0)==1179012417|(a|0)==538987841}function Ct(a){a=a|0;x[a>>2]=93624;Zb(a+4|0);return a|0}function BK(a,b,c){a=vb(a,b);vb(a+4|0,x[c>>2]);return a}function AM(a){a=a|0;x[a>>2]=77884;dc(a+4|0);return a|0}function z7(a,b){a=a|0;b=b|0;gc(a,iL(x[b>>2]),x[b>>2])}function yda(a,b){a=a|0;b=b|0;wO(x[x[a+4>>2]+24>>2],b)}function xd(a,b){a=FG(a,b-1|0);x[a>>2]=113768;return a}function usa(a,b){a=a|0;b=b|0;Lh(a,b,416,1042,-1332,2)}function tL(a){a=a|0;return Gt(x[x[a>>2]-12>>2]+a|0)|0}function rh(a,b){a=a|0;b=b|0;ib[x[x[b>>2]+20>>2]](a,b)}function nL(a){a=a|0;return Dt(x[x[a>>2]-12>>2]+a|0)|0}function mua(a,b){a=a|0;b=b|0;Lh(a,b,296,1058,-1332,2)}function m9(a){a=a|0;return nq(x[x[a>>2]-12>>2]+a|0)|0}function ki(a,b){a=a|0;b=b|0;ib[x[x[b>>2]+24>>2]](a,b)}function k9(a){a=a|0;return Ff(x[x[a>>2]-12>>2]+a|0)|0}function ji(a,b){a=a|0;b=b|0;ib[x[x[b>>2]+28>>2]](a,b)}function iz(a){return(a&6)==6?384:1152>>>((a&14)==2)|0}function epa(a,b){a=a|0;b=b|0;Lh(a,b,261,1042,-1332,2)}function eU(a,b){return(a|0)!=(b|0)?a>>>0<b>>>0?-1:1:0}function Yb(a,b,c){return(a|0)<(b|0)?b:(a|0)<(c|0)?a:c}function Qna(a,b){a=a|0;b=b|0;if(!NX(a,b)){Rb(b,0,40)}}function Pra(a,b){a=a|0;b=b|0;return Dc(a,b?b:22303)|0}function Pha(a,b,c){a=a|0;b=b|0;c=c|0;gc(a,b+4228|0,7)}function Ph(a){var b=0;b=Pt(a);x[a+1396>>2]=0;return b}function O8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;si(a,c,d)}function Lua(a,b){a=a|0;b=b|0;Lh(a,b,261,1025,-1284,2)}function L8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ho(a,c,d)}function Jm(a,b){x[a+16>>2]=!x[a+24>>2]|(x[a+16>>2]|b)}function Jaa(a,b){a=a|0;b=b|0;PT(x[a>>2],b);return a|0}function Ica(a,b){a=a|0;b=b|0;return SO(x[a+4>>2],b)|0}function IR(a,b){return D(b&65535,a&65535)+7>>>3&65535}function Hna(a,b){a=a|0;b=b|0;Lh(a,b,588,1058,-1332,3)}function G6(){xd(502024,1);hJ(502032);x[125506]=117140}function Eia(a,b,c){a=a|0;b=b|0;c=c|0;gc(a,b+4260|0,8)}function E6(){xd(502040,1);hJ(502048);x[125510]=117296}function yR(a,b){return(b>>>0>15?63:v[a+b|0])<<24>>24}function yK(a,b,c){a=CK(a,b,c,0,-2147483648);return a}function xR(a,b){return(b>>>0>46?63:v[a+b|0])<<24>>24}function w4(a,b){a=a|0;b=b|0;return xl(b&255)<<24>>24}function uj(a){a=a|0;return ib[x[x[a>>2]+16>>2]](a)|0}function u4(a,b){a=a|0;b=b|0;return yt(b&255)<<24>>24}function tj(a){a=a|0;return ib[x[x[a>>2]+12>>2]](a)|0}function tc(a,b){a=a|0;b=b|0;fG(a,b,is(b));return a|0}function tb(a){if(Cd(y[a+11|0])){Db(x[a>>2])}return a}function sea(a,b){a=a|0;b=b|0;Lh(a,b,80,1025,-1284,4)}function rl(a,b){return ib[x[x[a>>2]+36>>2]](a,b,0)|0}function rca(a){a=a|0;return eP(x[x[a+4>>2]+24>>2])|0}function qs(a,b){a=ic(a,b);Rb(a+20|0,0,1040);return a}function kia(a){a=a|0;v[a+4202|0]=1;nu(a);Xz(a);EQ(a)}function jB(a){Lq(a+223860|0);dc(a+223848|0);return a}function hg(a,b,c,d){b=b+d|0;hb=a+c>>>0<c>>>0?b+1|0:b}function gea(a,b){a=a|0;b=b|0;Lh(a,b,13,1025,-1284,2)}function cf(a,b,c,d){v[a+8|0]=d;x[a+4>>2]=c;x[a>>2]=b}function bf(a,b,c,d){bc(a,jd(b,c,d,0),z[c+480188>>1])}function aE(a,b){a=Ge(a,b);Rb(a+20|0,0,1040);return a}function _N(a,b){hb=0-(((a|0)!=0)+b|0)|0;return 0-a|0}function _C(a,b){a=a|0;b=b|0;Lh(a,b,588,1058,-1332,2)}function Zca(a){a=a|0;return XO(x[x[a+4>>2]+24>>2])|0}function Xra(a,b){a=a|0;b=b|0;Lh(a,b,80,1042,-1332,2)}function Xca(a){a=a|0;return dP(x[x[a+4>>2]+24>>2])|0}function Wqa(a,b,c){a=a|0;b=b|0;c=c|0;_c(a,k0(c,0,b))}function Wca(a){a=a|0;return wq(x[x[a+4>>2]+24>>2])|0}function Uca(a){a=a|0;return Ao(x[x[a+4>>2]+24>>2])|0}function Tca(a){a=a|0;return WO(x[x[a+4>>2]+24>>2])|0}function Qda(a,b){a=a|0;b=b|0;Lh(a,b,81,1025,-1284,2)}function Qca(a){a=a|0;return OO(x[x[a+4>>2]+24>>2])|0}function Pp(a,b,c){x[a+4>>2]=c;x[a>>2]=b;if(c){fl(c)}}function Mca(a){a=a|0;return gP(x[x[a+4>>2]+24>>2])|0}function Lca(a){a=a|0;return cP(x[x[a+4>>2]+24>>2])|0}function Kh(a){a=a|0;return ib[x[x[a>>2]+24>>2]](a)|0}function Kca(a){a=a|0;return bP(x[x[a+4>>2]+24>>2])|0}function K2(a,b,c){a=a|0;b=b|0;c=c|0;iI(a,b,c,75,148)}function I4(a,b){a=a|0;b=b|0;return JI(b,x[a+8>>2])|0}function Dv(a,b){a=a|0;b=b|0;Lh(a,b,589,1058,-1332,2)}function Dca(a){a=a|0;return xq(x[x[a+4>>2]+24>>2])|0}function Dc(a,b){a=a|0;b=b|0;Gu(a,b,Cf(b));return a|0}function DQ(a){vc(a+36|0);vc(a+24|0);mu(a+12|0);mu(a)}function AT(a,b,c,d){return ed(Ko(a,b,c,d,0)-32768|0)}function $da(a,b){a=a|0;b=b|0;Lh(a,b,80,1025,-1284,2)}function xu(a){a=a|0;a=ai(a);x[a+20>>2]=0;return a|0}function pG(a,b,c,d){return Zp(a,b,c,d,36,119304648)}function f5(a,b){a=a|0;b=b|0;Lh(a,b,13,1058,-1332,2)}function eo(a,b,c,d){return(a|0)==(c|0)&(b|0)==(d|0)}function ee(a,b){gc(a,Jb(b),Cb(x[b+4>>2],y[b+11|0]))}function de(a,b,c){v[a|0]=b;v[a+1|0]=y[c|0];return a}function d0(a,b,c,d){return Zp(a,b,c,d,28,153391690)}function cC(a){a=Nb(a);x[a+12>>2]=0;w[a+16>>1]=65280}function aha(a){a=a|0;return E(B[yb(a+4208|0,3)>>2])}function Yw(a){a=a|0;return ib[x[x[a>>2]+8>>2]](a)|0}function Wba(a,b,c){a=a|0;b=b|0;c=c|0;zN(a-88|0,b,c)}function WF(a,b){return(y[b+34|0]&8)>>>3&(a&2050)==2}function Uba(a,b,c){a=a|0;b=b|0;c=c|0;xN(a-88|0,b,c)}function SJ(a,b,c,d){return Zp(a,b,c,d,24,178956971)}function Rua(a){if(a){return 31-G(a-1^a)|0}return 32}function Rr(a,b,c){if(b){qP(a+36|0,b,Li(b,b+c|0,0))}}function QX(a){var b=0;a=a+8|0;hb=a>>>0<8|b;return a}function Ps(a,b,c,d,e,f){Ka(a|0,b|0,c|0,d|0,e|0,f|0)}function LQ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0}function Fha(a){a=a|0;return E(B[yb(a+4208|0,1)>>2])}function FG(a,b){x[a+4>>2]=b;x[a>>2]=124552;return a}function F$(a,b,c,d){return Zp(a,b,c,d,40,107374183)}function Eda(a){a=a|0;return Rz(x[a>>2],x[a+4>>2])|0}function Cr(a,b,c,d,e){gc(a,b+d|0,(e|0)==-1?c-d|0:e)}function zU(a,b){x[a+8>>2]=0;x[a+12>>2]=0;C[a>>3]=b}function xm(a){a=a|0;a=nc(a);ib[x[x[a>>2]>>2]](a)|0}function wo(a,b,c){x[a>>2]=b;x[a+4>>2]=c-b;return a}function wda(a,b){a=a|0;b=+b;return+xO(x[a+4>>2],b)}function wca(a){a=a|0;return+OA(x[x[a+4>>2]+24>>2])}function vua(a,b){a=a|0;b=b|0;Cx(a,b,261,274,-1332)}function vqa(a,b,c){a=a|0;b=b|0;c=c|0;Fs(a,b,c,596)}function uqa(a,b,c){a=a|0;b=b|0;c=c|0;Fs(a,b,c,597)}function ty(a,b,c){if(!c){return 0}return mK(a,b,c)}function tsa(a,b,c){a=a|0;b=b|0;c=c|0;aq(a,b,c,417)}function sx(a,b){a=a|0;b=b|0;return QS(a,b,is(b))|0}function sQ(a){a=a|0;return E(B[yb(a+4208|0,0)>>2])}function r3(a){a=a|0;a=ib[a|0]()|0;gb=hb;return a|0}function qqa(a,b,c){a=a|0;b=b|0;c=c|0;sH(a,b,c,503)}function oqa(a,b,c){a=a|0;b=b|0;c=c|0;AH(a,b,c,304)}function nqa(a,b,c){a=a|0;b=b|0;c=c|0;fH(a,b,c,304)}function me(a){var b=0;b=x[a>>2];x[a>>2]=0;return b}function mC(a){v[a+6|0]=0;w[a+4>>1]=65535;x[a>>2]=0}function lpa(a,b){a=a|0;b=b|0;return Es(a,b,1182)|0}function iua(a,b,c){a=a|0;b=b|0;c=c|0;Fs(a,b,c,299)}function hba(a,b){a=a|0;b=b|0;return Es(a,b,1185)|0}function fua(a,b,c){a=a|0;b=b|0;c=c|0;pH(a,b,c,304)}function dta(a,b,c){a=a|0;b=b|0;c=c|0;E_(a,c,b,0,0)}function doa(a,b,c){a=a|0;b=b|0;c=c|0;_c(a,sx(b,c))}function d2(a,b){a=a|0;b=b|0;return BF(a,b,Cf(b))|0}function bG(a){return GL(a,E(2524354896707238e-44))}function _qa(a,b,c){a=a|0;b=b|0;c=c|0;tH(a,b,c,256)}function ZA(a,b){x[a>>2]=b;x[a+4>>2]=b>>31;return a}function Z9(a,b,c){a=a|0;b=b|0;c=c|0;Fs(a,b,c,1168)}function Yba(a,b,c){a=a|0;b=b|0;c=+c;BN(a-88|0,b,c)}function XF(a,b,c){gc(a,(c>>>3&536870908)+b|0,1<<c)}function WT(a,b,c,d){return Zp(a,b,c,d,7,613566757)}function Vba(a,b){a=a|0;b=b|0;return yN(a-88|0,b)|0}function Tba(a,b){a=a|0;b=b|0;return wN(a-88|0,b)|0}function Spa(a,b){a=a|0;b=b|0;return di(a,b,1030)|0}function Rj(a){if(!a){return 0}return x[a+44>>2]!=0}function Mba(a,b,c){a=a|0;b=b|0;c=+c;rN(a-92|0,b,c)}function LN(a){a=a|0;a=x[a+4>>2];return(a?a:5011)|0}function Kba(a,b,c){a=a|0;b=b|0;c=+c;pN(a-92|0,b,c)}function Jpa(a,b){a=a|0;b=b|0;return Dx(a,b,1100)|0}function Ij(a){if(!a){return 0}return Qj(y[a+31|0])}function Fua(a,b,c){a=a|0;b=b|0;c=c|0;aq(a,b,c,262)}function Fca(a){a=a|0;return+aP(x[x[a+4>>2]+24>>2])}function Dp(a,b,c){gc(a,(c>>>3&536870908)+b|0,c&31)}function DG(a){return GL(a,E(15845632502852868e13))}function Csa(a,b){a=a|0;b=b|0;return Es(a,b,1186)|0}function yJ(a,b){a=xd(a,b);x[a>>2]=115124;return a}function xda(a,b,c){a=a|0;b=b|0;c=c|0;aq(a,b,c,83)}function xJ(a,b){a=xd(a,b);x[a>>2]=115156;return a}function vJ(a,b){a=xd(a,b);x[a>>2]=113824;return a}function sJ(a,b){a=xd(a,b);x[a>>2]=117656;return a}function rJ(a,b){a=xd(a,b);x[a>>2]=117804;return a}function qJ(a,b){a=xd(a,b);x[a>>2]=117920;return a}function pJ(a,b){a=xd(a,b);x[a>>2]=118036;return a}function mJ(a,b){a=xd(a,b);x[a>>2]=119224;return a}function lJ(a,b){a=xd(a,b);x[a>>2]=119344;return a}function hoa(a,b,c){a=a|0;b=b|0;c=c|0;pH(a,b,c,47)}function d3(a,b){a=a|0;b=b|0;return Es(a,b,1184)|0}function cn(a){Hj(a+724|0);Hj(a+732|0);Hj(a+740|0)}function bl(a,b){return(a&65535)>>>0<(b&65535)>>>0}function Yy(a){if(!a){return 0}x[31612]=a;return-1}function Rqa(a,b){a=a|0;b=b|0;return di(a,b,422)|0}function Oca(a,b,c){a=a|0;b=b|0;c=c|0;fH(a,b,c,47)}function Msa(a,b){a=a|0;b=b|0;return di(a,b,308)|0}function Mqa(a,b){a=a|0;b=b|0;return di(a,b,826)|0}function MG(a,b,c){a=a|0;b=b|0;c=c|0;_c(a,_w(b,c))}function Lja(a,b){a=a|0;b=b|0;return di(a,b,225)|0}function Lda(a,b,c){a=a|0;b=b|0;c=c|0;aq(a,b,c,82)}function Kr(a,b,c){a=a|0;b=b|0;c=c|0;sH(a,b,c,124)}function KY(a,b,c){a=a|0;b=b|0;c=c|0;_c(a,Xy(b,c))}function Ija(a,b){a=a|0;b=b|0;return di(a,b,326)|0}function Iga(a,b){a=a|0;b=b|0;return E(Fm(a,b,12))}function Eua(a,b,c){a=a|0;b=b|0;c=c|0;AH(a,b,c,47)}function Dba(a){a=a|0;x[a>>2]=48528;return du(a)|0}function BG(a,b){a=zG(a,b);x[a>>2]=125360;return a}function zpa(a,b){a=a|0;b=b|0;return di(a,b,71)|0}function xha(a,b){a=a|0;b=b|0;return E(Fm(a,b,5))}function xX(a){return(x[zb(a)>>2]-x[a>>2]|0)/56|0}function we(a,b,c){x[a>>2]=b;x[a+4>>2]=c;return a}function uga(a,b){a=a|0;b=b|0;return E(Fm(a,b,3))}function sh(a,b){a=a|0;b=b|0;return pL(a)^pL(b)^1}function rra(a,b){a=a|0;b=b|0;return di(a,b,91)|0}function rE(a){return(x[zb(a)>>2]-x[a>>2]|0)/28|0}function q5(a,b){a=a|0;b=b|0;Cx(a,b,13,290,-1332)}function pha(a,b){a=a|0;b=b|0;return E(Fm(a,b,4))}function pO(a){x[a+4>>2]=0;x[a>>2]=47700;return a}function pI(a){return(a<<1)+16777216>>>0<16777217}function ot(a){return a-48>>>0<10|(a|32)-97>>>0<6}function n2(a,b){a=a|0;b=b|0;Cx(a,b,13,257,-1284)}function mra(a,b){a=a|0;b=b|0;if(!eZ(a,b)){dZ(b)}}function li(a,b){a=a|0;b=b|0;return jL(a)^jL(b)^1}function jl(a){return(x[zb(a)>>2]-x[a>>2]|0)/12|0}function jF(a){return!kd(a,24592,25)&y[a+34|0]<65}function hn(a,b,c){x[a+4>>2]=c;w[a>>1]=b;return a}function gc(a,b,c){x[a+4>>2]=c;x[a>>2]=b;return a}function g$(a,b){a=a|0;b=b|0;return oH(a,b,346)|0}function cx(a){return(x[zb(a)>>2]-x[a>>2]|0)/36|0}function bZ(a){return(x[zb(a)>>2]-x[a>>2]|0)/33|0}function at(a){return(x[zb(a)>>2]-x[a>>2]|0)/24|0}function _Z(a){if(!(a&255)){return 1}return Sc(a)}function Xba(a,b){a=a|0;b=b|0;return+AN(a-88|0,b)}function Wl(a,b,c){C[a+8>>3]=c;C[a>>3]=b;return a}function VZ(a,b){a=a|0;b=b|0;return oH(a,b,323)|0}function Uja(a,b){a=a|0;b=b|0;if(!jG(a,b)){qx(b)}}function Uga(a,b){a=a|0;b=b|0;return E(Fm(a,b,1))}function Tsa(a,b){a=a|0;b=b|0;if(!g_(a,b)){f_(b)}}function TK(a){return(Oh(a)|0)!=0|(a|32)-97>>>0<6}function TE(a){return(x[zb(a)>>2]-x[a>>2]|0)/20|0}function Ssa(a,b){a=a|0;b=b|0;return di(a,b,78)|0}function Nja(a,b){a=a|0;b=b|0;return di(a,b,73)|0}function Mq(a,b){x[a+4>>2]=256;x[a>>2]=b;return a}function Lba(a,b){a=a|0;b=b|0;return+qN(a-92|0,b)}function Kha(a,b){a=a|0;b=b|0;return E(Fm(a,b,6))}function Jqa(a,b){a=a|0;b=b|0;return di(a,b,41)|0}function Jba(a,b){a=a|0;b=b|0;return+oN(a-92|0,b)}function Gja(a,b){a=a|0;b=b|0;return di(a,b,60)|0}function FR(a,b){return(a|0)==1179011410&b>>>0>80}function F1(a,b,c){a=a|0;b=b|0;c=c|0;aq(a,b,c,18)}function C$(a){return(x[zb(a)>>2]-x[a>>2]|0)/40|0}function Bu(a){return(x[zb(a)>>2]-x[a>>2]|0)/52|0}function Bga(a,b){a=a|0;b=b|0;return E(Fm(a,b,2))}function $pa(a,b){a=a|0;b=b|0;if(!yE(a,b)){DE(b)}}function zz(a,b){x[a>>2]=x[b>>2];_c(a+4|0,b+4|0)}function wta(a,b){a=a|0;b=b|0;$p(a,b,363,362,8)}
function v$(a,b){a=a|0;b=b|0;if(!t$(a,b)){aw(b)}}function su(a){a=a|0;vc(a+4208|0);return ag(a)|0}function o_(a,b){a=a|0;b=b|0;if(!aG(a,b)){gs(b)}}function np(a,b){a=a|0;b=b|0;if(!$h(a,b)){el(b)}}function mQ(a){a=a|0;vc(a+4256|0);return ag(a)|0}function gE(a,b){a=a|0;b=b|0;if(!O$(a,b)){Jr(b)}}function fi(a,b,c){return Fa(1016,a|0,b|0,c|0)|0}function fD(a,b){a=a|0;b=b|0;if(!qZ(a,b)){mD(b)}}function em(a,b,c){v[a+2|0]=c;w[a>>1]=b;return a}function eV(a,b){x[a>>2]=x[a>>2]+(b<<1);return a}function eF(a,b){a=$E(a,b);if(!a){Hn(b)}return a}function dw(a){return(a|0)<=0?1:a>>>0>=120?120:a}function cw(a){return(x[zb(a)>>2]-x[a>>2]|0)/6|0}function _S(a,b,c){x[a+4>>2]=c;v[a|0]=b;return a}function _0(a,b){a=a|0;b=b|0;if(!S0(a,b)){FE(b)}}function Vn(a,b,c){a=Nd(a);x[a+4>>2]=c;x[a>>2]=b}function V$(a,b){a=z$(a,b);if(!a){kE(b)}return a}function Uda(a){a=a|0;return WH(a,47640,12605)|0}function UB(a){x[a+24>>2]=z[a+20>>1]<<z[a+22>>1]}function RG(a){x[a>>2]=0;x[a+4>>2]=0;x[a+8>>2]=0}function OM(a,b){a=a|0;b=b|0;kl(a,b,74504,74512)}function NM(a,b){a=a|0;b=b|0;kl(a,b,74520,74528)}function KM(a,b){a=a|0;b=b|0;kl(a,b,75324,75332)}function J_(a,b){x[a>>2]=x[a>>2]+D(b,6);return a}function JQ(a){a=a|0;dc(a+4208|0);return ag(a)|0}function JM(a,b){a=a|0;b=b|0;kl(a,b,75340,75348)}function IM(a,b){a=a|0;b=b|0;kl(a,b,76152,76160)}function HM(a,b){a=a|0;b=b|0;kl(a,b,76168,76176)}function HE(a,b){a=a|0;b=b|0;if(!Ip(a,b)){wp(b)}}function FB(a){return(x[zb(a)>>2]-x[a>>2]|0)/7|0}function EM(a,b){a=a|0;b=b|0;kl(a,b,76980,76988)}function DM(a,b){a=a|0;b=b|0;kl(a,b,76996,77004)}function Aw(a,b){a=a|0;b=b|0;if(!gx(a,b)){fx(b)}}function zca(a){a=a|0;return+C[x[a+4>>2]+16>>3]}function zL(a,b){if(!a){return 0}return Vy(a,b)}function z5(a,b){a=a|0;b=b|0;$c(a,b,Tc(500508))}function yY(a){var b=0;b=x[a>>2];le(a);return b}function yL(a,b,c){a=a|0;b=b|0;c=c|0;return a|0}function xua(a,b){a=a|0;b=b|0;$p(a,b,298,297,8)}function x5(a,b){a=a|0;b=b|0;$c(a,b,Tc(500516))}function v5(a,b){a=a|0;b=b|0;$c(a,b,Tc(500524))}function uha(a){a=a|0;v[a+4202|0]=1;jQ(a);lQ(a)}function ud(a,b){return cr(x[b>>2],x[a>>2])?b:a}function tra(a,b){a=a|0;b=b|0;$p(a,b,521,520,6)}function tpa(a,b){a=a|0;b=b|0;$p(a,b,683,682,8)}function tla(a,b,c){a=a|0;b=b|0;c=c|0;fe(a,b,c)}function tB(a){if(y[a+24|0]){iT(a);v[a+24|0]=0}}function t5(a,b){a=a|0;b=b|0;$c(a,b,Tc(500336))}function r5(a,b){a=a|0;b=b|0;$c(a,b,Tc(500344))}function pe(a,b){return bl(z[a>>1],z[b>>1])?b:a}function oba(a,b){a=a|0;b=b|0;_c(a,sO(b,18292))}function o5(a,b){a=a|0;b=b|0;$c(a,b,Tc(500352))}function nha(a){a=a|0;v[a+4202|0]=1;hQ(a);gQ(a)}function m5(a,b){a=a|0;b=b|0;$c(a,b,Tc(500360))}function k5(a,b){a=a|0;b=b|0;$c(a,b,Tc(500304))}function jo(a){return ib[x[x[a>>2]+28>>2]](a)|0}function i5(a,b){a=a|0;b=b|0;$c(a,b,Tc(500312))}function hJ(a){var b=0,c=0;b=a,c=Od(),x[b>>2]=c}function g5(a,b){a=a|0;b=b|0;$c(a,b,Tc(500320))}function d5(a,b){a=a|0;b=b|0;$c(a,b,Tc(500328))}function c5(a,b){a=a|0;b=b|0;$c(a,b,Tc(500400))}function bk(a,b){a=a|0;b=b|0;l0(a,x[a+16>>2]|b)}function bfa(a,b,c){a=a|0;b=b|0;c=c|0;VO(a,b,c)}function b5(a,b){a=a|0;b=b|0;$c(a,b,Tc(500408))}function ad(a,b){return xn(x[a>>2],x[b>>2])?b:a}function Ye(a,b){return cr(x[a>>2],x[b>>2])?b:a}function Xm(a,b){return Kv(B[b>>2],B[a>>2])?b:a}function Wz(a,b){return Kv(B[a>>2],B[b>>2])?b:a}function Ul(a,b){return fn((b<<1)+123872|0,2,a)}function Tda(a){a=a|0;return WH(a,47660,8191)|0}function P0(a,b){return(b&255)==2&(a&255)>>>0<3}function Ok(a){return ib[x[x[a>>2]+36>>2]](a)|0}function Nc(a,b){return bl(z[b>>1],z[a>>1])?b:a}function Mv(a,b){a=a|0;b=b|0;return Mb(a,b,1)^1}function Lpa(a,b){a=a|0;b=b|0;$p(a,b,650,649,8)}function K5(a,b){a=a|0;b=b|0;$c(a,b,Tc(500256))}function I5(a,b){a=a|0;b=b|0;$c(a,b,Tc(500264))}function H5(a,b){a=a|0;b=b|0;$c(a,b,Tc(500460))}function Gua(a,b,c){a=a|0;b=b|0;c=c|0;I0(a,b,c)}function Gga(a){a=a|0;$P(a);Sz(a);v[a+4202|0]=1}function Gb(a,b){return xn(x[b>>2],x[a>>2])?b:a}function G5(a,b){a=a|0;b=b|0;$c(a,b,Tc(500452))}function F5(a,b){a=a|0;b=b|0;$c(a,b,Tc(500468))}function E1(a,b){a=a|0;b=b|0;Xp(a,b);return a|0}function D5(a,b){a=a|0;b=b|0;$c(a,b,Tc(500476))}function C5(a,b){a=a|0;b=b|0;$c(a,b,Tc(500484))}function B5(a,b){a=a|0;b=b|0;$c(a,b,Tc(500500))}function A5(a,b){a=a|0;b=b|0;$c(a,b,Tc(500492))}function yca(a){a=a|0;return x[x[a+4>>2]+8>>2]}function xaa(a){a=a|0;x[a>>2]=77520;return a|0}function wE(a,b,c){a=a|0;b=b|0;c=c|0;p0(a,b,c)}function um(a){return(a>>>0<=127?-1:a^128)&255}function ti(a,b){return(D(b,104)+a|0)+484380|0}function taa(a){a=a|0;x[a>>2]=77020;return a|0}function sja(a,b){a=a|0;b=b|0;PA(tR(a+24|0,b))}function raa(a,b){a=a|0;b=b|0;PH(a,b,1162,292)}function naa(a){a=a|0;x[a>>2]=78328;return a|0}function mf(a,b){v[a+4|0]=1;x[a>>2]=b;return a}function mea(a,b){a=a|0;b=b|0;return _w(a,b)|0}function iaa(a){a=a|0;x[a>>2]=77940;return a|0}function dfa(a){a=a|0;return bI(a,7109,1060)|0}function bv(a){return(a>>>0<9?a:a-9|256)&65535}function ao(a,b,c,d,e){Oa(a|0,b|0,c|0,d|0,e|0)}function a4(a,b,c){a=a|0;b=b|0;c=c|0;gc(a,c,b)}function Wv(a,b){return y[a+b|0]!=63&b>>>0<=15}function Vt(a,b){return(a&255)>>>0<(b&255)>>>0}function U$(a,b,c){a=a|0;b=b|0;c=c|0;T0(a,b,c)}function Tka(a,b){a=a|0;b=b|0;return Xy(a,b)|0}function SZ(a,b,c){a=a|0;b=b|0;c=c|0;Q0(a,b,c)}function Os(a,b,c,d,e){Ea(a|0,b|0,c|0,d|0,e|0)}function Nea(a){a=a|0;return bI(a,6626,1068)|0}function Mg(a,b){v[a+4|0]=0;x[a>>2]=b;return a}function Kpa(a,b){a=a|0;b=b|0;return NX(a,b)|0}function Kf(a,b,c){if(!(y[a|0]&32)){IE(b,c,a)}}function JP(a){x[a>>2]=0;x[a+4>>2]=-1;return a}function HU(a){QB(a);Rb(a+27|0,0,255);return a}function Gg(a,b,c){a=Tua(a,b,c,c>>31);return a}function E4(a,b,c){a=a|0;b=b|0;c=c|0;II(a,b,c)}function An(a){a=Kj(a);x[a>>2]=124964;return a}function $i(a,b){return y[a+b|0]!=63&b>>>0<=46}function xy(a,b,c){a=CK(a,b,c,-1,-1);return a}function wc(a,b){if(A[a>>2]>b>>>0){x[a>>2]=b}}function uua(a,b){a=a|0;b=b|0;Ex(a,b,44,2,44)}function sL(a){a=a|0;Ry(x[x[a>>2]-12>>2]+a|0)}function qn(a,b,c,d){return(b-d|0)+(a-c<<3)|0}function q2(a){a=a|0;x[a>>2]=78600;return a|0}function mX(a){a=Sua(a&65535,0,80,0);return a}function mL(a){a=a|0;Py(x[x[a>>2]-12>>2]+a|0)}function lu(a,b){a=a|0;b=b|0;return lg(a,b)|0}function lta(a,b){a=a|0;b=b|0;vH(a,b,367,366)}function l9(a){a=a|0;fL(x[x[a>>2]-12>>2]+a|0)}function jZ(a,b,c){a=a|0;b=b|0;c=c|0;return 0}function j9(a){a=a|0;eL(x[x[a>>2]-12>>2]+a|0)}function e2(a){a=a|0;x[a>>2]=41480;return a|0}function du(a){a=a|0;x[a>>2]=48508;return a|0}function df(a,b){return Vt(y[a|0],y[b|0])?b:a}function cua(a,b){a=a|0;b=b|0;vH(a,b,307,306)}function cA(a){return x[zb(a)>>2]-x[a>>2]>>11}function b2(a){a=a|0;x[a>>2]=41240;return a|0}function XK(a){a=YL(a);x[a>>2]=95248;return a}function Vca(a,b){a=a|0;b=b|0;TO(a,x[b+4>>2])}function U_(a){a=(a&65535)-98|0;hb=0;return a}function T$(a){v[a+12|0]=y[a+12|0]|2;return a}function R2(a,b){a=a|0;b=b|0;return sx(a,b)|0}function Qt(a){a=YL(a);x[a>>2]=94856;return a}function Qb(a,b){return Vt(y[b|0],y[a|0])?b:a}function Pca(a,b){a=a|0;b=b|0;MO(a,x[b+4>>2])}function Nd(a){x[a>>2]=0;x[a+4>>2]=0;return a}function Nca(a,b){a=a|0;b=b|0;nP(a,x[b+4>>2])}function NW(a){return Ze(443250/+(a>>>0)*1e4)}function Jsa(a,b){a=a|0;b=b|0;Ex(a,b,17,3,16)}function Hca(a,b){a=a|0;b=b|0;RO(a,x[b+4>>2])}function Gf(a,b){if(z[a>>1]>b>>>0){w[a>>1]=b}}function Gca(a,b){a=a|0;b=b|0;LO(a,x[b+4>>2])}function Gaa(a,b){a=a|0;b=b|0;PH(a,b,1158,36)}function GJ(a,b,c){a=a|0;b=b|0;c=c|0;return-1}function Daa(a){a=a|0;yM(a);return x[a+16>>2]}function Bda(a,b){a=a|0;b=b|0;Jz(x[a+4>>2],b)}function Bca(a,b){a=a|0;b=b|0;_O(a,x[b+4>>2])}function BP(a,b){a=a|0;b=b|0;return sO(a,b)|0}function Ai(a,b){if(x[a>>2]>(b|0)){x[a>>2]=b}}function yk(a){a=a&255;return(a|0)==255?-1:a}function wI(a,b,c){a=a|0;b=b|0;c=c|0;dL(a,c)}function rA(a,b){return D((b-a|0)/6|0,6)+a|0}function lC(a){return x[zb(a)>>2]-x[a>>2]>>8}function hv(a){return x[zb(a)>>2]-x[a>>2]>>4}function hB(a){v[a+24|0]=0;v[a|0]=0;return a}function f7(a){a=a|0;$c(a,501744,Tc(500256))}function e7(a){a=a|0;$c(a,501752,Tc(500264))}function d7(a){a=a|0;$c(a,501760,Tc(500460))}function c7(a){a=a|0;$c(a,501776,Tc(500452))}function b7(a){a=a|0;$c(a,501784,Tc(500468))}function ap(a){return x[zb(a)>>2]-x[a>>2]>>5}function _6(a){a=a|0;$c(a,501808,Tc(500484))}function Zz(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0}function Z6(a){a=a|0;$c(a,501816,Tc(500500))}function Y6(a){a=a|0;$c(a,501824,Tc(500492))}function Xn(a){return x[zb(a)>>2]-x[a>>2]>>3}function X6(a){a=a|0;$c(a,501832,Tc(500508))}function W6(a){a=a|0;$c(a,501840,Tc(500516))}function V6(a){a=a|0;$c(a,501864,Tc(500524))}function Uz(a){return x[nc(a)>>2]-x[a>>2]>>2}function Uh(a){return x[x[a+8>>2]>>2]==(a|0)}function Ug(a){return x[zb(a)>>2]-x[a>>2]>>2}function U6(a){a=a|0;$c(a,501896,Tc(500272))}function Tz(a){return E(E(a*E(7900))+E(100))}function T6(a){a=a|0;$c(a,501904,Tc(500280))}function Sca(a){a=a|0;return UO(x[a+4>>2])|0}function S9(a){a=a|0;return Ba(x[a+60>>2])|0}function S6(a){a=a|0;$c(a,501912,Tc(500288))}function R6(a){a=a|0;$c(a,501920,Tc(500296))}function Q6(a){a=a|0;$c(a,501928,Tc(500336))}function PQ(a){x[a>>2]=x[a>>2]-2048;return a}function P6(a){a=a|0;$c(a,501936,Tc(500344))}function O6(a){a=a|0;$c(a,501944,Tc(500352))}function Nn(a){return x[zb(a)>>2]-x[a>>2]>>1}function N6(a){a=a|0;$c(a,501952,Tc(500360))}function M6(a){a=a|0;$c(a,501960,Tc(500368))}function Lp(a,b,c,d){a=Tua(a,b,c,d);return a}function L6(a){a=a|0;$c(a,501968,Tc(500376))}function K6(a){a=a|0;$c(a,501976,Tc(500384))}function JY(a,b,c){w[a>>1]=b;v[a+2|0]=y[c|0]}function J6(a){a=a|0;$c(a,501984,Tc(500392))}function I6(a){a=a|0;$c(a,501992,Tc(500304))}function H6(a){a=a|0;$c(a,502008,Tc(500312))}function Gk(a){return gH(a,E(4294967296),-1)}function F6(a){a=a|0;$c(a,502024,Tc(500320))}function Eca(a){a=a|0;return fP(x[a+4>>2])|0}function Eaa(a){a=a|0;yM(a);return x[a+4>>2]}function D6(a){a=a|0;$c(a,502040,Tc(500328))}function Cb(a,b){if(!Cd(b)){a=Fh(b)}return a}function C6(a){a=a|0;$c(a,502056,Tc(500400))}function B6(a){a=a|0;$c(a,502064,Tc(500408))}function AZ(a,b,c){gc(a,b,Li(b,b+c|0,0)-b|0)}function $6(a){a=a|0;$c(a,501792,Tc(500476))}function vp(a,b,c){return ck(a,b)>>>0>c>>>0}function ru(a){a=a|0;ib[x[x[a>>2]+4>>2]](a)}function lo(a){a=a|0;iL(x[a>>2]);return a|0}function gp(a,b){w[a>>1]=b;w[a+2>>1]=b>>>16}function eia(a,b,c){a=a|0;b=b|0;c=c|0;Nd(a)}function dp(a){return x[zb(a)>>2]-x[a>>2]|0}function bW(a){x[a>>2]=x[a>>2]-256;return a}function bP(a){return A[a+1074420>>2]/1e4|0}function ar(a,b){return a<<16>>16<b<<16>>16}function Yl(a,b){return ar(z[a>>1],z[b>>1])}function XU(a,b){x[a>>2]=x[a>>2]+b;return a}function Sw(a,b){if(b){Dc(a,b);return}Fb(a)}function Qf(a,b){if(y[a|0]>b>>>0){v[a|0]=b}}function Pv(){da(An(ac(4))|0,125048,34);p()}function Oi(a,b){a=a|0;b=b|0;return E(E(0))}function M4(a,b){a=a|0;b=b|0;return Cy(b)|0}function Km(a){a=a|0;Qy(x[a>>2]);return a|0}function K4(a,b){a=a|0;b=b|0;return Dy(b)|0}function Jia(a,b){a=a|0;b=b|0;v[a+4201|0]=b}function BB(a){v[a+4|0]=0;v[a|0]=0;return a}function z9(a){a=a|0;return Wh(a,500288)|0}function w2(a){a=a|0;return x[a+4>>2]!=0|0}function vf(a,b,c){a=Sua(c,0,a,b);return a}function vX(a){x[a>>2]=x[a>>2]-56;return a}function vW(a,b,c,d){gc(a,b,(d|0)==-1?c:d)}function sy(a){a=a|0;return Wh(a,500524)|0}function sn(a){aC(x[a+20>>2]);x[a+20>>2]=0}function ql(a,b){ib[x[x[b>>2]+44>>2]](a,b)}function qk(a){x[a>>2]=x[a>>2]-12;return a}function pl(a,b){ib[x[x[b>>2]+32>>2]](a,b)}function oua(a,b){a=a|0;b=b|0;qw(a+36|0,b)}function mG(a){x[a>>2]=x[a>>2]-36;return a}function lw(a){x[a>>2]=x[a>>2]-28;return a}function lm(a){x[a>>2]=x[a>>2]+28;return a}function kR(a){x[a>>2]=x[a>>2]-52;return a}function jka(a,b){a=a|0;b=b|0;us(a+40|0,b)}function io(a){a=a|0;Gs(a,163,125408,1057)}function id(a,b){a=a|0;b=b|0;VO(a,b,Cf(b))}function hl(a){x[a>>2]=x[a>>2]+12;return a}function fA(a){x[a>>2]=x[a>>2]+24;return a}function er(a){tf(a+24|0);dc(a+12|0);dc(a)}function eca(a,b){a=a|0;b=b|0;JN(a-88|0,b)}function dca(a,b){a=a|0;b=b|0;IN(a-88|0,b)}function bt(a,b){ib[x[x[b>>2]+40>>2]](a,b)}function br(a){x[a>>2]=x[a>>2]+32;return a}function am(a){x[a>>2]=x[a>>2]+52;return a}function aaa(a,b){a=a|0;b=b|0;Bm(a,b+12|0)}function _Y(a){x[a>>2]=x[a>>2]-33;return a}function Zo(a){x[a>>2]=x[a>>2]+16;return a}function Yo(a){x[a>>2]=x[a>>2]-32;return a}function Y4(a){a=a|0;Gs(a,163,125408,1189)}function X_(a){x[a>>2]=x[a>>2]-20;return a}function St(a){return(a|0)<=65535&(a|0)>=0}function Sf(a){x[a>>2]=x[a>>2]+20;return a}function Rba(a,b){a=a|0;b=b|0;uN(a-88|0,b)}function RP(a){return E(E(a*E(96))+E(-96))}function Qoa(a,b){a=a|0;b=b|0;rH(a,b,2,31)}function Oba(a,b){a=a|0;b=b|0;tN(a-92|0,b)}function Ny(a){a=a|0;return Wh(a,500452)|0}function Nba(a,b){a=a|0;b=b|0;sN(a-92|0,b)}function Mp(a){rs(a+32|0);ub(a+12|0);tb(a)}function Ky(a){a=a|0;return Wh(a,500468)|0}function Jg(a){return E(F(a))==E(Infinity)}function GL(a,b){return E(zx(a?E(-b):b)*b)}function GD(a){a=a|0;return Wh(a,500476)|0}function G9(a){a=a|0;return Wh(a,500272)|0}function EI(a){a=a|0;return GH(a,118464)|0}function DI(a){a=a|0;return GH(a,118360)|0}function Cca(a){a=a|0;return+$O(x[a+4>>2])}function CI(a){a=a|0;return FH(a,118256)|0}function Bw(a){a=a|0;return Wh(a,500460)|0}function Bk(a){tb(a+36|0);vc(a+24|0);Qk(a)}function BI(a){a=a|0;return FH(a,118152)|0}function B$(a){x[a>>2]=x[a>>2]-40;return a}function Ay(a){a=a|0;return Wh(a,500516)|0}function $s(a){x[a>>2]=x[a>>2]-24;return a}function $q(a){x[a>>2]=x[a>>2]-16;return a}function $S(a,b){return DH(a,b,2147483647)}function yB(a,b){if(B[a>>2]>b){B[a>>2]=b}}function xe(a){return Bb(a&65535)<<16>>16}function vg(a){x[a>>2]=x[a>>2]+6;return a}function vC(a){x[a>>2]=x[a>>2]-1;return a}function uq(a){a=a|0;zq(a+8|0);return a|0}function tN(a,b){a=a|0;b=b|0;SH(a,b,2048)}function sN(a,b){a=a|0;b=b|0;SH(a,b,4096)}function nD(a){x[a>>2]=x[a>>2]-6;return a}function mz(a,b,c){gc(a,(c<<12)+b|0,4096)}function lz(a,b){a=a|0;b=b|0;lg(a,b+36|0)}function le(a){x[a>>2]=x[a>>2]+1;return a}function l6(a,b){a=a|0;b=b|0;Bn(a,113432)}function ky(a,b){a=a|0;b=b|0;lg(a,b+12|0)}function kua(a,b){a=a|0;b=b|0;Ci(a,b,136)}function k6(a,b){a=a|0;b=b|0;Bn(a,113452)}function jI(a){a=Da(a|0)|0;hb=gb;return a}function iy(a,b){a=a|0;b=b|0;lg(a,b+16|0)}function ij(a){x[a>>2]=x[a>>2]-2;return a}function gca(a){a=a|0;return uq(a-88|0)|0}function cv(a){Vm(a,Wo(a),78832);return a}function cca(a,b){a=a|0;b=+b;HN(a-88|0,b)}function aca(a,b){a=a|0;b=+b;FN(a-88|0,b)}function aP(a){return+A[a+1074420>>2]/1e4}function aK(a,b){a=a|0;b=b|0;lg(a,b+24|0)}function _pa(a,b){a=a|0;b=b|0;Ci(a,b,274)}function _m(a){return E(F(a))<E(Infinity)}function _ba(a,b){a=a|0;b=+b;DN(a-88|0,b)}function Yu(a){x[a>>2]=x[a>>2]+8;return a}function Xg(a,b,c){Kk(b,b+c|0,a);return a}function XJ(a,b){a=a|0;b=b|0;jq(a,b+28|0)}function WJ(a,b){a=a|0;b=b|0;jq(a,b+40|0)}function Vpa(a,b){a=a|0;b=b|0;Ci(a,b,106)}function VJ(a,b){a=a|0;b=b|0;jq(a,b+52|0)}function Tf(a){a=a|0;ai(a+8|0);return a|0}function SP(a){a=a|0;Rb(a+4296|0,0,81928)}function Rta(a,b){a=a|0;b=b|0;rH(a,b,3,8)}function RT(a){x[a>>2]=x[a>>2]-7;return a}function Qha(a){a=a|0;v[a+4202|0]=1;yQ(a)}function Qba(a){a=a|0;return uq(a-92|0)|0}function Pq(a,b){v[a|0]=b+48;return a+1|0}function Np(a){x[a>>2]=x[a>>2]-8;return a}function Mi(a){x[a>>2]=x[a>>2]-4;return a}function Md(a){x[a>>2]=x[a>>2]+2;return a}function Lga(a){a=a|0;return x[a+4260>>2]}function Je(a){x[a>>2]=x[a>>2]+4;return a}function Iba(a){a=a|0;return uq(a-96|0)|0}function Hsa(a,b){a=a|0;b=b|0;Ci(a,b,282)}function Gt(a){a=a|0;Bl(a+8|0);return a|0}function Gba(a,b){a=a|0;b=+b;nN(a-96|0,b)}function Dt(a){a=a|0;Bl(a+4|0);return a|0}function Ds(a,b){x[a>>2]=b;fl(b);return a}function Cg(a,b,c){Wg(b,b+c|0,a);return a}function Al(a){a=a|0;return qL(a)<<24>>24}function $J(a,b){a=a|0;b=b|0;lg(a,b+48|0)}function yt(a){return a-65>>>0<26?a|32:a}function xl(a){return a-97>>>0<26?a&95:a}function wl(a){return(a|0)==32|a-9>>>0<5}function sua(a,b){a=a|0;b=b|0;xH(a,b,28)}function rta(a,b){a=a|0;b=b|0;Ci(a,b,34)}function qo(a,b,c){return ib[c|0](a,b)|0}function of(a,b){x[a+8>>2]=b|-2147483648}function mga(a){a=a|0;return(a|0)==277|0}function mg(a,b){a=Tua(0,a,b,0);return a}function je(a,b){return(b|0)!=0&(a|0)!=0}function j_(a,b,c){x[a>>2]=b;x[a+4>>2]=c}function j6(a,b){a=a|0;b=b|0;Dc(a,11296)}function i6(a,b){a=a|0;b=b|0;Dc(a,11413)}function hj(a,b){v[a|0]=b;v[a+1|0]=b>>>8}function hc(a){x[x[a>>2]+4>>2]=x[a+4>>2]}function cl(a){return D(On(a),_d(a))&255}function Zqa(a,b){a=a|0;b=b|0;Ci(a,b,42)}function Vr(a,b,c,d,e){CH(a,b,c,d,e,256)}function Tpa(a,b){a=a|0;b=b|0;Ci(a,b,72)}function Qx(a){return a-502256>>>2&65535}function QY(a,b){a=a|0;b=b|0;Ci(a,b,284)}function Isa(a,b){a=a|0;b=b|0;Rr(a,b,17)}function Iia(a){a=a|0;return y[a+4201|0]}function Hj(a){w[a+4>>1]=65535;x[a>>2]=0}function Hia(a){a=a|0;return y[a+4202|0]}function GG(a,b){Tb(a,b);Tb(a+4|0,b+4|0)}function Fw(a,b,c,d,e){CH(a,b,c,d,e,128)}function Bt(a,b){x[a+24>>2]=x[a+24>>2]+b}function zm(a){a=x[a+8>>2];if(a){Db(a)}}function zB(a,b,c){return a<b?b:a>c?c:a}function x0(a,b){a=a|0;b=b|0;Ci(a,b,50)}function wga(a){a=a|0;return-2013527448}function ui(a){return(a&65535)>>>0<3999}function tI(a){return(z[a+2>>1]<<2)+a|0}function sY(a,b){a=a|0;b=b|0;return b|0}function rX(a,b,c,d){return qn(c,d,a,b)}function rR(a,b){x[a>>2]=x[a>>2]+D(b,6)}function q1(a,b){a=a|0;b=b|0;Ci(a,b,59)}function nt(a){return(a|0)==32|(a|0)==9}function lra(a,b){a=a|0;b=b|0;V0(a,b,8)}function lP(a,b){return aI(a,b,1075834)}function jP(a,b){return $H(a,b,1075834)}function iP(a,b){return $H(a,b,1075835)}function i0(a,b){x[a>>2]=x[a>>2]+(b<<1)}function hP(a,b){return aI(a,b,1075835)}function fn(a,b,c){return Wg(a,a+b|0,c)}function d1(a,b){a=a|0;b=b|0;Rr(a,b,11)}function cK(a,b){a=a|0;b=b|0;rf(a,1,45)}function bca(a){a=a|0;return+GN(a-88|0)}function bK(a,b){a=a|0;b=b|0;ny(a,1,45)}function _g(a,b,c){v[a+4|0]=c;x[a>>2]=b}function Zy(a){return(q(a),j(2))>>>20|0}function Zba(a){a=a|0;return+CN(a-88|0)}function YK(a){x[a+4>>2]=x[a+4>>2]|8192}function Uv(a,b,c){return a<b?b:a>c?c:a}function US(a,b){return(Xl(a,b)|0)!=255}function U3(a){a=a|0;if(a){vI(ol(a),1)}}function RI(a){a=a|0;return td(a-8|0)|0}function QI(a){a=a|0;return _x(a-8|0)|0}function PI(a){a=a|0;return Zx(a-8|0)|0}function OZ(a,b){a=a|0;b=b|0;Rr(a,b,32)}function OI(a){a=a|0;return Yx(a-8|0)|0}function NI(a){a=a|0;return Xx(a-8|0)|0}function MI(a){a=a|0;return Wx(a-8|0)|0}function LI(a){a=a|0;return Vx(a-8|0)|0}function Jj(a,b){return rB(a&255,b&255)}function HY(a,b){x[a>>2]=x[a>>2]+(b<<2)}function HS(a,b,c,d){return gq(a,b,c,d)}function HD(a){return mH(a,65535,65535)}function F0(a,b){return(a&255)==(b&255)}function Bb(a){return(a<<8|a>>>8)&65535}function $ba(a){a=a|0;return+EN(a-88|0)}function zw(a,b,c){return Yp(a,b,c,20)}function zia(a){a=a|0;return 542066252}function zh(a){return gH(a,E(255),255)}function zaa(a){a=a|0;return y[a+40|0]}function rx(a,b){x[a+4>>2]=3;x[a>>2]=b}function rv(a,b,c){return Yp(a,b,c,12)}function rk(a,b){x[a+4>>2]=2;x[a>>2]=b}function rha(a){a=a|0;return-284078960}function re(a,b,c){wo(a,b,Vc(b,c)+b|0)}function pga(a,b){a=a|0;b=b|0;return 3}function nga(a,b){a=a|0;b=b|0;return 2}function kha(a){a=a|0;return-281111764}function jy(a){a=a|0;return x[a+12>>2]}function i_(a,b,c){em(a,b&65535,c&255)}function i2(a){a=a|0;return x[a+16>>2]}function he(a){x[x[a+8>>2]>>2]=x[a>>2]}function eE(a){return a>>>0>=120?120:a}function dt(a){a=a|0;return 2147483647}function dha(a){a=a|0;return-271958638}function aN(a){return a?(a|0)==2?3:2:1}function a5(a,b){a=a|0;b=b|0;IH(a,b,0)}function _u(a,b,c){ng(a,c);fd(b+c|0,0)}function _J(a){a=a|0;return x[a+60>>2]}function _4(a,b){a=a|0;b=b|0;HH(a,b,0)}function Z4(a,b){a=a|0;b=b|0;HH(a,b,1)}function Z2(a,b){a=a|0;b=b|0;Bs(a,1,b)}function Xga(a){a=a|0;return-620920304}function WP(a,b,c){return kH(a,b,c,68)}function Vd(a,b){return Jb(a)+(b<<2)|0}function Ux(a,b){x[a+4>>2]=4;x[a>>2]=b}function UJ(a){a=a|0;return x[a+64>>2]}function Su(a,b){return BH(a,b,-1,0,0)}function OX(a,b){a=a|0;b=b|0;xH(a,b,4)}function NQ(a){a=a|0;return 1869112133}function Mha(a){a=a|0;return-270114148}function Mga(a){a=a|0;return-275227023}function Kj(a){x[a>>2]=125660;return a}function I$(a,b,c){return Yp(a,b,c,40)}function Gna(a){a=a|0;gX(a);return a|0}function EJ(a,b,c){return Yp(a,b,c,24)}function Dga(a){a=a|0;return 302837129}function Cj(a,b){x[a+4>>2]=1;x[a>>2]=b}function Aha(a){a=a|0;return-285139079}function $4(a,b){a=a|0;b=b|0;IH(a,b,1)}function wla(a,b){a=a|0;b=b|0;Vb(a,b)}function vP(a){a=a|0;eI(a,47504,1005)}function vG(a,b,c){bc(a,b,jh(b,c)<<3)}function st(a){return(Dy(a)|0)!=(a|0)}function sO(a,b){return Jt(a,b,Cf(b))}function rt(a){return(Cy(a)|0)!=(a|0)}function ps(a){a=a|0;return x[a+4>>2]}function os(a){a=a|0;return x[a+8>>2]}function nl(a){a=x[a>>2];if(a){ul(a)}}function mp(a,b){w[a+8>>1]=b;return a}function lZ(a,b,c){bc(a,b,oc(b,c)<<2)}function ks(a,b,c){return _p(a,b,c,3)}function jC(a,b,c){return _p(a,b,c,5)}function iD(a,b,c){Kk(a,(b<<2)+a|0,c)}function gv(a,b,c){return _p(a,b,c,4)}function gua(a,b){a=a|0;b=b|0;Xy(a,b)}function gP(a){return z[a+1074448>>1]}function daa(a,b){a=a|0;b=b|0;lu(a,b)}function dX(a){return(a|0)>=120?120:a}function dP(a){return x[a+1074424>>2]}function ck(a,b){return pm(a,b)&65535}function cP(a){return x[a+1074416>>2]}function bia(a,b){a=a|0;b=b|0;wF(a,b)}function aH(a,b){Ns(a,b,12,357913942)}function _z(a,b){a=a|0;b=b|0;return 1}function _h(a,b,c){return _p(a,b,c,1)}function _8(a){a=a|0;return VK(a,1)|0}function Zl(a,b){return v[a|0]<v[b|0]}function Yi(a,b,c){iD(b,c,a);return a}function YL(a){x[a>>2]=94884;return a}function Xe(a,b){x[a+4>>2]=b;return a}function Un(a){x[a>>2]=77472;return a}function U8(a){a=a|0;return UK(a,0)|0}function Tg(a,b,c){return _p(a,b,c,2)}function TM(a){x[a>>2]=48828;return a}function T8(a){a=a|0;return UK(a,1)|0}function Ska(a,b){a=a|0;b=b|0;Mr(a,b)}function SV(a,b,c){return Fx(a,b,c,5)}function SI(a){a=E(a-a);return E(a/a)}function RE(a,b){Ns(a,b,20,214748365)}function Qz(a){a=a|0;eI(a,47560,1007)}function Qj(a){return(a-1&255)>>>0<17}function PM(a){x[a>>2]=74488;return a}function NV(a){return(a&65535)==65534}function Mh(a){a=x[a>>2];if(a){EK(a)}}function MP(a){return Zi(OP(a)*32768)}function Ln(a,b,c){return Fx(a,b,c,2)}function Kka(a,b){a=a|0;b=b|0;MU(a,b)}function Jka(a,b){a=a|0;b=b|0;oT(a,b)}function Ji(a,b,c){_c(_c(a,b)+12|0,c)}function Ir(a,b,c){return Yp(a,b,c,6)}function Ht(a,b){a=a|0;b=b|0;return-1}function HT(a,b){return(0-b|0)!=(a|0)}function HP(a,b){a=a|0;b=b|0;return 0}function Gp(a,b,c){return Fx(a,b,c,1)}function Ez(a){x[a>>2]=48344;return a}function En(a){return(a&740327453)!=0}function Dz(a){x[a>>2]=48368;return a}function Cz(a){x[a>>2]=48448;return a}function CR(a,b){Xc(a,b&4?16:8,1,0,0)}function Bz(a){x[a>>2]=48488;return a}function AY(a){fz(a);Ie(x[a+80>>2],a)}function $8(a){a=a|0;return VK(a,0)|0}function zf(a){return F(a)==Infinity}function xq(a){return z[a+480192>>1]}function wq(a){return z[a+480190>>1]}function wF(a,b){a=a|0;b=b|0;K_(a,b)}function vd(a,b){return D(b,160)+a|0}function vZ(a,b){Ns(a,b,6,715827883)}function uW(a,b){return D(b,872)+a|0}function tG(a,b){Gx(a,b,3,536870912)}function q4(a,b){a=a|0;b=b|0;_w(a,b)}function pT(a){return(a+5&255)>>>0<2}function my(a){a=a|0;return v[a+8|0]}function mR(a,b){Ns(a,b,52,82595525)}function ly(a){a=a|0;return v[a+9|0]}function hC(a,b,c,d,e){UU(a,b,c,d,e)}function g3(a,b){a=a|0;b=b|0;Ax(a,b)}function fl(a){x[a+4>>2]=x[a+4>>2]+1}function fR(a,b){return Jk(a,b-a>>2)}function ev(a){return x[zb(a)>>2]<<5}function eP(a){return z[a+480214>>1]}function eC(a,b){a=a|0;b=b|0;AV(a,b)}function co(a,b){a=a|0;b=b|0;Zk(a,b)}function cka(a){a=a|0;return Ri(a)|0}function bX(a){return(a&255)>>>0<129}function az(a){return!kd(a,125976,6)}function ata(a){a=a|0;return JD(a)|0}function _2(a,b){a=a|0;b=b|0;Cs(a,b)}function Zk(a,b){a=a|0;b=b|0;Bm(a,b)}function Xr(a,b){a=a|0;b=b|0;ax(a,b)}function XV(a,b){Gx(a,b,4,268435456)}function Wf(a,b){a=a|0;b=b|0;lg(a,b)}function VD(a,b,c){vb(vb(a,b)+4|0,c)}function TV(a,b){Gx(a,b,5,134217728)}function T2(a,b){a=a|0;b=b|0;Up(a,b)}function Rx(a){return(a<<2)+502256|0}function Rga(a){a=a|0;x[a+4224>>2]=0}function Pka(a){a=a|0;return Kh(a)|0}function PP(a){x[a>>2]=0;x[a+4>>2]=0}function OO(a){return x[a+480272>>2]}function Mr(a,b){a=a|0;b=b|0;Wf(a,b)}function MQ(a,b,c){a=a|0;b=b|0;c=c|0}function LC(a,b){if(!gY(a,b)){aY(b)}}function H2(a,b){a=a|0;b=b|0;co(a,b)}function Fta(a){a=a|0;return k$(a)|0}function Ata(a){a=a|0;return Ec(a)|0}function Ao(a){return z[a+480188>>1]}function Ah(a){nf(a+52|0);dc(a+40|0)}function zr(a,b,c){return Wg(a,b,c)}function zJ(a){if(!y[a+4|0]){kJ(a)}}function yl(a,b,c){return AK(a,b,c)}function y0(a){a=a|0;return Yw(a)|0}function xv(a,b){return(b-a|0)/56|0}function xn(a,b){return a>>>0<b>>>0}function xY(a){if(!y[a+4|0]){tY(a)}}function wf(a,b){return D(b,24)+a|0}function wA(a,b){return D(b,28)+a|0}function vb(a,b){x[a>>2]=b;return a}function u9(a){a=a|0;return zl(a)|0}function rL(a){a=a|0;return Bl(a)|0}function qe(a,b){return Fc(a,me(b))}function pv(a,b){return D(b,36)+a|0}function pm(a,b){return(b-a|0)/52|0}function pd(a,b){return(a|0)!=(b|0)}function pU(a){if(!y[a+4|0]){wW(a)}}function oj(a,b){return(b-a|0)/24|0}function nja(a){a=a|0;Rr(a,22303,1)}function nW(a){if(!y[a+4|0]){mW(a)}}function nM(a){if(!y[a+4|0]){VH(a)}}function mr(a){return(a&255)==1?1:2}function mc(a,b){return(a|0)==(b|0)}function mN(a){if(!y[a+4|0]){lN(a)}}function mK(a,b,c){return kd(a,b,c)}function m7(a){a=a|0;return gy(a)|0}function km(a,b){return jm(Zc(a,b))}function js(a,b){return(b-a|0)/36|0}function jca(a,b){a=a|0;b=b|0;mP(a)}function im(a){if(!y[a+4|0]){N$(a)}}function gj(a,b){return D(b,52)+a|0}function gZ(a,b){return D(b,33)+a|0}function gW(a){if(!y[a+4|0]){fW(a)}}function fu(a,b,c){return Kz(a,b,c)}function fm(a){return mH(a,255,255)}function dh(a,b){return D(b,20)+a|0}function cj(a){if(!y[a+4|0]){TZ(a)}}function ch(a){if(!y[a+4|0]){oR(a)}}function bL(a){a=a|0;return jx(a)|0}function _x(a){a=a|0;return a+184|0}function _G(a,b,c){return mK(a,b,c)}function _1(a){a=a|0;return ai(a)|0}function Zx(a){a=a|0;return a+472|0}function Zu(a){if(!y[a+4|0]){KG(a)}}function Yx(a){a=a|0;return a+496|0}function Yj(a){if(!y[a+4|0]){QF(a)}}function YC(a,b){return uf(a,0-b|0)}function Xx(a){a=a|0;return a+508|0}function Xb(a,b){return Oe(a,b&255)}function Wx(a){a=a|0;return a+520|0}function WD(a,b){return uf(a,b-a|0)}function Vx(a){a=a|0;return a+532|0}function Vka(a){a=a|0;hI(a,116,115)}function VE(a){if(!y[a+4|0]){UE(a)}}function Ui(a,b,c){return ml(a,b,c)}function Uf(a,b){return(b-a|0)/20|0}function Ud(a,b){return(b-a|0)/12|0}function TF(a){a=a|0;return hh(a)|0}function Rw(a){v[a+2|0]=0;w[a>>1]=0}function Nr(a,b){return(b-a|0)/28|0}function Nj(a,b){return Lg(a,b)&255}function Ml(a){return K$(a,251,255)}function Lq(a){if(y[a+24|0]){iT(a)}}function Jv(a,b){return(b-a|0)/33|0}function Jca(a,b){a=a|0;b=b|0;YO(a)}function Iu(a){return!(a&204473357)}function Hr(a,b){return(b-a|0)/40|0}function Hd(a,b){return D(b,12)+a|0}function HW(a){if(!y[a+4|0]){GW(a)}}function Gw(a,b){w[a>>1]=b;return a}function EF(a){a=a|0;return Zd(a)|0}function D2(a){a=a|0;return Pg(a)|0}function CC(a,b){return D(b,56)+a|0}function Be(a,b,c){return BK(a,b,c)}function $1(a){a=a|0;kG(Rb(a,0,36))}function zF(a){return(a&255)+704|0}function yo(a,b){x[a+1298472>>2]=b}function wx(a,b){return $l(a,b,12)}function wu(a,b){return(a-b|0)/6|0}function wp(a){v[a|0]=0;v[a+1|0]=0}function vl(a){return(a&255)>>>0>1}function uy(a,b){return!(b>>>31|0)}function td(a){a=a|0;return a+16|0}function rG(a,b){return $l(a,b,36)}function qT(a){Ae(a+8|0);hT(a+4|0)}function pq(a,b){v[a|0]=b;return a}function ii(a,b){a=a|0;b=b|0;Fb(a)}function g_(a,b){return Dx(a,b,56)}function f0(a,b){return $l(a,b,28)}function es(a,b){return(b<<11)+a|0}function ej(a){return a&2147483647}function eZ(a,b){return Dx(a,b,18)}function cr(a,b){return(a|0)<(b|0)}function c$(a,b){x[a>>2]=x[a>>2]+b}function ZM(a){return(yk(a)|0)==-1}function YM(a,b){a=a|0;b=b|0;dc(b)}function XM(a,b){a=a|0;b=b|0;an(b)}function Wc(a,b){return D(b,6)+a|0}function Vk(a,b){return D(cl(b),a)}function V9(a,b){a=a|0;b=b|0;Db(b)}function Ro(a,b){return(b<<13)+a|0}function QJ(a){return Wh(a,500344)}function PJ(a){return Wh(a,500336)}function Ni(a){a=a|0;v[a+4202|0]=0}function Mk(a,b){return(b-a|0)/6|0}function MJ(a){return Wh(a,500360)}function Ly(a){return mc(a,-1)?0:a}function LJ(a){return Wh(a,500352)}function KJ(a){C[(fb-16|0)+8>>3]=a}function Gl(a,b){return(a+b|0)-1|0}function EB(a,b){return(b-a|0)/7|0}function Cd(a){return(a&128)>>>7|0}function Bc(a,b){return DH(a,b,-1)}function yb(a,b){return(b<<2)+a|0}function xz(a,b){return KR(a,b)^1}function wqa(a){a=a|0;ig(a,16865)}function wO(a,b){x[a+480272>>2]=b}function sc(a){x[a>>2]=0;return a}function rpa(a){a=a|0;OY(a,65535)}function pka(a){a=a|0;xg(a,Oj(a))}function nn(a,b){return(b<<8)+a|0}function kt(a,b){return BK(a,0,b)}function kM(a){return a+1298412|0}function kL(a){return eH(a,93624)}function i9(a){a=a|0;return 10422}function gC(a,b){return $l(a,b,4)}function g0(a){Gs(a,17,125288,33)}function esa(a){a=a|0;ig(a,16262)}function cg(a){return a!=a?E(0):a}function ce(a){return x[ec(a)>>2]}function cc(a,b){return Jb(a)+b|0}function bF(a){return a>>>0>8?5:4}function al(a){w[a>>1]=0;return a}function aU(a,b){return $l(a,b,8)}function aC(a){if(a){Db(a+-64|0)}}function _b(a,b){return(b<<1)+a|0}function Z3(a){a=a|0;return 13222}function Yh(a){x[a>>2]=1;return a}function Y3(a){a=a|0;return 10302}function Xd(a,b){return(b<<4)+a|0}function Wq(a){Gs(a,17,125340,51)}function Ue(a,b){return(b<<3)+a|0}function UF(a){return(a&16)>>>4|0}function UA(a){dc(a+4|0);return a}function Sc(a){return K$(a,1,120)}function Oh(a){return a-48>>>0<10}function Oe(a,b){return(b<<5)+a|0}function Nt(a){return eH(a,93560)}function Mx(a,b){return x[a+b>>2]}function Io(a){return a+1074328|0}function Ib(a,b){return mc(a,b)^1}function Gn(a){x[a>>2]=2;return a}function D3(a){a=a|0;return 13108}function C3(a){a=a|0;return 10825}function xqa(a){a=a|0;ig(a,3985)}function ww(a,b,c,d){KB(a,b,c,d)}function wg(a,b,c,d){cf(a,c,d,b)}function vF(a,b,c,d){kx(a,b,c,d)}function sv(a){v[a|0]=0;return a}function lf(a,b,c){wo(a,b,b+c|0)}function kw(a,b,c){tH(a,b,c,128)}function kF(a){Vm(a,Tp(a),78832)}function fca(a){a=a|0;au(a-88|0)}function fO(a){a=a|0;cu(a);Db(a)}function b4(a){a=a|0;return 6920}function asa(a){a=a|0;ig(a,4484)}function apa(a){a=a|0;ig(a,4165)}function ZK(a){x[a+72>>2]=499356}function Yra(a){a=a|0;ig(a,4378)}function VF(a){return(a&2)>>>1|0}function V3(a){a=a|0;return 6901}function SN(a){a=a|0;Um(a);Db(a)}function Qqa(a){a=a|0;mw(a,3863)}function Pba(a){a=a|0;au(a-92|0)}function PY(a,b){yc(a,b+4|0,256)}function PN(a){a=a|0;vq(a);Db(a)}function Ow(a,b){return Vua(a,b)}function Oqa(a){a=a|0;mw(a,4887)}function Mua(a){a=a|0;ig(a,4358)}function L2(a){a=a|0;ig(a,16892)}function Kg(a,b){vb(sc(a)+4|0,b)}function J2(a){a=a|0;hI(a,50,49)}function Hba(a){a=a|0;au(a-96|0)}function E3(a){a=a|0;return 9861}function Cta(a){a=a|0;ig(a,3872)}function BQ(a){return(a&8)>>>3|0}function B3(a){a=a|0;return 5720}function $K(a){x[a+72>>2]=499272}function zg(a){tb(a+20|0);tb(a)}function zd(a){return wb(Jb(a))}function yf(a,b){return Fc(a,b)}function xh(a,b){return Yc(a,b)}function wj(a,b){return a>>>b&1}function wR(a,b){return rA(a,b)}function vi(a,b,c){cf(a,c,20,b)}function vE(a,b,c){cf(a,c,30,b)}function ul(a){if(KK(a)){Db(a)}}function ub(a){ke(a+12|0);ke(a)}function tq(a,b){return yb(a,b)}function t_(a,b,c){cf(a,c,24,b)}function qE(a,b){return xn(a,b)}function nE(a,b){return pp(b,a)}function mk(a,b){return b-a>>11}function lt(a,b){return Ud(a,b)}function laa(a){a=a|0;Db(qM(a))}function kA(a,b){return fR(a,b)}function jk(a,b,c){cf(a,c,13,b)}function ic(a,b){return yG(a,b)}function iT(a){gT(a+12|0);fT(a)}function hq(a){return zb(a+8|0)}function hM(a,b){return jh(a,b)}function et(a){a=a|0;return 127}function en(a){tb(a+12|0);tb(a)}function e$(a,b){return WD(a,b)}function dba(a){a=a|0;Db(Yt(a))}function cp(a,b){return bl(a,b)}function ci(a,b){return pd(a,b)}function aj(a,b,c){cf(a,c,28,b)}function Zi(a){return Cn(Ee(a))}function Zh(a,b){return Jw(a,b)}function Zg(a,b){return Ib(a,b)}function Ze(a){return yr(Ee(a))}function Yc(a,b){return Cb(a,b)}function YD(a,b){return Fk(b,a)}function Xk(a,b,c){cf(a,c,22,b)}function Wb(a,b){return gj(a,b)}function WR(a,b){return TR(a,b)}function Vj(a,b){return Vc(a,b)}function Vg(a){return pT(a&255)}function Ve(a,b,c){cf(a,c,32,b)}function Tj(a,b){return Oe(a,b)}function Ti(a,b){return(a|b)!=0}function Sd(a,b){return oc(a,b)}function Pu(a){kU(a+12|0);oU(a)}function Pk(a,b,c){cf(a,c,12,b)}function Pc(a,b,c){gc(a,b,1<<c)}function Nl(a){SA(a,0);return a}function Nga(a){a=a|0;Db(bQ(a))}function NE(a){return(a&255)==1}function Mw(a,b){return DF(a,b)}function M2(a){a=a|0;ig(a,4532)}function Le(a){a=a|0;return a|0}function Kga(a){a=a|0;return 13}function KA(a){w[a+480214>>1]=0}function Ig(a){return Vi(a)?0:a}function Hc(a,b){return es(a,b)}function Hb(a,b){return(a&b)!=0}function HC(a,b,c){cf(a,c,64,b)}function HB(a,b){return Zc(a,b)}function Gy(a,b){return qh(a,b)}function Go(a,b){return Vt(a,b)}function Ge(a,b){return q0(a,b)}function Gd(a){return(a&255)!=0}function GF(a,b){return CF(a,b)}function Fc(a,b){return vb(a,b)}function Ek(a){tb(a+12|0);md(a)}function Bha(a){a=a|0;Db(mQ(a))}function Aia(a){a=a|0;Db(JQ(a))}function Af(a,b){return fh(a,b)}function Ad(a,b){return!Cb(a,b)}function $G(a,b){return _c(a,b)}function zha(a){a=a|0;return 6}function zX(a,b){Ex(a,b,5,3,4)}function zM(a){a=a|0;Db(AM(a))}function yia(a){a=a|0;return 9}function y4(a){a=a|0;Db(HI(a))}function wd(a,b){II(a,b,OC(b))}function vQ(a){a=a|0;Db(wQ(a))}function uX(a){return ll(a,56)}function sC(a){return a+4096|0}function rZ(a,b){wo(a,b,td(b))}function rO(a){a=a|0;Db(vq(a))}function rB(a,b){return a<<8|b}function pu(a){return a>>>27^a}function pp(a,b){return a-b>>1}function p9(a){a=a|0;Db(Et(a))}function p4(a){a=a|0;Db(EI(a))}function oc(a,b){return b-a>>2}function o4(a){a=a|0;Db(DI(a))}function n4(a){a=a|0;Db(CI(a))}function mo(a){return(a|0)==-1}function m4(a){a=a|0;Db(BI(a))}function m2(a){a=a|0;Db(xG(a))}function lG(a){return ll(a,36)}function lE(a){return ll(a,28)}function ju(a){a=a|0;Db(ag(a))}function jh(a,b){return b-a>>3}function j4(a){a=a|0;Db(AI(a))}function iR(a){return ll(a,52)}function gJ(a){a=a|0;Db(ay(a))}function g4(a){a=a|0;Db(zI(a))}function fc(a,b){x[a+100>>2]=b}function fL(a){a=a|0;Db(nq(a))}function fJ(a){a=a|0;Db($x(a))}function eL(a){a=a|0;Db(Ff(a))}function bo(a){a=a|0;Db(Z_(a))}function bA(a){a=a|0;Db(su(a))}function au(a){a=a|0;Db(uq(a))}function _s(a){a=a|0;Db(by(a))}function _d(a){return a&64?2:1}function Zc(a,b){return b-a>>1}function W_(a){return ll(a,20)}function WU(a){return ll(a,32)}function W5(a){a=a|0;Db(Zs(a))}function Vp(a){return ll(a,12)}function Ty(a){a=a|0;Db(Bl(a))}function Tn(a){a=a|0;Db(jx(a))}function Th(a,b){return b-a>>8}function T4(a){a=a|0;Db(TI(a))}function Sy(a){a=a|0;Db(no(a))}function Ry(a){a=a|0;Db(Gt(a))}function Rk(a){return a>>>0<11}function QQ(a){return a-2048|0}function Py(a){a=a|0;Db(Dt(a))}function Oy(a){a=a|0;Db(Ct(a))}function O5(a){a=a|0;Db(ZI(a))}function NO(a,b){hH(a,b,22303)}function MN(a,b){hH(a,b,13618)}function Lg(a,b){return b-a>>5}function KI(a){a=a|0;Db(Ys(a))}function Ik(a,b){return b-a>>4}function Ie(a,b){if(!a){Db(b)}}function Gv(a,b){return a-b>>2}function FJ(a){a=a|0;Db(gy(a))}function FI(a){a=a|0;Db(Vs(a))}function CG(a){return a+1024|0}function BV(a){return a+4896|0}function BU(a,b){_u(a,Jb(a),b)}function Az(a){return ll(a,16)}function zp(a){return a>>>0<5}function zV(a){return a+512|0}function zQ(a){a=a|0;return 3}function xr(a){return a+256|0}function xb(a,b){return a+b|0}function vL(a){a=a|0;return-1}function uQ(a){a=a|0;return 7}function tp(a,b){Ab(a+12|0,b)}function tk(a){return(a&5)!=0}function sM(a){return tk(a)^1}function nZ(a){op(Rb(a,0,40))}function kc(a){a=a|0;return 0}function kD(a,b){bc(a,b,4896)}function jr(a){return a>>>0<2}function iQ(a){a=a|0;return 5}function cW(a){return a-256|0}function as(a,b){cf(a,b,26,3)}function af(a,b){w[a+28>>1]=b}function Vc(a,b){return b-a|0}function So(a,b){x[a+36>>2]=b}function Sj(a){return!(a&255)}function R_(a,b){cf(a,b,40,2)}function PX(a,b){bc(a,b,1108)}function PC(a,b){bc(a,b,1024)}function On(a){return a&1?2:1}function OQ(a,b){ei(a,b,2048)}function Mj(a){return Dd(a)^1}function MC(a){return a+128|0}function Ke(a){a=a|0;return 2}function JR(a,b,c){Wl(a,b,-c)}function Fk(a,b){return a-b|0}function Fb(a){RG(a);return a}function FP(){return 20054022}function E0(a,b){bc(a,b,1954)}function Dy(a){return GK(a,0)}function Do(a){a=a|0;return 4}function De(a){a=a|0;return 1}function Dd(a){return(a|0)!=0}function Cy(a){return GK(a,1)}function BX(a,b){cf(a,b,33,1)}function B0(a,b){cf(a,b,13,1)}function Ak(a){return a+4e4|0}function $t(a,b){x[a+32>>2]=b}function yX(a){return a-56|0}function yF(a,b){bc(a,b,772)}function xE(a,b){bc(a,b,512)}function v_(a,b){bc(a,b,236)}function vD(a,b,c){de(a,b,c)}function uF(a,b){cf(a,b,8,3)}function r_(a){return a+10|0}function rW(a,b){yc(a,b,128)}function qp(a,b){Ge(a,b+8|0)}function qd(a,b){return a>>b}function pX(a,b){bc(a,b,146)}function pF(a,b){bc(a,b,497)}function ow(a,b){bc(a,b,192)}function ol(a){return a-24|0}function oZ(a,b){bc(a,b,128)}function nc(a){return a+12|0}function mx(a,b){LG(a,me(b))}function m_(a,b){bc(a,b,102)}function ln(a){return a-32|0}function lj(a){return a-36|0}function lX(a,b){bc(a,b,608)}function kr(a,b){return a<<b}function kj(a){PF(a,x[a>>2])}function kC(a){return a-16|0}function jU(a){iU(a,x[a>>2])}function il(a){return a-12|0}function iY(a){hY(a,x[a>>2])}function hp(a){return a+14|0}function gw(a){A$(a,x[a>>2])}function ep(a){MZ(a,x[a>>2])}function eY(a,b){bc(a,b,600)}function dr(a,b,c){Dp(a,b,c)}function dW(a,b){ei(a,b,256)}function dA(a){OQ(a,x[a>>2])}function bw(a){return a-40|0}function bc(a,b,c){gc(a,b,c)}function a_(a,b){bc(a,b,576)}function aV(a){$U(a,x[a>>2])}function _P(a){return a+48|0}function ZZ(a,b){bc(a,b,674)}function Yd(a,b){x[a+4>>2]=b}function YX(a,b){bc(a,b,126)}function Wo(a){return a+32|0}function WS(a,b,c){j_(a,b,c)}function W0(a,b,c){ef(a,c,b)}function Vh(a,b,c){u$(a,b,c)}function VV(a){dW(a,x[a>>2])}function VG(a,b,c){hf(a,c,b)}function Tp(a){return a+20|0}function Te(a,b){a=a|0;b=b|0}function TC(a,b){bc(a,b,130)}function SY(a){return a+3&-4}function RZ(a){return a+36|0}function QW(a,b){bc(a,b,204)}function Nf(a){$Q(a,x[a>>2])}function ND(a,b){cf(a,b,8,2)}function Me(a,b){v[a+11|0]=b}function M$(a){L$(a,x[a>>2])}function Lr(a){return a-28|0}function L_(a,b){bc(a,b,218)}function Kb(a,b,c){XF(a,b,c)}function JG(a){IG(a,x[a>>2])}function IB(a){v[a+6152|0]=0}function H_(a,b){bc(a,b,157)}function GV(a,b){bc(a,b,263)}function Fq(a,b){B[a+8>>2]=b}function FA(a,b){v[a+34|0]=b}function Eq(a,b){B[a+4>>2]=b}function EA(a,b){v[a+32|0]=b}function Dq(a,b){v[a+33|0]=b}function Dn(a,b){x[a+8>>2]=b}function DZ(a){JJ(a,x[a>>2])}function DA(a,b){v[a+35|0]=b}function Cu(a){sS(a,x[a>>2])}function B_(a,b){bc(a,b,206)}function BA(a,b){SA(a,me(b))}function Ac(a,b,c){vn(a,b,c)}function $Y(a){return a-33|0}function $V(a){_V(a,x[a>>2])}function $T(a,b,c){we(a,b,c)}function $R(a){return a+24|0}function $$(a,b){bc(a,b,610)}function zb(a){return a+8|0}function yw(a,b){bc(a,b,65)}function yg(a,b){v[a+3|0]=b}function xf(a){return a-4|0}function uE(a,b){wH(a,b,32)}function tu(a){Rb(a,0,2048)}function tZ(a){return a-6|0}function tE(a){x[a+12>>2]=0}function s_(a){return a+6|0}function pf(){g0(11050);p()}function pZ(a,b){bc(a,b,80)}function nw(a,b){wH(a,b,64)}function jn(){Wq(11050);p()}function iw(a,b){bc(a,b,64)}function hw(a,b){bc(a,b,66)}function hY(a,b){ei(a,b,32)}function hF(a,b){bc(a,b,38)}function hD(a,b){bc(a,b,33)}function fs(a,b){bc(a,b,36)}function fF(a,b){Ci(a,b,37)}function ex(a,b){bc(a,b,20)}function ec(a){return a+4|0}function dj(a){return a+3|0}function bE(a,b){bc(a,b,16)}function aZ(a,b){ei(a,b,33)}function aD(a,b){bc(a,b,40)}function _V(a,b){ei(a,b,16)}function Zv(a,b){bc(a,b,22)}function VA(a){Rb(a,0,4096)}function UY(a,b){bc(a,b,52)}function U0(a,b){gc(a,b,20)}function T_(a,b){bc(a,b,98)}function ST(a){return a-7|0}function R0(a,b){bc(a,b,17)}function Pw(a,b){gc(a,b,22)}function Pf(a){return a&255}function PW(a){return a-1|0}function PE(a,b){bc(a,b,32)}function Op(a){return a-8|0}function O_(a,b){bc(a,b,48)}function NN(a){return 0-a|0}function NG(a,b){bc(a,b,24)}function Mn(a){return a-2|0}function LV(a,b){return a<b}function Kv(a,b){return a<b}function Kn(a,b){gc(a,b,32)}function Jc(a){return a+1|0}function JJ(a,b){ei(a,b,24)}function Hw(a,b){bc(a,b,11)}function Hq(a){Rb(a,0,8192)}function H$(a,b){yc(a,b,40)}function Fr(a,b){bc(a,b,12)}function Fh(a){return a&127}function FU(a,b){bc(a,b,27)}function EP(){return 524288}function Dda(a){a=a|0;CP(a)}function DX(a,b){bc(a,b,96)}function D0(a){Rb(a,0,1954)}function Cv(a,b){bc(a,b,30)}function Bp(a,b){v[a+1|0]=b}function A$(a,b){ei(a,b,40)}function $e(a){return a+2|0}function zk(a,b){B[a>>2]=b}function yd(a,b){x[a>>2]=b}function xc(a){x[a+8>>2]=0}function xF(a){Rb(a,0,772)}function wha(){return fb|0}function vs(a){a=a|0;xs(a)}function uc(a){a=a|0;Db(a)}function u_(a){Rb(a,0,236)}function tQ(a,b){bR(a,3,b)}function tF(a,b){Vh(a,2,b)}function rn(a,b){Dp(a,b,0)}function oX(a){Rb(a,0,146)}function oF(a){Rb(a,0,497)}function nh(a,b){bc(a,b,4)}function lga(a){a=a|0;fb=a}function lW(a){oC(a,ce(a))}function k_(a){ED(a,ce(a))}function kX(a){Rb(a,0,608)}function kW(a){pC(a,ce(a))}function kU(a){Qq(a,ce(a))}function j1(a){a=a|0;ai(a)}function gT(a){Ku(a,ce(a))}function fT(a){Lu(a,ce(a))}function ek(a,b){bc(a,b,5)}function dl(a,b){bc(a,b,8)}function dd(){g0(7718);p()}function dY(a){Rb(a,0,600)}function cD(a){bD(a,ce(a))}function aW(a){Rb(a,0,256)}function _$(a){Rb(a,0,610)}function Zr(a,b){bc(a,b,1)}function Zb(a){Am(x[a>>2])}function Xs(a){ul(x[a>>2])}function XX(a){Rb(a,0,126)}function WZ(a){Rb(a,0,192)}function Vi(a){return a!=a}function Tv(a){DD(a,ce(a))}function Tl(a){DB(a,ce(a))}function TD(a,b){bc(a,b,6)}function Pr(a,b){bc(a,b,7)}function Pe(a){v[a+12|0]=1}function PF(a,b){ei(a,b,2)}function OW(a){Rb(a,0,204)}function NR(a){AA(a,ce(a))}function MZ(a,b){ei(a,b,1)}function L$(a,b){ei(a,b,6)}function JZ(a){pD(a,ce(a))}function JC(a){Rb(a,0,130)}function IG(a,b){ei(a,b,8)}function Hp(a,b){bc(a,b,2)}function HZ(a){qD(a,ce(a))}function G_(a){Rb(a,0,157)}function Fia(a){a=a|0;gb=a}function Ew(){Wq(7718);p()}function A_(a){Rb(a,0,206)}function $w(a,b){bc(a,b,3)}function $Z(a){Rb(a,0,576)}function $Q(a,b){ei(a,b,4)}function vO(){return 2048}function mD(a){Rb(a,0,80)}function kE(a){Rb(a,0,66)}function gs(a){Rb(a,0,36)}function gF(a){Rb(a,0,38)}function fd(a,b){v[a|0]=b}function f_(a){Rb(a,0,56)}function aw(a){Rb(a,0,64)}function ZY(a){Rb(a,0,33)}function TY(a){Rb(a,0,52)}function S_(a){Rb(a,0,98)}function RQ(a){Em(a,2048)}function Qd(a){v[a+4|0]=1}function P_(a){Rb(a,0,48)}function Jp(a){return a&1}function Hh(a){tb(a+16|0)}function EX(a){Rb(a,0,96)}function uG(a,b){IG(a,b)}function sD(a,b){L$(a,b)}function qR(a,b){sS(a,b)}function or(a,b){MZ(a,b)}function mE(a,b){Sk(a,b)}function kg(a,b){l0(a,b)}function j$(a,b){XU(a,b)}function hU(a){Ae(a+8|0)}function gD(a,b){XY(a,b)}function fj(a,b){Gw(a,b)}function fW(a){iH(a,872)}function eA(a,b){qe(a,b)}function bd(a,b){Ds(a,b)}function _U(a,b){$U(a,b)}function YT(a,b){i0(a,b)}function Wj(a){tb(a+4|0)}function Vo(a,b){_c(a,b)}function VU(a,b){pg(a,b)}function Uu(a,b){cS(a,b)}function Sh(a,b){Vo(a,b)}function SD(a,b){ic(a,b)}function Rn(a,b){gG(a,b)}function Rd(a,b){Mg(a,b)}function Qg(a){a=a|0;p()}function Ki(a,b){mi(a,b)}function Kc(a){dc(a+8|0)}function In(a,b){PF(a,b)}function Ih(a,b){$Q(a,b)}function IX(a,b){Ge(a,b)}function IU(a,b){Gh(a,b)}function Fd(a){ub(a+8|0)}function Dl(a,b){pq(a,b)}function Co(a,b){vb(a,b)}function CW(a,b){_l(a,b)}function As(a,b){$G(a,b)}function $C(a,b){HY(a,b)}function xka(){ua();p()}function kp(a){EH(a,16)}function eh(a){v[a|0]=0}function Yn(a){Bx(a,36)}function NJ(a){Em(a,24)}function GI(a){Bx(a,48)}function D$(a){Em(a,40)}function Cp(a){EH(a,11)}function Ag(a){Bx(a,24)}function wZ(a){Em(a,6)}function vh(a){fN(a,0)}function uh(a){dN(a,0)}function uI(){va();p()}function rs(a){LG(a,0)}function og(a){IZ(a,0)}function ls(a){Em(a,8)}function jj(a){Em(a,2)}function ZR(a){zS(a,0)}function XA(a){vS(a,0)}function WA(a){uS(a,0)}function UT(a){Em(a,7)}function S3(){uI();p()}function Lc(a){Se(a,0)}function Hl(a){eN(a,0)}function GW(a){iH(a,9)}function ys(a){nc(a)}function yW(a){Je(a)}function vV(a){le(a)}function cU(a){Xo(a)}function an(a){vc(a)}function Vw(a){al(a)}function Lf(a){a=a|0}function JX(a){sv(a)}function IC(a){vg(a)}function HV(a){sc(a)}function Eb(a){tb(a)}function EW(a){Nb(a)}
// EMSCRIPTEN_END_FUNCS
e=y;var ib=c([null,tc,MG,Bm,x2,AG,n2,d2,a2,sG,nG,oe,H1,F1,wF,A1,y_,Z_,hoa,goa,coa,Qua,Oua,pw,bk,Aua,Z,dta,Bw,rm,lL,Kh,rp,qta,Le,loa,Dc,N5,GD,Nk,rr,Bn,ysa,E_,si,AV,eC,una,Rma,MU,xla,Nla,sg,Hka,Uj,Aka,xka,wka,qka,MA,gka,fka,Vga,yja,jR,N9,M9,It,jR,cga,qP,lg,Cfa,bfa,sea,mea,gea,$da,Vda,Qda,Lda,xda,Oca,mda,Qy,ua,Mb,$5,q5,f5,X4,R4,co,D4,Kka,q4,Jka,d4,da,A3,j3,i3,h3,g3,f3,zH,e3,d3,c3,b3,a3,_2,Z2,$2,f9,Cs,Xp,sg,Y2,YG,XG,X2,tx,W2,WG,Wf,V2,T2,R2,vs,us,bi,ig,O2,Up,Q2,P2,N2,U2,M2,SG,L2,SG,S2,TG,K2,J2,I2,H2,G2,cd,Mb,D2,Sp,C2,Kh,B2,rd,A2,gl,rd,lx,z2,jx,ix,$1,y2,p2,o2,_1,X1,U1,T1,Yw,kG,S1,R1,aka,bka,PT,_ja,$ja,CA,xu,Vb,cka,fe,hG,O1,N1,TF,L1,K1,TF,EF,Lw,E1,Ng,EF,Iw,oja,zja,nja,kf,Qka,M1,ug,Dua,Pka,Pta,_E,ZE,t1,s1,YE,r1,fg,q1,p1,Cc,Aw,o1,n1,m1,Vf,l1,qm,k1,WE,j1,g1,KE,f1,e1,d1,uw,c1,mF,JE,b1,a1,$0,_0,Z0,EE,X0,N0,Bd,qw,Mua,Lua,CE,BE,Kua,Jua,Iua,Aw,Hua,M0,Gua,vw,Fua,Eua,$k,xua,Or,wua,Lb,dg,ig,vua,wE,uua,id,Uk,tua,sua,rua,y0,x0,ld,qua,sp,pua,oua,nua,u0,t0,Nk,mw,mua,lua,Hla,kua,gh,jua,iua,cua,$j,fua,eua,dua,hua,gua,Wf,k0,$h,Tf,$ta,_ta,Zta,Wta,$j,_j,Vta,Uta,Tta,hE,U$,gE,Sta,Rta,Qta,$k,y$,v$,Mta,Hta,m$,vo,Gta,xg,Z$,Fta,uw,Eta,Dta,_D,Cta,l$,ix,Bta,g$,f$,z_,zta,$k,wta,Or,fk,vta,uta,x0,tta,sta,rta,$_,__,sm,pta,ota,nta,lta,$j,Y_,mta,$h,Tf,fE,gta,Kr,l$,$sa,_sa,Zsa,Ysa,Vsa,Or,Usa,Tsa,np,$_,Ssa,Rsa,ig,Qsa,Psa,Osa,Nsa,Msa,q_,Lsa,Ksa,AK,p_,Jsa,Isa,L0,o_,Hsa,Gsa,Fsa,Ola,Esa,n_,Dsa,n_,ata,Bsa,$j,Csa,$h,Tf,gk,vsa,usa,tsa,ssa,psa,osa,nsa,msa,lsa,np,ksa,jsa,isa,yD,G1,hsa,gsa,fsa,esa,dsa,VZ,csa,D1,bsa,asa,$ra,_ra,UZ,Zra,wsa,Yra,Xra,ig,Wra,jE,Vra,xsa,Ura,Tra,Sra,uD,uD,SZ,Rra,Qra,QZ,uD,NZ,Pra,n9,Ora,Nra,Mra,Lra,Kra,Jra,Ira,LZ,rd,nr,xra,Rv,Hra,aja,$ia,_ia,Zia,Yia,Xia,Gra,Fra,pg,Era,Dra,Cra,Bra,MG,Gla,Ela,lja,wja,xja,Ara,KZ,zra,yra,lka,Via,Zk,WG,Cla,Jla,Bla,Ala,Pv,tra,sra,rra,qra,pra,ora,nra,mra,lra,kra,jra,hra,gra,ira,YY,Tf,QY,fD,dra,eD,cra,bra,ara,$qa,dD,_qa,Lw,YE,Zqa,OY,NY,Yqa,Ur,Xqa,rf,Wqa,KY,np,HE,np,o_,Xr,ig,_E,np,vo,Tqa,Sqa,Rqa,Qqa,_C,Dv,Pqa,Oqa,Nqa,Mqa,Lqa,Kqa,Jqa,Iqa,Hqa,Gqa,Fqa,Eqa,Dqa,Cqa,Bqa,rD,Aqa,zqa,yqa,ig,PZ,OZ,AD,xqa,wqa,CE,ix,vqa,uqa,tqa,sqa,rqa,lla,kla,jla,nqa,oqa,Mr,pqa,qqa,fw,mY,kqa,Oka,pla,Wu,Nka,Mka,JT,Qu,DT,Lka,tT,NU,Ika,RB,Lj,Bi,dqa,cqa,Er,lqa,Mv,$pa,H0,_pa,Zpa,VX,nr,Ypa,Xpa,Cw,Wpa,KZ,Vpa,Upa,Dr,Tpa,Spa,Rpa,Qpa,GC,Lpa,EC,Kpa,Jpa,OX,Ep,Ipa,$j,$h,Tf,Bi,Fpa,Epa,Dpa,Cpa,eD,zpa,ypa,Dr,xpa,qm,Aja,upa,tpa,_j,LX,EC,vw,spa,OX,rpa,qpa,ppa,zv,opa,zv,npa,Cm,I1,kpa,$j,mpa,zC,tX,uv,lpa,$h,Tf,Er,hpa,epa,fD,dpa,apa,$oa,gX,Cw,yD,_oa,CE,ig,Roa,Qoa,Aw,Poa,Ooa,Noa,Moa,Vv,Loa,sp,Ioa,Hoa,Goa,Foa,Eoa,Doa,on,zW,Coa,Boa,Aoa,zoa,yoa,xoa,woa,voa,uoa,toa,soa,roa,qoa,eD,poa,ooa,noa,Mv,moa,koa,joa,Or,ala,Sp,y0,hla,gla,Or,fla,Bi,Sp,ela,dla,cla,ioa,hW,doa,boa,aoa,$na,_na,$r,Xna,Wna,Vna,Una,Tna,Sna,Rna,Qna,Pna,Ona,Nna,H3,WI,Mna,ig,Lna,Kna,mla,Pla,Ata,bV,Lla,Kla,ZU,Ila,Fla,Dla,OU,vla,yla,wla,ula,Zd,tla,DU,sla,rla,qla,tU,sU,qU,Qo,mU,ola,nla,ila,lp,_ka,_j,QT,ss,Zja,Yja,Xja,Rka,Wja,J1,Vja,Zw,ss,N0,Uja,QT,Yka,Tja,bla,$j,$h,Tf,$ka,$j,$h,Tf,Zka,$j,$h,Tf,Wka,Tka,Ska,Le,X0,Gka,Fka,Eka,Dka,Cka,Bka,Mla,Gna,aQ,zka,Ec,vka,rja,uka,F2,Z1,Q1,W1,ska,rka,P1,Y1,E2,V1,mS,pka,oka,nka,lS,kS,RA,mka,zla,kka,jka,ika,hka,hR,jja,Bja,sx,oT,AG,OG,CA,lS,dka,Zk,Bs,Tr,Vka,Xka,Pja,Oja,_j,Nja,EC,Mja,Lja,Kja,Er,Jja,Bi,Ija,Hja,Gja,Fja,Eja,$j,$h,Tf,Qja,vja,uja,tja,sja,mi,Tm,qja,pja,uu,vu,mja,hja,gja,fja,eja,dja,eR,kja,Cq,dR,tl,mi,pg,bja,Wia,A9,cja,ija,Tia,Sia,iia,Ria,Qia,UQ,$f,cR,Bia,jia,un,dia,Sja,cia,aia,$ha,_ha,CA,bia,se,lu,lu,Zha,Yha,Wha,GQ,xQ,Cha,sha,lha,eha,Yga,Oga,Qga,Ega,xga,IP,iu,rga,qga,Haa,Iaa,DP,iga,CP,BP,eka,Kaa,ega,IP,dga,qba,eba,tba,wP,oM,vP,Qz,$fa,Uda,vq,Tda,Rm,uP,nba,sP,mba,tP,lba,rP,AK,Fba,Wfa,oba,Pz,KY,Oz,Nz,Mz,Mfa,Kfa,vP,Qz,Hfa,Gfa,Ffa,Efa,Dfa,Bfa,Afa,zfa,yfa,xfa,wfa,vfa,ufa,tfa,sfa,rfa,qfa,pfa,ofa,nfa,mfa,lfa,kfa,jfa,ifa,pP,oP,nP,zG,_9,uba,mP,$O,jba,_O,ZO,Eba,baa,caa,YO,haa,UO,TO,lz,RO,Qz,PO,MO,LO,zo,aaa,$9,KO,JO,IO,HO,GO,FO,EO,DO,CO,BO,AO,zO,Jz,yO,xO,hS,Bv,Iz,Hz,_da,uO,Zda,Yda,Xda,oO,Pda,wP,Oda,hda,Nda,gda,Mda,fda,Kda,eda,Jda,dda,Ida,cda,Gda,saa,oM,fr,Uka,Ax,ts,qU,Aba,zba,yba,wba,sba,yka,pba,hba,kba,K9,z9,y9,iba,qm,$k,$k,fba,tka,rba,Bba,vba,ox,_,Jaa,hN,gN,Hz,CM,Gaa,Faa,waa,tM,raa,qaa,maa,gaa,faa,eaa,daa,Z9,Y9,X9,bS,Hna,W9,V9,U9,T9,P9,O9,cL,bL,c4,G9,F9,E9,D9,C9,B9,Le,W3,W4,g9,bL,Ky,R8,Q8,Ay,ki,ji,mt,Db,Pv,sh,Al,yy,Km,I8,H8,uj,rh,rK,tj,Ny,sy,ki,ji,it,li,u9,rm,lo,uj,rh,nK,tj,n8,i8,hL,d8,At,rp,_7,ft,Lf,I7,io,H7,G7,F7,RJ,D7,Jt,B7,A7,yj,z7,RJ,x7,zZ,v7,u7,r7,q7,f7,e7,d7,c7,b7,a7,$6,_6,Z6,Y6,X6,W6,V6,U6,T6,S6,R6,Q6,P6,O6,N6,M6,L6,K6,J6,I6,H6,G6,F6,E6,D6,C6,B6,AJ,A6,M5,L5,K5,J5,I5,YI,H5,XI,G5,F5,E5,D5,C5,B5,A5,z5,y5,x5,w5,v5,u5,t5,s5,r5,p5,o5,n5,m5,l5,k5,j5,i5,h5,g5,e5,d5,c5,b5,Y4,k4,l4,a5,$4,_4,Z4,Gm,jq,A4,z4,V4,U4,E4,C4,B4,uk,s4,r4,ho,ny,si,uI,Tn,ps,Fna,Ena,Dna,Cna,Bna,Ana,zna,yna,xna,wna,vna,tna,sna,rna,qna,pna,ona,nna,mna,lna,kna,jna,ina,hna,gna,fna,ena,dna,cna,bna,ana,$ma,_ma,Zma,Yma,Xma,Wma,Vma,Uma,Tma,Sma,Qma,Pma,Oma,Nma,Mma,Lma,Kma,Jma,Ima,Hma,Gma,Fma,Ema,Dma,Cma,Bma,Ama,zma,yma,xma,wma,vma,uma,tma,sma,rma,qma,pma,oma,nma,mma,lma,kma,jma,ima,hma,gma,fma,ema,dma,cma,bma,ama,$la,_la,Zla,Yla,Xla,Wla,Vla,Ula,Tla,Sla,Rla,Qla,Tn,Zna,Yna,rsa,qsa,cpa,bpa,Xoa,Woa,fra,era,Ppa,Opa,vra,ura,zua,yua,kta,jta,i1,h1,Pua,Nua,Hpa,Gpa,gpa,fpa,foa,eoa,Yta,Xta,Ota,Nta,x1,w1,v1,u1,wpa,vpa,jpa,ipa,bqa,aqa,wra,jZ,fta,eta,Asa,zsa,bua,aua,yta,xta,Bpa,Apa,Rja,Dja,Cja,Xsa,Wsa,cta,bta,fqa,eqa,Koa,Joa,Npa,Mpa,ita,hta,Zoa,Yoa,Toa,Soa,Jta,Ita,Voa,Uoa,mqa,hqa,gqa,z1,y1,C1,B1,Cua,Bua,Vqa,Uqa,Lta,Kta,jqa,iqa,Jna,Ina,bo,ps,b2,uc,xm,HP,uc,Le,uc,kc,De,De,kc,kc,c2,s2,r2,e2,uc,xm,uc,xG,m2,l2,De,k2,j2,i2,h2,g2,f2,su,bA,ru,NQ,kc,Lf,kc,kc,kc,Te,Do,Pia,Oia,Nia,Mia,Lia,Oi,_z,_z,Zz,MQ,Zz,LQ,Zz,LQ,Lf,jZ,Kia,Jia,Iia,Hia,Gia,Ni,KQ,fia,kc,kc,De,Yz,Ke,Ke,De,Eia,Dia,Te,Lf,Te,Lf,JQ,Aia,zia,kc,Lf,kc,kc,kc,Te,yia,IQ,xia,wia,via,uia,Oi,tia,sia,ria,qia,pia,oia,nia,mia,lia,kia,Ni,EQ,kc,kc,De,Ke,Ke,De,HQ,FQ,ag,Qg,S3,hia,$z,gia,kc,eia,MQ,Nha,Dha,tha,mha,fha,Zga,Pga,Fga,yga,_ga,Uia,Cia,Xha,su,bA,NQ,kc,Lf,kc,kc,kc,Te,zQ,Vha,Uha,Tha,Sha,Rha,Oi,Qha,Ni,yQ,kc,kc,De,Ke,Ke,De,Pha,Oha,mQ,Bha,Aha,kc,Lf,kc,kc,kc,Te,zha,yha,xha,vha,Oi,uha,Ni,jQ,kc,kc,De,Ke,Ke,ju,rha,kc,Lf,kc,kc,kc,Te,iQ,qha,pha,oha,Oi,nha,Ni,gQ,kc,kc,De,Ke,Ke,su,bA,kha,kc,Lf,kc,kc,kc,Te,iQ,jha,iha,hha,Oi,gha,Ni,eQ,kc,kc,De,Ke,Ke,wQ,vQ,dha,kc,Lf,kc,kc,kc,Te,uQ,cha,Kha,Jha,Oi,Iha,Ni,Hha,kc,kc,De,Ke,Ke,Te,Lf,sQ,bha,aha,rQ,$ga,qQ,pQ,vQ,Mha,uQ,Lha,sQ,Gha,Fha,rQ,Eha,qQ,pQ,ju,Xga,kc,Lf,kc,kc,kc,Te,Ke,Wga,Uga,Tga,Oi,Sga,Ni,Rga,kc,kc,De,Ke,Ke,bQ,Nga,Mga,kc,Lf,kc,kc,Lga,Te,Kga,Jga,Iga,Hga,Oi,Gga,Ni,Sz,kc,kc,De,Ke,Ke,Te,Lf,ju,Dga,kc,Lf,kc,kc,kc,Te,zQ,Cga,Bga,Aga,Oi,zga,Ni,VP,kc,kc,De,Ke,Ke,ju,wga,kc,Lf,kc,kc,kc,Te,Do,vga,uga,tga,Oi,sga,Ni,SP,kc,kc,De,Ke,Ke,du,uc,Sda,rO,LN,rO,PN,Um,SN,cu,fO,uq,au,ica,hca,JN,IN,HN,GN,FN,EN,DN,CN,BN,AN,zN,yN,xN,wN,vN,uN,tN,sN,rN,qN,pN,oN,nN,gca,fca,eca,dca,cca,bca,aca,$ba,_ba,Zba,Yba,Xba,Wba,Vba,Uba,Tba,Sba,Rba,Qba,Pba,Oba,Nba,Mba,Lba,Kba,Jba,Iba,Hba,Gba,Le,Qg,Le,Qg,Le,Qg,Le,Qg,Qg,Dba,uc,Cba,Yt,dba,xba,Le,Qg,Le,uc,cba,bba,Qg,VM,UM,VM,UM,Te,Zt,Te,Zt,YM,XM,YM,XM,uc,gba,Le,uc,aba,$aa,uc,OM,NM,Qg,Yaa,LM,Xaa,LM,_aa,MM,Zaa,MM,uc,Waa,Vaa,uc,KM,JM,Ut,Ut,Ut,Ut,Uaa,qz,qz,qz,uc,Taa,Saa,uc,IM,HM,Paa,FM,Oaa,FM,Raa,GM,Qaa,GM,uc,Naa,Maa,uc,EM,DM,Tt,Tt,Tt,Tt,Laa,oz,oz,oz,taa,uc,xm,uc,uc,De,De,kc,kc,ps,vaa,uaa,Qg,Qg,xaa,uc,xm,uc,AM,zM,De,kc,De,Eaa,Daa,Caa,Baa,Aaa,zaa,yaa,Qg,iaa,uc,xm,uc,qM,laa,kaa,jaa,Qg,naa,uc,xm,uc,zM,paa,oaa,q2,uc,xm,uc,uc,w2,De,De,ps,os,v2,u2,t2,Te,Zt,Te,Zt,S9,R9,Q9,no,Sy,Te,yL,xL,wL,kc,kc,J9,vL,I9,Ht,H9,Ht,Ct,Oy,Te,yL,xL,wL,kc,kc,x9,vL,w9,Ht,v9,Ht,Et,p9,q9,o9,t9,s9,r9,nq,fL,m9,l9,Dt,Py,nL,mL,Ff,eL,k9,j9,Gt,Ry,tL,sL,Le,uc,i9,a4,$3,_3,h9,Tn,L9,kc,e9,Sy,V8,U8,T8,S8,rL,Ty,Bl,Ty,Sy,Y8,WK,X8,W8,Oy,a9,$8,_8,Z8,Gt,Ry,tL,sL,rL,Ty,Oy,d9,WK,c9,b9,Dt,Py,nL,mL,ZI,O5,ru,zI,g4,f4,e4,N8,AI,j4,i4,h4,K8,Zs,W5,V5,U5,T5,S5,sY,R5,Q5,P5,Vs,FI,w4,v4,u4,t4,Ys,KI,Q4,P4,O4,N4,M4,L4,K4,J4,I4,H4,G4,F4,gy,FJ,l7,k7,j7,i7,kc,h7,g7,$x,fJ,my,ly,ky,j6,i6,ay,gJ,os,jy,iy,l6,k6,fJ,gJ,Le,uc,uc,g6,f6,e6,d6,c6,b6,a6,_5,sY,Z5,Y5,X5,uc,_I,_I,fq,De,De,h6,De,uc,bJ,aJ,fq,kc,kc,$I,Do,uc,bJ,aJ,fq,kc,kc,$I,Do,uc,eJ,dJ,fq,kc,kc,cJ,Do,uc,eJ,dJ,fq,kc,kc,cJ,Do,Le,uc,P8,O8,Le,uc,M8,L8,uc,J8,G8,F8,E8,vK,vK,D8,C8,B8,A8,z8,uc,y8,x8,w8,v8,lK,lK,u8,t8,s8,r8,q8,uc,p8,o8,m8,l8,k8,j8,h8,g8,uc,f8,e8,c8,b8,a8,$7,Z7,Y7,Le,uc,Ke,X7,W7,V7,U7,T7,S7,s6,r6,q6,p6,o6,n6,m6,Le,uc,Ke,R7,Q7,P7,O7,N7,M7,z6,y6,x6,w6,v6,u6,t6,HI,y4,x4,td,_x,Zx,Yx,Xx,Wx,Vx,RI,QI,PI,OI,NI,MI,LI,TI,T4,S4,td,_x,Zx,Yx,Xx,Wx,Vx,RI,QI,PI,OI,NI,MI,LI,by,_s,L7,by,_s,K7,_s,_s,uc,et,et,ii,ii,ii,cK,kc,hi,hi,uc,et,et,ii,ii,ii,cK,kc,hi,hi,uc,dt,dt,ii,ii,ii,bK,kc,hi,hi,uc,dt,dt,ii,ii,ii,bK,kc,hi,hi,BI,m4,my,ly,ky,aK,lz,$J,_J,ZJ,ct,CI,n4,my,ly,ky,aK,lz,$J,_J,ZJ,ct,DI,o4,os,jy,iy,XJ,WJ,VJ,UJ,ct,TJ,EI,p4,os,jy,iy,XJ,WJ,VJ,UJ,ct,TJ,uc,J7,E7,uc,C7,y7,uc,w7,t7,uc,s7,p7,uc,GJ,o7,Te,uc,GJ,n7,Te,uc,uc,Le,uc,m7,FJ,Le,uc,Le,uc,Le,uc,Le,uc,FI,KI,Le,Qg,uc,b4,uc,Z3,wI,uc,Y3,X3,wI,Tn,Qg,uc,V3,va,Le,uc,Lf,Lf,R3,J3,L3,M3,uc,D3,uc,C3,bo,Tn,bo,bo,bo,bo,Tn,uc,B3,uc,I3,K3,N3,uc,Q3,P3,O3,uc,E3]);function jb(){return u.byteLength/65536|0}function ob(pb){pb=pb|0;var kb=jb()|0;var lb=kb+pb|0;if(kb<lb&&lb<65536){var mb=new ArrayBuffer(D(lb,65536));var nb=new Int8Array(mb);nb.set(v);v=new Int8Array(mb);w=new Int16Array(mb);x=new Int32Array(mb);y=new Uint8Array(mb);z=new Uint16Array(mb);A=new Uint32Array(mb);B=new Float32Array(mb);C=new Float64Array(mb);u=mb;t.buffer=u;e=y}return kb}return{"va":Y0,"wa":EP,"xa":EP,"ya":FP,"za":FP,"Aa":uc,"Ba":Db,"Ca":jga,"Da":DP,"Ea":hga,"Fa":gga,"Ga":iu,"Ha":Te,"Ia":mga,"Ja":kga,"Ka":pga,"La":_z,"Ma":nga,"Na":HP,"Oa":oga,"Pa":Le,"Qa":LP,"Ra":KP,"Sa":LP,"Ta":vO,"Ua":z3,"Va":y3,"Wa":x3,"Xa":fga,"Ya":yP,"Za":bga,"_a":xP,"$a":Sfa,"ab":eea,"bb":fea,"cb":Qfa,"db":Pfa,"eb":Ofa,"fb":Rfa,"gb":hea,"hb":xea,"ib":aea,"jb":zea,"kb":Qea,"lb":cea,"mb":Bea,"nb":dea,"ob":Aea,"pb":bea,"qb":kea,"rb":iea,"sb":jea,"tb":tea,"ub":qea,"vb":rea,"wb":lea,"xb":nea,"yb":oea,"zb":pea,"Ab":Nea,"Bb":Oea,"Cb":Yea,"Db":Tea,"Eb":Sea,"Fb":Rea,"Gb":Xea,"Hb":Wea,"Ib":Uea,"Jb":Vea,"Kb":afa,"Lb":cfa,"Mb":Zea,"Nb":$ea,"Ob":_ea,"Pb":Hea,"Qb":Mea,"Rb":Kea,"Sb":Jea,"Tb":Lea,"Ub":Iea,"Vb":wea,"Wb":efa,"Xb":Gea,"Yb":Eea,"Zb":Pea,"_b":yea,"$b":Fea,"ac":Dea,"bc":Cea,"cc":ffa,"dc":uea,"ec":gfa,"fc":vea,"gc":dfa,"hc":aga,"ic":_fa,"jc":w3,"kc":Zfa,"lc":Yfa,"mc":Xfa,"nc":Vfa,"oc":v3,"pc":Ufa,"qc":Tfa,"rc":Nfa,"sc":Lfa,"tc":Jfa,"uc":hfa,"vc":Ifa,"wc":pc,"xc":LN,"yc":vq,"zc":Ed,"Ac":QN,"Bc":RN,"Cc":ada,"Dc":bda,"Ec":PN,"Fc":Dda,"Gc":Fda,"Hc":Eda,"Ic":eO,"Jc":eO,"Kc":vO,"Lc":nI,"Mc":nI,"Nc":mI,"Oc":mI,"Pc":u3,"Qc":UN,"Rc":XN,"Sc":dO,"Tc":cO,"Uc":VN,"Vc":$N,"Wc":ZN,"Xc":WN,"Yc":bO,"Zc":aO,"_c":YN,"$c":Um,"ad":SN,"bd":Bda,"cd":yca,"dd":yda,"ed":Qca,"fd":Cca,"gd":wda,"hd":zca,"id":sda,"jd":Rca,"kd":zda,"ld":lda,"md":kda,"nd":jda,"od":pda,"pd":oda,"qd":nda,"rd":qda,"sd":tda,"td":rda,"ud":uda,"vd":Jca,"wd":_ca,"xd":wca,"yd":Lca,"zd":Kca,"Ad":Fca,"Bd":Mca,"Cd":Eca,"Dd":Xca,"Ed":rca,"Fd":tca,"Gd":uca,"Hd":sca,"Id":oca,"Jd":nca,"Kd":Sca,"Ld":Uca,"Md":Zca,"Nd":Tca,"Od":Dca,"Pd":Wca,"Qd":Gca,"Rd":Nca,"Sd":Vca,"Td":Hca,"Ud":Bca,"Vd":Pca,"Wd":Ica,"Xd":Aca,"Yd":pca,"Zd":mca,"_d":lca,"$d":vca,"ae":qca,"be":jca,"ce":kca,"de":Yca,"ee":t3,"fe":xca,"ge":$ca,"he":ida,"ie":Ada,"je":s3,"ke":vda,"le":Cda,"me":gO,"ne":iO,"oe":jO,"pe":kO,"qe":mO,"re":nO,"se":qO,"te":lO,"ue":cu,"ve":fO,"we":hO,"xe":Hda,"ye":Rda,"ze":pc,"Ae":QN,"Be":RN,"Ce":vq,"De":UN,"Ee":XN,"Fe":dO,"Ge":cO,"He":VN,"Ie":$N,"Je":ZN,"Ke":WN,"Le":bO,"Me":aO,"Ne":YN,"Oe":Um,"Pe":gO,"Qe":iO,"Re":jO,"Se":kO,"Te":mO,"Ue":nO,"Ve":qO,"We":lO,"Xe":cu,"Ye":hO,"Ze":ib,"_e":Wda,"$e":Fia,"af":wha,"bf":lga,"cf":T3,"df":U3,"ef":G3,"ff":F3,"gf":r3,"hf":q3,"jf":o3,"kf":k3,"lf":p3,"mf":o3,"nf":n3,"of":l3,"pf":m3,"qf":l3,"rf":k3,"sf":k3}}return qb(sb)}
// EMSCRIPTEN_END_ASM


)(info);
  },

  instantiate: /** @suppress{checkTypes} */ function(binary, info) {
    return {
      then: function(ok) {
        var module = new WebAssembly.Module(binary);
        ok({
          'instance': new WebAssembly.Instance(module, info)
        });
        // Emulate a simple WebAssembly.instantiate(..).then(()=>{}).catch(()=>{}) syntax.
        return { catch: function() {} };
      }
    };
  },

  RuntimeError: Error
};

// We don't need to actually download a wasm binary, mark it as present but empty.
wasmBinary = [];
